@@ -25,6 +25,8 @@
 
 #define DENEMO_TEXTEDITOR_TAG "texteditor"
 
+#define DENEMO_CLICK_TRACK_NAME _("Click")
+
 /* values for is_grace attribute of CHORD type */
 #define GRACED_NOTE (1<<1) /*Note is an (appogiatura) grace note */
 #define ENDGRACE (1<<2) /*Note is last grace note in a group */
@@ -100,13 +102,13 @@ DenemoSelection;
 
 typedef struct DenemoPalette
 {
-	gchar *name;
-	GtkWidget *box;
-	GtkWidget *window;
-	gboolean rows; /* widgets should be packed row-wise or not */
-	gint limit; /* how many widgets to pack in the chosen direction */
-	gboolean docked; /**< whether this palette is displayed in the main display */
-	GList *buttons; /**< the data are GtkWidget which have a script attached to be run when activated */
+    gchar *name;
+    GtkWidget *box;
+    GtkWidget *window;
+    gboolean rows; /* widgets should be packed row-wise or not */
+    gint limit; /* how many widgets to pack in the chosen direction */
+    gboolean docked; /**< whether this palette is displayed in the main display */
+    GList *buttons; /**< the data are GtkWidget which have a script attached to be run when activated */
 }
 DenemoPalette;
 
@@ -158,12 +160,12 @@ extern gchar *DenemoObjTypeNames[18];
  * 
  */
 typedef enum tuplet_type{
-	DUPLET,
-	TRIPLET,
-	QUADTUPLET,
-	QUINTUPLET,
-	SEXTUPLET,
-	SEPTUPLET	
+    DUPLET,
+    TRIPLET,
+    QUADTUPLET,
+    QUINTUPLET,
+    SEXTUPLET,
+    SEPTUPLET   
 }tuplet_type;
 
 /**
@@ -288,7 +290,7 @@ typedef struct
   gint no_of_lines; /**< Number of lines on the staff */
   gint transposition; /**< Determines if the notes are to be played back at pitch or not */
 
-  gint volume;	/**< Master Volume used to scale midi playback */
+  gint volume;  /**< Master Volume used to scale midi playback */
   gboolean override_volume; /**< when true staff plays full Volume always */
   /* Back to Hiller stuff */
   //  GString *staff_name;
@@ -308,13 +310,13 @@ typedef struct
   gboolean hasfakechords; /**<TRUE if the staff has had chord symbols attached. Only one staff should have this set */
   DenemoVoice voicecontrol; /**< either controls whether this staff is displayed and printed separately or as a voice */
   measurenode ** is_parasite; /**< points to address of host staff's measures 
-				 field if measures are owned by another 
-				 staff */
+                 field if measures are owned by another 
+                 staff */
 
   gint nummeasures; /**< Number of measures in the staff*/
   GList *tone_store; /**< list of pitches and durations used a source for
-			the notes in this staff
-			the data are tone* */
+            the notes in this staff
+            the data are tone* */
 
   GList *staff_directives;/**< List of DenemoDirective for the staff context, (only relevant for primary staff)*/
   GList *voice_directives;/**< List of DenemoDirective for the voice context */
@@ -338,24 +340,23 @@ staff_info;
 
 typedef enum
 {
-	KeymapEntry,
-	KeymapToggleEntry,
-	KeymapRadioEntry
+    KeymapEntry,
+    KeymapToggleEntry,
+    KeymapRadioEntry
 }KeymapCommandType;
 
 typedef struct DenemoKeymap
 {
-  //command information store
-  GtkListStore *commands; // ListStore for the commands
+  GHashTable *commands; // hashtable for the commands
 
   //reference for easy access
   GHashTable *idx_from_name; //hashtable linking the name of a command to
-							 //its index in the ListStore (values are guint *)
+                             //its index in the ListStore (values are guint *)
 
   GHashTable *idx_from_keystring; //hashtable linking the string representing
                                   //a keypress to the index of its command
                                   //The keystring is the output of
-  				  //dnm_accelerator_name()
+                  //dnm_accelerator_name()
   GHashTable *cursors;//hashtable linking GdkEvent state to a cursor that should be used in that state
  
   GHashTable *continuations_table;//hashtable giving possible continuations for two-keybindings
@@ -368,16 +369,18 @@ typedef struct DenemoKeymap
 typedef struct command_row
 {
   KeymapCommandType type;
-  GtkAction *action;
   gchar *name;
   gchar *label;
   gchar *tooltip;
   gpointer callback;
-  GtkListStore *bindings;
+  GList *bindings;
   gboolean hidden;
   gboolean deleted;
   gint script_type;
   GList* locations;
+  gchar* after;
+  gchar* fallback;
+  gchar* menupath;
 } command_row;
 
 typedef enum{
@@ -389,7 +392,6 @@ typedef enum{
 enum
 {
   COL_TYPE = 0,
-  COL_ACTION,
   COL_NAME,
   COL_LABEL,
   COL_TOOLTIP,
@@ -399,6 +401,7 @@ enum
   COL_DELETED,
   COL_SCRIPTTYPE,
   COL_LOCATIONS,
+  COL_ROW,
   N_COLUMNS
 } COMMAND_COLS;
 
@@ -433,7 +436,6 @@ typedef struct DenemoPrefs
   gboolean lilyentrystyle;  
   gboolean createclones;
   gint mode; /**< mode to start in */
-  gboolean modal;/**< whether mode-switching menu is desired */
   gboolean persistence;/**< whether Denemo should re-use settings over sessions */
   gint zoom; /**< percent zoom of score area display  1-100 */
   gint system_height; /**< percent of display height per system  1-100 */
@@ -570,6 +572,7 @@ typedef struct DenemoDirective
   guint32 override; /**< specifies what if anything of the built-in behaviour of the object the directive is attached to is to be overriden by this directive and values to use when overriding MIDI */
   GString *midibytes;/**< values to be used for MIDI generation; the meaning depends fields in override */
   gboolean locked;/**< If true the directive cannot be deleted easily */
+  GString *data;/**< data used by scripts that manipulate the directive, typically scheme data */
 } DenemoDirective;
 
 /**
@@ -608,7 +611,8 @@ typedef enum
 {
   REPLACE_SCORE,
   ADD_STAFFS,
-  ADD_MOVEMENTS
+  ADD_MOVEMENTS,
+  GUIDED_IMPORT
 } ImportType;
 
 typedef enum 
@@ -653,11 +657,11 @@ typedef enum DenemoViewType {
  */
 typedef struct 
 {
-	GString *name;
-	GString *midiinstrument;
-	gint sclef;
-	gint transposition;
-	gint numstaffs;
+    GString *name;
+    GString *midiinstrument;
+    gint sclef;
+    gint transposition;
+    gint numstaffs;
 
 }InstrumentConfig;
 
@@ -666,8 +670,8 @@ typedef struct
  */
 typedef struct 
 {
-	InstrumentType type;
-	GList *instruments;  // List to contain a list of Instruments of given type
+    InstrumentType type;
+    GList *instruments;  // List to contain a list of Instruments of given type
 }InstrumentList;
 
 typedef struct DenemoPosition { /**<Represents a position in a Score */
@@ -708,7 +712,7 @@ typedef struct Bookmark
 }Bookmark;
 
 /** 
- * Control of the LilyPond output for the whole musical score DenemoGUI
+ * Control of the LilyPond output for the whole musical score DenemoProject
  *
  */
 typedef struct DenemoLilyControl
@@ -719,7 +723,7 @@ typedef struct DenemoLilyControl
   gboolean orientation;
   gboolean excerpt;
   GList *directives; /**< list of DenemoDirective for all music in the movements */
-	
+    
 } DenemoLilyControl;
 
 
@@ -732,7 +736,7 @@ typedef struct DenemoScriptParam { /**< commands called by scripts use one of th
 typedef struct DenemoScoreblock {
   GString *lilypond;/**< text of the scoreblock */
   gboolean visible;/**< Whether the scoreblock should be used by default */
-  gboolean layout_sync;/**< Value of gui->layout_sync when the scoreblock was created */
+  gboolean layout_sync;/**< Value of project->layout_sync when the scoreblock was created */
   GtkWidget *widget;/**< Widget to be placed in the Score Layout window for this scoreblock */
   GList *staff_list;/**< List of staff frames contained in widget */
   gchar *name;/**< name for this scoreblock */
@@ -770,28 +774,46 @@ typedef struct movementcontrol
   GList *directives;
 }
 movementcontrol;
-typedef struct DenemoAudio {
-  gchar *filename;
-  gint samplerate;
-  gint channels;
+
+typedef enum DenemoRecordingType {
+  DENEMO_RECORDING_AUDIO,/**< Recording is an audio file represented by libsndfile handle */
+  DENEMO_RECORDING_MIDI/**< Recording is an audio file stored in recorded_midi_track */ 
+} DenemoRecordingType;
+
+typedef struct DenemoRecordedNote {
+  gint timing;/**< time in frames, (divide by samplerate to get to seconds) */
+  gboolean noteoff;
+  gint mid_c_offset;
+  gint enshift;
+  gint octave;
+  gint duration;/**< guessed baseduration, 0 if not known */
+  gint dots; /**<guessed number of dots */
+  gpointer event;/**< midi event giving rise to the note */
+} DenemoRecordedNote;
+
+typedef struct DenemoRecording {
+  DenemoRecordingType type;
+  gchar *filename; /**< audio file. Could be extended to take MIDI file too */
+  gint samplerate; /**< frames per second */
+  gint channels; /**< audio only */
   gint leadin;/**< number of frames to skip at start, silence to be emitted before play if negative */
   gdouble volume;
   gint nframes;/**< number of frames in the audio */
-  GList *onsets;  /**< Candidate note onsets in sndfile */
+  GList *notes;  /**< data is DenemoRecordedNote* */
   gpointer sndfile; /**< sndfile handle */
-} DenemoAudio;
+} DenemoRecording;
 
 typedef enum DenemoTargetType {
-	TARGET_NONE = 0,
-	TARGET_OBJECT,
-	TARGET_CHORD,
-	TARGET_NOTE,
-	TARGET_SLUR,
-	TARGET_TIE,		
-	TARGET_CRESC,		
-	TARGET_DIM,		
+    TARGET_NONE = 0,
+    TARGET_OBJECT,
+    TARGET_CHORD,
+    TARGET_NOTE,
+    TARGET_SLUR,
+    TARGET_TIE,     
+    TARGET_CRESC,       
+    TARGET_DIM,     
 
-	//TARGET_,
+    //TARGET_,
 } DenemoTargetType;
 
 typedef struct DenemoTarget {
@@ -810,11 +832,11 @@ typedef struct DenemoTarget {
  *  that is,  uninterrupted music on a set of staffs, preceded by a title.
  */
  
-typedef struct DenemoScore
+typedef struct DenemoMovement
 {
   gboolean readonly; /**< Indicates if the file is readonly or not */
   GList *curlilynode; /**< the node of the lily parse tree on display 
-			 in textwindow */
+             in textwindow */
   GList *lily_file; /**< root of lily file parse, see lilyparser.y etc  */
 
  
@@ -827,7 +849,7 @@ typedef struct DenemoScore
   gint widthtoworkwith;
   gint staffspace;
 
-  DenemoAudio *audio;/**< Audio attached to movement */ 
+  DenemoRecording *recording;/**< Audio or MIDI recording attached to movement */ 
   gint marked_onset_position;/**< horizontal position in display of note onset in audio marked by user */ 
   GList *marked_onset;/**< Note onset in audio selected by user */ 
   GList *sources; /**< List of source pixbufs, one for each measure score-view*/
@@ -858,7 +880,7 @@ typedef struct DenemoScore
    * though they may be modified by side-effects of the drawing routines */
   // score thescore;
   staffnode *thescore;
-  gint currentmovementnum;/**< position of this DenemoScore in the gui->movements list starting at 1 */
+  gint currentmovementnum;/**< position of this DenemoMovement in the project->movements list starting at 1 */
   staffnode *currentprimarystaff;
   staffnode *currentstaff;
   gint currentstaffnum;/**< start at 1 */
@@ -935,19 +957,19 @@ typedef struct DenemoScore
   GList *Instruments;
   GtkWidget *buttonbox;/*< box for buttons accessing DenemoDirectives attached to the this movement*/
   GtkWidget *lyricsbox;/*< box for notebooks containing verses of lyrics for the movement */
-} DenemoScore;
+} DenemoMovement;
 
 /**
- * DenemoGUI representing a musical score, with associated top level
- * GUI and a list of movements (DenemoScore) and a pointer to the current
+ * DenemoProject representing a musical score, with associated top level
+ * GUI and a list of movements (DenemoMovement) and a pointer to the current
  * movement. 
  */
-typedef struct DenemoGUI
+#define DENEMO_MAX_SYSTEMS (100) /**< Number of lines of music that can be displayed */
+typedef struct DenemoProject
 {
   gint id; /* A unique id, not repeated for this run of the Denemo program */
 
   DenemoViewType view;/**< The current view */
-#define DENEMO_MAX_SYSTEMS (100) /**< Number of lines of music that can be displayed */
   gint lefts[DENEMO_MAX_SYSTEMS];/**< an array to hold the leftmeasurenum of each system in the last-drawn score, used for determining the mouse position on the music */
   gint rights[DENEMO_MAX_SYSTEMS];/**< an array to hold the rightmeasurenum of each system in the last-drawn score, used for determining the mouse position on the music */
   gint scales[DENEMO_MAX_SYSTEMS];/**< an array to hold the percent horizontal scaling of each system in the last-drawn score, used for determining the mouse position on the music */
@@ -973,14 +995,14 @@ typedef struct DenemoGUI
   input_mode mode; /**< Input mode for Score */
   GtkWidget *progressbar;
 
-  GList *movements;   /**< a list of DenemoScore, NULL if just one movement */
-  DenemoScore *si;  /**< the (current)  movement in the musical score controlled by this gui */
+  GList *movements;   /**< a list of DenemoMovement, NULL if just one movement */
+  DenemoMovement *movement;  /**< the (current)  movement in the musical score controlled by this project */
   DenemoLilyControl lilycontrol; /**< Directives for the start of the score and before every movement */
 
   scoreheader scoreheader;/*< Directives for the header block at the start of the score */
   paper paper;/*< Directives for the paper block of the score */
   GList *midi_events;/*< midi_events to be output at start of first track of each movement */
-	gboolean has_script;/*< true if there is a script to be run on loading the DenemoGUI from disk */
+    gboolean has_script;/*< true if there is a script to be run on loading the DenemoProject from disk */
   GList *standard_scoreblocks; /**< List of automatically generated \score blocks for LilyPond output elements are DenemoScoreblock * */
   GList *custom_scoreblocks; /**< List of customized  \score blocks for LilyPond output, elements are DenemoScoreblock * */
   GtkWidget *score_layout; /**< The window in which custom_scoreblock widgets are placed */
@@ -1015,7 +1037,7 @@ typedef struct DenemoGUI
   gint source_width;
   gint source_height;
   gint source_scale;/* scale is x1000 */
-}DenemoGUI;
+}DenemoProject;
 
 
 /**
@@ -1040,18 +1062,18 @@ typedef struct RhythmPattern
 typedef struct RhythmElement
 {
   GList* functions; /**< data in list are functions to be called including modifiers 
-		      eg insert_chord_3key, add dot, slur ...  */
+              eg insert_chord_3key, add dot, slur ...  */
   gpointer icon; /**< a string, but displayed in music font, which labels the button when this RhythmElement is
-		  the current one*/
+          the current one*/
   RhythmPattern *rhythm_pattern;/**< the rhythm pattern which this element belongs to */
 } RhythmElement;
 
 
 struct cs_callback
 {
-	GtkWidget *entry;
-	GtkWidget *dialog;
-	DenemoGUI *gui;
+    GtkWidget *entry;
+    GtkWidget *dialog;
+    DenemoProject *project;
 };
 
 
@@ -1061,7 +1083,7 @@ struct cs_callback
  */
 struct DenemoRoot
 {
-  gboolean non_interactive; /* if TRUE denemo should not display gui, receive or send sounds etc*/
+  gboolean non_interactive; /* if TRUE denemo should not display project, receive or send sounds etc*/
   gchar *scheme_file;/* filename for scheme code to run on startup */
   gchar *scheme_commands;/* scheme code to run on startup after scheme_file */
   /* Fields used fairly directly for drawing */
@@ -1090,8 +1112,8 @@ struct DenemoRoot
   keymap *map; /**< pointer to data describing each of the Denemo commands and their keyboard shortcuts */
   gchar *last_merged_command;/**<filename of last command merged into the menu system */
   gint last_keyval, last_keystate;/**< most recent keypress which successfully invoked a command */
-  GList *guis; /**< the list of DenemoGUI objects, representing pieces of music
-		  simultaneously open */
+  GList *projects; /**< the list of DenemoProject objects, representing pieces of music simultaneously open */
+  DenemoProject *project; /**< The current project */
   DenemoPrefs prefs;  /**< Preferences stored on exit and re-loaded on startup */
   gint autosaveid;/**< autosave timer id: only one musical score is being autosaved at present */
   gint accelerator_status; /**< if the accelerators have been saved, or extra ones for special keys defined  */
@@ -1099,20 +1121,15 @@ struct DenemoRoot
   GtkWidget *window;
   GtkWidget *console;/**< GtkTextView for console output */
   GtkActionGroup *action_group;/*< The action group for the actions that are Denemo commands */
-  DenemoGUI *gui; /**< The current gui */
-  GtkWidget *notebook;/**< contains the gui.page widgets */
-  GtkWidget *statusbar;
+  GtkWidget *notebook;/**< contains the project.page widgets */
+  GtkWidget *statuslabel;/**< label that appears at bottom left of main window to describe cursor position in score */
   GtkWidget *playback_control;/**< frame containing controls for playback */
   GtkWidget *midi_in_control;/**< frame containing controls for midi in */
   GtkWidget *audio_vol_control;/**< hbox containing vol control for source audio */
-  gint status_context_id;
   GtkWidget *input_source; /**< A label widget advising of source of external input */
   GString *input_filters; /**< Description of any filters operating on external input */
   GtkWidget *menubar;/**< Main menubar to giving load/save play etc functionality */
-  GtkWidget *ClassicModeMenu;/**< Menu to give the note editing facilities in Classic mode */
-  GtkWidget *InsertModeMenu;/**< Menu to give the note editing facilities in Insert mode */
-  GtkWidget *EditModeMenu;/**< Menu to give the note editing facilities in Edit mode */
-  GtkWidget *ModelessMenu;/**< Menu to give the note editing facilities when used without modes */
+
   GList *continuations;
   struct RhythmPattern *singleton_rhythms[256]; /**< rhythm patterns for the EntryToolbar */
   gboolean ScriptRecording;/**< TRUE when menuitems presses are being recorded as scheme script*/
@@ -1120,6 +1137,9 @@ struct DenemoRoot
   GtkWidget *ScriptView; /**< a GtkTextView containing a scheme script */
   GList *palettes; /**< list of palettes of buttons for activating scripts */
   gchar *old_user_data_dir; /**< set in case of upgrading denemo version */
+  gboolean *fatal_scheme_errors; /** Abort on scheme errors */
+  gboolean *silent; /** Don't log any message */
+  gboolean *verbose; /** Display every messages */
 }  Denemo; /**< The root object. */
 
 #endif
