@@ -116,14 +116,14 @@ initialize_audio (DenemoPrefs * config)
   char const *driver = config->audio_driver->str;
 
 
-  g_print ("audio driver is '%s' %d\n", driver, strcmp (driver, "portaudio"));
+  g_message ("Audio driver is '%s' %d", driver, strcmp (driver, "portaudio"));
 
   if (strcmp (driver, "jack") == 0)
     {
 #ifdef _HAVE_JACK_
       backends[AUDIO_BACKEND] = &jack_audio_backend;
 #else
-      g_warning ("JACK backend is not enabled\n");
+      g_warning ("JACK backend is not enabled");
 #endif
     }
   else if (strcmp (driver, "portaudio") == 0)
@@ -131,7 +131,7 @@ initialize_audio (DenemoPrefs * config)
 #ifdef _HAVE_PORTAUDIO_
       backends[AUDIO_BACKEND] = &portaudio_backend;
 #else
-      g_warning ("PortAudio backend is not enabled\n");
+      g_warning ("PortAudio backend is not enabled");
 #endif
     }
   else if (strcmp (driver, "dummy") == 0)
@@ -140,7 +140,7 @@ initialize_audio (DenemoPrefs * config)
     }
   else
     {
-      g_warning ("unknown audio backend '%s'\n", driver);
+      g_warning ("Unknown audio backend '%s'", driver);
     }
 
   if (backends[AUDIO_BACKEND] == NULL)
@@ -154,7 +154,7 @@ initialize_audio (DenemoPrefs * config)
 
   if (ret)
     {
-      g_warning ("initializing audio backend '%s' failed, falling back to dummy", driver);
+      g_warning ("Initializing audio backend '%s' failed, falling back to dummy", driver);
       backends[AUDIO_BACKEND] = &dummy_audio_backend;
       ret = get_backend (AUDIO_BACKEND)->initialize (config);
     }
@@ -168,14 +168,14 @@ initialize_midi (DenemoPrefs * config)
 {
   char const *driver = config->midi_driver->str;
 
-  g_print ("MIDI driver is '%s'\n", driver);
+  g_message ("MIDI driver is '%s'", driver);
 
   if (strcmp (driver, "jack") == 0)
     {
 #ifdef _HAVE_JACK_
       backends[MIDI_BACKEND] = &jack_midi_backend;
 #else
-      g_warning ("JACK backend is not enabled\n");
+      g_warning ("JACK backend is not enabled");
 #endif
     }
   else if (strcmp (driver, "portmidi") == 0)
@@ -183,7 +183,7 @@ initialize_midi (DenemoPrefs * config)
 #ifdef _HAVE_PORTMIDI_
       backends[MIDI_BACKEND] = &portmidi_backend;
 #else
-      g_warning ("PortMidi backend is not enabled\n");
+      g_warning ("PortMidi backend is not enabled");
 #endif
     }
   else if (strcmp (driver, "alsa") == 0)
@@ -191,7 +191,7 @@ initialize_midi (DenemoPrefs * config)
 #ifdef _HAVE_ALSA_
       backends[MIDI_BACKEND] = &alsa_seq_midi_backend;
 #else
-      g_warning ("ALSA backend is not enabled\n");
+      g_warning ("ALSA backend is not enabled");
 #endif
     }
   else if (strcmp (driver, "dummy") == 0)
@@ -200,7 +200,7 @@ initialize_midi (DenemoPrefs * config)
     }
   else
     {
-      g_warning ("unknown MIDI backend '%s'\n", driver);
+      g_warning ("Unknown MIDI backend '%s'", driver);
     }
 
   if (backends[MIDI_BACKEND] == NULL)
@@ -214,7 +214,7 @@ initialize_midi (DenemoPrefs * config)
 
   if (ret)
     {
-      g_warning ("initializing MIDI backend '%s' failed, falling back to dummy", driver);
+      g_warning ("Initializing MIDI backend '%s' failed, falling back to dummy", driver);
       backends[MIDI_BACKEND] = &dummy_midi_backend;
       ret = get_backend (MIDI_BACKEND)->initialize (config);
     }
@@ -316,7 +316,7 @@ static gboolean
 redraw_all_callback (gpointer data)
 {
   gdk_threads_enter ();
-  //displayhelper(Denemo.gui);
+  //displayhelper(Denemo.project);
   gtk_widget_queue_draw (Denemo.scorearea);
   gdk_threads_leave ();
   return FALSE;
@@ -327,7 +327,7 @@ redraw_playhead_callback (gpointer data)
 {
   gdk_threads_enter ();
 
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
 
   smf_event_t *event = (smf_event_t *) data;
 
@@ -458,7 +458,7 @@ queue_thread_func (gpointer data)
 
       if (g_atomic_int_get (&quit_thread))
         {
-          g_print ("that's it, i quit!\n");
+          g_message ("That's it, I quit!");
           break;
         }
 
@@ -545,7 +545,7 @@ try_signal_queue ()
       return FALSE;
     }
 }
-
+static gboolean time_reset = FALSE;
 
 void
 update_playback_time (backend_timebase_prio_t prio, double new_time)
@@ -555,22 +555,26 @@ update_playback_time (backend_timebase_prio_t prio, double new_time)
       // ignore new playback time if another backend has higher priority
       return;
     }
-
+  if(time_reset)
+	{
+		time_reset = FALSE;
+		return;
+	}
   if (new_time != playback_time)
     {
       playback_time = new_time;
-
+// g_debug(" %2.2f", new_time);midi_play tries to set playback_time, which then gets overriden by the call in the portaudio callback.
       // if the lock fails, the playback time update will be delayed until the
       // queue thread wakes up on its own
       if (!try_signal_queue ())
         {
-          g_debug ("couldn't signal playback time update to queue");
+          g_debug ("Couldn't signal playback time update to queue");
         }
     }
 }
 
 double
-get_playback_time ()
+get_playback_time (void)
 {
   return playback_time;
 }
@@ -584,14 +588,15 @@ midi_play (gchar * callback)
   reset_playback_queue (AUDIO_BACKEND);
   reset_playback_queue (MIDI_BACKEND);
 
-  g_print ("starting playback\n");
-
-  playback_start_time = get_start_time ();
-  playback_time = playback_start_time;
-  //g_print ("starting playback at %f\n", playback_start_time);
+  g_message ("Starting playback");
   start_playing (callback);
-
-  get_backend (AUDIO_BACKEND)->start_playing ();
+  do {//FIXME, this is a crude attempt to get the playback_time set without the callback from portaudio re-writing it.
+  playback_time = playback_start_time;
+	time_reset = TRUE;
+	playback_time = playback_start_time;
+	get_backend (AUDIO_BACKEND)->start_playing ();// this must pick up the playback_start_time, which won't happen if an interrrupt has occurred meanwhile.
+  	} while(playback_time != playback_start_time);
+  g_message ("Starting playback at %f", playback_start_time);
   get_backend (MIDI_BACKEND)->start_playing ();
 }
 
@@ -603,7 +608,7 @@ audio_play (void)
   reset_rubberband_queue (AUDIO_BACKEND);
 #endif
   playback_start_time = get_start_time ();
-  //g_print ("starting audio playback at %f\n", playback_start_time);
+  //g_debug ("starting audio playback at %f\n", playback_start_time);
   playback_time = playback_start_time;
 
 }
@@ -611,7 +616,7 @@ audio_play (void)
 void
 midi_stop ()
 {
-  g_print ("stopping playback\n");
+  g_message ("Stopping playback");
 
   get_backend (AUDIO_BACKEND)->stop_playing ();
   get_backend (MIDI_BACKEND)->stop_playing ();
@@ -675,7 +680,7 @@ play_note (backend_type_t backend, int port, int channel, int key, int duration,
   unsigned char buffer[] = {
     MIDI_NOTE_ON | channel,
     key,
-    (volume ? volume : 127) * Denemo.gui->si->master_volume
+    (volume ? volume : 127) * Denemo.project->movement->master_volume
   };
 
   int r = play_midi_event (backend, port, buffer);
@@ -723,15 +728,15 @@ rhythm_feedback (backend_type_t backend, gint duration, gboolean rest, gboolean
 {
   int key;
   if (dot)
-    play_note (backend, 0, 9, 67, 100, 60 * Denemo.gui->si->master_volume);
+    play_note (backend, 0, 9, 67, 100, 60 * Denemo.project->movement->master_volume);
   else
-    play_note (backend, 0, 9, rhythm_sounds[duration], rest ? 100 : 200, 127 * Denemo.gui->si->master_volume);
+    play_note (backend, 0, 9, rhythm_sounds[duration], rest ? 100 : 200, 127 * Denemo.project->movement->master_volume);
   //add extra sound effect for rests
   if (rest)
-    play_note (backend, 0, 9, 46, 300, 127 * Denemo.gui->si->master_volume);
-  while ((key = GPOINTER_TO_INT( g_queue_pop_head (Denemo.gui->pending_midi)) ))
-    play_note (backend, 0, 9, key, 300, 127 * Denemo.gui->si->master_volume);
-  //g_print("playing %d %d\n", rhythm_sounds[duration], (60/(4*Denemo.gui->si->tempo*(1<<duration)))*1000);
+    play_note (backend, 0, 9, 46, 300, 127 * Denemo.project->movement->master_volume);
+  while ((key = GPOINTER_TO_INT( g_queue_pop_head (Denemo.project->pending_midi)) ))
+    play_note (backend, 0, 9, key, 300, 127 * Denemo.project->movement->master_volume);
+  //g_debug("playing %d %d\n", rhythm_sounds[duration], (60/(4*Denemo.project->movement->tempo*(1<<duration)))*1000);
 
   return 0;
 }
@@ -740,12 +745,12 @@ rhythm_feedback (backend_type_t backend, gint duration, gboolean rest, gboolean
 int
 panic (backend_type_t backend)
 {
-  g_print ("panicking\n");
+ // g_critical ("Panicking");
   return get_backend (backend)->panic ();
 }
 
 int
-panic_all ()
+panic_all (void)
 {
   backend_type_t n;
   for (n = 0; n < NUM_BACKENDS; ++n)
@@ -778,7 +783,7 @@ input_midi_event (backend_type_t backend, int port, unsigned char *buffer)
   // queue thread wakes up on its own
   if (!try_signal_queue ())
     {
-      g_debug ("couldn't signal MIDI event input to queue");
+      g_debug ("Couldn't signal MIDI event input to queue");
     }
 }
 
@@ -790,7 +795,7 @@ queue_redraw_all ()
 
   if (!try_signal_queue ())
     {
-      g_debug ("couldn't signal redraw request to queue");
+      g_debug ("Couldn't signal redraw request to queue");
     }
 }
 
@@ -802,7 +807,7 @@ queue_redraw_playhead (smf_event_t * event)
 
   if (!try_signal_queue ())
     {
-      g_debug ("couldn't signal redraw request to queue");
+      g_debug ("Couldn't signal redraw request to queue");
     }
 }
 
