@@ -20,7 +20,7 @@
  * minpixels is width of rectangle to draw indicating an object position (used when not a CHORD
  */
 void
-draw_cursor (cairo_t * cr, DenemoScore * si, gint xx, gint y, gint insert_control, gint minpixels, gint dclef)
+draw_cursor (cairo_t * cr, DenemoMovement * si, gint xx, gint y, gint insert_control, gint minpixels, gint dclef)
 {
   if (!cr)
     return;
@@ -64,7 +64,7 @@ draw_cursor (cairo_t * cr, DenemoScore * si, gint xx, gint y, gint insert_contro
       insert_pos = insert_control * CURSOR_WIDTH;
     static gboolean on;
     on = !on;
-    // g_print("on is %d %d\n", on,  Denemo.prefs.cursor_highlight);
+    //g_debug("on is %d %d\n", on,  Denemo.prefs.cursor_highlight);
     if ((!Denemo.prefs.cursor_highlight) || (on && Denemo.prefs.cursor_highlight))
       {
         cairo_set_source_rgb (cr, 0, 0, 255);
@@ -74,14 +74,14 @@ draw_cursor (cairo_t * cr, DenemoScore * si, gint xx, gint y, gint insert_contro
         cairo_stroke (cr);
         //setcairocolor( cr, paintgc );
 
-        if (Denemo.gui->view == DENEMO_PAGE_VIEW)
+        if (Denemo.project->view == DENEMO_PAGE_VIEW)
           {
             cairo_set_line_width (cr, 6.0 / si->zoom);
             cairo_set_source_rgba (cr, 0, 1, 0, 0.40);
             cairo_arc (cr, xx + CURSOR_WIDTH / 2, height + y, length, 0, 2 * M_PI);
             cairo_stroke (cr);
           }
-        if(Denemo.gui->audio_recording)
+        if(Denemo.project->audio_recording)
             highlight_audio_record();
       }
   }
