@@ -151,7 +151,7 @@ draw_notehead (cairo_t * cr,
       {
         if (override_notehead)
           {
-            //g_print("drawing a chord override graphic at %d %d\n",  xx+gx-override_notehead->width/2,  y+height+gy-override_notehead->height/2);
+            //g_debug("drawing a chord override graphic at %d %d\n",  xx+gx-override_notehead->width/2,  y+height+gy-override_notehead->height/2);
             drawbitmapinverse_cr (cr, override_notehead, xx + gx - override_notehead->width / 2, y + height + gy - override_notehead->height / 2, FALSE);
           }
         else
@@ -260,13 +260,16 @@ draw_chord (cairo_t * cr, objnode * curobj, gint xx, gint y, gint mwidth, gint *
           cairo_scale (cr, 0.8, 0.8);
           cairo_translate (cr, -xx, -(y + thenote->y));
         }
-      //  g_print("Invisible is %d\n", mudelaitem->isinvisible); 
+      //g_debug("Invisible is %d\n", mudelaitem->isinvisible); 
       if (mudelaitem->isinvisible)
         {
           if (selected)
             cairo_set_source_rgb (cr, 231.0 / 255, 1, 39.0 / 255);
+          else if (Denemo.project->movement->recording)
+            cairo_set_source_rgba (cr, 180.0 / 255, 160.0 / 255, 32.0 / 255, 0.4);    // yellow for non printing
           else
             cairo_set_source_rgb (cr, 180.0 / 255, 160.0 / 255, 32.0 / 255);    // yellow for non printing
+
         }
 
       if (thechord.slur_begin_p)
