@@ -9,7 +9,7 @@
  * License: this file may be used under the FSF GPL version 3 or later
  */
 
-#define EXPORTMIDI_VERSION	"1.2"
+#define EXPORTMIDI_VERSION  "1.2"
 
 /*
  * The function exportmidi() writes a "Standard MIDI file" to disk.
@@ -58,11 +58,10 @@
 
 #include <denemo/denemo.h>
 #include "exportmidi.h"
-#include "smf.h"
 #include "instrumentname.h"
 #include "audiointerface.h"
 #include "view.h"
-
+#include "smf.h"
 /* 
  * only for developers
  */
@@ -71,12 +70,23 @@ static int debug = 0;
 
 /****************************************************************/
 
+
+/**
+ * some important midi command bytes
+ */
+
+#define MIDI_NOTE_OFF       0x80
+#define MIDI_NOTE_ON        0x90
+#define MIDI_PROG_CHANGE    0xc0
+#define MAX_TRACKS      16
+
+
 /*
  * support macros for exportmidi()
  */
 
 /* length, in ticks, of a quarter note */
-#define MIDI_RESOLUTION		384
+#define MIDI_RESOLUTION     384
 
 /* tick conversion */
 #define ticks2bars(t,u,l) (t/(MIDI_RESOLUTION*4*u/l))
@@ -140,9 +150,9 @@ string_to_vol (char *dynamic, int default_vol)
 /****************************************************************/
 
 /**
- *	unbiased random generator,
- *	
- *	returns a value within +- maxdev
+ *  unbiased random generator,
+ *  
+ *  returns a value within +- maxdev
  */
 /* UNUSED
 static int
@@ -165,8 +175,8 @@ i_random (int *accumulate, int maxdev)
 /****************************************************************/
 
 /**
- *	limit a value to be within limits
- *	(simple first approach)
+ *  limit a value to be within limits
+ *  (simple first approach)
  */
 /* UNUSED
 static int
@@ -233,7 +243,6 @@ midi_change_event (int type, int chan, int val)
   return event;
 }
 
-
 /**
  * meta event: set time signature, time scale and metronome FF 58 04 nn dd cc bb Time Signature
  */
@@ -334,18 +343,18 @@ dia_to_midinote (int offs)
  * constants used in note status table
  */
 
-#define FLG_CONNECT_B		0x01
-#define FLG_CONNECT_F		0x02
-#define FLG_SLUR_BEGIN		0x04
-#define FLG_SLUR_END		0x08
+#define FLG_CONNECT_B       0x01
+#define FLG_CONNECT_F       0x02
+#define FLG_SLUR_BEGIN      0x04
+#define FLG_SLUR_END        0x08
 
-#define FLG_NOTE_ON		0x10
-#define FLG_NOTE_OFF		0x20
-#define FLG_STACCATO		0x40
-#define FLG_STACCATISSIMO	0x80
+#define FLG_NOTE_ON     0x10
+#define FLG_NOTE_OFF        0x20
+#define FLG_STACCATO        0x40
+#define FLG_STACCATISSIMO   0x80
 
-#define FLG_TIED_F		0x100
-#define FLG_TIED_B		0x200
+#define FLG_TIED_F      0x100
+#define FLG_TIED_B      0x200
 
 /**
  * debug print-out of slur table
@@ -393,10 +402,10 @@ print_slurs (FILE * fd, int *tab, int status, int t_read, int t_written, char *t
 }
 #endif
 
-#define STATE_NONE	0
-#define STATE_FIRST	1
-#define	STATE_LAST	2
-#define STATE_THROUGH	3
+#define STATE_NONE  0
+#define STATE_FIRST 1
+#define STATE_LAST  2
+#define STATE_THROUGH   3
 
 /**
  * reset note status table and slur status
@@ -684,14 +693,6 @@ compute_beat (long ticks, long ticks_in_a_beat, long ticks_in_a_measure, int len
 */
 /****************************************************************/
 
-/**
- * some important midi command bytes
- */
-
-#define MIDI_NOTE_OFF		0x80
-#define MIDI_NOTE_ON		0x90
-#define MIDI_PROG_CHANGE	0xc0
-#define	MAX_TRACKS		16
 
 /* convert denemo time values to ticks */
 
@@ -700,12 +701,12 @@ compute_beat (long ticks, long ticks_in_a_beat, long ticks_in_a_measure, int len
 
 /* this is a real high-tech macro */
 
-#define percent(t,p)	((t*p)/100)
+#define percent(t,p)    ((t*p)/100)
 
 static int
 is_status_byte(const unsigned char status)
 {
-	return (status & 0x80);
+    return (status & 0x80);
 }
 
 /* puts an event into track if buffer contains valid midi message.
@@ -721,7 +722,7 @@ put_event (gchar * buffer, gint numbytes, GList ** midi_events, smf_track_t * tr
     {
       smf_track_add_event_delta_pulses (track, event, 0);
       *midi_events = g_list_append (*midi_events, event);
-      //g_print("Added %x\n", event->midi_buffer[0]);
+      //g_debug("Added %x\n", event->midi_buffer[0]);
     }
   g_free (buffer);
   return event;
@@ -757,7 +758,7 @@ substitute_midi_values (gchar * str, gint channel, gint volume)
       if (*c == '%' && *(c + 1) == '%' && *(c + 2) == '%')
         sprintf (c, "%3d", volume);     //*c = itoa(volume);
     }
-  //  g_print("We have transformed %s to %s\n", str, bytes);
+  //  g_debug("We have transformed %s to %s\n", str, bytes);
   return bytes;
 }
 
@@ -768,7 +769,7 @@ directive_get_midi_buffer (DenemoDirective * directive, gint * pnumbytes, gint c
     {
       gchar *bytes;
       bytes = substitute_midi_values (directive->midibytes->str, channel, volume);
-      //g_print("Got %s as midi bytes\n", bytes);
+      //g_debug("Got %s as midi bytes\n", bytes);
       char *next;
       gint i, numbytes;
       errno = 0;
@@ -776,7 +777,7 @@ directive_get_midi_buffer (DenemoDirective * directive, gint * pnumbytes, gint c
         {
           if (errno)
             {
-              g_warning ("Bytes %s bad format for MIDI\n", bytes);
+              g_warning ("Bytes %s bad format for MIDI", bytes);
               return NULL;
             }
           i++;
@@ -790,7 +791,7 @@ directive_get_midi_buffer (DenemoDirective * directive, gint * pnumbytes, gint c
       for (i = 0, next = bytes; i < numbytes; i++, next++)
         {
           buffer[i] = (char) strtol (next, &next, 0);
-          //g_print("byte %x\n", buffer[i]);
+          //g_debug("byte %x\n", buffer[i]);
         }
       *pnumbytes = numbytes;
       g_free (bytes);
@@ -811,7 +812,7 @@ directive_get_midi_val (DenemoDirective * directive)
       val = strtol (bytes, NULL, 0);
       if (errno)
         {
-          g_warning ("String %s is bad format for MIDI value\n", bytes);
+          g_warning ("String %s is bad format for MIDI value", bytes);
           return 0;
         }
     }
@@ -823,7 +824,7 @@ static void
 change_volume (gint * volume, gint midi_val, gint midi_interpretation, gint midi_action)
 {
   gdouble val;
-  // g_print("midi_val %d cur_volume %d\n", midi_val, cur_volume);
+  // g_debug("midi_val %d cur_volume %d\n", midi_val, cur_volume);
   val = (gdouble) midi_val;
   if (midi_interpretation & DENEMO_OVERRIDE_PERCENT)
     val = *volume * (midi_val / 100.0);
@@ -850,7 +851,7 @@ static void
 change_channel (gint * channel, gint midi_val, gint midi_interpretation, gint midi_action)
 {
   gdouble val;
-  // g_print("midi_val %d cur_channel %d\n", midi_val, cur_channel);
+  //g_debug("midi_val %d cur_channel %d\n", midi_val, cur_channel);
   val = (gdouble) midi_val;
   if (midi_interpretation & DENEMO_OVERRIDE_PERCENT)
     g_warning ("Percent meaningless with channel change");
@@ -866,7 +867,7 @@ change_channel (gint * channel, gint midi_val, gint midi_interpretation, gint mi
     *channel = 127;
   if (*channel < 0)
     *channel = 0;
-  g_print ("After channel change channel = %d\n", *channel);
+  g_message ("After channel change channel = %d", *channel);
 }
 
 
@@ -906,7 +907,7 @@ change_tempo (gint * tempo, gint midi_val, gint midi_interpretation, gint midi_a
  * return the duration in seconds of the music stored
  */
 gdouble
-exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
+exportmidi (gchar * thefilename, DenemoMovement * si, gint start, gint end)
 {
   /* variables for reading and decoding the object list */
   smf_event_t *event = NULL;
@@ -1054,7 +1055,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
       prognum = curstaffstruct->midi_prognum;
 
       /* set selected midi program */
-      g_print ("Using channel %d prognum %d\n", midi_channel, prognum);
+      g_message ("Using channel %d prognum %d", midi_channel, prognum);
       event = midi_change_event (MIDI_PROG_CHANGE, midi_channel, prognum);
       smf_track_add_event_delta_pulses (track, event, 0);
 
@@ -1082,7 +1083,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 
 
       if (tuplet > 0)
-        g_print ("Unterminated tuplet at end of voice %d\n", tracknumber - 1);
+        g_warning ("Unterminated tuplet at end of voice %d", tracknumber - 1);
       //Reset to  tuplets nesting level 0, in case unbalanced tuplet start end in last staff
       tuplet = 0;
       //Now that we have the channel and volume we can interpret any score and staff-wide directives for midi
@@ -1099,16 +1100,16 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
               if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                 if (buffer)
                   if (NULL == put_event (buffer, numbytes, &curstaffstruct->midi_events, track))
-                    g_warning ("Invalid midi bytes in staff directive\n");
+                    g_warning ("Invalid midi bytes in staff directive");
             }
         }
 
       if (tracknumber == 1)
         {
-          if (Denemo.gui->lilycontrol.directives)
+          if (Denemo.project->lilycontrol.directives)
             {
               //FIXME repeated code
-              GList *g = Denemo.gui->lilycontrol.directives;
+              GList *g = Denemo.project->lilycontrol.directives;
               DenemoDirective *directive = NULL;
 
               for (; g; g = g->next)
@@ -1119,14 +1120,14 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                   gchar *buffer = directive_get_midi_buffer (directive, &numbytes, midi_channel, cur_volume);
                   if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                     if (buffer)
-                      if (NULL == put_event (buffer, numbytes, &Denemo.gui->midi_events, track))
-                        g_warning ("Invalid midi bytes in score directive\n");
+                      if (NULL == put_event (buffer, numbytes, &Denemo.project->midi_events, track))
+                        g_warning ("Invalid midi bytes in score directive");
                 }
             }
 
-          if (Denemo.gui->si->movementcontrol.directives)
+          if (Denemo.project->movement->movementcontrol.directives)
             {
-              GList *g = Denemo.gui->si->movementcontrol.directives;
+              GList *g = Denemo.project->movement->movementcontrol.directives;
               DenemoDirective *directive = NULL;
               for (; g; g = g->next)
                 {
@@ -1136,8 +1137,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                   gchar *buffer = directive_get_midi_buffer (directive, &numbytes, midi_channel, cur_volume);
                   if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                     if (buffer)
-                      if (NULL == put_event (buffer, numbytes, &Denemo.gui->si->midi_events, track))
-                        g_warning ("Invalid midi bytes in movement directive\n");
+                      if (NULL == put_event (buffer, numbytes, &Denemo.project->movement->midi_events, track))
+                        g_warning ("Invalid midi bytes in movement directive");
                 }
             }
 
@@ -1190,10 +1191,10 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 
 
         /*******************************************
-	 *	huge switch:
-	 * 	here we handle every kind of object
-	 * 	that seems relevant to us
-	 *******************************************/
+     *  huge switch:
+     *  here we handle every kind of object
+     *  that seems relevant to us
+     *******************************************/
               int tmpstaccato = 0, tmpstaccatissimo = 0;
               gboolean skip_midi = FALSE;
 
@@ -1201,8 +1202,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                 {
                 case CHORD:
           /******************** 
-	   * one or more notes
-	   ********************/
+       * one or more notes
+       ********************/
 
 
                   measure_is_empty = 0;
@@ -1254,7 +1255,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                                 if (buffer)
                                   {
                                     if (NULL == put_event (buffer, numbytes, &curobj->midi_events, track))
-                                      g_warning ("Invalid midi bytes in chord directive\n");
+                                      g_warning ("Invalid midi bytes in chord directive");
                                   }
                               break;
                             }
@@ -1262,11 +1263,14 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                     }           //if there are directives
                   /* FIXME sound grace notes either simultaneously for shorter duration or steal time .... */
                   if (chordval.is_grace)
-                    break;
+                    {
+                        curobj->latest_time = curobj->earliest_time;
+                        break;
+                    }
 
           /***********************************
-	   * compute nominal duration of note 
-	   ***********************************/
+       * compute nominal duration of note 
+       ***********************************/
 
                   numdots = chordval.numdots;
                   duration = 0;
@@ -1302,8 +1306,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                     duration = curobj->durinticks;
 
           /********************************
-	   * compute real duration of note
-	   ********************************/
+       * compute real duration of note
+       ********************************/
 #if 0
                   //this is not working - it causes the delta to be -ve later
                   for (tmp = chordval.ornamentlist; tmp; tmp = tmp->next)
@@ -1335,13 +1339,13 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                     {
                       //MUST GIVE OFF TIME FOR RESTS HERE
                       curobj->latest_time = curobj->earliest_time + duration * 60.0 / (cur_tempo * MIDI_RESOLUTION);
-                      //g_print("Adding Dummy event for rest %d %d %d\n", duration, ticks_read, ticks_written); 
+                      //g_debug("Adding Dummy event for rest %d %d %d\n", duration, ticks_read, ticks_written); 
                       event = midi_meta_text (1 /* comment */ , "rest");
                       smf_track_add_event_delta_pulses (track, event, duration);
                       curobj->midi_events = g_list_append (curobj->midi_events, event);
                       ticks_written += duration;
                       event->user_pointer = curobj;
-                      //g_print("rest of %f seconds at %f\n", duration/(double)MIDI_RESOLUTION, curobj->latest_time);
+                      //g_debug("rest of %f seconds at %f\n", duration/(double)MIDI_RESOLUTION, curobj->latest_time);
                     }
 
                   if (chordval.notes)
@@ -1352,21 +1356,22 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                         midi_channel = 9;
 
             /**************************
-	     * prepare for note output
-	     **************************/
+         * prepare for note output
+         **************************/
 
                       notes_in_chord = 0;
                       if (debug)
                         fprintf (stderr, "this is a chord\n");
 
-                      slur_update (&slur_status, chordval.slur_begin_p, chordval.slur_end_p);
+                     // slur_update (&slur_status, chordval.slur_begin_p, chordval.slur_end_p);
+ slur_update (&slur_status, 0, 0);
 
                       /* compute beat to add to note velocity */
                       //beat = compute_beat (ticks_read - ticks_at_bar, beats2ticks (1, timesigupper, timesiglower), bars2ticks (1, timesigupper, timesiglower), duration, vel_beatfact);
 
             /************************
-	     * begin chord read loop 
-	     ************************/
+         * begin chord read loop 
+         ************************/
 
                       for (curtone = chordval.notes; curtone; curtone = curtone->next)
                         {
@@ -1396,7 +1401,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 
                               if (notenumber > 127)
                                 {
-                                  g_warning ("Note out of range: %d\n", notenumber = 60);
+                                  g_warning ("Note out of range: %d", notenumber = 60);
                                 }
                               slur_note (note_status, slur_status, notenumber, tmpstaccato, tmpstaccatissimo, chordval.is_tied);
                             }
@@ -1407,8 +1412,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                       print_slurs (stderr, note_status, slur_status, ticks_read, ticks_written, "after chord read");
 #endif
             /****************************
-	     * start note-on output loop
-	     ****************************/
+         * start note-on output loop
+         ****************************/
 
                       /* kill old slurs and ties */
                       /* start new notes */
@@ -1445,24 +1450,21 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                               curobj->earliest_time = event->time_seconds;
                               curobj->latest_time = curobj->earliest_time + duration * 60.0 / (cur_tempo * MIDI_RESOLUTION);
 
-
-#if DEBUG
-                              g_print ("'%d len %d'", event->event_number, event->midi_buffer_length);
+                              g_debug ("'%d len %d'", event->event_number, event->midi_buffer_length);
                               //printf ("volume = %i\n", (override_volume ? 0:mix));
-#endif
                             }
                           else if (slur_kill_p (note_status, n))
                             {
                               event = smf_event_new_from_bytes (MIDI_NOTE_OFF | midi_channel, n, 0);
-                              //g_print("{%d}", event->event_number);
+                              //g_debug("{%d}", event->event_number);
                               smf_track_add_event_delta_pulses (track, event, mididelta);
-                              //g_print("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
+                              //g_debug("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
                               event->user_pointer = curobj;
                               curobj->midi_events = g_list_append (curobj->midi_events, event);
 
                               curobj->latest_time = event->time_seconds;
                               curobj->earliest_time = curobj->latest_time - duration * 60.0 / (cur_tempo * MIDI_RESOLUTION);
-                              // g_print("event off lur kill %f\n", event->time_seconds);
+                              //g_debug("event off lur kill %f\n", event->time_seconds);
                             }
                         }
                       /* end of first chord output loop */
@@ -1471,8 +1473,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                       print_slurs (stderr, note_status, slur_status, ticks_read, ticks_written, "after loop1");
 #endif
             /*****************************
-	     * start note-off output loop
-	     *****************************/
+         * start note-off output loop
+         *****************************/
 
                       /* kill untied notes */
 
@@ -1503,15 +1505,15 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                                 }
                               /* write note off */
                               event = smf_event_new_from_bytes (MIDI_NOTE_OFF | midi_channel, n, 60);
-                              //g_print("smf length before %d %f mididelta %d",smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
+                              //g_debug("smf length before %d %f mididelta %d",smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
                               smf_track_add_event_delta_pulses (track, event, mididelta);
-                              //g_print("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
-                              //g_print("smf length after %d %f mididelta %d", smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
+                              //g_debug("Note  off for track %x at delta (%d) %.1f for cur_tempo %d\n", track, mididelta, event->time_seconds, cur_tempo);
+                              //g_debug("smf length after %d %f mididelta %d", smf_get_length_pulses(smf), smf_get_length_seconds(smf),mididelta);
                               event->user_pointer = curobj;
                               curobj->midi_events = g_list_append (curobj->midi_events, event);
                               curobj->latest_time = event->time_seconds;
                               curobj->earliest_time = curobj->latest_time - duration * 60.0 / (cur_tempo * MIDI_RESOLUTION);
-                              //g_print("event off %f mididelta %d duration %d for curobj->type = %d\n", event->time_seconds, mididelta, duration, curobj->type);
+                              //g_debug("event off %f mididelta %d duration %d for curobj->type = %d\n", event->time_seconds, mididelta, duration, curobj->type);
 
                             }
                         }
@@ -1536,8 +1538,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                 case TIMESIG:
 
           /************************
-	   * time signature change
-	   ************************/
+       * time signature change
+       ************************/
 
                   if (ticks_read != ticks_at_bar)
                     {
@@ -1560,8 +1562,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                 case TUPOPEN:
 
           /***************
-	   * tuplet begin
-	   ***************/
+       * tuplet begin
+       ***************/
 
                   switch (tuplet)
                     {
@@ -1585,8 +1587,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                 case TUPCLOSE:
 
           /*************
-	   * tuplet end
-	   *************/
+       * tuplet end
+       *************/
 
                   tuplet--;
                   switch (tuplet)
@@ -1612,8 +1614,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                 case DYNAMIC:
 
           /********************
-	   * dynamic directive
-	   ********************/
+       * dynamic directive
+       ********************/
 
                   cur_volume = string_to_vol (((dynamic *) curobj->object)->type->str, cur_volume);
                   curobj->earliest_time = curobj->latest_time = event->time_seconds;    //the last event
@@ -1633,8 +1635,8 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                 case CLEF:
 
           /***********
-	   * ignored!
-	   ***********/
+       * ignored!
+       ***********/
 
                   break;
 
@@ -1676,14 +1678,14 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                             break;
                           case DENEMO_OVERRIDE_DURATION:
                             theduration = midi_interpretation;
-                            g_print ("duration is %d\n", theduration);
+                            g_debug ("Duration is %d", theduration);
                             break;
                           default:
                             if (!(midi_override & DENEMO_OVERRIDE_HIDDEN))
                               if (buffer)
                                 {
                                   if (NULL == put_event (buffer, numbytes, &curobj->midi_events, track))
-                                    g_warning ("Directive has invalid MIDI bytes\n");
+                                    g_warning ("Directive has invalid MIDI bytes");
                                 }
                             break;
                           }
@@ -1703,7 +1705,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
                   break;
                 }
 
-              //g_print("Object type  0x%x Starts at %f Finishes %f\n",curobj->type, curobj->earliest_time, curobj->latest_time);
+              //g_debug("Object type  0x%x Starts at %f Finishes %f\n",curobj->type, curobj->earliest_time, curobj->latest_time);
             }                   // end of objects
 
       /*******************
@@ -1719,7 +1721,7 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
             {
               if ((!measure_is_empty) && curmeasure->next)
                 {
-                  g_warning ("warning: overfull measure in %s " "measure %d from %ld to %ld " "\n%sdifference is %ld, measure began at %ld)\n", curstaffstruct->lily_name->str, measurenum, ticks_read, ticks_at_bar + measurewidth, measure_has_odd_tuplet ? "(after unusual tuplet: " : "(", ticks_at_bar + measurewidth - ticks_read, ticks_at_bar);
+                  g_warning ("warning: overfull measure in %s " "measure %d from %ld to %ld " "\n%sdifference is %ld, measure began at %ld)", curstaffstruct->lily_name->str, measurenum, ticks_read, ticks_at_bar + measurewidth, measure_has_odd_tuplet ? "(after unusual tuplet: " : "(", ticks_at_bar + measurewidth - ticks_read, ticks_at_bar);
                 }
               if (debug)
                 {
@@ -1762,12 +1764,12 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
    ********/
   if (thefilename)
     {
-      if (Denemo.gui->si->recorded_midi_track)
-        smf_add_track (smf, Denemo.gui->si->recorded_midi_track);
+      if (Denemo.project->movement->recorded_midi_track)
+        smf_add_track (smf, Denemo.project->movement->recorded_midi_track);
       if(smf_save (smf, (const char *) thefilename))
         g_debug("smf_save failed");
-      if (Denemo.gui->si->recorded_midi_track)
-        smf_track_remove_from_smf (Denemo.gui->si->recorded_midi_track);
+      if (Denemo.project->movement->recorded_midi_track)
+        smf_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
     }
   /* we are done */
   {
@@ -1775,18 +1777,18 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
 
 
     g_static_mutex_lock (&smfmutex);
-    if (Denemo.gui->si->recorded_midi_track)
+    if (Denemo.project->movement->recorded_midi_track)
       {
-        if (si->smf && (((smf_track_t *) Denemo.gui->si->recorded_midi_track)->smf == si->smf))
+        if (si->smf && (((smf_track_t *) Denemo.project->movement->recorded_midi_track)->smf == si->smf))
           {
-            smf_track_remove_from_smf (Denemo.gui->si->recorded_midi_track);
+            smf_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
             midi_track = TRUE;
           }
       }
     free_midi_data (si);
     si->smf = smf;
     if (midi_track)
-      smf_add_track (smf, Denemo.gui->si->recorded_midi_track);
+      smf_add_track (smf, Denemo.project->movement->recorded_midi_track);
 
 
     si->smfsync = si->changecount;
@@ -1801,14 +1803,14 @@ exportmidi (gchar * thefilename, DenemoScore * si, gint start, gint end)
         si->start_time = 0.0;
       if (si->end_time < 0.0)
         si->end_time = smf_get_length_seconds (smf);
-      g_print ("Start time %f end time %f\n", si->start_time, si->end_time);
+      g_debug ("Start time %f end time %f\n", si->start_time, si->end_time);
     }
   call_out_to_guile ("(FinalizeMidiGeneration)");
   return smf_get_length_seconds (smf);
 }
 
 void
-free_midi_data (DenemoScore * si)
+free_midi_data (DenemoMovement * si)
 {
   if (si->smf)
     {
