@@ -324,7 +324,7 @@ newThumbnailElem (xmlNodePtr curElem, xmlNsPtr ns, DenemoSelection * thumbnail,
 }
 
 static void
-newSourceFileElem (xmlNodePtr curElem, xmlNsPtr ns, DenemoGUI * gui)
+newSourceFileElem (xmlNodePtr curElem, xmlNsPtr ns, DenemoProject * gui)
 {
 #ifndef USE_EVINCE  
   g_debug("This feature requires denemo to be built with evince");
@@ -371,15 +371,16 @@ newDirectivesElem (xmlNodePtr objElem, xmlNsPtr ns, GList * g, gchar * type)
 #define DO_DIREC(field)  if (directive->field \
                    && directive->field->len)\
                       xmlNewTextChild (directiveElem, ns, (xmlChar *) #field,\
-				     (xmlChar *) directive->field->str);
+                     (xmlChar *) directive->field->str);
 #define DO_INTDIREC(field)   if(directive->field) newXMLIntChild (directiveElem, ns, (xmlChar *) #field,\
-				             directive->field);
+                             directive->field);
       DO_DIREC (tag);
       DO_DIREC (prefix);
       DO_DIREC (postfix);
       DO_DIREC (display);
       DO_DIREC (midibytes);
       DO_DIREC (grob);
+      DO_DIREC (data);
       DO_DIREC (graphic_name);
 
       DO_INTDIREC (minpixels);
@@ -664,7 +665,7 @@ outputSources (xmlNodePtr mvmntElem, xmlNsPtr ns, GList * sources)
 
 
 static void
-outputAudio (xmlNodePtr mvmntElem, xmlNsPtr ns, DenemoAudio * audio)
+outputAudio (xmlNodePtr mvmntElem, xmlNsPtr ns, DenemoRecording * audio)
 {
   xmlNodePtr curElem = xmlNewChild (mvmntElem, ns, (xmlChar *) "audio", NULL);
   xmlNewChild (curElem, ns, (xmlChar *) "filename", (xmlChar*) audio->filename);
@@ -687,7 +688,7 @@ set_invisible (xmlNodePtr objElem, DenemoObject * curObj)
  * Denemo XML file to the given file.
  */
 gint
-exportXML (gchar * thefilename, DenemoGUI * gui)
+exportXML (gchar * thefilename, DenemoProject * gui)
 {
   gint ret = 0;
   GString *filename = g_string_new (thefilename);
@@ -733,7 +734,7 @@ exportXML (gchar * thefilename, DenemoGUI * gui)
   xmlSetProp (scoreElem, (xmlChar *) "version", (xmlChar *) version_string);
   /* FIXME: Put comment here ("Denemo XML file generated by..."). */
 
-  if (getNumCharsSchemeText ())
+  if (!Denemo.non_interactive && getNumCharsSchemeText ())
     {
       gchar *text = (gchar *) getSchemeText ();
       xmlNewTextChild (scoreElem, ns, (xmlChar *) "scheme", (xmlChar *) text);
@@ -785,13 +786,13 @@ exportXML (gchar * thefilename, DenemoGUI * gui)
     }
   //  if(gui->custom_prolog && gui->custom_prolog->len)
   //   xmlNewChild (scoreElem, ns, "custom_prolog", (xmlChar *)gui->custom_prolog->str);
-  gint movement_number = 1 + g_list_index (gui->movements, gui->si);
+  gint movement_number = 1 + g_list_index (gui->movements, gui->movement);
   if (movement_number)
     newXMLIntChild (scoreElem, ns, (xmlChar *) "movement-number", movement_number);
   GList *g;
   for (g = gui->movements; g; g = g->next)
     {
-      DenemoScore *si = g->data;
+      DenemoMovement *si = g->data;
 
       mvmntElem = xmlNewChild (scoreElem, ns, (xmlChar *) "movement", NULL);
       parentElem = xmlNewChild (mvmntElem, ns, (xmlChar *) "edit-info", NULL);
@@ -830,8 +831,8 @@ exportXML (gchar * thefilename, DenemoGUI * gui)
       if (si->sources)
         outputSources (mvmntElem, ns, si->sources);
       // output audio source
-      if (si->audio)
-        outputAudio (mvmntElem, ns, si->audio);
+      if (si->recording)
+        outputAudio (mvmntElem, ns, si->recording);
 
       parentElem = xmlNewChild (mvmntElem, ns, (xmlChar *) "score-info", NULL);
       curElem = xmlNewChild (parentElem, ns, (xmlChar *) "tempo", NULL);
@@ -1289,21 +1290,22 @@ exportXML (gchar * thefilename, DenemoGUI * gui)
                         xmlSetProp (objElem, (xmlChar *) "locked", (xmlChar *) "true");
 
 #define SETSTRING_PROP(field)\
-		  if(((lilydirective *) curObj->object)->field && ((lilydirective *) curObj->object)->field->len)\
-		    xmlSetProp (objElem, (xmlChar *) #field,\
-			      (xmlChar *) (((lilydirective *) curObj->object)->field->str));
+          if(((lilydirective *) curObj->object)->field && ((lilydirective *) curObj->object)->field->len)\
+            xmlSetProp (objElem, (xmlChar *) #field,\
+                  (xmlChar *) (((lilydirective *) curObj->object)->field->str));
 
                       SETSTRING_PROP (tag);
                       SETSTRING_PROP (display);
                       SETSTRING_PROP (midibytes);
                       SETSTRING_PROP (grob);
+                      SETSTRING_PROP (data);
                       SETSTRING_PROP (graphic_name);
                       SETSTRING_PROP (prefix);  //postfix done above, for backward compatibility
 #undef SETSTRING_PROP
 
 #define SETINT_PROP(x)\
-		    if(((lilydirective *) curObj->object)->x) newXMLIntProp (objElem, (xmlChar *) #x, \
-				   (((lilydirective *) curObj->object)->x));
+            if(((lilydirective *) curObj->object)->x) newXMLIntProp (objElem, (xmlChar *) #x, \
+                   (((lilydirective *) curObj->object)->x));
                       SETINT_PROP (x);
                       SETINT_PROP (y);
                       SETINT_PROP (tx);
