@@ -14,7 +14,7 @@
 
 struct callbackdata
 {
-  DenemoGUI *gui;
+  DenemoProject *gui;
   gchar *string;
 };
 /**
@@ -102,8 +102,8 @@ separate_fakechord_elements (gchar * fakechord, DenemoObject * curObj)
     }
   while (*++fakechord);
 
-  //g_print("\nthe base chord is %s\n", base->str);
-  //g_print("\nthe chord extension is %s\n", extension->str);
+  //g_debug("\nthe base chord is %s\n", base->str);
+  //g_debug("\nthe chord extension is %s\n", extension->str);
 
 
   if (curObj && curObj->type == CHORD)
@@ -129,8 +129,8 @@ gboolean
 insertfakechord (GtkWidget * widget, gpointer data)
 {
   struct callbackdata *cbdata = (struct callbackdata *) data;
-  DenemoGUI *gui = cbdata->gui;
-  DenemoScore *si = gui->si;
+  DenemoProject *gui = cbdata->gui;
+  DenemoMovement *si = gui->movement;
   if (cbdata->string == NULL)
     return FALSE;
   if (si->currentobject != NULL)
@@ -145,9 +145,9 @@ insertfakechord (GtkWidget * widget, gpointer data)
       do
         {
           if (si->currentobject->next)
-            movecursorright (NULL);
-          else if (gui->si->currentmeasure->next)
-            movetomeasureright (NULL);
+            movecursorright (NULL, NULL);
+          else if (gui->movement->currentmeasure->next)
+            movetomeasureright (NULL, NULL);
           else
             break;
           curObj = si->currentobject ? (DenemoObject *) si->currentobject->data : NULL;
@@ -167,20 +167,46 @@ insertfakechord (GtkWidget * widget, gpointer data)
     }
   return FALSE;
 }
-
+void
+delete_fakechords (GtkAction * action, DenemoScriptParam * param)
+{
+  DenemoProject *gui = Denemo.project;
+  DenemoStaff *thestaff = (DenemoStaff *) gui->movement->currentstaff->data;
+  if (confirm (_("Chord Symbol Deletion"), _("Delete all Chord Symbols from this staff?")))
+    {
+      thestaff->hasfakechords = FALSE;
+      score_status (gui, TRUE);
+      measurenode *curmeasure;
+      for (curmeasure = thestaff->measures; curmeasure; curmeasure = curmeasure->next)
+        {
+          objnode *curobj;
+          for (curobj = curmeasure->data; curobj; curobj = curobj->next)
+            {
+              DenemoObject *curObj = (DenemoObject *) curobj->data;
+              if (curObj && curObj->type == CHORD)
+                {
+                  GString *s = ((chord *) curObj->object)->fakechord;
+                  if (s)
+                    g_string_free (s, TRUE);
+                  ((chord *) curObj->object)->fakechord = NULL;
+                }
+            }
+        }
+    }
+}
 
 /**
  * Creates fakebook style chord entry dialog
  *
  */
 void
-fakechord_insert (GtkAction * action, gpointer param)
+fakechord_insert (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   gchar *string;
   gchar *PreValue = NULL;
   GString *temp = g_string_new ("");
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = gui->movement;
   static struct callbackdata cbdata;
   DenemoObject *curObj = (DenemoObject *) si->currentobject ? (DenemoObject *) si->currentobject->data : NULL;
 
