@@ -22,7 +22,7 @@
 
 struct callbackdata
 {
-  DenemoGUI *gui;
+  DenemoProject *gui;
   gchar *string;
 };
 
@@ -37,8 +37,8 @@ static void
 insertfigure (gboolean filter, gpointer data)
 {
   struct callbackdata *cbdata = (struct callbackdata *) data;
-  DenemoGUI *gui = cbdata->gui;
-  DenemoScore *si = gui->si;
+  DenemoProject *gui = cbdata->gui;
+  DenemoMovement *si = gui->movement;
   gchar filter_sep = filter ? '/' : '|';
   gchar filter_spc = filter ? '*' : ' ';
   if (si->measurewidth == DENEMO_INITIAL_MEASURE_WIDTH)
@@ -82,16 +82,16 @@ insertfigure (gboolean filter, gpointer data)
 
       if (curObj && curObj->type == CHORD)
         ((chord *) curObj->object)->is_figure = TRUE;
-			if(((chord *) curObj->object)->figure)
-				g_string_free (((chord *) curObj->object)->figure, TRUE);
+            if(((chord *) curObj->object)->figure)
+                g_string_free (((chord *) curObj->object)->figure, TRUE);
       ((chord *) curObj->object)->figure = g_string_new (f->str);
       g_string_free (f, TRUE);
       do
         {
           if (si->currentobject->next)
-            movecursorright (NULL);
-          else if (gui->si->currentmeasure->next)
-            movetomeasureright (NULL);
+            movecursorright (NULL, NULL);
+          else if (gui->movement->currentmeasure->next)
+            movetomeasureright (NULL, NULL);
           else
             break;
           curObj = si->currentobject ? (DenemoObject *) si->currentobject->data : NULL;
@@ -112,13 +112,14 @@ insertfigure (gboolean filter, gpointer data)
 
 
 void
-delete_figured_bass (GtkAction * action, gpointer param)
+delete_figured_bass (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoStaff *thestaff = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoProject *gui = Denemo.project;
+  DenemoStaff *thestaff = (DenemoStaff *) gui->movement->currentstaff->data;
   if (confirm ("Figured Bass Deletion", "Delete all figured bass markings from this staff?"))
     {
       thestaff->hasfigures = FALSE;
+      score_status (gui, TRUE);
       measurenode *curmeasure;
       for (curmeasure = thestaff->measures; curmeasure; curmeasure = curmeasure->next)
         {
@@ -139,19 +140,19 @@ delete_figured_bass (GtkAction * action, gpointer param)
 }
 
 void
-hide_figured_bass (GtkAction * action, gpointer param)
+hide_figured_bass (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoStaff *thestaff = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoProject *gui = Denemo.project;
+  DenemoStaff *thestaff = (DenemoStaff *) gui->movement->currentstaff->data;
   thestaff->hasfigures = FALSE;
 }
 
 /* turn on figured bass if any figures are present */
 void
-show_figured_bass (GtkAction * action, gpointer param)
+show_figured_bass (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoStaff *thestaff = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoProject *gui = Denemo.project;
+  DenemoStaff *thestaff = (DenemoStaff *) gui->movement->currentstaff->data;
   measurenode *curmeasure;
   for (curmeasure = thestaff->measures; curmeasure; curmeasure = curmeasure->next)
     {
@@ -176,10 +177,10 @@ show_figured_bass (GtkAction * action, gpointer param)
 void
 figure_insert (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   gchar *string = NULL;
   gchar *PreValue = NULL;
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = gui->movement;
   static struct callbackdata cbdata;
   DenemoObject *curObj = (DenemoObject *) si->currentobject ? (DenemoObject *) si->currentobject->data : NULL;
 
