@@ -12,7 +12,7 @@
 
 void figure_insert (GtkAction * action, DenemoScriptParam * param);
 DenemoObject *newfigure (gint baseduration, gint numdots, gchar * figs);
-void delete_figured_bass (GtkAction * action, gpointer param);
-void hide_figured_bass (GtkAction * action, gpointer param);
-void show_figured_bass (GtkAction * action, gpointer param);
+void delete_figured_bass (GtkAction * action, DenemoScriptParam * param);
+void hide_figured_bass (GtkAction * action, DenemoScriptParam * param);
+void show_figured_bass (GtkAction * action, DenemoScriptParam * param);
 #endif
