@@ -1,10 +1,10 @@
-/*	file.c
+/*  file.c
  * License: this file may be used under the FSF GPL version 3 or later
- * 	Denemo File IO 
+ *  Denemo File IO 
  *
- * 	for Denemo, a gtk+ frontend to GNU Lilypond
- * 	(c) Adam Tee, Matthew Hiller 2000-2005
- * 	(c) University of Leeds 2000-2005
+ *  for Denemo, a gtk+ frontend to GNU Lilypond
+ *  (c) Adam Tee, Matthew Hiller 2000-2005
+ *  (c) University of Leeds 2000-2005
  *      (c) Richard Shann 2010
  */
 
@@ -40,12 +40,16 @@
 #include "sourceaudio.h"
 #include "pitchentry.h"
 
-static gint file_open (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename);
-static gint file_import_lilypond (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename);
-static gint file_import_midi (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename);
-static gint file_import_musicxml (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename);
+static gint file_open (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename);
+static gint file_import_lilypond (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename);
+static gint file_import_midi (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename);
+static gint file_import_musicxml (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename);
 static gboolean replace_existing_file_dialog (const gchar * filename, gint format_id);
 
+
+
+
+
 typedef enum
 { DENEMO_FORMAT = 0,
   DNM_FORMAT,
@@ -124,8 +128,10 @@ static gchar *default_template_path = NULL;
  * or close without saving
  */
 static gboolean
-confirm_save (DenemoGUI * gui, gchar * primary, gchar * secondary)
+confirm_save (DenemoProject * gui, gchar * primary, gchar * secondary)
 {
+  if (Denemo.non_interactive)
+    return TRUE;
   GtkWidget *dialog;
   gboolean r = FALSE;
 
@@ -170,7 +176,7 @@ confirm_save (DenemoGUI * gui, gchar * primary, gchar * secondary)
  * @return TRUE if the OK button clicked or Enter pressed
  */
 gboolean
-confirmbox (DenemoGUI * gui)
+confirmbox (DenemoProject * gui)
 {
   gboolean ret;
   gchar *primary = g_strdup_printf (_("The score %s has unsaved changes"), gui->filename->len ? gui->filename->str : _("(Untitled)"));
@@ -201,7 +207,7 @@ history_compare (gconstpointer a, gconstpointer b)
 void
 openrecent (G_GNUC_UNUSED GtkWidget * widget, gchar * filename)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (!gui->notsaved || (gui->notsaved && confirmbox (gui)))
     {
       // deletescore(NULL, gui);
@@ -218,10 +224,11 @@ openrecent (G_GNUC_UNUSED GtkWidget * widget, gchar * filename)
  * Decorate the window with the tile
  */
 static void
-set_gui_tabname (DenemoGUI * gui, gchar * filename)
+set_gui_tabname (DenemoProject * gui, gchar * filename)
 {
   g_string_assign (gui->tabname, filename);
-  set_title_bar (gui);
+  if(!Denemo.non_interactive)
+    set_title_bar (gui);
 }
 
 /**
@@ -229,7 +236,7 @@ set_gui_tabname (DenemoGUI * gui, gchar * filename)
  * and adds it to the history
  */
 static void
-set_gui_filename (DenemoGUI * gui, gchar * filename)
+set_project_filename (DenemoProject * gui, gchar * filename)
 {
   GList *link = NULL;
   g_string_assign (gui->filename, filename);
@@ -242,12 +249,14 @@ set_gui_filename (DenemoGUI * gui, gchar * filename)
   if (g_queue_get_length (Denemo.prefs.history) > Denemo.prefs.maxhistory)
     {
       gpointer data = g_queue_pop_head (Denemo.prefs.history);
-      g_print ("losing one history\n");
+      g_debug ("Losing one history");
       if (data)
         g_free (data);
     }
-  if (link)                     /* not a new one */
-    addhistorymenuitem (filename);
+  if(!Denemo.non_interactive){
+    if (link)                     /* not a new one */
+      addhistorymenuitem (filename);
+  }
   g_queue_push_tail (Denemo.prefs.history, g_strdup (gui->filename->str));
 }
 
@@ -276,7 +285,7 @@ lyinput (gchar * filename)
 #ifdef G_OS_WIN32
   gchar *call = g_strescape (path, "");
   call = g_strdup_printf ("%s%s%s%s%s", "(debug-set! stack 200000) (lyimport::load-file \"", call, "\\\\\" \"", base, "\")");
-  g_print ("Calling %s\n", call);
+  g_debug ("Calling %s\n", call);
 #else
   gchar *call = g_strdup_printf ("%s%s%c%s%s%s", "(lyimport::load-file \"", path, G_DIR_SEPARATOR, "\" \"", base, "\")");
 #endif
@@ -289,6 +298,11 @@ lyinput (gchar * filename)
   return 0;
 }
 
+static gboolean
+exists(gchar* filename, const gchar* extension)
+{
+  return (strcmp (filename + strlen (filename) - strlen(extension), extension) == 0);
+}
 
 /**
  * The function that actually determines the file type and calls the
@@ -297,34 +311,35 @@ lyinput (gchar * filename)
  * @return 0 for success non zero for failure
  */
 gint
-open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, ImportType type)
+open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, ImportType type)
 {
-  g_signal_handlers_block_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
+  if(!Denemo.non_interactive)
+    g_signal_handlers_block_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
   gint result;
   gboolean xml = FALSE;
   result = 1;                   //FAILURE
-#define EXISTS(extension) (strcmp (filename + strlen (filename) - strlen(extension), extension) == 0)
+
   if (g_file_test (filename, G_FILE_TEST_EXISTS))
     {
-      if (EXISTS (".denemo") || EXISTS (".dnm"))
+      if (exists (filename, ".denemo") || exists (filename, ".dnm"))
         xml = TRUE, result = importXML (filename, gui, type);
-      else if (EXISTS (".ly"))
+      else if (exists (filename, ".ly"))
         result = lyinput (filename);
-      else if (EXISTS (".mxml") || EXISTS (".xml"))
+      else if (exists (filename, ".mxml") || exists (filename, ".xml"))
         result = mxmlinput (filename);
-      else if (EXISTS (".mid") || EXISTS (".midi"))
-        result = importMidi (filename);
-      else if (EXISTS (".pdf") || EXISTS (".PDF"))
+      else if (exists (filename, ".mid") || exists (filename, ".midi"))
+        result = (type==GUIDED_IMPORT)?guidedImportMidi (filename):importMidi (filename);
+      else if (exists (filename, ".pdf") || exists (filename, ".PDF"))
         {                       
 #ifndef USE_EVINCE  
-  g_debug("This feature requires denemo to be built with evince");
+          g_debug("This feature requires denemo to be built with evince");
 #else
           // a .pdf file for transcribing from, does not affect the current score.
           g_signal_handlers_unblock_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
           return !open_source (filename, 0, 0, 0);
 #endif
         }
-#undef EXISTS
+    g_message("Opening file %s", filename);
     }
   //printf("\nResult == %d type == %d template == %d xml == %d\n",result,type,template,(int)xml);
   if (result == 0)
@@ -334,8 +349,9 @@ open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, Impor
           update_file_selection_path (filename);
           if (type == REPLACE_SCORE)
             {
-              if (xml)
-                set_gui_filename (gui, filename);
+              if (xml){
+                 set_project_filename (gui, filename);
+              }
               else
                 {
                   gchar *sname = strip_path_and_extension (filename);
@@ -350,45 +366,54 @@ open_for_real (gchar * filename, DenemoGUI * gui, DenemoSaveType template, Impor
         {
           g_string_assign (gui->filename, "");
         }
-      if (Denemo.printarea)
-        g_object_set_data (G_OBJECT (Denemo.printarea), "printviewupdate", (gpointer) G_MAXUINT);
+      //if (Denemo.printarea)
+      //  g_object_set_data (G_OBJECT (Denemo.printarea), "printviewupdate", (gpointer) G_MAXUINT);
       if (!xml)
         updatescoreinfo (gui);
       else
         {
-          if (getNumCharsSchemeText ())
+          if (!Denemo.non_interactive && getNumCharsSchemeText ())
             {
               gui->has_script = TRUE;
               executeScript ();
             }
         }
-      set_rightmeasurenum (gui->si);
+      set_rightmeasurenum (gui->movement);
       select_lyrics ();
-      set_bottom_staff (gui);
-      update_hscrollbar (gui);
-      update_vscrollbar (gui);
-      gtk_widget_queue_draw (Denemo.scorearea);
-      g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
-      g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
-      force_lily_refresh (gui);
+
+      if(!Denemo.non_interactive){
+        set_bottom_staff (gui);
+        update_hscrollbar (gui);
+        update_vscrollbar (gui);
+        gtk_widget_queue_draw (Denemo.scorearea);
+        g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
+        g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+        force_lily_refresh (gui);
+      }
     }
   else                          /*file load failed - gui may not be valid */
     {
-      deletescore (NULL, gui);
+      if(!Denemo.non_interactive)
+        deletescore (NULL, gui);
     }
-  g_signal_handlers_unblock_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
-  gui->si->undo_guard = 1;
+  if(!Denemo.non_interactive){
+    g_signal_handlers_unblock_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
+    gui->movement->undo_guard = 1;
+  }
   denemo_scheme_init ();        //to re-instate any user defined directives for whole score
-  if (!(type == ADD_STAFFS || type == ADD_MOVEMENTS))
-    score_status (gui, FALSE);
-  rewind_audio ();
-  gui->si->undo_guard = Denemo.prefs.disable_undo;      //user pref to (dis)allow undo information to be collected
+  if(!Denemo.non_interactive){
+    if (!(type == ADD_STAFFS || type == ADD_MOVEMENTS))
+      score_status (gui, FALSE);
+    rewind_audio ();
+    gui->movement->undo_guard = Denemo.prefs.disable_undo;      //user pref to (dis)allow undo information to be collected
+  }
+
   return result;
 }
 
 /*
-	If the filename format already has the correct extension use
-	it. otherwise add the file name extension 
+    If the filename format already has the correct extension use
+    it. otherwise add the file name extension 
 */
 static gchar *
 create_filename (const gchar * file_name, gint format_id)
@@ -428,7 +453,7 @@ strip_filename_ext (const gchar * file_name, gint format_id)
    If there is a scheme script, offers to save that with the file.
  */
 static gint
-save_in_format (gint format_id, DenemoGUI * gui, gchar * filename)
+save_in_format (gint format_id, DenemoProject * gui, gchar * filename)
 {
   gint ret = 0;
   gchar *file = filename ? filename : gui->filename->str;
@@ -443,7 +468,7 @@ save_in_format (gint format_id, DenemoGUI * gui, gchar * filename)
          * delete the script.
          */
 
-        if ((!gui->has_script) && getNumCharsSchemeText ())
+        if (!Denemo.non_interactive && (!gui->has_script) && getNumCharsSchemeText ())
           if (!confirm (_("You have a Script defined"), _("Use this script every time this file is opened?")))
             {
               deleteSchemeText ();
@@ -453,19 +478,19 @@ save_in_format (gint format_id, DenemoGUI * gui, gchar * filename)
       };
     case MUDELA_FORMAT:
       {
-        gui->si->markstaffnum = 0;
+        gui->movement->markstaffnum = 0;
         exportlilypond (file, gui, TRUE);
         break;
       };
     case PDF_FORMAT:
       {
-        gui->si->markstaffnum = 0;
+        gui->movement->markstaffnum = 0;
         export_pdf (file, gui);
         break;
       };
     case PNG_FORMAT:
       {
-        gui->si->markstaffnum = 0;
+        gui->movement->markstaffnum = 0;
         export_png (file, (GChildWatchFunc) printpng_finished, gui);
         break;
       };
@@ -476,7 +501,7 @@ save_in_format (gint format_id, DenemoGUI * gui, gchar * filename)
       };
     case MIDI_FORMAT:
       {
-        exportmidi (file, gui->si, 0, 0);
+        exportmidi (file, gui->movement, 0, 0);
         break;
       };
     default:
@@ -490,14 +515,13 @@ save_in_format (gint format_id, DenemoGUI * gui, gchar * filename)
  * param file_name is full path to file possibly with extension
  */
 static gint
-filesel_save (DenemoGUI * gui, const gchar * file_name, gint format_id, DenemoSaveType template)
+filesel_save (DenemoProject * gui, const gchar * file_name, gint format_id, DenemoSaveType template)
 {
   gint ret = 0;
   g_assert (gui != NULL);
   g_assert (file_name != NULL);
   g_assert (format_id >= 0 && format_id < (int) G_N_ELEMENTS (supported_file_formats));
 
-  DenemoScore *si = gui->si;
   // Append file extension if needed
   gchar *file = NULL;
   gchar *basename = NULL;
@@ -505,7 +529,8 @@ filesel_save (DenemoGUI * gui, const gchar * file_name, gint format_id, DenemoSa
   if (!template && format_id == DENEMO_FORMAT)
     {
       update_file_selection_path (file);
-      set_gui_filename (gui, file);
+      if(!Denemo.non_interactive)
+        set_project_filename (gui, file);
     }
   basename = g_path_get_basename (file);
   if (basename[0] != '.')       // avoids empty filename
@@ -518,7 +543,8 @@ filesel_save (DenemoGUI * gui, const gchar * file_name, gint format_id, DenemoSa
       /*export parts as lilypond files */
       if (Denemo.prefs.saveparts)
         export_lilypond_parts (file, gui);
-      si->readonly = FALSE;
+      if(!Denemo.non_interactive)
+        gui->movement->readonly = FALSE;
     }
   g_free (basename);
   g_free (file);
@@ -554,7 +580,7 @@ typedef enum
  * filename is NULL for interactive use, otherwise file base name
  */
 static gint
-template_open (DenemoGUI * gui, TemplateType local, gchar * filename)
+template_open (DenemoProject * gui, TemplateType local, gchar * filename)
 {
   gboolean ret = FALSE;
   if (local == LOCAL)
@@ -606,13 +632,13 @@ template_open (DenemoGUI * gui, TemplateType local, gchar * filename)
 
 #define OPEN_WITH_CHECK(dir) \
 GET_1PARAM(action, param, filename); \
-  DenemoGUI *gui = Denemo.gui; \
+  DenemoProject *gui = Denemo.project; \
   if (gui->notsaved) \
     { \
       if (filename==NULL && confirmbox (gui)) \
-	{ \
-	  param->status = !template_open (gui, dir, filename); \
-	} \
+    { \
+      param->status = !template_open (gui, dir, filename); \
+    } \
     } \
   else \
     { \
@@ -654,28 +680,21 @@ file_open_with_check (GtkAction * action, DenemoScriptParam * param)
   GET_1PARAM (action, param, filename);
   if (query)
     {
-      param->status = (Denemo.gui->filename != NULL) && Denemo.gui->filename->len;
+      param->status = (Denemo.project->filename != NULL) && Denemo.project->filename->len;
       if (param->status)
-        g_string_assign (param->string, Denemo.gui->filename->str);
+        g_string_assign (param->string, Denemo.project->filename->str);
       return;
     }
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (!gui->notsaved || (gui->notsaved && (confirmbox (gui))))
     {
       param->status = !file_open (gui, FALSE, REPLACE_SCORE, filename);
     }
 }
 
-#define IMPORT(import_type) \
+#define IMPORT(import_type)  \
   GET_1PARAM(action, param, filename); \
-  if(query){ \
-    param->status = (Denemo.gui->filename!=NULL) && Denemo.gui->filename->len; \
-    if(param->status) \
-      g_string_assign(param->string, Denemo.gui->filename->str); \
-    return; \
-  } \
-  DenemoGUI *gui = Denemo.gui; \
-  param->status = !file_import_##import_type (gui, FALSE, REPLACE_SCORE, filename);
+  param->status = !file_import_##import_type (Denemo.project, FALSE, REPLACE_SCORE, filename);
 
 void
 file_import_lilypond_with_check (GtkAction * action, DenemoScriptParam * param)
@@ -685,7 +704,12 @@ IMPORT (lilypond)}
 void
 file_import_midi_with_check (GtkAction * action, DenemoScriptParam * param)
 {
-IMPORT (midi)}
+    GET_2PARAMS(action, param, filename, guided);
+    if(guided)
+        file_import_midi (Denemo.project, FALSE, GUIDED_IMPORT, filename);
+    else
+        file_import_midi (Denemo.project, FALSE, REPLACE_SCORE, filename);
+}
 
 void
 file_import_musicxml_with_check (GtkAction * action, DenemoScriptParam * param)
@@ -693,7 +717,7 @@ file_import_musicxml_with_check (GtkAction * action, DenemoScriptParam * param)
 IMPORT (musicxml)}
 
 #define ADD(insertion_strategy)\
-  DenemoGUI *gui = Denemo.gui;\
+  DenemoProject *gui = Denemo.project;\
   GET_1PARAM(action, param, filename);\
   (void)signal_structural_change(gui);\
   param->status = !file_open(gui, FALSE, insertion_strategy, filename);\
@@ -805,12 +829,12 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
   gint i;\
   \
   file_selection = gtk_file_chooser_dialog_new (_(message),\
-						GTK_WINDOW (Denemo.window),\
-						GTK_FILE_CHOOSER_ACTION_OPEN,\
-						GTK_STOCK_CANCEL,\
-						GTK_RESPONSE_REJECT,\
-						GTK_STOCK_OPEN,\
-						GTK_RESPONSE_ACCEPT, NULL);\
+                        GTK_WINDOW (Denemo.window),\
+                        GTK_FILE_CHOOSER_ACTION_OPEN,\
+                        GTK_STOCK_CANCEL,\
+                        GTK_RESPONSE_REJECT,\
+                        GTK_STOCK_OPEN,\
+                        GTK_RESPONSE_ACCEPT, NULL);\
   /* Open the last visited directory, if any. */\
   set_current_folder(file_selection, template);\
   \
@@ -821,22 +845,22 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
     gtk_file_filter_add_pattern (filter, supported_##format##_file_extension[i]); \
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_selection), filter);\
   gtk_dialog_set_default_response (GTK_DIALOG (file_selection),\
-				   GTK_RESPONSE_ACCEPT);\
+                   GTK_RESPONSE_ACCEPT);\
   gtk_widget_show_all (file_selection);\
   GtkWidget *preview;\
   preview = gtk_image_new();\
   gtk_file_chooser_set_preview_widget(GTK_FILE_CHOOSER (file_selection), preview);\
   g_signal_connect (GTK_FILE_CHOOSER(file_selection), "update-preview",\
-			G_CALLBACK (update_preview_cb), preview);\
+            G_CALLBACK (update_preview_cb), preview);\
   gtk_widget_show_all (preview);\
   if (gtk_dialog_run (GTK_DIALOG (file_selection)) == GTK_RESPONSE_ACCEPT)\
     {\
       gchar *name =\
-	gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selection));\
+    gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_selection));\
       if((ret=open_for_real (name, gui, template, type))) {\
-	gchar *warning = g_strdup_printf(_("Load of file %s failed"), name);\
-	warningdialog(warning);\
-	g_free(warning);\
+    gchar *warning = g_strdup_printf(_("Load of file %s failed"), name);\
+    warningdialog(warning);\
+    g_free(warning);\
       }\
       g_free (name);\
     }\
@@ -849,7 +873,7 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
  * filename must be full path or NULL for dialog
  */
 static gint
-file_open (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename)
+file_open (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
 FILE_OPEN_DIALOG ("Open", denemo, DENEMO_FORMAT)}
 
@@ -859,7 +883,7 @@ open_source_file (void)
   gchar *filename = NULL;
   ImportType type = 0;
   DenemoSaveType template = 0;
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   FILE_OPEN_DIALOG ("Open", evince, PDF_FORMAT);
 }
 
@@ -869,7 +893,7 @@ open_source_file (void)
  * filename must be full path or NULL for dialog
  */
 static gint
-file_import_lilypond (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename)
+file_import_lilypond (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
 FILE_OPEN_DIALOG ("Import Lilypond", lilypond, MUDELA_FORMAT)}
 
@@ -879,8 +903,9 @@ FILE_OPEN_DIALOG ("Import Lilypond", lilypond, MUDELA_FORMAT)}
  * filename must be full path or NULL for dialog
  */
 static gint
-file_import_midi (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename)
+file_import_midi (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
+    
 FILE_OPEN_DIALOG ("Import Midi", midi, MIDI_FORMAT)}
 
 /**
@@ -889,7 +914,7 @@ FILE_OPEN_DIALOG ("Import Midi", midi, MIDI_FORMAT)}
  * filename must be full path or NULL for dialog
  */
 static gint
-file_import_musicxml (DenemoGUI * gui, DenemoSaveType template, ImportType type, gchar * filename)
+file_import_musicxml (DenemoProject * gui, DenemoSaveType template, ImportType type, gchar * filename)
 {
 FILE_OPEN_DIALOG ("Import MusicXML", musicxml, MUSICXML_FORMAT)}
 
@@ -901,7 +926,7 @@ void
 file_saveaswrapper (GtkAction * action, DenemoScriptParam * param)
 {
   GET_1PARAM (action, param, filename);
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (filename == NULL)
     {
       file_saveas (FALSE);
@@ -909,9 +934,12 @@ file_saveaswrapper (GtkAction * action, DenemoScriptParam * param)
   else
     {
       gint status = filesel_save (gui, filename, DENEMO_FORMAT, FALSE);
-      if (status == 0)
-        score_status (gui, FALSE);
-      force_lily_refresh (gui);
+      
+      if(!Denemo.non_interactive){
+        if (status == 0)
+          score_status (gui, FALSE);
+        force_lily_refresh (gui);
+      }
     }
 }
 
@@ -944,11 +972,15 @@ file_copy_save (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptPara
 void
 file_savewrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-
+  DenemoProject *gui = Denemo.project;
+  GET_1PARAM (action, param, filename);
+  if (filename) {
+    exportXML (filename, gui);
+    return;
+  }
   if (file_save (NULL, gui))
     {
-      if (action && Denemo.gui->filename && Denemo.gui->filename->len)
+      if (action && Denemo.project->filename && Denemo.project->filename->len)
         {
           warningdialog (_("File save failed"));
           score_status (gui, TRUE);
@@ -966,11 +998,11 @@ file_savewrapper (GtkAction * action, DenemoScriptParam * param)
  * otherwise call saveas routine
  */
 gint
-file_save (GtkWidget * widget, DenemoGUI * gui)
+file_save (GtkWidget * widget, DenemoProject * gui)
 {
   gint ret;
-  DenemoScore *si = gui->si;
-  g_print ("READONLY %d\n", si->readonly);
+  DenemoMovement *si = gui->movement;
+  g_debug ("READONLY %d\n", si->readonly);
   if ((gui->filename->len == 0) /* || (si->readonly == TRUE) */ )
     /* No filename's been given or is opened from template */
     file_saveas (FALSE);
@@ -988,7 +1020,7 @@ file_save (GtkWidget * widget, DenemoGUI * gui)
 static void
 file_dialog_response (GtkWidget * dialog, gint response_id, struct FileDialogData *data)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (response_id == GTK_RESPONSE_ACCEPT)
     {
       gchar *file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
@@ -1010,12 +1042,12 @@ file_dialog_response (GtkWidget * dialog, gint response_id, struct FileDialogDat
   GtkWidget *file_selection;\
   GtkFileFilter *filter;\
   file_selection = gtk_file_chooser_dialog_new (description,\
-						GTK_WINDOW (Denemo.window),\
-						GTK_FILE_CHOOSER_ACTION_SAVE,\
-						GTK_STOCK_CANCEL,\
-						GTK_RESPONSE_REJECT,\
-						GTK_STOCK_SAVE,\
-						GTK_RESPONSE_ACCEPT, NULL);\
+                        GTK_WINDOW (Denemo.window),\
+                        GTK_FILE_CHOOSER_ACTION_SAVE,\
+                        GTK_STOCK_CANCEL,\
+                        GTK_RESPONSE_REJECT,\
+                        GTK_STOCK_SAVE,\
+                        GTK_RESPONSE_ACCEPT, NULL);\
   /*set default folder for saving */\
   set_current_folder(file_selection, template?SAVE_TEMPLATE:SAVE_NORMAL);\
   \
@@ -1031,7 +1063,7 @@ file_dialog_response (GtkWidget * dialog, gint response_id, struct FileDialogDat
   gtk_file_filter_add_pattern (filter, FORMAT_MASK(format_id));\
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_selection), filter);\
   gtk_dialog_set_default_response (GTK_DIALOG (file_selection),\
-				   GTK_RESPONSE_ACCEPT);\
+                   GTK_RESPONSE_ACCEPT);\
   gtk_widget_show_all (file_selection);\
   struct FileDialogData *data = (struct FileDialogData *) g_malloc (sizeof (struct FileDialogData));\
   data->template=template;\
@@ -1073,7 +1105,7 @@ file_newwrapper (GtkAction * action, DenemoScriptParam * param)
   dummy.string = NULL;
   if (param == NULL)
     param = &dummy;
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   g_signal_handlers_block_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
   if (gui->notsaved)
     {
@@ -1095,15 +1127,15 @@ file_newwrapper (GtkAction * action, DenemoScriptParam * param)
   deleteSchemeText ();
   gui->has_script = FALSE;
   set_enharmonic_position (0);
-  if (Denemo.printarea)
-    g_object_set_data (G_OBJECT (Denemo.printarea), "printviewupdate", (gpointer) G_MAXUINT);
+ // if (Denemo.printarea)
+  //  g_object_set_data (G_OBJECT (Denemo.printarea), "printviewupdate", (gpointer) G_MAXUINT);
   score_status (gui, FALSE);
   param->status = TRUE;
   g_signal_handlers_unblock_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
 
 }
 
-
+#if 0
 /* open_user_default_template
  * open the user's standard template if there is one
  * @return 0 for success non zero for failure
@@ -1115,12 +1147,12 @@ open_user_default_template (ImportType type)
   gchar *filename = g_build_filename (get_user_data_dir (TRUE), "templates", "default.denemo", NULL);
   if (g_file_test (filename, G_FILE_TEST_EXISTS))
     {
-      ret = open_for_real (filename, Denemo.gui, TRUE, type);
+      ret = open_for_real (filename, Denemo.project, TRUE, type);
     }
   g_free (filename);
   return ret;
 }
-
+#endif
 
 /**
  * Creates dialog to say that the chosen filename already exists
@@ -1153,7 +1185,7 @@ replace_existing_file_dialog (const gchar * filename, gint format_id)
 void
 file_savepartswrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (gui->filename->len == 0)
     {
       file_saveas (FALSE);
@@ -1177,33 +1209,33 @@ selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text,
     {
       fprintf (fp, "music = { %s }\n\\score {\n\\music\n\\layout {}\n}\n", text);
       fclose (fp);
-      gint theclef = find_prevailing_clef (Denemo.gui->si);
+      gint theclef = find_prevailing_clef (Denemo.project->movement);
       newview (NULL, NULL);
-      gint fail = open_for_real (filename, Denemo.gui, TRUE, REPLACE_SCORE);
+      gint fail = open_for_real (filename, Denemo.project, TRUE, REPLACE_SCORE);
       //thescore can be NULL after failed load....
       if (fail)
         {
-          DenemoGUI *gui = Denemo.gui;
+          DenemoProject *gui = Denemo.project;
           //FIXME repeated code
           free_movements (gui);
           gtk_widget_destroy (Denemo.page);
-          Denemo.guis = g_list_remove (Denemo.guis, gui);
+          Denemo.projects = g_list_remove (Denemo.projects, gui);
           g_free (gui);
           warningdialog (_("Could not interpret selection as LilyPond notes"));
           return;
         }
-      dnm_setinitialclef (Denemo.gui->si, (DenemoStaff *) Denemo.gui->si->currentstaff->data, theclef);
+      dnm_setinitialclef (Denemo.project->movement, (DenemoStaff *) Denemo.project->movement->currentstaff->data, theclef);
       call_out_to_guile ("(while (and (None?) (d-MoveToStaffDown)) (begin (d-MoveToStaffUp)(d-DeleteStaff)))");
       if (confirm (_("Paste from Selection"), _("Paste this music into your score?")))
         {
-          DenemoGUI *gui = Denemo.gui;
+          DenemoProject *gui = Denemo.project;
           tohome (NULL, NULL);
-          set_mark (gui);
+          set_mark (NULL, NULL);
           toend (NULL, NULL);
           copywrapper (NULL, NULL);
           free_movements (gui);
           gtk_widget_destroy (Denemo.page);
-          Denemo.guis = g_list_remove (Denemo.guis, gui);
+          Denemo.projects = g_list_remove (Denemo.projects, gui);
           g_free (gui);
           pastewrapper (NULL, NULL);
         }
@@ -1213,7 +1245,7 @@ selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text,
 void
 paste_clipboard (GtkAction * action, DenemoScriptParam * param)
 {
-  if (Denemo.gui != g_list_last (Denemo.guis)->data)
+  if (Denemo.project != g_list_last (Denemo.projects)->data)
     {
       warningdialog (_("Can only paste LilyPond text into the last tab, sorry"));
       return;
@@ -1225,7 +1257,7 @@ paste_clipboard (GtkAction * action, DenemoScriptParam * param)
 
 #define EXPORT_INTERFACE(format_id) \
   GET_1PARAM(action, param, filename); \
-  DenemoGUI *gui = Denemo.gui; \
+  DenemoProject *gui = Denemo.project; \
   if (filename==NULL) \
     file_export(format_id); \
   else \
