@@ -5,7 +5,5 @@
  * (c) 2000-2005 Matthew Hiller
  */
 
-void about (GtkAction * action, gpointer param);
-
-
-void browse_manual (GtkAction * action, gpointer param);
+void about (GtkAction * action, DenemoScriptParam* param);
+void browse_manual (GtkAction * action, DenemoScriptParam* param);
