@@ -188,9 +188,9 @@ ConvertLength (gint ppqn, gint duration, notetype * pnotetype)
 static void
 dotimesig (gint numerator, gint denominator)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   /*only does initial TS */
-  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->movement->currentstaff->data;
 
   curstaffstruct->timesig.time1 = numerator;
   curstaffstruct->timesig.time2 = denominator;
@@ -203,11 +203,11 @@ dotimesig (gint numerator, gint denominator)
 static void
 dokeysig (gint isminor, gint key)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (key > 7)
     key = key - 256;            /*get flat key num, see keysigdialog.cpp */
   g_debug ("\nkey = %d\n", key);
-  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->movement->currentstaff->data;
   curstaffstruct->keysig.number = key;
   curstaffstruct->keysig.isminor = isminor;
   dnm_setinitialkeysig (curstaffstruct, key, isminor);
@@ -216,15 +216,15 @@ dokeysig (gint isminor, gint key)
 static void
 dotempo (gint tempo)
 {
-  DenemoGUI *gui = Denemo.gui;
-  gui->si->tempo = (gint) (6.0e7 / (double) tempo);
+  DenemoProject *gui = Denemo.project;
+  gui->movement->tempo = (gint) (6.0e7 / (double) tempo);
 }
 
 static void
 dotrackname (gchar * name)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoProject *gui = Denemo.project;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->movement->currentstaff->data;
   if (name)
     g_string_assign (curstaffstruct->denemo_name, name);
 }
@@ -232,8 +232,8 @@ dotrackname (gchar * name)
 static void
 doinstrname (gchar * name)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoProject *gui = Denemo.project;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->movement->currentstaff->data;
   if (name)
     g_string_assign (curstaffstruct->midi_instrument, name);
 }
@@ -241,41 +241,41 @@ doinstrname (gchar * name)
 static void
 insert_rest_into_score (notetype length)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   gint i;
 
   switch (length.notetype)
     {
     case 0:
-      insert_rest_0key (gui);
+      insert_rest_0key (NULL, NULL);
       break;
     case 1:
-      insert_rest_1key (gui);
+      insert_rest_1key (NULL, NULL);
       break;
     case 2:
-      insert_rest_2key (gui);
+      insert_rest_2key (NULL, NULL);
       break;
     case 3:
-      insert_rest_3key (gui);
+      insert_rest_3key (NULL, NULL);
       break;
     case 4:
-      insert_rest_4key (gui);
+      insert_rest_4key (NULL, NULL);
       break;
     case 5:
-      insert_rest_5key (gui);
+      insert_rest_5key (NULL, NULL);
       break;
     case 6:
-      insert_rest_6key (gui);
+      insert_rest_6key (NULL, NULL);
       break;
     default:
-      insert_rest_2key (gui);
+      insert_rest_2key (NULL, NULL);
       break;
     }
   displayhelper (gui);
 
   /* add dots */
   for (i = 0; i < length.numofdots; i++)
-    add_dot_key (gui);
+    add_dot_key (NULL, NULL);
 }
 
 static gint
@@ -316,8 +316,8 @@ AddRest (gint ppqn, gint duration)
 static void
 insert_note_into_score (gint pitch, notetype length)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoProject *gui = Denemo.project;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->movement->currentstaff->data;
   gint i;
 
   /* 0-8 accepted bellow */
@@ -329,31 +329,31 @@ insert_note_into_score (gint pitch, notetype length)
   switch (length.notetype)
     {
     case 0:
-      insert_chord_0key (gui);
+      insert_chord_0key (NULL, NULL);
       break;
     case 1:
-      insert_chord_1key (gui);
+      insert_chord_1key (NULL, NULL);
       break;
     case 2:
-      insert_chord_2key (gui);
+      insert_chord_2key (NULL, NULL);
       break;
     case 3:
-      insert_chord_3key (gui);
+      insert_chord_3key (NULL, NULL);
       break;
     case 4:
-      insert_chord_4key (gui);
+      insert_chord_4key (NULL, NULL);
       break;
     case 5:
-      insert_chord_5key (gui);
+      insert_chord_5key (NULL, NULL);
       break;
     case 6:
-      insert_chord_6key (gui);
+      insert_chord_6key (NULL, NULL);
       break;
     case 7:
-      insert_chord_7key (gui);
+      insert_chord_7key (NULL, NULL);
       break;
     default:
-      insert_chord_8key (gui);
+      insert_chord_8key (NULL, NULL);
       g_warning ("Cannot handle size %d", length.notetype);
       break;
     }
@@ -374,13 +374,13 @@ insert_note_into_score (gint pitch, notetype length)
   g_free (accidental);
   /* Add dots */
   for (i = 0; i < length.numofdots; i++)
-    add_dot_key (gui);
+    add_dot_key (NULL, NULL);
 
   displayhelper (gui);
 }
 
 static void
-AddNote (gint ppqn, gint pitch, gint duration)
+AddMidiNote (gint ppqn, gint pitch, gint duration)
 {
   if (duration == 0)
     return;
@@ -577,7 +577,7 @@ donoteoff (const smf_event_t * event)
   ppqn = event->track->smf->ppqn;
   duration = event->delta_time_pulses;
   duration = round2granule (duration);
-  AddNote (ppqn, event->midi_buffer[1], duration);
+  AddMidiNote (ppqn, event->midi_buffer[1], duration);
 }
 
 /**
@@ -708,7 +708,8 @@ importMidi (gchar * filename)
 {
   smf_t *smf;
   gint ret = 0;                 // (-1 on failure)
-
+  gboolean save = Denemo.prefs.immediateplayback;
+  Denemo.prefs.immediateplayback = FALSE;
   /* load the file */
   smf = cmd_load (filename);
   if (!smf)
@@ -718,5 +719,6 @@ importMidi (gchar * filename)
     return -1;
   /* Delete data...Does it free it? */
   smf_delete (smf);
+  Denemo.prefs.immediateplayback = save;
   return ret;
 }
