@@ -19,6 +19,28 @@
 #include "mousing.h"
 #include "utils.h"
 
+
+static gint
+get_command_position(GtkTreeModel* model, gint command_idx){
+  gboolean valid;
+  command_row* row1 = NULL;
+  command_row* row2 = NULL;
+  gint i = 0;
+  GtkTreeIter iter;
+  
+  valid = gtk_tree_model_get_iter_first (model, &iter);
+  keymap_get_command_row(Denemo.map, &row2, command_idx);
+  
+  while (valid){
+    gtk_tree_model_get (model, &iter, COL_ROW, &row1, -1);
+    if(row1 && row1 == row2)
+      return i;
+    i++;
+    valid = gtk_tree_model_iter_next (model, &iter);
+  }
+  return -1;
+}
+
 #if 0
 static void
 validate_keymap_name (GtkEntry * entry, GtkDialog * dialog)
@@ -62,7 +84,7 @@ capture_add_binding (GtkWidget * widget, GdkEventKey * event, gpointer user_data
           warningdialog (msg);
           g_free (msg);
           g_free (name);
-          g_warning ("trying to set a two key starting with a single\n");
+          g_warning ("trying to set a two key starting with a single");
           return TRUE;
         }
     }
@@ -77,7 +99,7 @@ capture_add_binding (GtkWidget * widget, GdkEventKey * event, gpointer user_data
 
   if (cbdata->two_key == 0 && (GList *) g_hash_table_lookup (Denemo.map->continuations_table, name))
     {
-      //g_warning("There is a two key binding starting with this\n");
+      //g_warning("There is a two key binding starting with this");
       gchar *msg = g_strdup_printf (_("There is at least one two-key shortcut that starts with: %s\nFind them using the Find button\nDelete it/those first or start again selecting an unused keypress."), name);
       warningdialog (msg);
       g_free (msg);
@@ -90,6 +112,12 @@ capture_add_binding (GtkWidget * widget, GdkEventKey * event, gpointer user_data
     add_twokeybinding_to_idx (Denemo.map, cbdata->first_keyval, cbdata->first_modifiers, event->keyval, modifiers, command_idx, POS_FIRST);
   else
     add_keybinding_to_idx (Denemo.map, event->keyval, modifiers, command_idx, POS_FIRST);
+
+  command_row* row = NULL;
+  keymap_get_command_row (Denemo.map, &row, command_idx);
+  GtkListStore* bindings_model = GTK_LIST_STORE(gtk_tree_view_get_model(cbdata->binding_view));
+  update_bindings_model(bindings_model, row->bindings);
+  
   gtk_statusbar_pop (cbdata->statusbar, cbdata->context_id);
   g_signal_handler_disconnect (GTK_WIDGET (widget), cbdata->handler_key_press);
   g_signal_handler_disconnect (GTK_WIDGET (widget), cbdata->handler_focus_out);
@@ -136,10 +164,11 @@ capture_look_binding (GtkWidget * widget, GdkEventKey * event, gpointer user_dat
         cbdata->twokeylist = final_list;
     }
   if (command_idx != -1)
-    {
+  {
       model = gtk_tree_view_get_model (cbdata->command_view);
+      gint pos = get_command_position(model, command_idx);
       selection = gtk_tree_view_get_selection (cbdata->command_view);
-      gtk_tree_model_iter_nth_child (model, &iter, NULL, command_idx);
+      gtk_tree_model_iter_nth_child (model, &iter, NULL, pos);
       gtk_tree_selection_select_iter (selection, &iter);
       path = gtk_tree_model_get_path (model, &iter);
       gtk_tree_view_scroll_to_cell (cbdata->command_view, path, NULL, FALSE, 0, 0);
@@ -212,6 +241,7 @@ kbd_interface_del_binding (G_GNUC_UNUSED GtkButton * button, gpointer user_data)
   gchar *binding;
   GtkTreeModel *model;
   GtkTreeIter iter;
+  command_row* row = NULL;
   keyboard_dialog_data *cbdata = (keyboard_dialog_data *) user_data;
   gtk_statusbar_pop (cbdata->statusbar, cbdata->context_id);
   selection = gtk_tree_view_get_selection (cbdata->binding_view);
@@ -220,20 +250,30 @@ kbd_interface_del_binding (G_GNUC_UNUSED GtkButton * button, gpointer user_data)
     return;
   //else get the binding and remove it
   gtk_tree_model_get (model, &iter, 0, &binding, -1);
+  
+  gint command_id_ptr = lookup_command_for_keybinding_name(Denemo.map, binding);
   remove_keybinding_from_name (Denemo.map, binding);
+
+  if(command_id_ptr > -1){
+    if(keymap_get_command_row (Denemo.map, &row, command_id_ptr))
+      update_bindings_model(GTK_LIST_STORE(model), row->bindings);
+  }
+  else 
+    g_debug("Cannot find command to delete.\n");
   g_free (binding);
   Denemo.accelerator_status = TRUE;
 }
+
 static void
 execute_current (keyboard_dialog_data *data)
 {
-	//FIXME if recording, record to scheme window
- execute_callback_from_idx (Denemo.map, data->command_idx);
+    //FIXME if recording, record to scheme window
+ execute_callback_from_idx (Denemo.map, data->command_id);
 }
 static void
 add_current_to_palette (keyboard_dialog_data *data)
 {
- place_action_in_palette (data->command_idx, NULL);
+ place_action_in_palette (data->command_id, NULL);
 }
 
 
@@ -289,7 +329,7 @@ button_choice_callback (GtkWidget * w, gint * mask)
   gint choice = gtk_toggle_button_get_active ((GtkToggleButton *) w);
   if (choice)
     *mask = (intptr_t) g_object_get_data ((GObject *) w, "mask");
-  g_print ("button choice %x\n", *mask);
+  g_debug ("button choice %x\n", *mask);
 }
 
 
@@ -314,7 +354,7 @@ static  keyboard_dialog_data cbdata;
 
 GtkWidget *get_command_view(void)
 {
-return	cbdata.command_view;
+return  cbdata.command_view;
 }
 
 void
@@ -349,30 +389,32 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   guint context_id;
  
   if(Denemo.command_manager)   {
-	  model = gtk_tree_view_get_model (GTK_TREE_VIEW (cbdata.command_view));
-	  if (command_idx == -1)
-		{
-		//selecting the first command
-		gtk_tree_model_get_iter_first (model, &iter);
-		} 
-	  else
-		{
-			gtk_tree_model_iter_nth_child (model, &iter, NULL, command_idx);
-		}
-	  gtk_widget_grab_focus (SearchEntry);
-	  selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (cbdata.command_view));
+      model = gtk_tree_view_get_model (GTK_TREE_VIEW (cbdata.command_view));
+      if (command_idx == -1)
+        {
+        //selecting the first command
+        gtk_tree_model_get_iter_first (model, &iter);
+        } 
+      else
+        {
+      gint pos = get_command_position(model, command_idx);
+      gtk_tree_model_iter_nth_child (model, &iter, NULL, pos);
+        }
+      gtk_widget_grab_focus (SearchEntry);
+      selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (cbdata.command_view));
       gtk_tree_selection_select_iter (selection, &iter);
       path = gtk_tree_model_get_path (model, &iter);
       gtk_tree_view_scroll_to_cell ((GtkTreeView *) cbdata.command_view, path, NULL, FALSE, 0, 0);
       gtk_tree_path_free (path);
       if(!gtk_widget_get_visible(Denemo.command_manager))
-		activate_action ("/MainMenu/ViewMenu/" "ToggleCommandManager");
+        activate_action ("/MainMenu/ViewMenu/" "ToggleCommandManager");
       return;
     }
    if(SearchEntry==NULL) {
-	SearchEntry = gtk_entry_new ();
-	SearchNext = gtk_button_new_with_label ("->");
-	
+    SearchEntry = gtk_entry_new ();
+    SearchNext = gtk_button_new_with_label ("→");
+    gtk_widget_set_tooltip_text (SearchEntry, _("Type search text here. Either the start of a command label,\nor part of the text of a tooltip (if the tooltips flag is set).\nThe search is case insensitive."));
+    gtk_widget_set_tooltip_text (SearchNext, _("Search for the next matching command"));
 }   
   //getting a binding view and a command view and connecting the change of
   //command selection the the change of the model displayed by the binding view
@@ -402,7 +444,7 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_box_pack_start (GTK_BOX (outer_hbox), vbox, TRUE, TRUE, 0);
 
-	
+    
   frame = gtk_frame_new (_("Help for Selected Command"));
   gtk_frame_set_shadow_type ((GtkFrame *) frame, GTK_SHADOW_IN);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
@@ -438,19 +480,19 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   GtkWidget *inner_hbox = gtk_hbox_new (FALSE, 8);
   gtk_box_pack_start (GTK_BOX (vbox), inner_hbox, FALSE, TRUE, 0);
    button_save = gtk_button_new_with_label (_("Save as Default Command Set"));
-	gtk_box_pack_start (GTK_BOX (inner_hbox), button_save, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (inner_hbox), button_save, FALSE, TRUE, 0);
   gtk_widget_set_tooltip_text (button_save, _("Use this to save the changes you have made so that they are used every time you start Denemo. The changes are stored under a directory (folder) called .denemo-* in your home directory. Look in subdirectory actions for Default.commands"));
   button_save_as = gtk_button_new_with_label (_("Save as a Custom Command Set"));
-	gtk_box_pack_start (GTK_BOX (inner_hbox), button_save_as, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (inner_hbox), button_save_as, FALSE, TRUE, 0);
 
   button_load = gtk_button_new_with_label (_("Load a Standard Command Set"));
-	inner_hbox = gtk_hbox_new (FALSE, 8);
+    inner_hbox = gtk_hbox_new (FALSE, 8);
   gtk_box_pack_start (GTK_BOX (vbox), inner_hbox, FALSE, TRUE, 0);
     button_load = gtk_button_new_with_label (_("Load a Standard Command Set"));
-  	gtk_box_pack_start (GTK_BOX (inner_hbox), button_load, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (inner_hbox), button_load, FALSE, TRUE, 0);
 
   button_load_from = gtk_button_new_with_label (_("Load a Custom Command Set"));
-  	gtk_box_pack_start (GTK_BOX (inner_hbox), button_load_from, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (inner_hbox), button_load_from, FALSE, TRUE, 0);
 
    }
   
@@ -471,7 +513,7 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   lookbutton = gtk_button_new_from_stock (GTK_STOCK_FIND);
   gtk_button_set_label (GTK_BUTTON (lookbutton), _("Find Command for Shortcut"));
   gtk_widget_set_tooltip_text (lookbutton, _("Finds the command (if any) for a (one key) Keyboard Shortcut\n"
-											  "Click button then press the key shortcut you are looking for."));
+                                              "Click button then press the key shortcut you are looking for."));
   gtk_box_pack_end (GTK_BOX (inner_vbox), lookbutton, FALSE, TRUE, 0);
 
 
@@ -504,9 +546,10 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
   cbdata.command_view = GTK_TREE_VIEW (command_tree_view);
   cbdata.binding_view = GTK_TREE_VIEW (binding_tree_view);
   cbdata.text_view = GTK_TEXT_VIEW (text_view);
-  cbdata.command_idx = -1;
+  cbdata.command_id = -1;
   cbdata.two_key = 0;
   cbdata.twokeylist = NULL;
+
   //setup the link between command_view and binding_view
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (command_tree_view));
   gtk_tree_selection_set_select_function (selection, keymap_change_binding_view_on_command_selection, &cbdata, NULL);
@@ -519,7 +562,8 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
     }
   else
     {
-      gtk_tree_model_iter_nth_child (model, &iter, NULL, command_idx);
+      gint pos = get_command_position(model, command_idx);
+      gtk_tree_model_iter_nth_child (model, &iter, NULL, pos);
       path = gtk_tree_model_get_path (model, &iter);
       gtk_tree_view_scroll_to_cell ((GtkTreeView *) command_tree_view, path, NULL, FALSE, 0, 0);
       gtk_tree_path_free (path);
@@ -596,7 +640,7 @@ configure_keyboard_dialog_init_idx (GtkAction * action, gint command_idx)
 }
 
 void
-configure_keyboard_dialog (GtkAction * action, DenemoGUI * gui)
+configure_keyboard_dialog (GtkAction * action, DenemoScriptParam * param)
 {
   configure_keyboard_dialog_init_idx (action, -1);
 }
