@@ -123,7 +123,7 @@ get_state (gchar * key)
 static void
 instantiate_menus (gchar * menupath)
 {
-  //g_print("Instantiate menus for %s\n", menupath);
+  //g_info("Instantiate menus for %s\n", menupath);
 
   gchar *up1 = g_path_get_dirname (menupath);
   gchar *name = g_path_get_basename (menupath);
@@ -146,7 +146,7 @@ instantiate_menus (gchar * menupath)
       g_object_set_data (G_OBJECT (action), "menupath", up1);
     }
   gtk_ui_manager_add_ui (Denemo.ui_manager, gtk_ui_manager_new_merge_id (Denemo.ui_manager), up1, name, name, GTK_UI_MANAGER_MENU, FALSE);
-  //g_print("Adding %s to %s\n", name, up1);
+  //g_debug("Adding %s to %s\n", name, up1);
   // widget = gtk_ui_manager_get_widget(Denemo.ui_manager, menupath);
   //show_type (widget, "for menupath widget is ");
 
@@ -165,7 +165,13 @@ set_visibility_for_action (GtkAction * action, gboolean visible)
           else
             gtk_widget_hide (h->data);
         }
-      g_object_set_data (G_OBJECT (action), "hidden", GINT_TO_POINTER (!visible));
+      command_row* row = NULL;
+      const gchar* name = gtk_action_get_name(action);
+      gint id = lookup_command_from_name (Denemo.map, name);
+      if(id < 0)
+        g_error("Invalid command name:'%s' id:'%i'", name, id);
+      keymap_get_command_row (Denemo.map, &row, id);
+      row->hidden = !visible;
     }
 
 }
@@ -189,97 +195,78 @@ add_ui (gchar * menupath, gchar * after, gchar * name)
 {
   GtkWidget *widget = gtk_ui_manager_get_widget (Denemo.ui_manager, menupath);
   if (widget == NULL)
-    {
-      instantiate_menus (menupath);
-    }
-  //We place the item after the "after" item in the menupath, unless that isn't yet
-  //installed, in which case we just append to the menu
+    instantiate_menus (menupath);
   gchar *menupath_item = g_build_filename (menupath, after, NULL);
   GtkAction *sibling = gtk_ui_manager_get_action (Denemo.ui_manager, menupath_item);
 #ifdef DEBUG
-  if ((after != NULL) & (sibling == NULL))
-    {
-      static gboolean once = TRUE;
-      if (once)
-        {
-          gchar *msg = g_strdup_printf ("Cannot place %s after %s as requested,\nbecause I haven't seen %s yet\nTo fix this delete the %s command save the command set,\nQuit and restart Denemo\nThen re-install %s by right clicking on the %s item\nand choosing More Commands\nAnd finally saving command set again", name, after, after, name, name, after);
-          // infodialog(msg);
-          g_warning ("%s", msg);
-          g_free (msg);
-          //once = FALSE;
-        }
-    }
+  static gboolean once = TRUE;
+  if ((after != NULL) && (sibling == NULL) && once)
+    g_warning ("Cannot place %s after %s as requested, because I haven't seen %s yet. To fix this delete the %s command save the command set, quit and restart Denemo, then re-install %s by right clicking on the %s item and choosing More Commands and finally saving command set again.", name, after, after, name, name, after);
 #endif
   gtk_ui_manager_add_ui (Denemo.ui_manager, gtk_ui_manager_new_merge_id (Denemo.ui_manager), sibling ? menupath_item : menupath, name, name, GTK_UI_MANAGER_AUTO, FALSE);
   g_free (menupath_item);
 }
 
 void
-create_command(gchar* after,
-               gchar* fallback,
-               command_row *command)
+create_command(command_row *command)
 {
-  gchar* menupath = NULL;
+  GtkAction* action = NULL;
   if (command->script_type == COMMAND_SCHEME)
   {
-    gboolean new_command = FALSE;
-    command->action = lookup_action_from_name (command->name);
-    if (command->action == NULL)
-    {
-      new_command = TRUE;
-      gchar *icon_name = get_icon_for_name (command->name, command->label);
-      command->action = gtk_action_new (command->name, command->label, command->tooltip, icon_name);
+    gboolean new_command = (g_hash_table_lookup(Denemo.map->idx_from_name, command->name) == NULL);
+
+    if(!Denemo.non_interactive){
+      
+      if (!new_command)
+        action = lookup_action_from_name (command->name);
+      else
+      {
+        gchar *icon_name = get_icon_for_name (command->name, command->label);
+        action = gtk_action_new (command->name, command->label, command->tooltip, icon_name);
+        gtk_action_group_add_action (Denemo.action_group, action);
+      }
+    }
+
+    if(new_command){  
+      register_command_row (Denemo.map, command);
       command->callback = activate_script;
 
-      if (command->hidden)
-        g_object_set_data (G_OBJECT (command->action), "hidden", (gpointer) TRUE);
-      if (after)
-        g_object_set_data (G_OBJECT (command->action), "after", (gpointer) after);
-      register_command_row (Denemo.map, command);
-      GtkActionGroup *action_group;
-      // GList *groups = gtk_ui_manager_get_action_groups (Denemo.ui_manager);
-      action_group = Denemo.action_group;
-      gtk_action_group_add_action (action_group, command->action);
       // create a scheme function to call this script
       create_scheme_function_for_script (command->name);
     }
-
-    if(g_list_length(command->locations) > 0)
-    {
-      GList *g = NULL;
-      for (g = command->locations; g; g = g->next)
+    
+    if(!Denemo.non_interactive){
+      if(g_list_length(command->locations) > 0)
       {
-        menupath = (gchar *) g->data;
-        menupath = menupath ? menupath : (gchar *) "/MainMenu/Other";
-        add_ui (menupath, after, command->name);
+        GList *g = NULL;
+        for (g = command->locations; g; g = g->next)
+        {
+          command->menupath = (gchar *) (g->data ?: "/MainMenu/Other");
+          add_ui (command->menupath, command->after, command->name);
+        }
       }
+      else if (command->fallback)
+      {           
+        command->menupath = command->fallback;
+        add_ui (command->menupath, command->after, command->name);
+      }
+
+      g_object_set_data (G_OBJECT (action), "menupath", command->menupath);
+
+      if (new_command)
+        g_signal_connect (G_OBJECT (action), "activate", G_CALLBACK (activate_script), NULL);
     }
-    else if (fallback)
-    {           
-      /* no path given, use fallback */
-      menupath = fallback;
-      add_ui (menupath, after, command->name);
-    }
-
-    g_object_set_data (G_OBJECT (command->action), "menupath", menupath);
-
-    if (new_command)
-      g_signal_connect (G_OBJECT (command->action), "activate", G_CALLBACK (activate_script), NULL);
-
     // Note the script should *not* be in Default.cmdset
     // to delay loading it, but we should set the signal initally and we should not repeat setting the signal later.
     // the signal does not specify which script will be run, that is decided lazily, when the action is invoked for the first time
-
-    if (command->hidden)
-      g_object_set_data (G_OBJECT (command->action), "deleted", (gpointer) TRUE);      //Mark hidden items as deleted on loading them
   }
   
   // we are not as yet re-writing tooltips etc on builtin commands
-  else if (command->hidden)
+  else if (command->hidden && !Denemo.non_interactive)
   {
     hide_action_of_name (command->name);
     command->hidden = FALSE;
-    g_print ("Hiding Builtin %s\n", command->name);
+    g_info ("Hiding Builtin %s\n", command->name);
   }
 }
 
@@ -299,7 +286,7 @@ extract_menupath (gchar * filename)
       for (c = base; c && *c; c++)
         if (*c == G_DIR_SEPARATOR)
           *c = '/';
-      //g_print("got base as %s\n", base);
+      //g_debug("got base as %s\n", base);
     }
   g_free (head);
 
