@@ -7,12 +7,12 @@ static gchar*
 find_command_dir(GtkAction* action, gchar* filename)
 {
   gchar *menupath = (gchar *) g_object_get_data (G_OBJECT (action), "menupath");
-  gchar* dirs[] = {
-      g_build_filename (get_user_data_dir (TRUE), COMMANDS_DIR, "menus", menupath, NULL),
-      g_build_filename (get_user_data_dir (TRUE), "download", COMMANDS_DIR, "menus", menupath, NULL),
-      g_build_filename (get_system_data_dir (), COMMANDS_DIR, "menus", menupath, NULL),
-      NULL
-  };
+  GList* dirs = NULL;
+  dirs = g_list_append(dirs, g_build_filename (PACKAGE_SOURCE_DIR, COMMANDS_DIR, "menus", menupath, NULL));
+  dirs = g_list_append(dirs, g_build_filename (get_user_data_dir (TRUE), COMMANDS_DIR, "menus", menupath, NULL));
+  dirs = g_list_append(dirs, g_build_filename (get_user_data_dir (TRUE), "download", COMMANDS_DIR, "menus", menupath, NULL));
+  dirs = g_list_append(dirs, g_build_filename (get_system_data_dir (), COMMANDS_DIR, "menus", menupath, NULL));
+
   return find_dir_for_file (filename, dirs);
 }
 
@@ -25,60 +25,63 @@ get_command_type(xmlChar* type)
 static void
 parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback)
 {
-  command_row command;
-  command_row_init(&command);
-  xmlChar *after = NULL, *type = NULL;
-
+  command_row* command = NULL;
+  xmlChar *type = NULL;
   type = xmlGetProp(cur, COMMANDXML_TAG_TYPE);
-  if(type && 0 == xmlStrcmp (type, COMMAND_TYPE_SCHEME))
-    command.script_type = get_command_type(type);
-  xmlFree(type);
-
+  
   for (cur = cur->xmlChildrenNode; cur; cur = cur->next)
     {
       if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_ACTION))
         {
           if (cur->xmlChildrenNode == NULL)
             {
-              g_warning ("Empty action node found in keymap file\n");
+              g_warning ("Empty action node found in keymap file");
             }
           else
             {
-              command.name = (gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
               // We allow multiple locations for a given action, all are added to the gtk_ui when this command is processed after the tooltip node. 
               // This is very bad xml, as the action should have all the others as children, and not depend on the order.FIXME
-              command.locations = NULL;
+              gchar* name = (gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
+              command = get_or_create_command(name);
+              command->fallback = fallback;
+              command->locations = NULL;
+              
+              if(type && 0 == xmlStrcmp (type, COMMAND_TYPE_SCHEME))
+                command->script_type = get_command_type(type);
             }
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_HIDDEN))
         {
-          command.hidden = TRUE;
+          command->hidden = TRUE;
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_MENUPATH))
         {
-          command.locations = g_list_append (command.locations, xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
+          command->locations = g_list_append (command->locations, xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_LABEL))
         {
-          command.label = _((gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
+          command->label = _((gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_AFTER))
         {
-          after = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
+          command->after = (gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_TOOLTIP))
         {
-          command.tooltip = _((gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
+          command->tooltip = _((gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
         }
+      else
+        g_warning("Found XML tag '%s' reading a .commands file", cur->name);
     }
-  create_command((gchar*) after, fallback, &command);
+  create_command(command);
+  xmlFree(type);
 }
 
 static void
 parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
 {
 
-  xmlChar *name;                //keyval variables
+  xmlChar *name = NULL;                //keyval variables
   gint command_number = -1;
   guint keyval = 0;
   GdkModifierType state = 0;
@@ -89,13 +92,12 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
         {
           if (cur->xmlChildrenNode == NULL)
             {
-              g_warning ("Empty children node found in keymap file\n");
+              g_warning ("Empty children node found in keymap file");
             }
           else
             {
               name = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
               show_action_of_name ((gchar*) name);
-              g_debug ("Action %s\n", (gchar *) name);
             }
         }
       else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_HIDDEN))
@@ -108,10 +110,10 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
         {
           if (name)
             command_number = lookup_command_from_name (the_keymap, (gchar *) name);
-          //g_print("Found bind node for action %s %d\n", name, command_number);
+          //g_debug("Found bind node for action %s %d\n", name, command_number);
           if (cur->xmlChildrenNode == NULL)
             {
-              g_warning ("Empty <bind><\\bind> found in commandset file\n");
+              g_warning ("Empty <bind><\\bind> found in commandset file");
             }
           else
             {
@@ -119,13 +121,13 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
               if (name && tmp)
                 {
                   gchar *gtk_binding = translate_binding_dnm_to_gtk ((gchar *) tmp);
-                  //g_print("gtk_binding is %s\n", gtk_binding);
+                  //g_debug("gtk_binding is %s\n", gtk_binding);
                   if (gtk_binding)
                     {
                       keyval = 0;
                       if (Denemo.prefs.strictshortcuts)
                         dnm_accelerator_parse (gtk_binding, &keyval, &state);
-                      g_debug ("binding %s, keyval %d, state %d, Command Number %d\n", gtk_binding, keyval, state, command_number);
+                      g_debug ("binding %s, keyval %d, state %d, Command Number %d", gtk_binding, keyval, state, command_number);
                       {
                         gchar *comma;
                         comma = strtok (gtk_binding, ",");
@@ -147,7 +149,7 @@ parseBindings (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap)
                     }
                   else
                     {
-                      g_print ("No gtk equivalent for shortcut %s\n", tmp);
+                      g_warning ("No gtk equivalent for shortcut %s", tmp);
                     }
                   xmlFree (tmp);
                 }
@@ -182,7 +184,7 @@ parseCursorBinding (xmlDocPtr doc, xmlNodePtr cur)
               xmlFree (tmp);
             }
           assign_cursor (state, cursor_num);
-          // g_print("type is %s\n",g_type_name(G_TYPE_FROM_INSTANCE(Denemo.window->window)));
+          //g_debug("type is %s\n",g_type_name(G_TYPE_FROM_INSTANCE(Denemo.window->window)));
           // set_cursor_for(state);
         }
     }
@@ -206,7 +208,6 @@ parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menup
   xmlNodePtr ncur;
 
   //Parse commands first
-  ncur = cur->xmlChildrenNode;
   for (ncur = cur->xmlChildrenNode; ncur; ncur = ncur->next)
     {
       if ((0 == xmlStrcmp (ncur->name, COMMANDXML_TAG_ROW)))
@@ -216,18 +217,19 @@ parseCommands (xmlDocPtr doc, xmlNodePtr cur, keymap * the_keymap, gchar * menup
     }
 
   //Then parse bindings
-  ncur = cur->xmlChildrenNode;
-  for (ncur = cur->xmlChildrenNode; ncur; ncur = ncur->next)
-    {
-      if ((0 == xmlStrcmp (ncur->name, COMMANDXML_TAG_ROW)))
-        {
-          parseBindings (doc, ncur, the_keymap);
-        }
-      else if (0 == xmlStrcmp (ncur->name, COMMANDXML_TAG_CURSORS))
-        {
-          parseCursors (doc, ncur);
-        }
-    }
+  if(!Denemo.non_interactive){
+    for (ncur = cur->xmlChildrenNode; ncur; ncur = ncur->next)
+      {
+        if ((0 == xmlStrcmp (ncur->name, COMMANDXML_TAG_ROW)))
+          {
+            parseBindings (doc, ncur, the_keymap);
+          }
+        else if (0 == xmlStrcmp (ncur->name, COMMANDXML_TAG_CURSORS))
+          {
+            parseCursors (doc, ncur);
+          }
+      }
+  }
 }
 
 static void
@@ -258,6 +260,7 @@ load_xml_keymap (gchar * filename)
   gint ret = -1;
   xmlDocPtr doc;
   xmlNodePtr rootElem;
+  xmlKeepBlanksDefault (0);
   
   if (filename == NULL)
     return ret;
@@ -281,14 +284,14 @@ load_xml_keymap (gchar * filename)
   rootElem = xmlDocGetRootElement (doc);
   if (rootElem == NULL)
     {
-      g_warning ("Empty Document\n");
+      g_warning ("Empty Document");
       xmlFreeDoc (doc);
       return ret;
     }
 
   if (xmlStrcmp (rootElem->name, COMMANDXML_TAG_ROOT))
     {
-      g_warning ("Document has wrong type\n");
+      g_warning ("Document has wrong type");
       xmlFreeDoc (doc);
       return ret;
     }
@@ -297,7 +300,6 @@ load_xml_keymap (gchar * filename)
 
   while (rootElem != NULL)
     {
-      g_debug ("RootElem %s\n", rootElem->name);
       parseKeymap (doc, rootElem, Denemo.map, menupath);
 
       if (Denemo.last_merged_command)
@@ -306,7 +308,8 @@ load_xml_keymap (gchar * filename)
       if (menupath)
         execute_init_scripts (menupath);
 
-      update_all_labels (Denemo.map);
+      if(!Denemo.non_interactive)
+        update_all_labels (Denemo.map);
       ret = 0;
 
       rootElem = rootElem->next;
@@ -315,16 +318,16 @@ load_xml_keymap (gchar * filename)
   xmlFreeDoc (doc);
   {static gboolean init=FALSE;
   if (!init)
-	{
-	alphabeticalize_commands (Denemo.map);
-	init = TRUE;
-	}
+    {
+    alphabeticalize_commands (Denemo.map);
+    init = TRUE;
+    }
   }
   {
     //if this is a new-style .commands file, we need to load the keybindings separately
     gchar *name = g_strdup (filename);
     gchar *ext = remove_extension (name);
-    if (ext && !strcmp (ext, "commands"))
+    if (ext && !strcmp (ext, "commands") && !Denemo.non_interactive)
       {
         gchar *newname = g_strdup_printf ("%s%s", name, ".shortcuts");
         load_xml_keybindings (newname);
@@ -355,14 +358,14 @@ load_xml_keybindings (gchar * filename)
   rootElem = xmlDocGetRootElement (doc);
   if (rootElem == NULL)
     {
-      g_warning ("Empty Document\n");
+      g_warning ("Empty Document");
       xmlFreeDoc (doc);
       return ret;
     }
-  //g_print ("RootElem %s\n", rootElem->name);
+  //g_debug ("RootElem %s\n", rootElem->name);
   if (xmlStrcmp (rootElem->name, COMMANDXML_TAG_ROOT))
     {
-      g_warning ("Document has wrong type\n");
+      g_warning ("Document has wrong type");
       xmlFreeDoc (doc);
       return ret;
     }
@@ -431,6 +434,7 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
   const gchar *basename = NULL;
   gchar* dir = NULL;
   doc = xmlNewDoc ((xmlChar *) "1.0");
+  command_row* row;
   doc->xmlRootNode = parent = xmlNewDocNode (doc, NULL, COMMANDXML_TAG_ROOT, NULL);
 
   child = xmlNewChild (parent, NULL, COMMANDXML_TAG_MERGE, NULL);
@@ -447,9 +451,9 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
 
   for (i = 0; i < keymap_size (the_keymap); i++)
     {
+      keymap_get_command_row (the_keymap, &row, i);
+        
       gpointer action = (gpointer) lookup_action_from_idx (the_keymap, i);
-      gchar *after = action ? g_object_get_data (action, "after") : NULL;
-      gboolean deleted = (gboolean) (action ? GPOINTER_TO_INT (g_object_get_data (action, "deleted")) : 0);
       gchar *name = (gchar *) lookup_name_from_idx (the_keymap, i);
 
       basename = gtk_action_get_name (action);
@@ -480,15 +484,17 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
       child = xmlNewChild (parent, NULL, COMMANDXML_TAG_ROW, NULL);
 
       xmlNewTextChild (child, NULL, COMMANDXML_TAG_ACTION, (xmlChar *) name);
-      if (after)
-        xmlNewTextChild (child, NULL, COMMANDXML_TAG_AFTER, (xmlChar *) after);
-      if (deleted)              //store as hidden in commands file
-        xmlNewTextChild (child, NULL, COMMANDXML_TAG_HIDDEN, (xmlChar *) "true");
-
+      
       if(!is_action_name_builtin(name))
           xmlNewProp(child, COMMANDXML_TAG_TYPE, COMMAND_TYPE_SCHEME);
       else
           xmlNewProp(child, COMMANDXML_TAG_TYPE, COMMAND_TYPE_BUILTIN);
+      
+      if (row->after)
+        xmlNewTextChild (child, NULL, COMMANDXML_TAG_AFTER, (xmlChar *) row->after);
+      if (row->deleted)              //store as hidden in commands file
+        xmlNewTextChild (child, NULL, COMMANDXML_TAG_HIDDEN, (xmlChar *) "true");
+
 
       gchar *menupath = action ? g_object_get_data (action, "menupath") : NULL;
       if (menupath)
@@ -502,10 +508,6 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
       gchar *tooltip = (gchar *) lookup_tooltip_from_idx (the_keymap, i);
       if (tooltip)
         xmlNewTextChild (child, NULL, COMMANDXML_TAG_TOOLTIP, (xmlChar *) tooltip);
-
-      //  keymap_foreach_command_binding (the_keymap, i,
-      //                                      (GFunc) write_xml_keybinding_info, child);
-
     }
 
   xmlSaveFormatFileEnc (filename, doc, XML_ENCODING, 1);
@@ -522,7 +524,8 @@ save_xml_keybindings (gchar * filename)
   xmlDocPtr doc;
   //xmlNsPtr ns;
   xmlNodePtr parent, child;
-
+  command_row *row;
+    
   doc = xmlNewDoc ((xmlChar *) "1.0");
   doc->xmlRootNode = parent = xmlNewDocNode (doc, NULL, COMMANDXML_TAG_ROOT, NULL);
   child = xmlNewChild (parent, NULL, COMMANDXML_TAG_MERGE, NULL);
@@ -539,22 +542,22 @@ save_xml_keybindings (gchar * filename)
 
   for (i = 0; i < keymap_size (the_keymap); i++)
     {
+      keymap_get_command_row (the_keymap, &row, i);
+      
       gpointer action = (gpointer) lookup_action_from_idx (the_keymap, i);
-      gboolean deleted = (gboolean) (action ? GPOINTER_TO_INT (g_object_get_data (action, "deleted")) : 0);
-      gboolean hidden = (gboolean) (action ? GPOINTER_TO_INT (g_object_get_data (action, "hidden")) : 0);
-      if (deleted && !is_action_id_builtin(i))
+      if (row->deleted && !is_action_id_builtin(i))
         continue;
-      if (hidden || command_has_binding (i))
+      if (row->hidden || command_has_binding (i))
         {
           child = xmlNewChild (parent, NULL, COMMANDXML_TAG_ROW, NULL);
 
           gchar *name = (gchar *) lookup_name_from_idx (the_keymap, i);
           g_debug ("%s %s binding(s) \n", name, command_has_binding (i) ? "has" : "does not have");
           xmlNewTextChild (child, NULL, COMMANDXML_TAG_ACTION, (xmlChar *) name);
-          if (hidden)
+          if (row->hidden)
             xmlNewTextChild (child, NULL, COMMANDXML_TAG_HIDDEN, (xmlChar *) "true");
 
-          keymap_foreach_command_binding (the_keymap, i, (GFunc) write_xml_keybinding_info, child);
+          g_list_foreach(row->bindings, (GFunc) write_xml_keybinding_info, child);   
         }
     }
 
@@ -568,7 +571,7 @@ save_xml_keybindings (gchar * filename)
 static void
 show_type (GtkWidget * widget, gchar * message)
 {
-  g_print ("%s%s\n", message, widget ? g_type_name (G_TYPE_FROM_INSTANCE (widget)) : "NULL widget");
+  g_message ("%s%s", message, widget ? g_type_name (G_TYPE_FROM_INSTANCE (widget)) : "NULL widget");
 }
 */
 /* not used */
@@ -589,7 +592,7 @@ create_dir_for_menu (gchar * str)
    set menupath as attribute of widgets
  */
 static gint
-parseMenu (xmlNodePtr rootElem, gchar * path, DenemoGUI * gui)
+parseMenu (xmlNodePtr rootElem, gchar * path, DenemoProject * gui)
 {
   for (rootElem = rootElem->xmlChildrenNode; rootElem; rootElem = rootElem->next)
     {
@@ -611,11 +614,11 @@ parseMenu (xmlNodePtr rootElem, gchar * path, DenemoGUI * gui)
                   g_object_set_data (G_OBJECT (widget), "menupath", str);
                   // we do this in menu_click when needed create_dir_for_menu(str);//FIXME we only need do this once for a given denemoui.xml
                   //show_type(widget, "The type is ");
-                  //g_print("set %p %s\n",widget, str);
+                  //g_debug("set %p %s\n",widget, str);
                   parseMenu (rootElem, str, gui);
                 }
               else
-                g_warning ("no object for %s\n", str);
+                g_warning ("no object for %s", str);
             }
 
         }
@@ -628,7 +631,7 @@ parseMenu (xmlNodePtr rootElem, gchar * path, DenemoGUI * gui)
               GtkWidget *widget = gtk_ui_manager_get_widget (Denemo.ui_manager, str);
               g_free (str);
               //show_type(widget, "The type is ");
-              //g_print("set %p %s\n",widget, path);
+              //g_debug("set %p %s\n",widget, path);
               if (widget)
                 {
                   g_object_set_data (G_OBJECT (widget), "menupath", g_strdup (path));
@@ -646,7 +649,7 @@ parseMenu (xmlNodePtr rootElem, gchar * path, DenemoGUI * gui)
  * negative on failure
  */
 gint
-parse_paths (gchar * filename, DenemoGUI * gui)
+parse_paths (gchar * filename, DenemoProject * gui)
 {
   gint ret = -1;
   xmlDocPtr doc;
@@ -664,14 +667,14 @@ parse_paths (gchar * filename, DenemoGUI * gui)
   rootElem = xmlDocGetRootElement (doc);
   if (rootElem == NULL)
     {
-      g_warning ("Empty Document\n");
+      g_warning ("Empty Document");
       xmlFreeDoc (doc);
       return ret;
     }
 
   if (xmlStrcmp (rootElem->name, (const xmlChar *) "ui"))
     {
-      g_warning ("Document has wrong type\n");
+      g_warning ("Document has wrong type");
       xmlFreeDoc (doc);
       return ret;
     }
@@ -700,10 +703,11 @@ save_command_metadata (gchar * filename, gchar * myname, gchar * mylabel, gchar
   child = xmlNewChild (parent, NULL, COMMANDXML_TAG_ROW, NULL);
   xmlNewProp(child, COMMANDXML_TAG_TYPE, COMMAND_TYPE_SCHEME);
 
+  xmlNewTextChild (child, NULL, COMMANDXML_TAG_ACTION, (xmlChar *) myname);
+  
   if (after)
     xmlNewTextChild (child, NULL, COMMANDXML_TAG_AFTER, (xmlChar *) after);
 
-  xmlNewTextChild (child, NULL, COMMANDXML_TAG_ACTION, (xmlChar *) myname);
 
   xmlNewTextChild (child, NULL, COMMANDXML_TAG_LABEL, (xmlChar *) mylabel);
 
