@@ -16,7 +16,7 @@ static GtkWidget *DummyVerse;   /* a non-existent verse */
 gboolean
 lyric_change (GtkTextBuffer * buffer)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   score_status (gui, TRUE);
   gtk_widget_queue_draw (Denemo.scorearea);
   return FALSE;
@@ -53,7 +53,7 @@ switch_page (GtkNotebook * notebook, gpointer dummy, guint pagenum, DenemoStaff
 }
 
 GtkWidget *
-add_verse_to_staff (DenemoScore * si, DenemoStaff * staff)
+add_verse_to_staff (DenemoMovement * si, DenemoStaff * staff)
 {
   GtkWidget *notebook, *textview;
   if (staff->verses == NULL)
@@ -81,7 +81,7 @@ add_verse_to_staff (DenemoScore * si, DenemoStaff * staff)
   gtk_widget_show_all (gtk_widget_get_parent (textview));
   staff->verses = g_list_append (staff->verses, textview);
   staff->currentverse = g_list_last (staff->verses);
-  //  g_print("Setting verse to %p\n", staff->currentverse);
+  //g_debug("Setting verse to %p\n", staff->currentverse);
   gint pagenum = gtk_notebook_append_page (GTK_NOTEBOOK (notebook), gtk_widget_get_parent (textview), NULL);
   gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), pagenum);
   gchar *tablabel = g_strdup_printf ("Verse %d", pagenum + 1);
@@ -93,11 +93,11 @@ add_verse_to_staff (DenemoScore * si, DenemoStaff * staff)
 }
 
 void
-add_verse (GtkAction * action, gpointer param)
+add_verse (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoScore *si = gui->si;
-  if (gui->si->currentstaff)
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
+  if (gui->movement->currentstaff)
   {
     DenemoStaff *staff = si->currentstaff->data;
     add_verse_to_staff (si, staff);
@@ -108,10 +108,10 @@ add_verse (GtkAction * action, gpointer param)
 }
 
 void
-delete_verse (GtkAction * action, gpointer param)
+delete_verse (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoScore *si = gui->si;
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
   if (si->currentstaff)
   {
     DenemoStaff *staff = si->currentstaff->data;
@@ -195,6 +195,9 @@ next_syllable (gint count)
 void
 reset_lyrics (DenemoStaff * staff, gint count)
 {
+  if(Denemo.non_interactive)
+    return;
+
   if (DummyVerse == NULL)
     DummyVerse = gtk_text_view_new ();
   if (staff && staff->currentverse)
@@ -206,7 +209,7 @@ reset_lyrics (DenemoStaff * staff, gint count)
 
 
 void
-install_lyrics_preview (DenemoScore * si, GtkWidget * top_vbox)
+install_lyrics_preview (DenemoMovement * si, GtkWidget * top_vbox)
 {
   if (si->lyricsbox == NULL)
     si->lyricsbox = gtk_vbox_new (FALSE, 1);    //box to hold notebook of textview widgets
@@ -219,17 +222,17 @@ install_lyrics_preview (DenemoScore * si, GtkWidget * top_vbox)
 void
 hide_lyrics (void)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (gui->si->currentstaff && ((DenemoStaff *) gui->si->currentstaff->data)->verses)
-    gtk_widget_hide (gtk_widget_get_parent (gtk_widget_get_parent (((DenemoStaff *) gui->si->currentstaff->data)->verses->data)));      //hide the notebook
+  DenemoProject *gui = Denemo.project;
+  if (gui->movement->currentstaff && ((DenemoStaff *) gui->movement->currentstaff->data)->verses)
+    gtk_widget_hide (gtk_widget_get_parent (gtk_widget_get_parent (((DenemoStaff *) gui->movement->currentstaff->data)->verses->data)));      //hide the notebook
 }
 
 /* show the notebook of verses for the current staff hide all others*/
 void
 show_lyrics (void)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoScore *si = gui->si;
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
   if (si->currentstaff && ((DenemoStaff *) si->currentstaff->data)->verses)
     gtk_widget_show (gtk_widget_get_parent (gtk_widget_get_parent (((DenemoStaff *) si->currentstaff->data)->verses->data)));   //show the notebook
   select_lyrics ();
@@ -239,8 +242,8 @@ show_lyrics (void)
 void
 select_lyrics (void)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoScore *si = gui->si;
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
   GList *current = si->thescore;
   for (; current; current = current->next)
   {
@@ -296,10 +299,10 @@ put_lyrics_for_current_verse (DenemoStaff * thestaff, gchar * text)
 gint
 get_current_verse_number (void)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (gui->si->currentstaff)
+  DenemoProject *gui = Denemo.project;
+  if (gui->movement->currentstaff)
   {
-    DenemoStaff *thestaff = ((DenemoStaff *) gui->si->currentstaff->data);
+    DenemoStaff *thestaff = ((DenemoStaff *) gui->movement->currentstaff->data);
     if (thestaff->verses)
       return 1 + g_list_index (thestaff->verses, thestaff->currentverse);
 
@@ -309,10 +312,10 @@ get_current_verse_number (void)
 gboolean
 set_current_verse (gint number)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (gui->si->currentstaff)
+  DenemoProject *gui = Denemo.project;
+  if (gui->movement->currentstaff)
   {
-    DenemoStaff *thestaff = ((DenemoStaff *) gui->si->currentstaff->data);
+    DenemoStaff *thestaff = ((DenemoStaff *) gui->movement->currentstaff->data);
     if (thestaff->verses)
     {
       GList *g = g_list_nth (thestaff->verses, number - 1);
@@ -329,9 +332,9 @@ set_current_verse (gint number)
 
 gchar * get_lyrics_for_verse_num (gint number)
 {
-  DenemoGUI * gui = Denemo.gui; if (gui->si->currentstaff)
+  DenemoProject * gui = Denemo.project; if (gui->movement->currentstaff)
   {
-    DenemoStaff * thestaff = ((DenemoStaff *) gui->si->currentstaff->data); if (thestaff->verses)
+    DenemoStaff * thestaff = ((DenemoStaff *) gui->movement->currentstaff->data); if (thestaff->verses)
     {
       GList * verse = g_list_nth (thestaff->verses, number - 1); if (verse) return get_text_from_view (verse->data);
     }
