@@ -103,16 +103,6 @@ sigchld_handler (G_GNUC_UNUSED gint num)
 }
 #endif /* HAVE_SIGCHLD */
 
-
-/**
- * Handler used to print debug messages.
- */
-static void
-debug_handler (const gchar * log_domain, GLogLevelFlags log_level, const gchar * message, gpointer user_data)
-{
-  //g_debug ("%s",message);
-}
-
 static void
 append_to_path (gchar * path, gchar * extra, ...)
 {
@@ -138,7 +128,7 @@ append_to_path (gchar * path, gchar * extra, ...)
 }
 
 static gchar **
-process_command_line (int argc, char **argv)
+process_command_line (int argc, char **argv, gboolean gtkstatus)
 {
   GError *error = NULL;
   GOptionContext *context;
@@ -148,14 +138,17 @@ process_command_line (int argc, char **argv)
 
   GOptionEntry entries[] =
   {
-    { "scheme-path",       'i', 0, G_OPTION_ARG_FILENAME, &Denemo.scheme_file, _("Process scheme commands in pathtofile on file open"), _("path") },
-    { "scheme-script-name",'s', 0, G_OPTION_ARG_STRING, &scheme_script_name, _("Process scheme commands from system file on file open"), _("file")  },
-    { "scheme",            'a', 0, G_OPTION_ARG_STRING, &Denemo.scheme_commands, _("Process the scheme on startup"), _("scheme") },
-    { "non-interactive",   'n', 0, G_OPTION_ARG_NONE, &Denemo.non_interactive, _("Launch Denemo without GUI"), NULL },
-    { "version",           'v', 0, G_OPTION_ARG_NONE, &version,  _("Print version information and exit"), NULL },
-    { "audio-options",     'A', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &Denemo.prefs.audio_driver,_("Audio driver options"), _("options") },
-    { "midi-options",      'M', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &Denemo.prefs.midi_driver, _("Midi driver options"), _("options") },
-    { G_OPTION_REMAINING,  0,   0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, NULL, _("[FILE]...") },
+    { "scheme-path",         'i', 0, G_OPTION_ARG_FILENAME, &Denemo.scheme_file, _("Process scheme commands in pathtofile on file open"), _("path") },
+    { "scheme-script-name",  's', 0, G_OPTION_ARG_STRING, &scheme_script_name, _("Process scheme commands from system file on file open"), _("file")  },
+    { "scheme",              'a', 0, G_OPTION_ARG_STRING, &Denemo.scheme_commands, _("Process the scheme on startup"), _("scheme") },
+    { "fatal-scheme-errors", 'e', 0, G_OPTION_ARG_NONE, &Denemo.fatal_scheme_errors, _("Abort on scheme errors"), NULL },
+    { "silent",              'm', 0, G_OPTION_ARG_NONE, &Denemo.silent, _("Don't log any message"), NULL },
+    { "verbose",             'V', 0, G_OPTION_ARG_NONE, &Denemo.verbose, _("Display every messages"), NULL },
+    { "non-interactive",     'n', 0, G_OPTION_ARG_NONE, &Denemo.non_interactive, _("Launch Denemo without GUI"), NULL },
+    { "version",             'v', 0, G_OPTION_ARG_NONE, &version,  _("Print version information and exit"), NULL },
+    { "audio-options",       'A', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &Denemo.prefs.audio_driver,_("Audio driver options"), _("options") },
+    { "midi-options",        'M', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &Denemo.prefs.midi_driver, _("Midi driver options"), _("options") },
+    { G_OPTION_REMAINING,    0,   0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, NULL, _("[FILE]...") },
     { NULL }
   };
   const gchar* subtitle = _(" ");
@@ -171,12 +164,10 @@ process_command_line (int argc, char **argv)
   g_free(header);
   g_option_context_set_description (context, footer);
   g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
-  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+  if(gtkstatus)
+    g_option_context_add_group (context, gtk_get_option_group (TRUE));
   if (!g_option_context_parse (context, &argc, &argv, &error))
-    {
-      g_print ("Option parsing failed: %s\n", error->message);
-      exit (EXIT_FAILURE);
-    }
+    g_error ("Option parsing failed: %s", error->message);
 
   if(version)
   {
@@ -205,6 +196,10 @@ process_command_line (int argc, char **argv)
   signal (SIGCHLD, sigchld_handler);
 #endif
 
+  //Set command line mode if gtk could not be initialized
+  if(!gtkstatus)
+    Denemo.non_interactive = TRUE;
+
   return filenames;
 }
 
@@ -233,26 +228,26 @@ init_environment()
       gchar *guile_path = g_strconcat (guile, ";", guile_1_8, ";", denemo_scm, ";", denemo_modules_scm, ";", lilypond_current_scm, NULL);
       //FIXME TRUE means we overwrite any installed version of lilyponds scm, FALSE risks not putting denemos scm in the path...
       g_setenv ("GUILE_LOAD_PATH", guile_path, TRUE);
-      g_print ("Setting GUILE_LOAD_PATH=%s\n", guile_path);
+      g_info ("Setting GUILE_LOAD_PATH=%s\n", guile_path);
     }
   else
     warningdialog (_("You may need to set GUILE_LOAD_PATH to the directory where you have ice9 installed\n"));
   g_setenv ("PANGO_PREFIX", prefix, TRUE);
   g_setenv ("PANGO_MODULE_VERSION", "1.6.0", TRUE);
   g_setenv ("PANGO_SO_EXTENSION", ".dll", TRUE);
-  g_print ("Setting PANGO_PREFIX=%s\n", prefix);
+  g_info ("Setting PANGO_PREFIX=%s\n", prefix);
 
   g_setenv ("GTK_MODULE_VERSION", "2.10.0", TRUE);
   g_setenv ("GTK_SO_EXTENSION", ".dll", TRUE);
   g_setenv ("GTK_PREFIX", prefix, TRUE);
-  g_print ("Setting GTK_PREFIX=%s\n", prefix);
+  g_info ("Setting GTK_PREFIX=%s\n", prefix);
 
   gchar *fc_path = g_build_filename (prefix, "etc", "fonts", NULL);
   g_setenv ("FONTCONFIG_PATH", fc_path, TRUE);
-  g_print ("Setting FONTCONFIG_PATH=%s\n", fc_path);
+  g_info ("Setting FONTCONFIG_PATH=%s\n", fc_path);
   gchar *fc_file = g_build_filename (fc_path, "fonts.conf", NULL);
   g_setenv ("FONTCONFIG_FILE", fc_file, TRUE);
-  g_print ("Setting FONTCONFIG_FILE=%s\n", fc_file);
+  g_info ("Setting FONTCONFIG_FILE=%s\n", fc_file);
 
 
   //gchar *program_files = g_getenv ("PROGRAMFILES");
@@ -262,19 +257,24 @@ init_environment()
   path = g_strconcat (path, ";", lilypond_path, ";", lib_path, NULL);
 
   g_setenv ("PATH", path, TRUE);
-  g_print ("PATH set to %s\n", path);
+  g_info ("PATH set to %s\n", path);
   gchar *lilypond_data_path = g_build_filename (prefix, "share", "lilypond", "current", NULL);
   g_setenv ("LILYPOND_DATA_PATH", lilypond_data_path, FALSE);
-  g_print ("LILYPOND_DATA_PATH will be %s if not already set", lilypond_data_path);
+  g_info ("LILYPOND_DATA_PATH will be %s if not already set", lilypond_data_path);
 
   append_to_path ("GUILE_LOAD_PATH", get_system_data_dir (), NULL);
 
 #else
   add_font_directory (g_build_filename (get_system_data_dir (), "fonts", NULL));
 
+  GList* dirs = NULL;
+  dirs = g_list_append(dirs, g_build_filename (PACKAGE_SOURCE_DIR, COMMANDS_DIR, NULL));
+  dirs = g_list_append(dirs, g_build_filename (get_system_data_dir (), COMMANDS_DIR, NULL));
+  gchar* data_dir = find_dir_for_file ("denemo.scm", dirs);
+
   append_to_path ("GUILE_LOAD_PATH",
-                  g_build_filename (get_system_data_dir (), COMMANDS_DIR, NULL),
-                  g_build_filename (get_system_data_dir (), COMMANDS_DIR, "denemo-modules", NULL),
+                  g_build_filename (data_dir, NULL),
+                  g_build_filename (data_dir, "denemo-modules", NULL),
                   NULL);
 
 #endif /* end of else not windows */
@@ -310,7 +310,7 @@ static void check_if_upgrade (void) {
 		GDir *dir = g_dir_open (g_get_home_dir (), 0, NULL);
 		if(dir==NULL) 
 			{
-			g_warning ("Cannot find home directory\n");
+			g_warning ("Cannot find home directory");
 			return;
 			}		
 		while ((name = g_dir_read_name (dir))) {
@@ -319,9 +319,9 @@ static void check_if_upgrade (void) {
 				guint32 val;
 				ver_maj=ver_min=ver_mic=0;
 				sscanf (name, ".denemo-%u.%u.%u", &ver_maj, &ver_min, &ver_mic);
-				//g_print (" %u %u %u\n", ver_maj, ver_min, ver_mic);
+				//g_debug (" %u %u %u\n", ver_maj, ver_min, ver_mic);
 				val = (ver_maj<<16) + (ver_min<<8) + ver_mic;
-				if(val) g_print("name %s\n", name);
+				if(val) g_debug("name %s", name);
 				if (val>this_ver) {
 					g_warning ("Downgrade of Denemo version. Ignoring");
 					return;
@@ -338,56 +338,132 @@ static void check_if_upgrade (void) {
 		}
 	}
 }
-/**
- * Main function
- *
+
+/* main_log_handler:
+ * Message handler. How log levels should be used:
+ * ERROR:    Fatal error that makes the program stop.
+ * CRITICAL: Error that don't makes the program stop, but should make a test
+ *           fail
+ * WARNING:  Warns the user (or developper) about unwanted, but non fatal stuffs
+ * MESSAGE:  Regular messages about program execution.
+ * INFO:     Further information that may interest users, when launched with
+ *           --verbose. Thoses messages may be relevant to repport bugs, but
+ *           non interesting ortherwise.
+ * DEBUG:    Debug information that may interest developpers, when compiled with
+ *           -DDEBUG or configured with --enable-debug, and launched with
+ *           --verbose
  */
+static void
+main_log_handler(const gchar *log_domain,
+                 GLogLevelFlags log_level,
+                 const gchar *message,
+                 gpointer user_data ){
+  if(Denemo.silent)
+    return;
+
+  char* color = NULL;
+  char* level = NULL;
+  char* endcolor = "\033[0m";
+  FILE* stream = stdout;
+  char* prev = NULL;
+  char* next = NULL;
+  char* msg = NULL;
+
+  if(log_level & G_LOG_LEVEL_ERROR){
+    color = "\033[1;41m";
+    level = "ERROR";
+    stream = stderr;
+  }
+  else if (log_level & G_LOG_LEVEL_CRITICAL){
+    color = "\033[1;31m";
+    level = "CRITICAL";
+    stream = stderr;
+  }
+  else if (log_level & G_LOG_LEVEL_WARNING){
+    color = "\033[0;33m";
+    level = "WARNING";
+    stream = stderr;
+  }
+  else if (log_level & G_LOG_LEVEL_MESSAGE){
+    color = "\033[0;32m";
+    level = "MESSAGE";
+  }
+  else if (Denemo.verbose && (log_level & G_LOG_LEVEL_INFO)){
+    color = "\033[0;34m";
+    level = "INFO";
+  }
+
+#ifdef DEBUG
+  else if (Denemo.verbose && (log_level & G_LOG_LEVEL_DEBUG)){
+    color = "\033[0;35m";
+    level = "DEBUG";
+  }
+#endif
+
+#ifdef G_OS_WIN32
+  color = "";
+  level = "";
+#endif
+
+  if(color && level){
+    msg = g_strdup(message);
+    //Displays colored header
+    g_fprintf(stream, "%s%6s - %-8s%s: ", color, log_domain, level, endcolor);
+
+    //Add some tab
+    prev = msg;
+    while(next = strchr(prev, '\n')){
+      *next = '\0';
+      g_fprintf(stream, "%s\n                   ", prev);
+      prev = next+1;
+    }
+    g_fprintf(stream, "%s\n", prev);
+    g_free(msg);
+  }
+  if(log_level & G_LOG_FLAG_FATAL)
+    abort();
+}
+
 int
 main (int argc, char *argv[])
 {
+  gchar** files = NULL;
+  gboolean gtk_status = FALSE;
 
+  g_log_set_default_handler (main_log_handler, NULL);
 
-  /* glib/gtk initialization */
-  gtk_init (&argc, &argv);
- 
- 
+  if(!(gtk_status = gtk_init_check (&argc, &argv)))
+    g_message(_("Could not start graphical interface."));
+
+  files = process_command_line (argc, argv, gtk_status);
+  
   if (!g_thread_supported ())
       g_thread_init (NULL);
-    
-  gdk_threads_init ();
-  /* acquire gdk lock */
-  gdk_threads_enter ();
 
-  gchar** files = process_command_line (argc, argv);
-
-  
-  
+  if(!Denemo.non_interactive){
+    gdk_threads_init ();
+    gdk_threads_enter ();
+  }
 //#ifdef G_OS_WIN32
 //  /* workaround necessary for compilation on Cygwin */
 //  g_set_print_handler ((GPrintFunc)printf);
 //#endif
 
-  /* set the default handler for debug messages */
-  //FIXME this does not work
-  g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG, debug_handler, NULL);
-
   /* initialization of directory relocatability */
   initdir ();
 
   check_if_upgrade();
   init_environment();
 
-
   rsvg_init ();
 
   localization_init();
 
   //register_stock_items ();
-
   scm_with_guile (inner_main, files);
-
-  /* release gdk lock */
-  gdk_threads_leave ();
+  
+  if(!Denemo.non_interactive)
+    gdk_threads_leave ();
 
   return 0;
 }
