@@ -33,7 +33,7 @@
  * @return measurenode pointer to the first added in the current staff
  */
 measurenode *
-addmeasures (DenemoScore * si, gint pos, guint nummeasures, gint all)
+addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
 {
   staffnode *curstaff;
   guint i;
@@ -73,7 +73,10 @@ addmeasures (DenemoScore * si, gint pos, guint nummeasures, gint all)
     }
   set_measure_transition (-20 * nummeasures, all);
   measurenode *ret = g_list_nth (firstmeasurenode (si->currentstaff), pos);
+//  displayhelper (Denemo.project);
+ // score_status(Denemo.project, TRUE);
 //check not returning NULL!!!!
+  si->cursoroffend = FALSE;//This was left to the drawing routine to set, but it can happen that no draw occurs before the value is needed.
   if (ret)
     return ret;
   g_warning ("Add measures was going to return NULL");
@@ -81,7 +84,7 @@ addmeasures (DenemoScore * si, gint pos, guint nummeasures, gint all)
 }
 
 measurenode *
-dnm_addmeasures (DenemoScore * si, gint pos, guint nummeasures, gint all)
+dnm_addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
 {
   return addmeasures (si, pos, nummeasures, all);
 }
@@ -124,7 +127,7 @@ freeobjlist (gpointer data, gpointer user_data)
 void
 staffremovemeasures (staffnode * curstaff, guint pos)
 {
-  //g_print ("In Staffremovemeasures\n");
+  //g_debug ("In Staffremovemeasures\n");
   take_snapshot ();
   measurenode *firstmeasure;
   measurenode *delmeasure;
@@ -161,7 +164,7 @@ staffremovemeasures (staffnode * curstaff, guint pos)
  * @param all remove from all staffs
  */
 measurenode *
-removemeasures (DenemoScore * si, guint pos, guint nummeasures, gboolean all)
+removemeasures (DenemoMovement * si, guint pos, guint nummeasures, gboolean all)
 {
   staffnode *curstaff;
   measurenode *firstmeasure;
@@ -342,7 +345,7 @@ settickvalsinmeasure (objnode * theobjs)
 
       //this goes up too fast for grace notes...
 
-      //g_print("start tick next %d\n",       theobj->starttickofnextnote);
+      //g_debug("start tick next %d\n",       theobj->starttickofnextnote);
     }
 }
 
@@ -365,7 +368,7 @@ setsdir (objnode * starter, objnode * ender, gint beamgroup_sum, gint beamgroup_
   {
     static gint count = 0;
     count++;
-    g_print ("Call %d ++++++++++++++++++++++++++++++++\n\
+    g_debug ("Call %d ++++++++++++++++++++++++++++++++\n\
           Stem directive %s\n\
           Clef %d\n\
           ------------------------------\n", count, stem_directive == 2 ? "Neutral" : stem_directive == 1 ? "Down" : "Up", clef);
@@ -446,7 +449,7 @@ calculatebeamsandstemdirs (objnode * theobjs, gint * pclef, gint * time1, gint *
     static gint count = 0;
     count++;
     gint stem = *stem_directive;
-    g_print ("Call calc %d #################################\n\
+    g_debug ("Call calc %d #################################\n\
           Stem directive %s\n\
           Clef %d\n\
           ------------------------------\n", count, stem == 2 ? "Neutral" : stem == 1 ? "Down" : "Up", next_clef);
@@ -747,4 +750,6 @@ forceaccidentals (DenemoObject * theobj)
   ((chord *) theobj->object)->hasanacc = TRUE;
   set_accidental_positions (theobj);
   setpixelmin (theobj);
+  displayhelper (Denemo.project);
+  score_status(Denemo.project, TRUE);
 }
