@@ -26,11 +26,6 @@
 #include <string.h>
 #include <assert.h>
 
-
-#define SYS_EXCLUSIVE_MESSAGE1  0xF0
-#define NOTE_ON                 0x90
-#define NOTE_OFF                0x80
-
 #define SHAVING (0.01)          //seconds to shave off a note start time to ensure stopping before noteon is sent, and starting with noteon first note may depend of speed of machine??? FIXME
 
 
@@ -45,7 +40,7 @@ static gdouble play_until = G_MAXDOUBLE;
 
 /* MIDI in handling diversion to scheme scripts of MIDI in data */
 static gint *divert_midi_event;
-static gint divert_midi_id = 0; //id of the DenemoGUI which wants to intercept midi events
+static gint divert_midi_id = 0; //id of the DenemoProject which wants to intercept midi events
 
 static GQueue midi_queue = G_QUEUE_INIT;
 static gint
@@ -74,7 +69,7 @@ get_midiqueue (void)
 void
 update_position (smf_event_t * event)
 {
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
 
   if (event)
     {
@@ -98,32 +93,33 @@ update_position (smf_event_t * event)
 static void
 safely_add_track (smf_t * smf, smf_track_t * track)
 {
-  if (track->smf == NULL)
+    track->smf = NULL;
     smf_add_track (smf, track);
 }
 
 static void
 safely_track_remove_from_smf (smf_track_t * track)
 {
-  if (track->smf != NULL)
+  if (track->smf != NULL && (track->track_number>=1))
     smf_track_remove_from_smf (track);
+  track->smf = NULL;
 }
 
 static GString *callback_script = NULL;
 void
 start_playing (gchar * callback)
 {
-  smf_t *smf = Denemo.gui->si->smf;
+  smf_t *smf = Denemo.project->movement->smf;
   if (callback && *callback)
     callback_script = g_string_new (callback);
-  if (Denemo.gui->si->recorded_midi_track)
-    safely_add_track (Denemo.gui->si->smf, Denemo.gui->si->recorded_midi_track);
+  if (Denemo.project->movement->recorded_midi_track)
+    safely_add_track (Denemo.project->movement->smf, Denemo.project->movement->recorded_midi_track);
 
   set_start_and_end_objects_for_draw ();
   smf_rewind (smf);
-  gdouble start = (Denemo.gui->si->start_time/get_playback_speed()) - SHAVING;
+  gdouble start = (Denemo.project->movement->start_time/get_playback_speed()) - SHAVING;
   if(smf_seek_to_seconds (smf, (start>0.0)?start:0.0))
-    g_debug("smf_seek_to_seconds failed");
+    g_warning("smf_seek_to_seconds %f failed", start);
 
   initialize_until_time ();
 
@@ -150,6 +146,15 @@ update_playbutton_callback (gboolean paused)
   return FALSE;
 }
 
+static void
+finish_recording (void)
+{
+  if ((Denemo.project->midi_destination & MIDIRECORD))
+    {
+      Denemo.project->midi_destination ^= MIDIRECORD;
+      g_idle_add_full (G_PRIORITY_HIGH_IDLE, (GSourceFunc) show_midi_record_control, NULL, NULL);
+    }
+}
 void
 stop_playing ()
 {
@@ -157,9 +162,9 @@ stop_playing ()
   g_idle_add_full (G_PRIORITY_HIGH_IDLE, (GSourceFunc) update_playbutton_callback, GINT_TO_POINTER (is_paused ()), NULL);
   playing = FALSE;
   play_until = -G_MAXDOUBLE;
-  if (Denemo.gui->si && Denemo.gui->si->recorded_midi_track)
+  if (Denemo.project->movement && Denemo.project->movement->recorded_midi_track)
     {
-      safely_track_remove_from_smf (Denemo.gui->si->recorded_midi_track);
+      safely_track_remove_from_smf (Denemo.project->movement->recorded_midi_track);
       finish_recording ();
     }
   if (callback_script)
@@ -199,18 +204,18 @@ get_playuntil (void)
 void
 update_playback_start_time (double adjust)
 {
-  if (Denemo.gui && Denemo.gui->si)
+  if (Denemo.project && Denemo.project->movement)
     {
-      Denemo.gui->si->start_time += adjust;
+      Denemo.project->movement->start_time += adjust;
     }
 }
 
 double
 get_start_time ()
 {
-  if (Denemo.gui && Denemo.gui->si && (Denemo.gui->si->start_time > 0.0))
+  if (Denemo.project && Denemo.project->movement && (Denemo.project->movement->start_time > 0.0))
     {
-      return Denemo.gui->si->start_time;
+      return Denemo.project->movement->start_time;
     }
   else
     {
@@ -222,11 +227,11 @@ get_start_time ()
 double
 get_end_time ()
 {
-  if (Denemo.gui && Denemo.gui->si && Denemo.gui->si->smf)
+  if (Denemo.project && Denemo.project->movement && Denemo.project->movement->smf)
     {
-      if (Denemo.gui->si->end_time < 0.0)
-        Denemo.gui->si->end_time = smf_get_length_seconds (Denemo.gui->si->smf);
-      return Denemo.gui->si->end_time;
+      if (Denemo.project->movement->end_time < 0.0)
+        Denemo.project->movement->end_time = smf_get_length_seconds (Denemo.project->movement->smf);
+      return Denemo.project->movement->end_time;
     }
   else
     {
@@ -238,13 +243,13 @@ get_end_time ()
 smf_event_t *
 get_smf_event (double until_time)
 {
-  if (Denemo.gui == NULL || Denemo.gui->si == NULL || Denemo.gui->si->smf == NULL)
+  if (Denemo.project == NULL || Denemo.project->movement == NULL || Denemo.project->movement->smf == NULL)
     return NULL;
-  smf_t *smf = Denemo.gui->si->smf;
+  smf_t *smf = Denemo.project->movement->smf;
 
-  if (until_time > Denemo.gui->si->end_time)
+  if (until_time > Denemo.project->movement->end_time)
     {
-      until_time = Denemo.gui->si->end_time;
+      until_time = Denemo.project->movement->end_time;
     }
 
   for (;;)
@@ -267,7 +272,7 @@ get_smf_event (double until_time)
       event = smf_get_next_event (smf);
       if (event->midi_buffer_length > 3)
         {
-          g_warning ("Not Dropping event %d\n", event->midi_buffer_length);
+          g_warning ("Not Dropping event %d", event->midi_buffer_length);
           //continue;
         }
 
@@ -294,12 +299,12 @@ get_time ()
 void
 generate_midi ()
 {
-  if ((Denemo.gui->si->smf == NULL) || (Denemo.gui->si->smfsync != Denemo.gui->si->changecount))
+  if ((Denemo.project->movement->smf == NULL) || (Denemo.project->movement->smfsync != Denemo.project->movement->changecount))
     {
-      exportmidi (NULL, Denemo.gui->si, 0, 0);
+      exportmidi (NULL, Denemo.project->movement, 0, 0);
     }
 
-  if (Denemo.gui->si->smf == NULL)
+  if (Denemo.project->movement->smf == NULL)
     {
       g_critical ("Loading SMF failed.");
     }
@@ -341,7 +346,7 @@ get_obj_for_start_time (smf_t * smf, gdouble time)
     }
   while (event && (((event->midi_buffer[0] & 0xF0) == MIDI_NOTE_OFF) || !event->user_pointer));
   if (initial && smf_seek_to_event (smf, initial))
-      g_debug("smf_seek_to_event failed");  //if (event) g_print("sought for endObj %f found %f\n", time, event->time_seconds);
+      g_debug("smf_seek_to_event failed");  //if (event) g_debug("sought for endObj %f found %f\n", time, event->time_seconds);
   if (event)
     return (DenemoObject *) (event->user_pointer);
   return NULL;
@@ -365,7 +370,7 @@ get_obj_for_end_time (smf_t * smf, gdouble time)
     }
   while (event && (((event->midi_buffer[0] & 0xF0) == MIDI_NOTE_ON) || !event->user_pointer));
   if (initial && smf_seek_to_event (smf, initial))
-      g_debug("smf_seek_to_event failed");//if (event) g_print("sought for startObj %f found %f\n", time, event->time_seconds);
+      g_debug("smf_seek_to_event failed");//if (event) g_debug("sought for startObj %f found %f\n", time, event->time_seconds);
   if (event)
     return (DenemoObject *) (event->user_pointer);
   return NULL;
@@ -384,25 +389,25 @@ get_obj_for_end_time (smf_t * smf, gdouble time)
 static void
 action_note_into_score (gint mid_c_offset, gint enshift, gint octave)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   gui->last_source = INPUTMIDI;
-  gui->si->cursor_y = gui->si->staffletter_y = mid_c_offset;
-  gui->si->cursor_y += 7 * octave;
+  gui->movement->cursor_y = gui->movement->staffletter_y = mid_c_offset;
+  gui->movement->cursor_y += 7 * octave;
   shiftcursor (gui, mid_c_offset);
-  setenshift (gui->si, enshift);
+  setenshift (gui->movement, enshift);
   displayhelper (gui);
 }
 
 static void
 add_note_to_chord (gint mid_c_offset, gint enshift, gint octave)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   gui->last_source = INPUTMIDI;
-  gui->si->cursor_y = gui->si->staffletter_y = mid_c_offset;
-  gui->si->cursor_y += 7 * octave;
+  gui->movement->cursor_y = gui->movement->staffletter_y = mid_c_offset;
+  gui->movement->cursor_y += 7 * octave;
   insert_chordnote (gui);
   // shiftcursor(gui, mid_c_offset);
-  setenshift (gui->si, enshift);
+  setenshift (gui->movement, enshift);
   displayhelper (gui);
 }
 
@@ -414,16 +419,45 @@ typedef struct enharmonic
 } enharmonic;
 
 
-//Add the passed midi to a recording in Denemo.gui->si
-void
+void new_midi_recording (void) {
+  DenemoRecording *recording;
+  if(Denemo.project->movement->recording && (Denemo.project->movement->recording->type==DENEMO_RECORDING_MIDI))
+    {  
+      //FIXME a better name for the mutex which originally was just for midi data, but will work for audio data too.
+      recording = Denemo.project->movement->recording;
+      g_static_mutex_lock (&smfmutex);
+      Denemo.project->movement->recording = NULL;
+      g_static_mutex_unlock (&smfmutex);
+      g_free (recording->filename);
+      g_free (recording);
+      g_list_free_full (recording->notes, g_free);
+     } 
+  recording = (DenemoRecording *) g_malloc (sizeof (DenemoRecording));
+  recording->type = DENEMO_RECORDING_MIDI;
+  recording->samplerate = 44100;
+  Denemo.project->movement->recording = recording;
+}
+
+//Add the passed midi to a recording in Denemo.project->movement
+static void
 record_midi (gchar * buf, gdouble time)
 {
+  buf[0] |= 0xF; //here force the channel to 15 
   smf_event_t *event = smf_event_new_from_pointer (buf, 3);
   if (event && smf_event_is_valid (event))
     {
-      if (Denemo.gui->si->recorded_midi_track && ((smf_track_t *) Denemo.gui->si->recorded_midi_track)->smf)
+      if (Denemo.project->movement->recorded_midi_track && ((smf_track_t *) Denemo.project->movement->recorded_midi_track)->smf)
         {
-          smf_track_add_event_seconds (Denemo.gui->si->recorded_midi_track, event, time);
+           
+          smf_track_add_event_seconds (Denemo.project->movement->recorded_midi_track, event, time);
+          if(Denemo.project->movement->recording && noteon_key(event))
+            {
+                DenemoRecordedNote *note = g_malloc0(sizeof(DenemoRecordedNote));
+                note->timing = event->time_seconds * Denemo.project->movement->recording->samplerate;
+                notenum2enharmonic (noteon_key(event), &(note->mid_c_offset), &(note->enshift), &(note->octave));
+                note->event = event;
+                Denemo.project->movement->recording->notes = g_list_append (Denemo.project->movement->recording->notes, note);
+            }
         }
       else
         {
@@ -449,15 +483,15 @@ do_one_note (gint mid_c_offset, gint enshift, gint notenum)
       PushPosition (NULL, NULL);
       while (cursor_to_prev_note ())
         {
-          curobj = Denemo.gui->si->currentobject->data;
+          curobj = Denemo.project->movement->currentobject->data;
           if (!curobj->isinvisible)
             break;
           else
             non_printing_note = TRUE;
         }
-      if (Denemo.gui->si->currentobject)
+      if (Denemo.project->movement->currentobject)
         {
-          curobj = Denemo.gui->si->currentobject->data;
+          curobj = Denemo.project->movement->currentobject->data;
           if (non_printing_note)
             {
               if (!curobj->isinvisible)
@@ -468,7 +502,7 @@ do_one_note (gint mid_c_offset, gint enshift, gint notenum)
             PopPosition (NULL, NULL);// go to where we started, as there are no non-printing notes
         }          
        else
-				PopPosition (NULL, NULL);// go to where we started, as there are no non-printing notes		
+                PopPosition (NULL, NULL);// go to where we started, as there are no non-printing notes      
       action_note_into_score (mid_c_offset, enshift, notenum);
       
       if (Denemo.keyboard_state & ADDING_MASK)
@@ -482,9 +516,9 @@ static gboolean
 get_current (enharmonic * enote)
 {
   DenemoObject *curObj = NULL;
-  if (Denemo.gui->si->currentobject)
+  if (Denemo.project->movement->currentobject)
     {
-      curObj = Denemo.gui->si->currentobject->data;
+      curObj = Denemo.project->movement->currentobject->data;
       if (curObj && curObj->type == CHORD)
         {
           chord *thechord = (chord *) curObj->object;
@@ -504,15 +538,15 @@ static gboolean
 get_previous (enharmonic * enote)
 {
   DenemoObject *curObj = NULL;
-  if (Denemo.gui->si->currentobject)
+  if (Denemo.project->movement->currentobject)
     {
-      if (Denemo.gui->si->currentobject->prev)
-        curObj = Denemo.gui->si->currentobject->prev->data;
+      if (Denemo.project->movement->currentobject->prev)
+        curObj = Denemo.project->movement->currentobject->prev->data;
       else
         {
-          if (Denemo.gui->si->currentmeasure->prev && Denemo.gui->si->currentmeasure->prev->data)
+          if (Denemo.project->movement->currentmeasure->prev && Denemo.project->movement->currentmeasure->prev->data)
             {
-              curObj = g_list_last (Denemo.gui->si->currentmeasure->prev->data)->data;
+              curObj = g_list_last (Denemo.project->movement->currentmeasure->prev->data)->data;
             }
         }
     }
@@ -536,43 +570,43 @@ static gint
 midiaction (gint notenum)
 {
 
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (gui == NULL)
     return TRUE;
-  if (gui->si == NULL)
+  if (gui->movement == NULL)
     return TRUE;
-  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) gui->movement->currentstaff->data;
   enharmonic enote, prevenote;
   gboolean have_previous;
-  //g_print("Keyboard state %x, mask %x %x %x\n", Denemo.keyboard_state, CHECKING_MASK, GDK_CONTROL_MASK, GDK_MOD2_MASK);
+  //g_debug("Keyboard state %x, mask %x %x %x\n", Denemo.keyboard_state, CHECKING_MASK, GDK_CONTROL_MASK, GDK_MOD2_MASK);
   notenum2enharmonic (notenum, &enote.mid_c_offset, &enote.enshift, &enote.octave);
-  if (Denemo.gui->si->cursor_appending)
+  if (Denemo.project->movement->cursor_appending)
     have_previous = get_current (&prevenote);
   else
     have_previous = get_previous (&prevenote);
 
   if (!(Denemo.keyboard_state & CHECKING_MASK))
-    stage_undo (gui->si, ACTION_STAGE_END);     //undo is a queue so this is the end :)
+    stage_undo (gui->movement, ACTION_STAGE_END);     //undo is a queue so this is the end :)
 
   if ((gui->mode & INPUTEDIT) || (Denemo.keyboard_state & CHECKING_MASK))
     {
       static gboolean beep = FALSE;
       gboolean is_tied = FALSE;
-      gint measure = gui->si->currentmeasurenum;
-      if (Denemo.gui->si->currentobject)
+      gint measure = gui->movement->currentmeasurenum;
+      if (Denemo.project->movement->currentobject)
         {
-          DenemoObject *curObj = Denemo.gui->si->currentobject->data;
+          DenemoObject *curObj = Denemo.project->movement->currentobject->data;
           if (curObj->type == CHORD)
             {
               do
                 {
-                  curObj = Denemo.gui->si->currentobject->data;
+                  curObj = Denemo.project->movement->currentobject->data;
                   chord *thechord = (chord *) curObj->object;
                   is_tied = thechord->is_tied;
 
 //#define check_midi_note(a,b,c,d) ((a->mid_c_offset==b)&&(a->enshift==c))?playnote(a,curstaffstruct->midi_channel):gdk_beep();
 
-                  //g_print("check %d %d %d %d %d\n", a->mid_c_offset, a->enshift, b, c, d);
+                  //g_debug("check %d %d %d %d %d\n", a->mid_c_offset, a->enshift, b, c, d);
                   if ((Denemo.keyboard_state & CHECKING_MASK) && thechord->notes)
                     {
                       //later - find note nearest cursor and
@@ -595,24 +629,24 @@ midiaction (gint notenum)
                       do_one_note (enote.mid_c_offset, enote.enshift, enote.octave);
 
                     }
-                  if (Denemo.gui->si->cursor_appending)
+                  if (Denemo.project->movement->cursor_appending)
                     break;
                 }
               while ((!(Denemo.keyboard_state & ADDING_MASK)) && next_editable_note () && is_tied);
             }
           else //there is a current object that is not a chord
             {
-              if (gui->si->cursor_appending) {
+              if (gui->movement->cursor_appending) {
                 do_one_note (enote.mid_c_offset, enote.enshift, enote.octave);
                 next_editable_note ();//if we have gone back from an appending position after a non-chord we need this
-							}
+                            }
               else
                 gdk_beep ();
             }
           if (gui->mode & INPUTRHYTHM)
             {
-              //g_print("measure was %d now %d with appending %d\n", measure, gui->si->currentmeasurenum, gui->si->cursor_appending);
-              if (!beep && (measure != gui->si->currentmeasurenum) && !gui->si->cursor_appending)
+              //g_debug("measure was %d now %d with appending %d\n", measure, gui->movement->currentmeasurenum, gui->movement->cursor_appending);
+              if (!beep && (measure != gui->movement->currentmeasurenum) && !gui->movement->cursor_appending)
                 beep = TRUE;
               else if (beep)
                 signal_measure_end (), beep = FALSE;
@@ -630,7 +664,7 @@ midiaction (gint notenum)
     }
   if (!(Denemo.keyboard_state & CHECKING_MASK))
     {
-      stage_undo (gui->si, ACTION_STAGE_START);
+      stage_undo (gui->movement, ACTION_STAGE_START);
     }
   gtk_widget_queue_draw (Denemo.scorearea);     //just for advancing the cursor.
   if (!(Denemo.keyboard_state & CHECKING_MASK))
@@ -676,7 +710,7 @@ adjust_midi_velocity (gchar * buf, gint percent)
         }
       if (command == MIDI_NOTE_OFF)
         {
-          //g_print("after %f seconds\n", get_time()-times[notenumber]);
+          //g_debug("after %f seconds\n", get_time()-times[notenumber]);
 
           buf[0] = MIDI_NOTE_ON;        //or the channel here
           buf[2] = 60 / exp ((get_time () - times[notenumber]) * 1);    //scale according to the time
@@ -703,7 +737,7 @@ process_midi_event (gchar * buf)
           next_editable_note ();
         }
       set_midi_in_status ();
-      displayhelper (Denemo.gui);
+      displayhelper (Denemo.project);
     }
   if ((0xFFFFFF & *(gint *) buf) == 0)
     {
@@ -715,7 +749,7 @@ process_midi_event (gchar * buf)
           divert_midi_event = NULL;
           gtk_main_quit ();
         }
-      //g_print("queue emptied %d\n", g_queue_get_length(&midi_queue));
+      //g_debug("queue emptied %d\n", g_queue_get_length(&midi_queue));
     }
   else
     {
@@ -743,7 +777,7 @@ process_midi_event (gchar * buf)
                       next_editable_note ();
                     }
                   set_midi_in_status ();
-                  displayhelper (Denemo.gui);
+                  displayhelper (Denemo.project);
                 }
             }
         }
@@ -763,15 +797,15 @@ process_midi_event (gchar * buf)
 void
 initialize_until_time (void)
 {
-  if ((Denemo.gui->midi_destination & MIDIPLAYALONG) && Denemo.gui->si->currentobject)
+  if ((Denemo.project->midi_destination & MIDIPLAYALONG) && Denemo.project->movement->currentobject)
     {
-      DenemoObject *obj = Denemo.gui->si->currentobject->data;
+      DenemoObject *obj = Denemo.project->movement->currentobject->data;
       if (obj->type == CHORD)
         {
           chord *thechord = obj->object;
           if (thechord->notes)
             {
-              play_until = obj->earliest_time - SHAVING;        //g_print("initial until %f\n", play_until);
+              play_until = obj->earliest_time - SHAVING;        //g_debug("initial until %f\n", play_until);
             }
         }
     }
@@ -785,14 +819,14 @@ initialize_until_time (void)
 static void
 advance_until_time (gchar * buf)
 {
-  if (Denemo.gui->si->currentobject)
+  if (Denemo.project->movement->currentobject)
     {
-      DenemoObject *obj = Denemo.gui->si->currentobject->data;
+      DenemoObject *obj = Denemo.project->movement->currentobject->data;
       if (obj->type != CHORD)
         if (cursor_to_next_chord ())
-          obj = Denemo.gui->si->currentobject->data;
+          obj = Denemo.project->movement->currentobject->data;
 
-      if (Denemo.gui->si->currentobject && obj->type == CHORD)
+      if (Denemo.project->movement->currentobject && obj->type == CHORD)
         {
           chord *thechord = obj->object;
           if (thechord->notes)
@@ -801,11 +835,11 @@ advance_until_time (gchar * buf)
               if (((buf[0] & 0xf0) == MIDI_NOTE_ON) && buf[2] && buf[1] == (dia_to_midinote (thenote->mid_c_offset) + thenote->enshift))
                 {
                   gdouble thetime = get_time ();
-                  Denemo.gui->si->start_player = thetime - obj->earliest_time;
+                  Denemo.project->movement->start_player = thetime - obj->earliest_time;
 
                   if (thechord->is_tied && cursor_to_next_note ())
                     {
-                      obj = Denemo.gui->si->currentobject->data;
+                      obj = Denemo.project->movement->currentobject->data;
                     }
                   //IF THE NEXT OBJ IS A REST ADVANCE OVER IT/THEM
                   do
@@ -817,10 +851,10 @@ advance_until_time (gchar * buf)
                         }
                       else
                         {
-                          obj = Denemo.gui->si->currentobject->data;
+                          obj = Denemo.project->movement->currentobject->data;
                           thechord = obj->object;
                           play_until = obj->earliest_time - SHAVING;
-                          //g_print("play until %f\n", play_until);
+                          //g_debug("play until %f\n", play_until);
                         }
                     }
                   while (!thechord->notes);
@@ -837,15 +871,15 @@ advance_until_time (gchar * buf)
 static void
 adjust_midi_channel (gchar * buf)
 {
-  DenemoStaff *curstaffstruct = (DenemoStaff *) Denemo.gui->si->currentstaff->data;
+  DenemoStaff *curstaffstruct = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
   gint channel = curstaffstruct->midi_channel;
-  if ((buf[0] & SYS_EXCLUSIVE_MESSAGE1) == NOTE_ON)
+  if ((buf[0] & SYS_EXCLUSIVE_MESSAGE1) == MIDI_NOTE_ON)
     {
-      buf[0] = NOTE_ON | channel;
+      buf[0] = MIDI_NOTE_ON | channel;
     }
-  else if ((buf[0] & SYS_EXCLUSIVE_MESSAGE1) == NOTE_OFF)
+  else if ((buf[0] & SYS_EXCLUSIVE_MESSAGE1) == MIDI_NOTE_OFF)
     {
-      buf[0] = NOTE_OFF | channel;
+      buf[0] = MIDI_NOTE_OFF | channel;
     }
 }
 
@@ -862,8 +896,8 @@ play_adjusted_midi_event (gchar * buf)
 void
 handle_midi_event (gchar * buf)
 {
-  //g_print("%x : ready %d %x queue %d\n", midi_capture_on, divert_midi_event!=NULL, (0xFFFFFF & *(gint*)buf), g_queue_get_length(&midi_queue));
-  if (midi_capture_on && divert_midi_id == Denemo.gui->id)
+  //g_debug("%x : ready %d %x queue %d\n", midi_capture_on, divert_midi_event!=NULL, (0xFFFFFF & *(gint*)buf), g_queue_get_length(&midi_queue));
+  if (midi_capture_on && divert_midi_id == Denemo.project->id)
     {
       // this is only good for one endianness - FIXME ??
       if (divert_midi_event)
@@ -878,14 +912,14 @@ handle_midi_event (gchar * buf)
         }
       return;                   //this *is* reached
     }
-  if ((Denemo.gui->midi_destination & MIDIRECORD) || (Denemo.gui->midi_destination & (MIDIPLAYALONG | MIDICONDUCT)))
+  if ((Denemo.project->midi_destination & MIDIRECORD) || (Denemo.project->midi_destination & (MIDIPLAYALONG | MIDICONDUCT)))
     {
-      if (Denemo.gui->midi_destination & MIDIRECORD)
+      if (Denemo.project->midi_destination & MIDIRECORD)
         record_midi (buf, get_playback_time ());
-      if (Denemo.gui->midi_destination & (MIDIPLAYALONG))
-        advance_until_time (buf);
+      if (Denemo.project->midi_destination & (MIDIPLAYALONG))
+        advance_until_time (buf);//FIXME is this thread-safe????
       else
-        play_midi_event (DEFAULT_BACKEND, 0, (guchar *) buf);
+        play_adjusted_midi_event (buf);//play_midi_event (DEFAULT_BACKEND, 0, (guchar *) buf);
     }
   else
     {
@@ -915,7 +949,7 @@ intercept_midi_event (gint * midi)
   if (g_queue_is_empty (&midi_queue))
     {
       divert_midi_event = midi;
-      divert_midi_id = Denemo.gui->id;
+      divert_midi_id = Denemo.project->id;
       set_midi_capture (TRUE);
       gtk_main ();
       divert_midi_event = NULL;
@@ -924,7 +958,7 @@ intercept_midi_event (gint * midi)
   else
     {
       *midi = (0xFFFFFF & get_midiqueue ());
-      //g_print("getting from queue %x\n", *midi);
+      //g_debug("getting from queue %x\n", *midi);
     }
   return TRUE;
 }
@@ -939,7 +973,7 @@ get_midi_channel (DenemoStaff * staff)
     }
   else
     {
-      gint tracknumber = Denemo.gui->si->currentstaffnum - 1;
+      gint tracknumber = Denemo.project->movement->currentstaffnum - 1;
       tracknumber = (tracknumber >= 9) ? tracknumber + 1 : tracknumber;
       return tracknumber & 0xF;
     }
@@ -1007,7 +1041,7 @@ change_tuning (gdouble * cents)
 int
 noteon_key (smf_event_t * event)
 {
-  if ((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1) == NOTE_ON)
+  if ((event->midi_buffer[0] & SYS_EXCLUSIVE_MESSAGE1) == MIDI_NOTE_ON)
     return event->midi_buffer[1];
   return 0;
 }
