@@ -70,7 +70,7 @@ offset_from_height (gdouble height, enum clefs clef)
 
 
 static gdouble
-get_click_height (DenemoGUI * gui, gdouble y)
+get_click_height (DenemoProject * gui, gdouble y)
 {
   gdouble click_height;
   gint staffs_from_top;
@@ -79,18 +79,18 @@ get_click_height (DenemoGUI * gui, gdouble y)
   DenemoStaff *staff;
   gint extra_space = 0;
   gint space_below = 0;
-  curstaff = g_list_nth (gui->si->thescore, gui->si->top_staff - 1);
+  curstaff = g_list_nth (gui->movement->thescore, gui->movement->top_staff - 1);
 
-  if (!(((DenemoStaff *) (gui->si->currentstaff->data))->voicecontrol & DENEMO_PRIMARY))
+  if (!(((DenemoStaff *) (gui->movement->currentstaff->data))->voicecontrol & DENEMO_PRIMARY))
     staffs_from_top--;
 
-  for (curstaff = g_list_nth (gui->si->thescore, gui->si->top_staff - 1); curstaff; curstaff = curstaff->next)
+  for (curstaff = g_list_nth (gui->movement->thescore, gui->movement->top_staff - 1); curstaff; curstaff = curstaff->next)
     {
-      //g_print("before extra space %d\n", extra_space);
+      //g_debug("before extra space %d\n", extra_space);
       staff = (DenemoStaff *) curstaff->data;
       if (staff->voicecontrol & DENEMO_PRIMARY)
         extra_space += (staff->space_above) + space_below;
-      if (curstaff == gui->si->currentstaff)
+      if (curstaff == gui->movement->currentstaff)
         break;
 
       if (staff->voicecontrol & DENEMO_PRIMARY)
@@ -100,11 +100,11 @@ get_click_height (DenemoGUI * gui, gdouble y)
           staffs_from_top++;
         }
       space_below = MAX (space_below, ((staff->space_below) + (staff->verses ? LYRICS_HEIGHT : 0)));
-      //g_print("after extra space %d space_below %d\n", extra_space, space_below);
+      //g_debug("after extra space %d space_below %d\n", extra_space, space_below);
     }
 
-  click_height = y - (gui->si->staffspace * staffs_from_top + gui->si->staffspace / 4 + extra_space);
-  //  g_print("top staff is %d total %d staffs from top is %d click %f\n", gui->si->top_staff, extra_space, staffs_from_top, click_height);
+  click_height = y - (gui->movement->staffspace * staffs_from_top + gui->movement->staffspace / 4 + extra_space);
+  //g_debug("top staff is %d total %d staffs from top is %d click %f\n", gui->movement->top_staff, extra_space, staffs_from_top, click_height);
 
   return click_height;
 
@@ -117,12 +117,12 @@ get_click_height (DenemoGUI * gui, gdouble y)
  *
  */
 void
-set_cursor_y_from_click (DenemoGUI * gui, gdouble y)
+set_cursor_y_from_click (DenemoProject * gui, gdouble y)
 {
   /* Click height relative to the top of the staff.  */
   gdouble click_height = get_click_height (gui, y);
-  gui->si->cursor_y = offset_from_height (click_height, (enum clefs) gui->si->cursorclef);
-  gui->si->staffletter_y = offsettonumber (gui->si->cursor_y);
+  gui->movement->cursor_y = offset_from_height (click_height, (enum clefs) gui->movement->cursorclef);
+  gui->movement->staffletter_y = offsettonumber (gui->movement->cursor_y);
 }
 
 struct placement_info
@@ -133,16 +133,17 @@ struct placement_info
   objnode *the_obj;
   gboolean nextmeasure;
   gboolean offend;              //TRUE when the user has clicked beyond the last note, taking you into appending
+  gboolean at_edge; //TRUE when user clicked close (CURSOR_AT_EDGE) to right hand edge of scorearea.
 };
-
+#define CURSOR_AT_EDGE (60)
 /* find the primary staff of the current staff, return its staffnum */
 static gint
-primary_staff (DenemoScore * si)
+primary_staff (DenemoMovement * si)
 {
   GList *curstaff;
   for (curstaff = si->currentstaff; curstaff && !(((DenemoStaff *) curstaff->data)->voicecontrol & DENEMO_PRIMARY); curstaff = curstaff->prev)
     ;                           //do nothing
-  //g_print("The position is %d\n", 1+g_list_position(si->thescore, curstaff));
+  //g_debug("The position is %d\n", 1+g_list_position(si->thescore, curstaff));
   return 1 + g_list_position (si->thescore, curstaff);
 }
 
@@ -150,7 +151,7 @@ primary_staff (DenemoScore * si)
 /* find which staff in si the height y lies in, return the staff number (not counting non-primary staffs ie voices) */
 
 static gint
-staff_at (gint y, DenemoScore * si)
+staff_at (gint y, DenemoMovement * si)
 {
   GList *curstaff;
   gint space = 0;
@@ -163,7 +164,7 @@ staff_at (gint y, DenemoScore * si)
       count++;
       if (staff->voicecontrol & DENEMO_PRIMARY)
         space += (staff)->space_above + (staff)->space_below + si->staffspace;
-      //g_print("y %d and space %d count = %d\n",y,space, count);
+      //g_debug("y %d and space %d count = %d\n",y,space, count);
     }
 
   if (y <= 1)
@@ -181,7 +182,7 @@ staff_at (gint y, DenemoScore * si)
 static void
 get_placement_from_coordinates (struct placement_info *pi, gdouble x, gdouble y, gint leftmeasurenum, gint rightmeasurenum, gint scale)
 {
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   GList *mwidthiterator = g_list_nth (si->measurewidths,
                                       leftmeasurenum - 1);
   objnode *obj_iterator;
@@ -193,21 +194,22 @@ get_placement_from_coordinates (struct placement_info *pi, gdouble x, gdouble y,
       g_critical ("Array of measurewidths too small for leftmeasure %d\n", leftmeasurenum);
       return;
     }
+  pi->at_edge = (get_widget_width (Denemo.scorearea) -x) < CURSOR_AT_EDGE;
   pi->staff_number = staff_at ((gint) y, si);
-  //g_print("L/R %d %d got staff number %d\n", leftmeasurenum, rightmeasurenum, pi->staff_number); 
+  //g_debug("L/R %d %d got staff number %d\n", leftmeasurenum, rightmeasurenum, pi->staff_number); 
   pi->measure_number = leftmeasurenum;
   if (scale)
     x_to_explain = (x_to_explain * scale) / 100;
   x_to_explain -= (KEY_MARGIN + si->maxkeywidth + SPACE_FOR_TIME);
 
-  //g_print("Explaining %d\n", x_to_explain);
+  //g_debug("Explaining %d\n", x_to_explain);
   while (x_to_explain > GPOINTER_TO_INT (mwidthiterator->data) && pi->measure_number < rightmeasurenum)
     {
       x_to_explain -= (GPOINTER_TO_INT (mwidthiterator->data) + SPACE_FOR_BARLINE);
       mwidthiterator = mwidthiterator->next;
       pi->measure_number++;
     }
-  //g_print("got to measure %d\n", pi->measure_number);
+  //g_debug("got to measure %d\n", pi->measure_number);
   pi->nextmeasure = ((si->system_height > 0.5 || x_to_explain > GPOINTER_TO_INT (mwidthiterator->data)) && pi->measure_number >= rightmeasurenum);
 
   pi->the_staff = g_list_nth (si->thescore, pi->staff_number - 1);
@@ -253,7 +255,7 @@ get_placement_from_coordinates (struct placement_info *pi, gdouble x, gdouble y,
                 pi->offend = TRUE, pi->cursor_x++;
             }
         }
-      //g_print("got to cursor x %d\n", pi->cursor_x);
+      //g_debug("got to cursor x %d\n", pi->cursor_x);
     }
 }
 
@@ -263,7 +265,7 @@ assign_cursor (guint state, guint cursor_num)
 {
   guint *cursor_state = g_new (guint, 1);
   *cursor_state = state;
-  //g_print("Storing cursor %x for state %x in hash table %p\n", cursor_num, state, Denemo.map->cursors );  
+  //g_debug("Storing cursor %x for state %x in hash table %p\n", cursor_num, state, Denemo.map->cursors );  
   GdkCursor *cursor = gdk_cursor_new (cursor_num);
   g_assert (cursor);
   g_hash_table_insert (Denemo.map->cursors, cursor_state, cursor);
@@ -274,7 +276,7 @@ set_cursor_for (guint state)
 {
   gint the_state = state;
   GdkCursor *cursor = g_hash_table_lookup (Denemo.map->cursors, &the_state);
-  //g_print("looked up %x in %p got cursor %p which is number %d\n", state, Denemo.map->cursors,  cursor, cursor?cursor->type:-1);
+  //g_debug("looked up %x in %p got cursor %p which is number %d\n", state, Denemo.map->cursors,  cursor, cursor?cursor->type:-1);
   if (cursor)
     gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), cursor);
   else
@@ -312,7 +314,7 @@ mouse_shortcut_name (gint mod, mouse_gesture gesture, gboolean left)
   GString *ret = g_string_new ((gesture == GESTURE_PRESS) ? (left ? "PrsL" : "PrsR") : ((gesture == GESTURE_RELEASE) ? (left ? "RlsL" : "RlsR") : (left ? "MveL" : "MveR")));
 
   append_modifier_name (ret, mod);
-  //g_print("Returning %s for mod %d\n", ret->str, mod);
+  //g_debug("Returning %s for mod %d\n", ret->str, mod);
   return ret;
 
 }
@@ -357,7 +359,7 @@ perform_command (gint modnum, mouse_gesture press, gboolean left)
         KeyPlusMouseGestureShow(modname->str, command_idx);
       
       execute_callback_from_idx (Denemo.map, command_idx);
-      displayhelper (Denemo.gui);
+      displayhelper (Denemo.project);
     }
   g_string_free (modname, TRUE);
 }
@@ -369,7 +371,7 @@ static gboolean dragging_tempo = FALSE;
 
 
 static gboolean
-change_staff (DenemoScore * si, gint num, GList * staff)
+change_staff (DenemoMovement * si, gint num, GList * staff)
 {
   if (si->currentstaffnum == num)
     return FALSE;
@@ -383,15 +385,15 @@ change_staff (DenemoScore * si, gint num, GList * staff)
 static void
 transform_coords (double *x, double *y)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
 
   gint application_height = get_widget_height (Denemo.scorearea);
-  gint line_height = application_height * gui->si->system_height;
+  gint line_height = application_height * gui->movement->system_height;
   gint line_num = ((int) *y) / line_height;
   *y -= line_num * line_height;
-  *x /= gui->si->zoom;
-  *y /= gui->si->zoom;
-  // *x += ((double)line_num * gui->si->widthtoworkwith / ((int)(1/gui->si->system_height))) - 1.0* (line_num?(double)LEFT_MARGIN:0.0);
+  *x /= gui->movement->zoom;
+  *y /= gui->movement->zoom;
+  // *x += ((double)line_num * gui->movement->widthtoworkwith / ((int)(1/gui->movement->system_height))) - 1.0* (line_num?(double)LEFT_MARGIN:0.0);
 }
 
 
@@ -405,7 +407,7 @@ scorearea_leave_event (GtkWidget * widget, GdkEventCrossing * event)
 gint
 scorearea_enter_event (GtkWidget * widget, GdkEventCrossing * event)
 {
-//g_print("start the enter with ks = %x and state %x\n", Denemo.keyboard_state, event->state);
+//g_debug("start the enter with ks = %x and state %x\n", Denemo.keyboard_state, event->state);
   if (event->state & GDK_CONTROL_MASK)
     Denemo.keyboard_state |= GDK_CONTROL_MASK;
   else
@@ -422,7 +424,7 @@ scorearea_enter_event (GtkWidget * widget, GdkEventCrossing * event)
   else
     Denemo.keyboard_state &= ~(CHORD_MASK | GDK_MOD1_MASK);
 #endif
-//      g_print("end the enter with ks %x (values  %x %x)\n", event->state, ~GDK_CONTROL_MASK, Denemo.keyboard_state & (~GDK_CONTROL_MASK) );
+//      g_debug("end the enter with ks %x (values  %x %x)\n", event->state, ~GDK_CONTROL_MASK, Denemo.keyboard_state & (~GDK_CONTROL_MASK) );
   set_midi_in_status ();
   return FALSE;                 //allow other handlers 
 }
@@ -434,47 +436,72 @@ scorearea_enter_event (GtkWidget * widget, GdkEventCrossing * event)
 gint
 scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (gui == NULL || gui->si == NULL)
+  DenemoProject *gui = Denemo.project;
+  if (gui == NULL || gui->movement == NULL)
     return FALSE;
   if (Denemo.scorearea == NULL)
     return FALSE;
   gint allocated_height = get_widget_height (Denemo.scorearea);
-  gint line_height = allocated_height * gui->si->system_height;
+  gint line_height = allocated_height * gui->movement->system_height;
   
   if (event->y < 0)
     event->y = 0.0;
   gint line_num = ((int) event->y) / line_height;
 
-  if(gui->si->audio && dragging_audio)
-	{		
-		gui->si->audio->leadin -= 500*(event->x_root - last_event_x)/gui->si->zoom;//g_print("%d %d => %d\n", (int)(10*last_event_x), (int)(10*event->x_root), (int)(10*last_event_x) - (int)(10*event->x_root));
-		last_event_x = event->x_root;
-		update_leadin_widget ( gui->si->audio->leadin/(double)gui->si->audio->samplerate);
-		gtk_widget_queue_draw(Denemo.scorearea);
-		return TRUE; 
-	}
-  if(gui->si->audio && dragging_tempo)
-	{		
-		gdouble change = (event->x_root - last_event_x)/gui->si->zoom;
-		last_event_x = event->x_root;
-		struct placement_info pi;
-		get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
-		change /= pi.measure_number;
-		update_tempo_widget ( change);
-		gtk_widget_queue_draw(Denemo.scorearea);
-		return TRUE; 
-	}
+  if(gui->movement->recording && dragging_audio)
+    {   
+        if(gui->movement->recording->type == DENEMO_RECORDING_MIDI)
+        {
+            #if 0
+            //This is moving only the NoteOn, so it could be moved later than the note off, and indeed later than a later note in the stream 
+            //- quite a bit more work needed to drag MIDI to correct the timing.
+            smf_event_t *midievent;
+            GList *marked_onset = gui->movement->marked_onset;
+            if(marked_onset)
+                {
+                midievent = ((DenemoRecordedNote *)marked_onset->data)->event;
+                gint shift =  2500*(event->x_root - last_event_x)/gui->movement->zoom;
+                g_debug (" %f (%f %f)",shift/(double)gui->movement->recording->samplerate, 
+                    midievent->time_seconds,
+                    ((DenemoRecordedNote *)marked_onset->data)->timing/(double)gui->movement->recording->samplerate) ;
+
+                ((DenemoRecordedNote *)marked_onset->data)->timing += shift;
+                
+                midievent->time_seconds += shift/(double)gui->movement->recording->samplerate;
+                }
+            #endif
+            g_warning("No drag for MIDI yet");
+            return TRUE;
+        }
+
+        gui->movement->recording->leadin -= 500*(event->x_root - last_event_x)/gui->movement->zoom;//g_debug("%d %d => %d\n", (int)(10*last_event_x), (int)(10*event->x_root), (int)(10*last_event_x) - (int)(10*event->x_root));
+        last_event_x = event->x_root;
+        update_leadin_widget ( gui->movement->recording->leadin/(double)gui->movement->recording->samplerate);
+        gtk_widget_queue_draw(Denemo.scorearea);
+        return TRUE; 
+    }
+  if(gui->movement->recording && dragging_tempo)
+    {       
+        gdouble change = (event->x_root - last_event_x)/gui->movement->zoom;
+        last_event_x = event->x_root;
+        struct placement_info pi;
+        get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+        change /= pi.measure_number;
+        update_tempo_widget ( change);
+        set_tempo (); exportmidi (NULL, gui->movement, 0, 0);  
+        gtk_widget_queue_draw(Denemo.scorearea);
+        return TRUE; 
+    }
 #define DENEMO_MINIMUM_SYSTEM_HEIGHT (0.01)
 
 
   if (dragging_separator)
     {
-      gui->si->system_height = event->y / get_widget_height (Denemo.scorearea);
-      if (gui->si->system_height < DENEMO_MINIMUM_SYSTEM_HEIGHT)
-        gui->si->system_height = DENEMO_MINIMUM_SYSTEM_HEIGHT;
-      if (gui->si->system_height > 1.0)
-        gui->si->system_height = 1.0;
+      gui->movement->system_height = event->y / get_widget_height (Denemo.scorearea);
+      if (gui->movement->system_height < DENEMO_MINIMUM_SYSTEM_HEIGHT)
+        gui->movement->system_height = DENEMO_MINIMUM_SYSTEM_HEIGHT;
+      if (gui->movement->system_height > 1.0)
+        gui->movement->system_height = 1.0;
       scorearea_configure_event (Denemo.scorearea, NULL);
       gtk_widget_queue_draw (Denemo.scorearea);
       return TRUE;
@@ -486,14 +513,14 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
     gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR));       //FIXME? does this take time/hog memory
 
   transform_coords (&event->x, &event->y);
-  //  g_print("Marked %d\n", gui->si->markstaffnum);
+  //g_debug("Marked %d\n", gui->movement->markstaffnum);
   if (gui->lefts[line_num] == 0)
     return TRUE;
 
 
 
 
-  if (lh_down || (selecting && gui->si->markstaffnum))
+  if (lh_down || (selecting && gui->movement->markstaffnum))
     {
       struct placement_info pi;
       pi.the_staff = NULL;
@@ -505,20 +532,20 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
         return TRUE;            //could not place the cursor
       if (pi.the_measure != NULL)
         {                       /*don't place cursor in a place that is not there */
-          change_staff (gui->si, pi.staff_number, pi.the_staff);
-          gui->si->currentmeasurenum = pi.measure_number;
-          gui->si->currentmeasure = pi.the_measure;
-          gui->si->currentobject = pi.the_obj;
-          gui->si->cursor_x = pi.cursor_x;
-          gui->si->cursor_appending = (gui->si->cursor_x == (gint) (g_list_length ((objnode *) gui->si->currentmeasure->data)));
+          change_staff (gui->movement, pi.staff_number, pi.the_staff);
+          gui->movement->currentmeasurenum = pi.measure_number;
+          gui->movement->currentmeasure = pi.the_measure;
+          gui->movement->currentobject = pi.the_obj;
+          gui->movement->cursor_x = pi.cursor_x;
+          gui->movement->cursor_appending = (gui->movement->cursor_x == (gint) (g_list_length ((objnode *) gui->movement->currentmeasure->data)));
 
           set_cursor_y_from_click (gui, event->y);
           if (lh_down & !selecting)
             {
-              set_mark (gui);
+              set_mark (NULL, NULL);
               selecting = TRUE;
             }
-          calcmarkboundaries (gui->si);
+          calcmarkboundaries (gui->movement);
           if (event->state & (GDK_BUTTON1_MASK | GDK_BUTTON2_MASK | GDK_BUTTON3_MASK))
             perform_command (event->state, GESTURE_MOVE, event->state & GDK_BUTTON1_MASK);
 
@@ -527,7 +554,7 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
         }
     }
 
-  if (Denemo.gui->midi_destination & MIDICONDUCT)
+  if (Denemo.project->midi_destination & MIDICONDUCT)
     {
       advance_time (0.01);
       return TRUE;
@@ -543,16 +570,16 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
 gint
 scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (gui == NULL || gui->si == NULL)
+  DenemoProject *gui = Denemo.project;
+  if (gui == NULL || gui->movement == NULL)
     return FALSE;
   gboolean left = (event->button != 3);
   //if the cursor is at a system separator start dragging it
   gint allocated_height = get_widget_height (Denemo.scorearea);
-  gint line_height = allocated_height * gui->si->system_height;
+  gint line_height = allocated_height * gui->movement->system_height;
   gint line_num = ((int) event->y) / line_height;
   last_event_x = event->x_root;
-  //g_print("diff %d\n", line_height - ((int)event->y)%line_height);
+  //g_debug("diff %d\n", line_height - ((int)event->y)%line_height);
   if (dragging_separator == FALSE)
     if (line_height - ((int) event->y - 8) % line_height < 12)
       {
@@ -564,45 +591,48 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
       }
   dragging_separator = FALSE;
   
-  if(gui->si->audio)
-	{
-	 // g_print("audio %f %f\n", event->x, event->y);
+  if(gui->movement->recording)
+    {
+     //g_debug("audio %f %f\n", event->x, event->y);
 
 
-	  if(event->y < 20*gui->si->zoom /* see draw.c for this value, the note onsets are drawn in the top 20 pixels */)
-		{
-			if (event->type==GDK_2BUTTON_PRESS) 
-				{	
-					gui->si->marked_onset_position = (gint)event->x/gui->si->zoom;
-					if(gui->si->marked_onset_position < KEY_MARGIN + SPACE_FOR_TIME + gui->si->maxkeywidth) {
-						 MouseGestureShow(_("Double Click Note Onset"), _("This represents detected note onsets which occur\nbefore the start of the score.\nIf they are just noise,\nor if you are working on just a portion of the audio that is ok.\nOtherwise drag with left mouse button to synchronize\nwith the start of the score."),
+      if(event->y < 20*gui->movement->zoom /* see draw.c for this value, the note onsets are drawn in the top 20 pixels */)
+        {
+            if (event->type==GDK_2BUTTON_PRESS) 
+                {   
+                    gui->movement->marked_onset_position = (gint)event->x/gui->movement->zoom;
+                    if(gui->movement->marked_onset_position < KEY_MARGIN + SPACE_FOR_TIME + gui->movement->maxkeywidth) {
+                         if (Denemo.prefs.learning)
+                            MouseGestureShow(_("Double Click Note Onset"), _("This represents detected note onsets which occur\nbefore the start of the score.\nIf they are just noise,\nor if you are working on just a portion of the audio that is ok.\nOtherwise drag with left mouse button to synchronize\nwith the start of the score."),
           MouseGesture);
-						
-					}
-					gtk_widget_queue_draw(Denemo.scorearea);
-					return TRUE;
-				} else 
-				{
-					gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (left?GDK_SB_H_DOUBLE_ARROW:GDK_X_CURSOR));
-					left? (dragging_audio = TRUE) : (dragging_tempo = TRUE);
-					 left? MouseGestureShow(_("Left Drag Note Onset"), _("This moves the audio to synchronize the start with the score.\nYou can use the Leadin button for this too."),
+                        
+                    }
+                    gtk_widget_queue_draw(Denemo.scorearea);
+                    return TRUE;
+                } else 
+                {
+                    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (left?GDK_SB_H_DOUBLE_ARROW:GDK_X_CURSOR));
+                    left? (dragging_audio = TRUE) : (dragging_tempo = TRUE);
+                     if (Denemo.prefs.learning)
+                     left? MouseGestureShow(_("Left Drag Note Onset"), _("This moves the audio to synchronize the start with the score.\nYou can use the Leadin button for this too."),
           MouseGesture) :
-						MouseGestureShow(_("Right Drag Note Onset"), _("This changes the tempo of the score.\nUse this to synchronize the beat after setting the start"),
+                        MouseGestureShow(_("Right Drag Note Onset"), _("This changes the tempo of the score.\nUse this to synchronize the beat after setting the start"),
           MouseGesture);
-					return TRUE;
-				}
-		}
-	  
-	}
+                    gtk_widget_queue_draw(Denemo.scorearea);
+                    return TRUE;
+                }
+        }
+      
+    }
   
   
-  //g_print("before %f %f\n", event->x, event->y);
+  //g_debug("before %f %f\n", event->x, event->y);
   transform_coords (&event->x, &event->y);
-  //g_print("after %f %f\n", event->x, event->y);
+  //g_debug("after %f %f\n", event->x, event->y);
 
   
   gtk_widget_grab_focus (widget);
-  gint key = gui->si->maxkeywidth;
+  gint key = gui->movement->maxkeywidth;
   gint cmajor = key ? 0 : 5;    //allow some area for keysig in C-major
 
   if (gui->lefts[line_num] == 0)
@@ -616,34 +646,34 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
     get_placement_from_coordinates (&pi, event->x, event->y, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
   if (pi.the_staff == NULL)
     return TRUE;                //could not place the cursor
-  change_staff (gui->si, pi.staff_number, pi.the_staff);
+  change_staff (gui->movement, pi.staff_number, pi.the_staff);
 
 
-  if (left && (gui->si->leftmeasurenum > 1) && (event->x < KEY_MARGIN + SPACE_FOR_TIME + key) && (event->x > LEFT_MARGIN))
+  if (left && (gui->movement->leftmeasurenum > 1) && (event->x < KEY_MARGIN + SPACE_FOR_TIME + key) && (event->x > LEFT_MARGIN))
     {
       if (Denemo.prefs.learning)
         MouseGestureShow(_("Press Left."), _("This moved the cursor to the measure offscreen left. The display is shifted to place that measure on screen."),
           MouseGesture);
-      moveto_currentmeasurenum (gui, gui->si->leftmeasurenum - 1);
+      moveto_currentmeasurenum (gui, gui->movement->leftmeasurenum - 1);
       write_status (gui);
       gtk_widget_queue_draw (Denemo.scorearea);
       return TRUE;
     }
   else if (pi.nextmeasure)
     {
-      if ((pi.the_obj==NULL) || ((pi.the_obj->next == NULL) && (pi.offend)))//crashed here with the_obj 0x131 !!!
+      if ((pi.at_edge) && ((pi.the_obj==NULL) || ((pi.the_obj->next == NULL) && (pi.offend))))//crashed here with the_obj 0x131 !!!
         {
-          if ((gui->si->currentmeasurenum != gui->si->rightmeasurenum) &&
-                (!moveto_currentmeasurenum (gui, gui->si->rightmeasurenum + 1)))
-              moveto_currentmeasurenum (gui, gui->si->rightmeasurenum);
-          else if ((gui->si->cursor_appending) &&
-                (!moveto_currentmeasurenum (gui, gui->si->rightmeasurenum + 1)))
-              moveto_currentmeasurenum (gui, gui->si->rightmeasurenum);
+          if ((gui->movement->currentmeasurenum != gui->movement->rightmeasurenum) &&
+                (!moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
+              moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum);
+          else if ((gui->movement->cursor_appending) &&
+                (!moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum + 1)))
+              moveto_currentmeasurenum (gui, gui->movement->rightmeasurenum);
 
 
           
 
-          if (gui->si->currentmeasurenum != gui->si->rightmeasurenum) {
+          if (gui->movement->currentmeasurenum != gui->movement->rightmeasurenum) {
             if (Denemo.prefs.learning)
               MouseGestureShow(_("Press Left."), _("This moved the cursor to the measure off-screen right. The display is shifted to move the cursor to the middle."),
                 MouseGesture);
@@ -656,34 +686,45 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 
   if (pi.the_measure != NULL)
     {                           /*don't place cursor in a place that is not there */
-      //gui->si->currentstaffnum = pi.staff_number;
-      //gui->si->currentstaff = pi.the_staff;
-      gui->si->currentmeasurenum = pi.measure_number;
-      gui->si->currentmeasure = pi.the_measure;
-      gui->si->currentobject = pi.the_obj;
-      gui->si->cursor_x = pi.cursor_x;
-      gui->si->cursor_appending = (gui->si->cursor_x == (gint) (g_list_length ((objnode *) gui->si->currentmeasure->data)));
+      //gui->movement->currentstaffnum = pi.staff_number;
+      //gui->movement->currentstaff = pi.the_staff;
+      gui->movement->currentmeasurenum = pi.measure_number;
+      gui->movement->currentmeasure = pi.the_measure;
+      gui->movement->currentobject = pi.the_obj;
+      gui->movement->cursor_x = pi.cursor_x;
+      gui->movement->cursor_appending = (gui->movement->cursor_x == (gint) (g_list_length ((objnode *) gui->movement->currentmeasure->data)));
       set_cursor_y_from_click (gui, event->y);
       if (event->type==GDK_2BUTTON_PRESS) 
-				{
-          if (Denemo.prefs.learning)
-            MouseGestureShow(_("Double Click."), _("This gives information about the object at the cursor. Click on a notehead for information about a note in a chord."),
-              MouseGesture);
-					display_current_object();
-					return TRUE;
-				}
-			else 
-				{
-          if (Denemo.prefs.learning)
-            MouseGestureShow(_("Press Left."), _("This moved the cursor to the object position clicked. The cursor height becomes the clicked point."),
-              MouseGesture);
-					write_status (gui);
-				}
-    }
-
+                {
+                    if(gui->movement->recording &&  !g_strcmp0 (((DenemoStaff *) gui->movement->currentstaff->data)->denemo_name->str, DENEMO_CLICK_TRACK_NAME))
+                        {
+                            gui->movement->marked_onset_position = (gint)event->x/gui->movement->zoom;
+                            if (Denemo.prefs.learning)
+                                MouseGestureShow(_("Double Click on Click Track"), _("This will mark the MIDI note onset."), MouseGesture);
+                            return TRUE;
+                 
+                        }
+                        
+                    else
+                        {
+                          if (Denemo.prefs.learning)
+                            MouseGestureShow(_("Double Click."), _("This gives information about the object at the cursor. Click on a notehead for information about a note in a chord."),
+                              MouseGesture);
+                                    display_current_object();
+                                    return TRUE;
+                        }
+                }
+            else 
+                {
+                  if (Denemo.prefs.learning)
+                    MouseGestureShow(_("Press Left."), _("This moved the cursor to the object position clicked. The cursor height becomes the clicked point."),
+                      MouseGesture);
+                            write_status (gui);
+               }
+            }
 
   gint offset = (gint) get_click_height (gui, event->y);
-  if ((((DenemoStaff *) gui->si->currentstaff->data)->voicecontrol == DENEMO_PRIMARY) && (gui->si->leftmeasurenum == 1) && (event->x > LEFT_MARGIN))
+  if ((((DenemoStaff *) gui->movement->currentstaff->data)->voicecontrol == DENEMO_PRIMARY) && (gui->movement->leftmeasurenum == 1) && (event->x > LEFT_MARGIN))
     {
       if (event->x < KEY_MARGIN - cmajor)
         {
@@ -733,26 +774,26 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 
   if (event->x < LEFT_MARGIN)
     {
-      if (pi.staff_number == gui->si->currentstaffnum)
+      if (pi.staff_number == gui->movement->currentstaffnum)
         {
           gint offset = (gint) get_click_height (gui, event->y);
           if (offset < STAFF_HEIGHT / 2)
             {
-              if (((DenemoStaff *) gui->si->currentstaff->data)->staff_directives)
+              if (((DenemoStaff *) gui->movement->currentstaff->data)->staff_directives)
                 {
                   if (Denemo.prefs.learning)
                     MouseGestureShow(_("Click on Staff Directives."), _("This pops up the staff directives menu for editing"),
                       MouseGesture);                  
-                  gtk_menu_popup (((DenemoStaff *) gui->si->currentstaff->data)->staffmenu, NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time ());
+                  gtk_menu_popup (((DenemoStaff *) gui->movement->currentstaff->data)->staffmenu, NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time ());
                 }
               return TRUE;
             }
-          else if (((DenemoStaff *) gui->si->currentstaff->data)->voice_directives)
+          else if (((DenemoStaff *) gui->movement->currentstaff->data)->voice_directives)
             {
               if (Denemo.prefs.learning)
                 MouseGestureShow(_("Click on Voice Directives."), _("This pops up the voice directives menu for editing"),
                     MouseGesture);  
-              gtk_menu_popup (((DenemoStaff *) gui->si->currentstaff->data)->voicemenu, NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time ());
+              gtk_menu_popup (((DenemoStaff *) gui->movement->currentstaff->data)->voicemenu, NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time ());
               return TRUE;
             }
         }
@@ -761,12 +802,12 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
   if (left)
     {
       if (!(GDK_SHIFT_MASK & event->state))
-        gui->si->markstaffnum = 0;
+        gui->movement->markstaffnum = 0;
       lh_down = TRUE;
     }
   else
     {
-      if (gui->si->cursor_appending)
+      if (gui->movement->cursor_appending)
         {
           if (Denemo.prefs.learning)
             MouseGestureShow(_("Right Click Appending."), _("This pops up the append menu"),
@@ -781,7 +822,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 
 
   
-  //displayhelper(Denemo.gui);
+  //displayhelper(Denemo.project);
   draw_score(NULL);//this is needed to refresh cached values such as the prevailing time signature, before the command is invoked
 
   perform_command (event->state | (left ? GDK_BUTTON1_MASK : GDK_BUTTON3_MASK), GESTURE_PRESS, left);
@@ -797,16 +838,16 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 gint
 scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (gui == NULL || gui->si == NULL)
+  DenemoProject *gui = Denemo.project;
+  if (gui == NULL || gui->movement == NULL)
     return FALSE;
   gboolean left = (event->button != 3);
-  if(gui->si->audio && (dragging_tempo || dragging_audio))
-	{		
-			dragging_tempo = dragging_audio = FALSE;
-			gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR));       //FIXME? does this take time/hog memory
-			return TRUE; 
-	}
+  if(gui->movement->recording && (dragging_tempo || dragging_audio))
+    {       
+            dragging_tempo = dragging_audio = FALSE;
+            gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR));       //FIXME? does this take time/hog memory
+            return TRUE; 
+    }
   if (dragging_separator)
     {
       if (Denemo.prefs.learning)
@@ -832,8 +873,8 @@ scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
 gint
 scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (gui == NULL || gui->si == NULL)
+  DenemoProject *gui = Denemo.project;
+  if (gui == NULL || gui->movement == NULL)
     return FALSE;
   switch (event->direction)
     {
@@ -845,7 +886,7 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
             gint command_idx = lookup_command_from_name(Denemo.map, "ZoomIn");
             KeyStrokeShow (_("Ctrl + Mouse Wheel Up"), command_idx, TRUE);
           }
-          Denemo.gui->si->zoom *= 1.1;
+          Denemo.project->movement->zoom *= 1.1;
           scorearea_configure_event (Denemo.scorearea, NULL);
         }
       else if (event->state & GDK_SHIFT_MASK)
@@ -863,9 +904,9 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
             gint command_idx = lookup_command_from_name(Denemo.map, "MoveToStaffUp");
             KeyStrokeShow (_("Unshifted + Mouse Wheel Up"), command_idx, TRUE);
           }
-          movetostaffup (&param);
+          movetostaffup (NULL, &param);
           if (!param.status) {
-            DenemoStaff *thestaff = (DenemoStaff*)(Denemo.gui->si->currentstaff->data);
+            DenemoStaff *thestaff = (DenemoStaff*)(Denemo.project->movement->currentstaff->data);
             if(thestaff->space_above < MAXEXTRASPACE)
               {
                 thestaff->space_above++;
@@ -881,9 +922,9 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
             gint command_idx = lookup_command_from_name(Denemo.map, "ZoomOut");
             KeyStrokeShow (_("Ctrl + Mouse Wheel Down"), command_idx, TRUE);
           }
-          Denemo.gui->si->zoom /= 1.1;
-          if (Denemo.gui->si->zoom < 0.01)
-            Denemo.gui->si->zoom = 0.01;
+          Denemo.project->movement->zoom /= 1.1;
+          if (Denemo.project->movement->zoom < 0.01)
+            Denemo.project->movement->zoom = 0.01;
           scorearea_configure_event (Denemo.scorearea, NULL);
           //displayhelper(gui);
         }
@@ -901,23 +942,23 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
             gint command_idx = lookup_command_from_name(Denemo.map, "MoveToStaffDown");
             KeyStrokeShow (_("Unshifted + Mouse Wheel Down"), command_idx, TRUE);
           }
-          movetostaffdown (&param);
+          movetostaffdown (NULL, &param);
           if (!param.status) {
             warningmessage ("This is the bottom staff");
-           // DenemoStaff *thestaff = (DenemoStaff*)(Denemo.gui->si->currentstaff->data);
+           // DenemoStaff *thestaff = (DenemoStaff*)(Denemo.project->movement->currentstaff->data);
            // thestaff->space_below++; //This doesn't help, because the viewport does not change.
            // warningmessage ("Increasing the space below the bottom staff");
-           //move_viewport_down(Denemo.gui);
+           //move_viewport_down(Denemo.project);
           }
         }
       break;
     case GDK_SCROLL_LEFT:
-      movetomeasureleft (&param);
+      movetomeasureleft (NULL, &param);
       if (!param.status)
         warningmessage ("This is the first measure");
       break;
     case GDK_SCROLL_RIGHT:
-      movetomeasureright (&param);
+      movetomeasureright (NULL, &param);
       if (!param.status)
         warningmessage ("This is the last measure");
       break;
@@ -925,6 +966,6 @@ scorearea_scroll_event (GtkWidget * widget, GdkEventScroll * event)
     default:
       break;
     }
-  displayhelper (Denemo.gui);
+  displayhelper (Denemo.project);
   return FALSE;
 }
