@@ -123,7 +123,7 @@ static void toggle_dock (DenemoPalette *pal) {
 }
 static void set_limit (DenemoPalette *pal) {
 	gchar *initial = g_strdup_printf("%d", pal->limit);
-	gchar *response = string_dialog_entry (Denemo.gui, "Palette Layout", _("Give Limit"), initial);
+	gchar *response = string_dialog_entry (Denemo.project, "Palette Layout", _("Give Limit"), initial);
 	g_free(initial);
 	if(response && atoi(response))
 	{
@@ -204,15 +204,15 @@ static void put_script_for_button (GtkWidget *button) {
 	g_free(text);
 }
 
-static set_image_for_button (GtkWidget *button, gchar *name)
+static void set_image_for_button (GtkWidget *button, gchar *name)
 {
 	gchar *icon = find_denemo_file (DENEMO_DIR_PIXMAPS, name);
 	GtkWidget *child_widget = gtk_bin_get_child(GTK_BIN(button));
 	if(GTK_IS_LABEL(child_widget)) {
 		gtk_button_set_label (GTK_BUTTON(button), "");
-		//g_print("destroy %p, \n", child_widget);
+		//g_debug("destroy %p, \n", child_widget);
 		child_widget = gtk_bin_get_child(GTK_BIN(button));
-		//g_print("or rather destroy %p, is %d \n", child_widget, GTK_IS_WIDGET(child_widget));
+		//g_debug("or rather destroy %p, is %d \n", child_widget, GTK_IS_WIDGET(child_widget));
 		gtk_widget_destroy (child_widget);
 	}
 	GdkPixbuf *pb = gdk_pixbuf_new_from_file(icon, NULL);
@@ -233,7 +233,7 @@ static void edit_label_for_button (GtkWidget *button) {
 	label = g_object_get_data (G_OBJECT(button), "icon");
 	if(label==NULL)
 		label = gtk_button_get_label (GTK_BUTTON(button));
-	gchar *newlabel = string_dialog_entry (Denemo.gui, _("Write Label"), _("Write a label for this button"), (gchar*)label);
+	gchar *newlabel = string_dialog_entry (Denemo.project, _("Write Label"), _("Write a label for this button"), (gchar*)label);
 	
 	if(newlabel) {
 		gchar *icon = find_denemo_file (DENEMO_DIR_PIXMAPS, newlabel);
@@ -254,7 +254,7 @@ static void edit_label_for_button (GtkWidget *button) {
 }
 static void edit_tooltip_for_button (GtkWidget *button) {
 	const gchar *tooltip = gtk_widget_get_tooltip_text (button);
-	gchar *newtooltip = string_dialog_entry (Denemo.gui, _("Write Tooltip"), _("Write a tooltip for this button"), (gchar*)tooltip);
+	gchar *newtooltip = string_dialog_entry (Denemo.project, _("Write Tooltip"), _("Write a tooltip for this button"), (gchar*)tooltip);
 	if(newtooltip) {
 		gtk_widget_set_tooltip_text (button, newtooltip);
 	}
@@ -266,13 +266,13 @@ static void remove_button (GtkWidget *button) {
 	
 }
 
-static move_button_to_start (GtkWidget *button) {
+static void move_button_to_start (GtkWidget *button) {
 	DenemoPalette *pal = g_object_get_data (G_OBJECT(button), "palette");
 	pal->buttons = g_list_remove (pal->buttons, button);
 	pal->buttons = g_list_prepend (pal->buttons, button);
 	repack_palette (pal);
 }
-static move_button_to_end (GtkWidget *button) {
+static void move_button_to_end (GtkWidget *button) {
 	DenemoPalette *pal = g_object_get_data (G_OBJECT(button), "palette");
 	pal->buttons = g_list_remove (pal->buttons, button);
 	pal->buttons = g_list_append (pal->buttons, button);
@@ -292,7 +292,7 @@ static void copy_button (GtkWidget *button) {
 	}
 }
 
-static GtkWidget *popup_button_menu(DenemoPalette *pal, GtkWidget *button) {
+static void popup_button_menu(DenemoPalette *pal, GtkWidget *button) {
   GtkWidget *menu = gtk_menu_new ();
   GtkWidget *item;
 
@@ -390,8 +390,8 @@ static gboolean already_present (DenemoPalette *pal, gchar *label) {
 	return FALSE;
 }
 
-static fixup_image (GtkWidget *button, gchar *label) {
-	//g_print("Fixing up image");
+static void fixup_image (GtkWidget *button, gchar *label) {
+	//g_debug("Fixing up image");
 	set_image_for_button (button, label);	
 }
 gboolean palette_add_button (DenemoPalette *pal, gchar *label, const gchar *tooltip, gchar *script) 
@@ -406,7 +406,7 @@ gboolean palette_add_button (DenemoPalette *pal, gchar *label, const gchar *tool
 		g_signal_connect (button, "realize", G_CALLBACK (fixup_image), label);	
 	} else
 	{
-		GtkWidget *label_widget = gtk_bin_get_child(GTK_BIN(button));//g_print("is %s\n", g_type_name(G_TYPE_FROM_INSTANCE(label_widget)));
+		GtkWidget *label_widget = gtk_bin_get_child(GTK_BIN(button));//g_debug("is %s\n", g_type_name(G_TYPE_FROM_INSTANCE(label_widget)));
 		gtk_label_set_use_markup (GTK_LABEL(label_widget), TRUE);
 	}
 	//put button in a list pal->buttons and then call repack_palette.
@@ -487,7 +487,7 @@ static void palette_selected (gchar *name)
 static void user_palette_name (void)
 {
 	gchar *name;
-	name = string_dialog_entry (Denemo.gui, _("Palette Name"), _("Give name for Palette: "), _("MyPalette"));
+	name = string_dialog_entry (Denemo.project, _("Palette Name"), _("Give name for Palette: "), _("MyPalette"));
 	selected_palette_name = name;
 }
 
@@ -498,6 +498,8 @@ gchar *choose_palette_by_name (gboolean allow_custom, gboolean non_showing)
   GtkWidget *menu = gtk_menu_new ();
   GtkWidget *item;
   GList *g;
+  selected_palette_name = NULL;
+  if(Denemo.palettes) {
   if(allow_custom) {
   	item = gtk_menu_item_new_with_label (_("Custom"));
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -507,15 +509,16 @@ gchar *choose_palette_by_name (gboolean allow_custom, gboolean non_showing)
 	{
 	DenemoPalette *pal = (DenemoPalette *)g->data;
 	if(non_showing && pal->docked && gtk_widget_get_visible (pal->box))
-		continue;//g_print("palette %s is %d\n", pal->name,  gtk_widget_get_visible (pal->box));//continue;
+		continue;//g_debug("palette %s is %d\n", pal->name,  gtk_widget_get_visible (pal->box));//continue;
 	if(non_showing && (!pal->docked) && gtk_widget_get_visible (gtk_widget_get_parent(pal->box)))
 		continue;
 	item = gtk_menu_item_new_with_label (pal->name);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (palette_selected), (gpointer) pal->name);
 	}	
-	selected_palette_name = NULL;
+	
 	popupmenu (menu);
+}
 	if(allow_custom && (selected_palette_name==NULL))
 		{
 			user_palette_name ();
