@@ -15,14 +15,14 @@
 #include "pitchrecog.h"
 #include "audiocapture.h"
 
-#define  DEFAULT_HIGH (1400.0)
-#define  DEFAULT_LOW (60.0)
+#define DEFAULT_HIGH (1400.0)
+#define DEFAULT_LOW (60.0)
 #define DEFAULT_TIMER_RATE (50)
 #define QUARTER_COMMA_MEAN_TONE "Quarter comma meantone"
 
 static GtkWidget *PR_window = NULL;     /* a top level window for controlling pitch-recognition entry.
-                                           We do not create one of these for each view (ie each DenemoGUI object, ie each score) because there is only one audio input source being used, so we would have to cope with resource contention issues, there is just no point. */
-static DenemoGUI *PR_gui;       /* the gui for which the pitch recognition has been set up */
+                                           We do not create one of these for each view (ie each DenemoProject object, ie each score) because there is only one audio input source being used, so we would have to cope with resource contention issues, there is just no point. */
+static DenemoProject *PR_gui;       /* the gui for which the pitch recognition has been set up */
 
 
 gint PR_click;                  /*volume of a audible warning of next measure or extra tones in measure */
@@ -377,7 +377,7 @@ check_midi_intervals (GList * midichord)
       value = fifths[offset] + 7 * enshift;
       most = MAX (most, value);
       least = MIN (least, value);
-      //g_print("note %d value %d\noffset %d enshift %d least=%d most=%d\n", g->data, value, offset, least, least, most);
+      //g_debug("note %d value %d\noffset %d enshift %d least=%d most=%d\n", g->data, value, offset, least, least, most);
     }
   return abs (most - least) < 6;
 }
@@ -409,7 +409,7 @@ gchar *
 determine_interval (gint bass, gint harmony, gboolean * status)
 {
   gint semitones = harmony - bass;
-  gint *accs = ((DenemoStaff *) Denemo.gui->si->currentstaff->data)->keysig.accs;
+  gint *accs = ((DenemoStaff *) Denemo.project->movement->currentstaff->data)->keysig.accs;
   notepitch bassnote = PR_temperament->notepitches[bass % 12];
   notepitch harmonynote = PR_temperament->notepitches[harmony % 12];
   gint interval = harmonynote.spec.step - bassnote.spec.step + 1;
@@ -421,8 +421,8 @@ determine_interval (gint bass, gint harmony, gboolean * status)
 
   *status = check_interval (bassnote.spec.step, bassnote.spec.alteration, harmonynote.spec.step, harmonynote.spec.alteration);
 
-//g_print("have %d %d\n", bassnote.spec.step, harmonynote.spec.step);
-// g_print("Bass %d harmony %d\nInterval is %d, semitones is %d cf (%d, %d)  \n keyaccs of bass note %d of harmony %d\ninflection %d\n", bass, harmony, interval, semitones, bassnote.spec.alteration, harmonynote.spec.alteration, accs[bassnote.spec.step], accs[harmonynote.spec.step], inflection);
+//g_debug("have %d %d\n", bassnote.spec.step, harmonynote.spec.step);
+// g_debug("Bass %d harmony %d\nInterval is %d, semitones is %d cf (%d, %d)  \n keyaccs of bass note %d of harmony %d\ninflection %d\n", bass, harmony, interval, semitones, bassnote.spec.alteration, harmonynote.spec.alteration, accs[bassnote.spec.step], accs[harmonynote.spec.step], inflection);
   gchar *modifier = "";
   if (interval == 5 && semitones == 6)
     modifier = "/";
@@ -552,6 +552,7 @@ adjust_tonal_center (gint * accs)
 void
 set_enharmonic_position (gint position)
 {
+    if(Denemo.non_interactive) return;
   while (position < enharmonic_position)
     {
       set_flatter (NULL, NULL);
@@ -570,7 +571,7 @@ get_enharmonic_position (void)
 
 static void
 enharmonic_step (gboolean sharp)
-{
+{if(Denemo.non_interactive) return;
   gchar *sharpestname, *flattestname;
   if (sharp)
     sharpen (PR_label);
@@ -596,13 +597,13 @@ enharmonic_step (gboolean sharp)
 }
 
 void
-set_sharper (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+set_sharper (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
   enharmonic_step (TRUE);
 }
 
 void
-set_flatter (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+set_flatter (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
   enharmonic_step (FALSE);
 }
@@ -612,7 +613,7 @@ signal_measure_end (void)
 {
   if (Denemo.prefs.immediateplayback)
     {
-      play_note (DEFAULT_BACKEND, 0 /*port */ , 9, 74, 300, (gint) (100 * Denemo.gui->si->master_volume));
+      play_note (DEFAULT_BACKEND, 0 /*port */ , 9, 74, 300, 127);//(gint) (100 * Denemo.project->movement->master_volume));
     }
 }
 
@@ -658,7 +659,7 @@ get_tones (GList * tone_store, gint measurenum)
 */
 
 gboolean
-apply_tones (DenemoScore * si)
+apply_tones (DenemoMovement * si)
 {
   gboolean ret = FALSE;
   DenemoStaff *curstaff = ((DenemoStaff *) si->currentstaff->data);
@@ -698,7 +699,7 @@ apply_tones (DenemoScore * si)
                   modify_note ((chord *) theobj->object, mid_c_offset, thetone->enshift, dclef);
                   tone_stored = TRUE;
                   if (!si->cursor_appending)
-                    cursorright (NULL);
+                    cursorright (NULL, NULL);
                   store_el = store_el->next;
 
                 }               // tone available
@@ -724,17 +725,17 @@ apply_tones (DenemoScore * si)
 
 /*
  * enter_note_in_score
- * enters the note FOUND in the score gui->si at octave OCTAVE steps above/below mid-c
+ * enters the note FOUND in the score gui->movement at octave OCTAVE steps above/below mid-c
  */
 static void
-enter_note_in_score (DenemoGUI * gui, notepitch * found, gint octave)
+enter_note_in_score (DenemoProject * gui, notepitch * found, gint octave)
 {
-  //printf("Cursor_y %d and staffletter = %d\n", gui->si->cursor_y, gui->si->staffletter_y);
+  //printf("Cursor_y %d and staffletter = %d\n", gui->movement->cursor_y, gui->movement->staffletter_y);
   gui->last_source = INPUTAUDIO;
-  gui->si->cursor_y = gui->si->staffletter_y = found->spec.step;
-  gui->si->cursor_y += 7 * octave;
+  gui->movement->cursor_y = gui->movement->staffletter_y = found->spec.step;
+  gui->movement->cursor_y += 7 * octave;
   shiftcursor (gui, found->spec.step);
-  setenshift (gui->si, found->spec.alteration);
+  setenshift (gui->movement, found->spec.alteration);
   displayhelper (gui);
 }
 
@@ -763,23 +764,23 @@ put_tone (GList * store, gint measurenum, tone * thetone)
  * enters the note FOUND as a tone in the tone store
  */
 static void
-enter_tone_in_store (DenemoGUI * gui, notepitch * found, gint octave)
+enter_tone_in_store (DenemoProject * gui, notepitch * found, gint octave)
 {
   gboolean nextmeasure;
   tone *thetone = (tone *) g_malloc0 (sizeof (tone));
-  //g_print("tone %p\n", thetone);
+  //g_debug("tone %p\n", thetone);
   thetone->enshift = found->spec.alteration;
   thetone->step = found->spec.step + 7 * octave;
   thetone->octave = octave;
   thetone->valid = TRUE;
-#define store  (((DenemoStaff*)gui->si->currentstaff->data)->tone_store)
-  store = put_tone (store, gui->si->currentmeasurenum - 1, thetone);
-  nextmeasure = apply_tones (gui->si);
+#define store  (((DenemoStaff*)gui->movement->currentstaff->data)->tone_store)
+  store = put_tone (store, gui->movement->currentmeasurenum - 1, thetone);
+  nextmeasure = apply_tones (gui->movement);
   displayhelper (gui);
   if (Denemo.prefs.continuous && nextmeasure)
     {
       sound_click ();
-      measureright (NULL);
+      measureright (NULL, NULL);
     }
 #undef store
 }
@@ -788,9 +789,9 @@ enter_tone_in_store (DenemoGUI * gui, notepitch * found, gint octave)
  * clear the references to tones (ie any overlay) in the currentstaff
  */
 static void
-clear_tone_nodes (DenemoGUI * gui)
+clear_tone_nodes (DenemoProject * gui)
 {
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = gui->movement;
   DenemoStaff *curstaff = ((DenemoStaff *) si->currentstaff->data);
   measurenode *curmeasure;
   for (curmeasure = curstaff->measures; curmeasure; curmeasure = curmeasure->next)
@@ -817,11 +818,11 @@ free_tones (GList * tones)
     }
 }
 
-  // clear gui->si->currentstaff->data->tone_store and the references to it
+  // clear gui->movement->currentstaff->data->tone_store and the references to it
 static void
-clear_tone_store (G_GNUC_UNUSED GtkButton * button, DenemoGUI * gui)
+clear_tone_store (G_GNUC_UNUSED GtkButton * button, DenemoProject * gui)
 {
-#define store  (((DenemoStaff*)gui->si->currentstaff->data)->tone_store)
+#define store  (((DenemoStaff*)gui->movement->currentstaff->data)->tone_store)
   g_list_foreach (store, (GFunc) free_tones, NULL);
   clear_tone_nodes (gui);
   g_list_free (store);
@@ -833,9 +834,9 @@ clear_tone_store (G_GNUC_UNUSED GtkButton * button, DenemoGUI * gui)
 }
 
 void
-clear_overlay (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+clear_overlay (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam* param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   clear_tone_store (NULL, gui);
 }
 
@@ -844,7 +845,7 @@ clear_overlay (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
  */
 /* UNUSED
 static void
-clear_tone_nodes_currentmeasure (DenemoScore * si)
+clear_tone_nodes_currentmeasure (DenemoMovement * si)
 {
   measurenode *curmeasure = si->currentmeasure;
   objnode *curobj = curmeasure->data;
@@ -861,7 +862,7 @@ clear_tone_nodes_currentmeasure (DenemoScore * si)
 
 
 gboolean
-delete_tone (DenemoScore * si, chord * thechord)
+delete_tone (DenemoMovement * si, chord * thechord)
 {
   GList *tone_node = thechord->tone_node;
   if (tone_node)
@@ -877,7 +878,8 @@ delete_tone (DenemoScore * si, chord * thechord)
       si->cursor_appending = keepa;
       calcmarkboundaries (si);
 
-      displayhelper (Denemo.gui);
+      displayhelper (Denemo.project);
+      score_status(Denemo.project, TRUE);
       return TRUE;
     }
   else
@@ -973,7 +975,7 @@ static gint
 measure_pitch_accurately (G_GNUC_UNUSED gpointer data)
 {
   double note = determine_frequency ();
-  //g_print("returned %f\n", note);
+  //g_debug("returned %f\n", note);
   if (note > 0.0)
     display_pitch (note);
 
@@ -992,7 +994,7 @@ Freq2Pitch (float freq)
 /* look for a new note played into audio input, if
    present insert it into the score/store */
 gint
-pitchentry (DenemoGUI * gui)
+pitchentry (DenemoProject * gui)
 {
   static gint last_step = -1, last_alteration, last_octave;
   if (PR_window == NULL)
@@ -1040,9 +1042,9 @@ pitchentry (DenemoGUI * gui)
               if (gui->input_source == INPUTMIDI)
                 {
                   gint key = (gint) (Freq2Pitch (found->pitch * (pow (2, (octave)))));
-                  //g_print("pitch %f key number %d\n",found->pitch, key);
+                  //g_debug("pitch %f key number %d\n",found->pitch, key);
 
-                  DenemoStaff *curstaffstruct = ((DenemoStaff *) Denemo.gui->si->currentstaff->data);
+                  DenemoStaff *curstaffstruct = ((DenemoStaff *) Denemo.project->movement->currentstaff->data);
                   play_note (DEFAULT_BACKEND, curstaffstruct->midi_port, curstaffstruct->midi_channel, key, 300 /*duration */ , 0);
                 }
               if (gui->input_source == INPUTMIDI || !Denemo.prefs.overlays)
@@ -1051,9 +1053,9 @@ pitchentry (DenemoGUI * gui)
                   if (gui->mode & INPUTRHYTHM)
                     {
                       static gboolean beep = FALSE;
-                      gint measure = gui->si->currentmeasurenum;
+                      gint measure = gui->movement->currentmeasurenum;
                       scheme_next_note (NULL);
-                      if (measure != gui->si->currentmeasurenum)
+                      if (measure != gui->movement->currentmeasurenum)
                         beep = TRUE;
                       else if (beep)
                         signal_measure_end (), beep = FALSE;
@@ -1158,7 +1160,7 @@ frequency_smoothing (GtkSpinButton * widget, G_GNUC_UNUSED gpointer data)
 int
 stop_pitch_input (void)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (PR_timer)
     g_source_remove (PR_timer);
 
@@ -1192,7 +1194,7 @@ window_destroy_callback (void)
     return FALSE;
   activate_action ("/MainMenu/InputMenu/KeyboardOnly");
   PR_window = NULL;
-  clear_tone_store (NULL, Denemo.gui);
+  clear_tone_store (NULL, Denemo.project);
   return FALSE;
 }
 
@@ -1236,15 +1238,15 @@ change_timer_rate (GtkSpinButton * widget, G_GNUC_UNUSED gpointer data)
 
   // toggle Denemo.prefs.overlays to show where the notes detected should go
 static void
-toggle_insert (G_GNUC_UNUSED GtkButton * button, G_GNUC_UNUSED gpointer data)
+toggle_insert (G_GNUC_UNUSED GtkButton * button)
 {
   Denemo.prefs.overlays = !Denemo.prefs.overlays;
-  clear_tone_store (NULL, Denemo.gui);
+  clear_tone_store (NULL, Denemo.project);
   switch_back_to_main_window ();
 }
 
 static gint
-draw_indicator (GtkWidget * widget, G_GNUC_UNUSED GdkEventExpose * event, G_GNUC_UNUSED gpointer data)
+draw_indicator (GtkWidget * widget)
 {
   int barwidth = 20;
   int centre = 400;
@@ -1275,7 +1277,7 @@ draw_indicator (GtkWidget * widget, G_GNUC_UNUSED GdkEventExpose * event, G_GNUC
 }
 
 static void
-toggle_tuning (GtkToggleButton * button, DenemoGUI * gui)
+toggle_tuning (GtkToggleButton * button, DenemoProject * gui)
 {
   static int id;
   static GtkWidget *widget;
@@ -1294,7 +1296,12 @@ toggle_tuning (GtkToggleButton * button, DenemoGUI * gui)
           gtk_container_add (GTK_CONTAINER (widget), hbox);
           PR_indicator = gtk_drawing_area_new ();
           gtk_box_pack_start (GTK_BOX (hbox), PR_indicator, TRUE, TRUE, 0);
-          g_signal_connect (G_OBJECT (PR_indicator), "expose_event", G_CALLBACK (draw_indicator), gui);
+#if GTK_MAJOR_VERSION==3
+            g_signal_connect (G_OBJECT (PR_indicator), "draw", G_CALLBACK (draw_indicator), NULL);
+#else
+            g_signal_connect (G_OBJECT (PR_indicator), "expose_event", G_CALLBACK (draw_indicator), NULL);
+#endif
+          
           gtk_widget_show_all (widget);
         }
       gtk_window_present (GTK_WINDOW (widget));
@@ -1319,7 +1326,7 @@ get_cents (temperament * t)
   for (i = 0; i < 12; i++)
     {
       j = (i + temperament_offset) % 12;
-      //g_print("cents tempered %d to %d unshifted %f shifted %f\n", i, j, 1200 * log2(t->notepitches[i].pitch/Equal.notepitches[i].pitch), 1200 * log2(t->notepitches[j].pitch/Equal.notepitches[j].pitch));
+      //g_debug("cents tempered %d to %d unshifted %f shifted %f\n", i, j, 1200 * log2(t->notepitches[i].pitch/Equal.notepitches[i].pitch), 1200 * log2(t->notepitches[j].pitch/Equal.notepitches[j].pitch));
       array[i] = 1200 * log2 (t->notepitches[j].pitch / Equal.notepitches[j].pitch);
     }
   return array;
@@ -1455,7 +1462,7 @@ get_temperament_combo (void)
 #ifdef _HAVE_PORTAUDIO_
 
 static void
-create_pitch_recognition_window (DenemoGUI * gui)
+create_pitch_recognition_window (DenemoProject * gui)
 {
   GtkWidget *hbox, *hbox2;
   GtkWidget *button;
@@ -1489,7 +1496,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
       g_signal_connect (G_OBJECT (radio_button), "toggled", G_CALLBACK (toggle_insert), NULL);
       button = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio_button), "Insert Notes");
 
-      //g_print("Overlays %d\n", Denemo.prefs.overlays);
+      //g_debug("Overlays %d\n", Denemo.prefs.overlays);
       if (Denemo.prefs.overlays)
         {
           //gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(button), FALSE);
@@ -1502,7 +1509,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
 
           //gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(radio_button), FALSE);
         }
-      //g_print("Overlays after button setting %d\n", Denemo.prefs.overlays);
+      //g_debug("Overlays after button setting %d\n", Denemo.prefs.overlays);
       gtk_box_pack_start (GTK_BOX (vbox), button, TRUE, TRUE, 0);       /* no need for callback */
 
       gtk_box_pack_start (GTK_BOX (vbox), radio_button, TRUE, TRUE, 0);
@@ -1513,7 +1520,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
       gtk_box_pack_start (GTK_BOX (vbox), button, TRUE, TRUE, 0);
 
 
-      frame = gtk_frame_new ("Overlay Pitches");
+      frame = gtk_frame_new (_("Overlay Pitches"));
       gtk_container_add (GTK_CONTAINER (hbox), frame);
 
       GtkWidget *vbox2 = gtk_vbox_new (FALSE, 1);
@@ -1523,13 +1530,13 @@ create_pitch_recognition_window (DenemoGUI * gui)
 
       gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, TRUE, 0);
 
-      button = gtk_button_new_with_label ("Clear Overlay");     //FIXME make this a proxy for the ClearOverlay action ??
+      button = gtk_button_new_with_label (_("Clear Overlay"));     //FIXME make this a proxy for the ClearOverlay action ??
       gtk_box_pack_start (GTK_BOX (hbox2), button, TRUE, TRUE, 0);
       g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (clear_tone_store), gui);
       hbox2 = gtk_hbox_new (FALSE, 1);
 
       gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, TRUE, 0);
-      button = gtk_check_button_new_with_label ("Continuous");
+      button = gtk_check_button_new_with_label (_("Continuous"));
       gtk_box_pack_start (GTK_BOX (hbox2), button, TRUE, TRUE, 0);
 
       g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (toggle_continuous), NULL);
@@ -1538,7 +1545,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
           Denemo.prefs.continuous = !Denemo.prefs.continuous;
           gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), !Denemo.prefs.continuous);
         }
-      label = gtk_label_new ("Click Volume");
+      label = gtk_label_new (_("Click Volume"));
       gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
       PR_click = 1;
       spinner_adj = (GtkAdjustment *) gtk_adjustment_new ((double) PR_click, 0.0, 1.0, 1.0, 1.0, 1.0);
@@ -1574,7 +1581,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
     {
       /* spinners to select silence, threshold, smoothing */
 
-      frame = gtk_frame_new ("Pitch Recognition Parameters");
+      frame = gtk_frame_new (_("Pitch Recognition Parameters"));
       gtk_container_add (GTK_CONTAINER (main_vbox), frame);
       hbox = gtk_hbox_new (FALSE, 1);
       gtk_container_add (GTK_CONTAINER (frame), hbox);
@@ -1582,7 +1589,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
       hbox2 = gtk_hbox_new (FALSE, 1);
       gtk_box_pack_start (GTK_BOX (hbox), hbox2, TRUE, TRUE, 0);
 
-      label = gtk_label_new ("Silence");
+      label = gtk_label_new (_("Silence"));
       gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
       spinner_adj = (GtkAdjustment *) gtk_adjustment_new (-90.0, -1000.0, 100.0, 10.0, 1.0, 1.0);
       spinner = gtk_spin_button_new (spinner_adj, 100.0, 0);
@@ -1592,7 +1599,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
       hbox2 = gtk_hbox_new (FALSE, 1);
       gtk_box_pack_start (GTK_BOX (hbox), hbox2, TRUE, TRUE, 0);
 
-      label = gtk_label_new ("Threshold");
+      label = gtk_label_new (_("Threshold"));
       gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
       spinner_adj = (GtkAdjustment *) gtk_adjustment_new (1.0, 0.01, 100.0, 0.1, 1.0, 1.0);
       spinner = gtk_spin_button_new (spinner_adj, 0.5, 2);
@@ -1602,14 +1609,14 @@ create_pitch_recognition_window (DenemoGUI * gui)
       hbox2 = gtk_hbox_new (FALSE, 1);
       gtk_box_pack_start (GTK_BOX (hbox), hbox2, TRUE, TRUE, 0);
 
-      label = gtk_label_new ("Smoothing");
+      label = gtk_label_new (_("Smoothing"));
       gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
       spinner_adj = (GtkAdjustment *) gtk_adjustment_new (6.0, 0.0, 100.0, 1.0, 1.0, 1.0);
       spinner = gtk_spin_button_new (spinner_adj, 0.5, 2);
       gtk_box_pack_start (GTK_BOX (hbox2), spinner, TRUE, TRUE, 0);
       g_signal_connect (G_OBJECT (spinner), "value-changed", G_CALLBACK (change_smoothing), NULL);
 
-      label = gtk_label_new ("Onset");
+      label = gtk_label_new (_("Onset"));
       gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
       spinner_adj = (GtkAdjustment *) gtk_adjustment_new (7.0, 0.0, 7.0, 1.0, 1.0, 1.0);
       spinner = gtk_spin_button_new (spinner_adj, 0.5, 2);
@@ -1621,7 +1628,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
   /* spinners to constrain the note values */
 
 
-  frame = gtk_frame_new ("Note validation criteria");
+  frame = gtk_frame_new (_("Note validation criteria"));
   gtk_container_add (GTK_CONTAINER (main_vbox), frame);
   hbox = gtk_hbox_new (FALSE, 1);
   gtk_container_add (GTK_CONTAINER (frame), hbox);
@@ -1629,7 +1636,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
   hbox2 = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (hbox), hbox2, TRUE, TRUE, 0);
 
-  label = gtk_label_new ("Lowest Pitch");
+  label = gtk_label_new (_("Lowest Pitch"));
   gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
   spinner_adj = (GtkAdjustment *) gtk_adjustment_new (DEFAULT_LOW, 10.0, 2080.0, 10.0, 1.0, 1.0);
   spinner = gtk_spin_button_new (spinner_adj, 100.0, 1);
@@ -1639,7 +1646,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
   hbox2 = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (hbox), hbox2, TRUE, TRUE, 0);
 
-  label = gtk_label_new ("Highest Pitch");
+  label = gtk_label_new (_("Highest Pitch"));
   gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
   spinner_adj = (GtkAdjustment *) gtk_adjustment_new (DEFAULT_HIGH, 120.0, 9600.0, 10.0, 1.0, 1.0);
   spinner = gtk_spin_button_new (spinner_adj, 100.0, 1);
@@ -1649,7 +1656,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
   hbox2 = gtk_hbox_new (FALSE, 1);
   gtk_box_pack_start (GTK_BOX (hbox), hbox2, TRUE, TRUE, 0);
 
-  label = gtk_label_new ("Greatest Interval");
+  label = gtk_label_new (_("Greatest Interval"));
   gtk_box_pack_start (GTK_BOX (hbox2), label, TRUE, TRUE, 0);
   spinner_adj = (GtkAdjustment *) gtk_adjustment_new (8.0, 1.0, 15.0, 1.0, 1.0, 1.0);
   spinner = gtk_spin_button_new (spinner_adj, 1.0, 0);
@@ -1661,14 +1668,14 @@ create_pitch_recognition_window (DenemoGUI * gui)
   /* options */
   if (gui->input_source == INPUTAUDIO)
     {
-      frame = gtk_frame_new ("Input handling");
+      frame = gtk_frame_new (_("Input handling"));
       gtk_container_add (GTK_CONTAINER (main_vbox), frame);
       hbox = gtk_hbox_new (FALSE, 1);
       gtk_container_add (GTK_CONTAINER (frame), hbox);
 
 
 
-      label = gtk_check_button_new_with_label ("Disable repeated notes");
+      label = gtk_check_button_new_with_label (_("Disable repeated notes"));
       gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
       g_signal_connect (G_OBJECT (label), "clicked", G_CALLBACK (toggle_repeated_notes_allowed), NULL);
       label = gtk_label_new ("Transpose Input");
@@ -1678,19 +1685,19 @@ create_pitch_recognition_window (DenemoGUI * gui)
       gtk_box_pack_start (GTK_BOX (hbox), spinner, TRUE, TRUE, 0);
       g_signal_connect (G_OBJECT (spinner), "value-changed", G_CALLBACK (change_transposition), NULL);
 
-      label = gtk_label_new ("Delay");
+      label = gtk_label_new (_("Delay"));
       gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
       spinner_adj = (GtkAdjustment *) gtk_adjustment_new (DEFAULT_TIMER_RATE, 1.0, 500.0, 10.0, 1.0, 1.0);
       spinner = gtk_spin_button_new (spinner_adj, 10.0, 0);
       gtk_box_pack_start (GTK_BOX (hbox), spinner, TRUE, TRUE, 0);
       g_signal_connect (G_OBJECT (spinner), "value-changed", G_CALLBACK (change_timer_rate), NULL);
 
-      frame = gtk_frame_new ("Frequency Measurement");
+      frame = gtk_frame_new (_("Frequency Measurement"));
       gtk_container_add (GTK_CONTAINER (main_vbox), frame);
       hbox = gtk_hbox_new (FALSE, 1);
       gtk_container_add (GTK_CONTAINER (frame), hbox);
 
-      label = gtk_label_new ("Frequency smoothing");
+      label = gtk_label_new (_("Frequency smoothing"));
       gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
       spinner_adj = (GtkAdjustment *) gtk_adjustment_new (0.25, 0.1, 1.0, 0.05, 0.05, 0.05);
       spinner = gtk_spin_button_new (spinner_adj, 0.5, 2);
@@ -1718,7 +1725,7 @@ create_pitch_recognition_window (DenemoGUI * gui)
 gint
 setup_pitch_input (void)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (GTK_IS_WINDOW (PR_window))
     {
       gtk_window_present (GTK_WINDOW (PR_window));
@@ -1772,11 +1779,11 @@ scorearea_set_inactive (G_GNUC_UNUSED GtkWidget * widget, G_GNUC_UNUSED GdkEvent
 void
 start_pitch_input (void)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (PR_timer)
     g_source_remove (PR_timer);
 
-  PR_timer = g_timeout_add (PR_time, (GSourceFunc) pitchentry, Denemo.gui);
+  PR_timer = g_timeout_add (PR_time, (GSourceFunc) pitchentry, Denemo.project);
 
   if (PR_timer == 0)
     g_error ("Timer id 0 - if valid the code needs re-writing (documentation not clear)");
@@ -1798,14 +1805,14 @@ pitch_recognition_system_active (void)
 }
 
 gboolean
-pitch_entry_active (DenemoGUI * gui)
+pitch_entry_active (DenemoProject * gui)
 {
   return (PR_gui == gui) && PR_enable;
 }
 
 #else
 gboolean
-pitch_entry_active (DenemoGUI * gui)
+pitch_entry_active (DenemoProject * gui)
 {
   return 0;
 }
@@ -1828,7 +1835,7 @@ stop_pitch_input (void)
 }
 
 void
-clear_overlay (GtkAction * action, gpointer param)
+clear_overlay (GtkAction * action, DenemoScriptParam* param)
 {
 }
 #endif
