@@ -20,19 +20,19 @@ gint setup_pitch_input (void);
 gint stop_pitch_input (void);
 void start_pitch_input (void);
 gboolean pitch_recognition_system_active (void);
-gboolean delete_tone (DenemoScore * si, chord * thechord);
-gboolean apply_tones (DenemoScore * si);
-void clear_overlay (GtkAction * action, gpointer param);
+gboolean delete_tone (DenemoMovement * si, chord * thechord);
+gboolean apply_tones (DenemoMovement * si);
+void clear_overlay (GtkAction * action, DenemoScriptParam* param);
 void store_pitch (double pitch);
 double get_pitch (void);
-void set_sharper (GtkAction * action, gpointer param);
-void set_flatter (GtkAction * action, gpointer param);
+void set_sharper (GtkAction * action, DenemoScriptParam * param);
+void set_flatter (GtkAction * action, DenemoScriptParam * param);
 gchar *determine_interval (gint bass, gint harmony, gboolean * status);
 gchar *sharpest (void);
 gchar *flattest (void);
 
 void signal_measure_end (void);
-gboolean pitch_entry_active (DenemoGUI * gui);
+gboolean pitch_entry_active (DenemoProject * gui);
 GtkWidget *get_enharmonic_frame (void);
 GtkWidget *get_temperament_combo (void);
 void reset_temperament (void);
