@@ -55,7 +55,6 @@ struct callbackdata
   GtkWidget *laststaff;
   GtkWidget *pitchspellingchannel;
   GtkWidget *pitchspellingprogram;
-  GtkWidget *modal;
   GtkWidget *cursor_highlight;
   GtkWidget *return_key_is_special;
   GtkWidget *newbie;
@@ -271,17 +270,17 @@ set_preferences (struct callbackdata *cbdata)
     ASSIGNINT (laststaff)
     ASSIGNINT (pitchspellingchannel)
     ASSIGNINT (pitchspellingprogram)
-    ASSIGNBOOLEAN (modal)
+   
     ASSIGNBOOLEAN (persistence)
     ASSIGNBOOLEAN (cursor_highlight)
     ASSIGNBOOLEAN (return_key_is_special)
     ASSIGNBOOLEAN (newbie)
     ASSIGNBOOLEAN (learning)
     ASSIGNBOOLEAN (startmidiin) ASSIGNBOOLEAN (applytoselection) ASSIGNBOOLEAN (quickshortcuts) ASSIGNBOOLEAN (autosave) ASSIGNINT (autosave_timeout) ASSIGNBOOLEAN (midi_in_controls) ASSIGNBOOLEAN (playback_controls) ASSIGNBOOLEAN (console_pane) ASSIGNBOOLEAN (lyrics_pane) ASSIGNBOOLEAN (visible_directive_buttons) ASSIGNBOOLEAN (autoupdate) ASSIGNBOOLEAN (toolbar) ASSIGNBOOLEAN (rhythm_palette) ASSIGNBOOLEAN (object_palette) ASSIGNBOOLEAN (saveparts)
-    //g_print ("Timeout %d \n", prefs->autosave_timeout);
+    //g_debug ("Timeout %d \n", prefs->autosave_timeout);
     if (midi_in_device_was_default && strcmp (prefs->portmidi_input_device->str, "default"))
     {
-      Denemo.gui->input_source = INPUTMIDI;
+      Denemo.project->input_source = INPUTMIDI;
       prefs->startmidiin = TRUE;
     }
   if (prefs->learning)
@@ -317,9 +316,9 @@ midi_audio_tab_update (GtkWidget * box, gpointer data)
 
 //callback for Prefences command
 void
-preferences_change (GtkAction * action, gpointer param)
+preferences_change (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   GtkWidget *dialog;
   GtkWidget *label;
   GtkWidget *separator;
@@ -575,7 +574,7 @@ preferences_change (GtkAction * action, gpointer param)
 
   INTENTRY_LIMITS (_("Excerpt Resolution"), resolution, 72, 600);
   BOOLEANENTRY (_("Enable Thumbnails"), enable_thumbnails);
-  INTENTRY (_("Max recent files"), maxhistory) TEXTENTRY (_("User Name"), username) PASSWORDENTRY (_("Password for Denemo.org"), password) BOOLEANENTRY (_("Use Denemo modally"), modal);
+  INTENTRY (_("Max recent files"), maxhistory) TEXTENTRY (_("User Name"), username) PASSWORDENTRY (_("Password for Denemo.org"), password)
 
   hbox = gtk_hbox_new (FALSE, 8);
   gtk_box_pack_start (GTK_BOX (main_vbox), hbox, FALSE, TRUE, 0);
