@@ -37,13 +37,13 @@ initprefs ()
 #define ret (&Denemo.prefs)
   gchar *dotdenemo = (gchar *) get_user_data_dir (TRUE);
   gchar *localrc = dotdenemo ? g_build_filename (dotdenemo, PREFS_FILE, NULL) : NULL;
-	if(Denemo.old_user_data_dir) {
-		if(confirm (_("Denemo Upgrade"), _("Re-use your old preferences and shortcuts?")))
-			localrc =  g_build_filename (Denemo.old_user_data_dir, PREFS_FILE, NULL);
-		else
-		Denemo.old_user_data_dir = NULL;
-			
-	}
+    if(Denemo.old_user_data_dir) {
+        if(confirm (_("Denemo Upgrade"), _("Re-use your old preferences and shortcuts?")))
+            localrc =  g_build_filename (Denemo.old_user_data_dir, PREFS_FILE, NULL);
+        else
+        Denemo.old_user_data_dir = NULL;
+            
+    }
   /* Reasonable default values */
 
   ret->mode = INPUTEDIT | INPUTRHYTHM | INPUTNORMAL;
@@ -63,7 +63,11 @@ initprefs ()
   ret->browser = g_string_new ("firefox");
   ret->audioplayer = g_string_new ("play");
  #ifdef _GUB_BUILD_
-  ret->lilypath = g_string_new (g_build_filename (get_system_bin_dir (), "lilypond", NULL));
+   #ifdef _MACH_O_
+     ret->lilypath = g_string_new (getenv("LILYPOND_PATH"));
+   #else
+     ret->lilypath = g_string_new (g_build_filename (get_system_bin_dir (), "lilypond", NULL));
+   #endif
  #else
   ret->lilypath = g_string_new ("lilypond");
  #endif
@@ -175,56 +179,56 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
     {
 #define READXMLENTRY(field)  \
       else if (0 == xmlStrcmp (cur->name, (const xmlChar *) #field))\
-	{\
-	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
-	  if(tmp)\
-	    {\
+    {\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      if(tmp)\
+        {\
               define_scheme_variable("DenemoPref_" #field, (gchar*) tmp, NULL);\
-	      prefs->field =\
-		g_string_assign (prefs->field, (gchar *) tmp);\
-	      xmlFree (tmp);\
-	    }\
-	}
+          prefs->field =\
+        g_string_assign (prefs->field, (gchar *) tmp);\
+          xmlFree (tmp);\
+        }\
+    }
 
 #define READINTXMLENTRY(field) \
       else if (0 ==\
-	       xmlStrcmp (cur->name, (const xmlChar *) #field))\
-	{\
-	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
-	  if(tmp)\
-	    {\
+           xmlStrcmp (cur->name, (const xmlChar *) #field))\
+    {\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      if(tmp)\
+        {\
               define_scheme_int_variable("DenemoPref_" #field, atoi((gchar *) tmp), NULL); \
-	      prefs->field = atoi ((gchar *) tmp);\
-	      xmlFree (tmp);\
-	    }\
-	}
+          prefs->field = atoi ((gchar *) tmp);\
+          xmlFree (tmp);\
+        }\
+    }
 
 #define READDOUBLEXMLENTRY(field) \
       else if (0 ==\
-	       xmlStrcmp (cur->name, (const xmlChar *) #field))\
-	{\
-	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
-	  if(tmp)\
-	    {\
+           xmlStrcmp (cur->name, (const xmlChar *) #field))\
+    {\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      if(tmp)\
+        {\
               define_scheme_int_variable("DenemoPref_" #field, atof((gchar *) tmp), NULL); \
-	      prefs->field = atof ((gchar *) tmp);\
-	      xmlFree (tmp);\
-	    }\
-	}
+          prefs->field = atof ((gchar *) tmp);\
+          xmlFree (tmp);\
+        }\
+    }
 
 
 #define READBOOLXMLENTRY(field) \
       else if (0 ==\
-	       xmlStrcmp (cur->name, (const xmlChar *) #field))\
-	{\
-	  xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
-	  if(tmp)\
-	    {\
+           xmlStrcmp (cur->name, (const xmlChar *) #field))\
+    {\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      if(tmp)\
+        {\
               define_scheme_bool_variable("DenemoPref_" #field, atoi((gchar *) tmp), NULL); \
-	      prefs->field = atoi ((gchar *) tmp);\
-	      xmlFree (tmp);\
-	    }\
-	}
+          prefs->field = atoi ((gchar *) tmp);\
+          xmlFree (tmp);\
+        }\
+    }
 
 
 
@@ -238,7 +242,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
               define_scheme_variable (curname, (gchar*) tmp, NULL);
               g_free (curname);
               prefs->lilypath = g_string_assign (prefs->lilypath, (gchar *) tmp);
-              //g_print ("Lilypond Path %s\n", tmp);
+              //g_debug ("Lilypond Path %s\n", tmp);
               xmlFree (tmp);
             }
         }
@@ -255,7 +259,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
               prefs->autosave_timeout = atoi ((gchar *) tmp);
               if (prefs->autosave_timeout < 1)
                 prefs->autosave_timeout = 1;
-              //g_print ("Autosave Timeout %s\n", tmp);
+              //g_debug ("Autosave Timeout %s\n", tmp);
               xmlFree (tmp);
             }
         }
@@ -293,7 +297,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
         READINTXMLENTRY (laststaff)
         READINTXMLENTRY (pitchspellingchannel)
         READINTXMLENTRY (pitchspellingprogram)
-        READBOOLXMLENTRY (modal)
+        
         READBOOLXMLENTRY (persistence)
         READBOOLXMLENTRY (cursor_highlight)
         READBOOLXMLENTRY (return_key_is_special)
@@ -372,7 +376,7 @@ get_bool_pref (gchar * prefname)
     GETBOOLPREF (createclones)
     GETBOOLPREF (immediateplayback)
     GETBOOLPREF (manualtypeset)
-    GETBOOLPREF (modal)
+   
     GETBOOLPREF (persistence)
     GETBOOLPREF (cursor_highlight)
     GETBOOLPREF (return_key_is_special)
@@ -423,12 +427,12 @@ get_string_pref (gchar * prefname)
 /**
  * writeHistoryEntry - adds history entry to the denemohistory file
  * @param data - pointer to the filename to add
- * @param user_data	- pointer to the xml Node
+ * @param user_data - pointer to the xml Node
  */
 static void
 writeHistoryEntry (gpointer data, gpointer user_data)
 {
-  //g_print ("filename %s\n", (gchar *) data);
+  //g_debug ("filename %s\n", (gchar *) data);
   xmlNewTextChild ((xmlNodePtr) user_data, NULL, (xmlChar *) "file", (xmlChar *) data);
 }
 
@@ -439,7 +443,7 @@ writeHistoryEntry (gpointer data, gpointer user_data)
 /**
  * parseHistory - reads history entry from xml node and adds it to the history queue
  * 
- * @param  doc	document pointer
+ * @param  doc  document pointer
  * @param cur pointer to the current XML Node
  * @param prefs pointer to the preferences structure
  */
@@ -465,7 +469,6 @@ parseHistory (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
                   g_warning ("%s", err->message);
                   g_error_free (err);
                 }
-              g_debug ("Filename %s\n", tmp);
               g_queue_push_tail (prefs->history, g_strdup (file));
               g_free (tmp);
               g_free (file);
@@ -517,28 +520,28 @@ readxmlprefs (gchar * xmlsource, gboolean from_file)
   xmlDocPtr doc = NULL;
   xmlNodePtr rootElem;
   if (from_file)
-    printf ("\nxmlsource == %s\n", xmlsource);
+    g_message ("Loading preference file: %s", xmlsource);
   if (from_file)
     doc = xmlParseFile (xmlsource);
   else
     doc = xmlReadMemory (xmlsource, strlen (xmlsource), "noname.xml", NULL, 0);
   if (doc == NULL)
     {
-      g_warning ("Could not read XML %s %s\n", from_file ? "File: " : ":\n", xmlsource);
+      g_warning ("Could not read XML %s %s", from_file ? "File: " : ":", xmlsource);
       return ret;
     }
 
   rootElem = xmlDocGetRootElement (doc);
   if (rootElem == NULL)
     {
-      g_warning ("Empty Document\n");
+      g_warning ("Empty Document");
       xmlFreeDoc (doc);
       return ret;
     }
-  //g_print ("RootElem %s\n", rootElem->name);
+  //g_debug ("RootElem %s\n", rootElem->name);
   if (xmlStrcmp (rootElem->name, (const xmlChar *) "Denemo"))
     {
-      g_warning ("Document has wrong type\n");
+      g_warning ("Document has wrong type");
       xmlFreeDoc (doc);
       return ret;
     }
@@ -620,7 +623,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     g_free(curname);\
     g_free(def);\
     xmlNewChild (child, NULL, (xmlChar *) #field,\
-		 (xmlChar *) prefs->field->str);}
+         (xmlChar *) prefs->field->str);}
 
 #define WRITEXMLENTRY2(field) \
   if (prefs->field){\
@@ -630,7 +633,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     g_free(curname);\
     g_free(def);\
     xmlNewChild (child, NULL, (xmlChar *) #field,\
-		 (xmlChar *) prefs->field);}
+         (xmlChar *) prefs->field);}
 
 
   WRITEXMLENTRY (lilypath) WRITEXMLENTRY (audioplayer) WRITEXMLENTRY (fontspec) WRITEXMLENTRY (imageviewer) WRITEXMLENTRY (profile) WRITEXMLENTRY (username) WRITEXMLENTRY (password) WRITEXMLENTRY (denemopath) WRITEXMLENTRY (temperament)
@@ -642,7 +645,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     g_free(curname);\
     g_free(def);\
   newXMLIntChild (child, (xmlChar *) #field,\
-		  prefs->field);}
+          prefs->field);}
 #define WRITEDOUBLEXMLENTRY(field){ \
     gchar *def = g_strdup("Holds the interger value of the user's " #field " preference");\
     gdouble value = prefs->field;\
@@ -651,7 +654,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     g_free(curname);\
     g_free(def);\
   newXMLDoubleChild (child, (xmlChar *) #field,\
-		  prefs->field);}
+          prefs->field);}
 #define WRITEBOOLXMLENTRY(field){ \
     gchar *def = g_strdup("Holds #t or #f, the user's " #field " preference");\
     gboolean value = prefs->field;\
@@ -660,7 +663,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     g_free(curname);\
     g_free(def);\
   newXMLIntChild (child, (xmlChar *) #field,\
-		  prefs->field);}
+          prefs->field);}
     WRITEBOOLXMLENTRY (autosave)
     WRITEINTXMLENTRY (autosave_timeout)
     WRITEINTXMLENTRY (maxhistory)
@@ -677,7 +680,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
     WRITEINTXMLENTRY (laststaff)
     WRITEINTXMLENTRY (pitchspellingchannel)
     WRITEINTXMLENTRY (pitchspellingprogram)
-    WRITEBOOLXMLENTRY (modal)
+   
     WRITEBOOLXMLENTRY (persistence)
     WRITEBOOLXMLENTRY (cursor_highlight)
     WRITEBOOLXMLENTRY (return_key_is_special)
@@ -738,7 +741,7 @@ writeXMLPrefs (DenemoPrefs * prefs)
 /**
  * Read denemohistory file
  *
- * @param prefs	pointer to the preferences structure 
+ * @param prefs pointer to the preferences structure 
  *
  */
 gint
@@ -753,10 +756,13 @@ readHistory ()
     {
       filename = g_string_new (g_build_filename (get_user_data_dir (TRUE), "denemohistory", NULL));
     }
+
+  gchar* history = oldhistory ? oldhistory : filename->str;
+
   if(Denemo.old_user_data_dir)
-	  oldhistory = g_build_filename (Denemo.old_user_data_dir, "denemohistory", NULL);
-  if (g_file_test (oldhistory? oldhistory:filename->str, G_FILE_TEST_EXISTS))
-    doc = xmlParseFile (oldhistory? oldhistory : filename->str);
+      oldhistory = g_build_filename (Denemo.old_user_data_dir, "denemohistory", NULL);
+  if (g_file_test (history, G_FILE_TEST_EXISTS))
+    doc = xmlParseFile (history);
   else
     return ret;
 
@@ -770,21 +776,21 @@ readHistory ()
   rootElem = xmlDocGetRootElement (doc);
   if (rootElem == NULL)
     {
-      g_warning ("Empty Document\n");
+      g_warning ("Empty history document");
       xmlFreeDoc (doc);
       return ret;
     }
-  g_debug ("RootElem %s\n", rootElem->name);
+
   if (xmlStrcmp (rootElem->name, (const xmlChar *) "Denemo"))
     {
-      g_warning ("Document has wrong type\n");
+      g_warning ("Document has wrong type");
       xmlFreeDoc (doc);
       return ret;
     }
   rootElem = rootElem->xmlChildrenNode;
+  g_message("Reading history file %s", history);
   while (rootElem != NULL)
     {
-      g_debug ("RootElem 2 %s\n", rootElem->name);
       if (0 == xmlStrcmp (rootElem->name, (const xmlChar *) "History"))
         {
           parseHistory (doc, rootElem, &Denemo.prefs);
