@@ -47,7 +47,7 @@ typedef struct lilyversion
 
 gint LilyPond_stderr = -1;       //A file descriptor to pipe for LilyPond's stderr
 GError *lily_err = NULL;
-gint changecount = -1;   //changecount when the printfile was last created FIXME multiple tabs are muddled
+
 GPid previewerpid = GPID_NONE;
 
 printstatus*
@@ -77,7 +77,7 @@ advance_printname ()
 
   get_print_status()->cycle = !get_print_status()->cycle;
   /*gint success =*/ g_unlink (get_print_status()->printname_pdf[get_print_status()->cycle]);
-  //g_print("Removed old pdf file %s %d\n",get_print_status()->printname_pdf[get_print_status()->cycle], success);
+  //g_debug("Removed old pdf file %s %d\n",get_print_status()->printname_pdf[get_print_status()->cycle], success);
 }
 
 
@@ -86,7 +86,7 @@ advance_printname ()
  */
 /* UNUSED
 gboolean
-check_lilypond_path (DenemoGUI * gui)
+check_lilypond_path (DenemoProject * gui)
 {
 
   gchar *lilypath = g_find_program_in_path (Denemo.prefs.lilypath->str);
@@ -288,7 +288,7 @@ process_lilypond_errors (gchar * filename)
       g_free (bytes);
       return;
     }
-  //g_print("\nLilyPond error messages\n8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8>< %s \n8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><\n", bytes);
+  //g_debug("\nLilyPond error messages\n8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8>< %s \n8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><8><\n", bytes);
   epoint = g_strstr_len (bytes, strlen (bytes), filename_colon);
   if (epoint)
     {
@@ -386,7 +386,7 @@ open_viewer (gint status, gchar * filename)
           if (!ok)
             {
               err = g_error_new (G_FILE_ERROR, -1, "Could not run file assoc for %s", ".png");
-              g_warning ("Could not run the file association for a %s file\n", ".png");
+              g_warning ("Could not run the file association for a %s file", ".png");
             }
         }
       else
@@ -448,7 +448,7 @@ run_lilypond (gchar ** arguments)
     }
   if (lily_err)
     {
-      g_warning ("Old error message from launching lilypond still present - message was %s\nDiscarding...\n", lily_err->message);
+      g_warning ("Old error message from launching lilypond still present - message was %s\nDiscarding...", lily_err->message);
       g_error_free (lily_err);
       lily_err = NULL;
     }
@@ -470,7 +470,7 @@ run_lilypond (gchar ** arguments)
                                                                &lily_err);
   if (lily_err)
     {
-      g_warning ("Error launching lilypond! Message is %s\n", lily_err->message);
+      g_warning ("Error launching lilypond! Message is %s", lily_err->message);
       g_error_free (lily_err);
       lily_err = NULL;
       error = -1;
@@ -500,7 +500,7 @@ stop_lilypond ()
 static void
 generate_lilypond (gchar * lilyfile, gboolean part_only, gboolean all_movements)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (part_only)
     export_lilypond_part (lilyfile, gui, all_movements);
   else
@@ -545,7 +545,7 @@ create_pdf (gboolean part_only, gboolean all_movements)
  */
 
 void
-printrangedialog (DenemoGUI * gui)
+printrangedialog (DenemoProject * gui)
 {
   GtkWidget *dialog;
   GtkWidget *label;
@@ -560,14 +560,14 @@ printrangedialog (DenemoGUI * gui)
   GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
   gtk_container_add (GTK_CONTAINER (content_area), hbox);
 
-  gint max_measure = g_list_length (((DenemoStaff *) (gui->si->thescore->data))->measures);
+  gint max_measure = g_list_length (((DenemoStaff *) (gui->movement->thescore->data))->measures);
 
   label = gtk_label_new (_("Print from Measure"));
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
   from_measure = gtk_spin_button_new_with_range (1.0, (gdouble) max_measure, 1.0);
   gtk_box_pack_start (GTK_BOX (hbox), from_measure, TRUE, TRUE, 0);
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (from_measure), (gdouble) gui->si->selection.firstmeasuremarked);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (from_measure), (gdouble) gui->movement->selection.firstmeasuremarked);
 
   label = gtk_label_new (_("to"));
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
@@ -575,7 +575,7 @@ printrangedialog (DenemoGUI * gui)
   to_measure = gtk_spin_button_new_with_range (1.0, (gdouble) max_measure, 1.0);
   gtk_box_pack_start (GTK_BOX (hbox), to_measure, TRUE, TRUE, 0);
   //  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), to_measure, TRUE, TRUE, 0);
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (to_measure), (gdouble) gui->si->selection.lastmeasuremarked);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (to_measure), (gdouble) gui->movement->selection.lastmeasuremarked);
 
   gtk_widget_show (hbox);
   gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
@@ -584,18 +584,18 @@ printrangedialog (DenemoGUI * gui)
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     {
-      gui->si->selection.firstmeasuremarked = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (from_measure));
-      gui->si->selection.lastmeasuremarked = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (to_measure));
+      gui->movement->selection.firstmeasuremarked = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (from_measure));
+      gui->movement->selection.lastmeasuremarked = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (to_measure));
       //gtk_widget_destroy (dialog);
     }
   else
     {
-      gui->si->selection.firstmeasuremarked = gui->si->selection.lastmeasuremarked = 0;
+      gui->movement->selection.firstmeasuremarked = gui->movement->selection.lastmeasuremarked = 0;
     }
-  if (gui->si->selection.firstmeasuremarked)
+  if (gui->movement->selection.firstmeasuremarked)
     {
-      gui->si->markstaffnum = gui->si->selection.firststaffmarked = 1;
-      gui->si->selection.laststaffmarked = g_list_length (gui->si->thescore);
+      gui->movement->markstaffnum = gui->movement->selection.firststaffmarked = 1;
+      gui->movement->selection.laststaffmarked = g_list_length (gui->movement->thescore);
     }
 
   gtk_widget_destroy (dialog);
@@ -604,7 +604,7 @@ printrangedialog (DenemoGUI * gui)
 static void
 rm_temp_files (gchar * file, gpointer free_only)
 {
-  //g_print("\n%s Deleting temp file %s\n",free_only?"Not":"", file);
+  //g_debug("\n%s Deleting temp file %s\n",free_only?"Not":"", file);
   if (!free_only)
     g_remove (file);
   g_free (file);
@@ -654,10 +654,10 @@ prepare_preview (GPid pid, gint status, GList * filelist)
  *
  *  @param filename filename to save score to
  *  @param finish callback after creating png or if NULL, wait for finish before returning.
- *  @param gui pointer to the DenemoGUI structure
+ *  @param gui pointer to the DenemoProject structure
  */
 void
-export_png (gchar * filename, GChildWatchFunc finish, DenemoGUI * gui)
+export_png (gchar * filename, GChildWatchFunc finish, DenemoProject * gui)
 {
   gchar *basename;
   gchar *lilyfile;
@@ -705,26 +705,36 @@ export_png (gchar * filename, GChildWatchFunc finish, DenemoGUI * gui)
     NULL
   };
 
+  gchar* output = g_strconcat(filename, ".png", NULL);
+  g_debug("Generating %s from Lilypond", output);
+
   /* generate the png file */
   if (finish)
     {
       gint error = run_lilypond (arguments);
       if (!error)
         g_child_watch_add (get_print_status()->printpid, (GChildWatchFunc) finish, (gchar *) filelist);
+
+      if(!g_file_test(output, G_FILE_TEST_EXISTS))
+        g_critical("Lilypond has not generated %s", output);
     }
   else
     {
       GError *err = NULL;
       g_spawn_sync (locateprintdir (),  /* dir */
-                    arguments, NULL,    /* env */
-                    G_SPAWN_SEARCH_PATH, NULL,  /* child setup func */
+                    arguments, 
+                    NULL,    /* env */
+                    G_SPAWN_SEARCH_PATH, 
+                    NULL,  /* child setup func */
                     NULL,       /* user data */
                     NULL,       /* stdout */
                     NULL,       /* stderr */
                     NULL, &err);
-      //These are in tmpdir and can be used for the .eps file, so don't delete them   g_list_foreach(filelist, (GFunc)rm_temp_files, FALSE);
+      //These are in tmpdir and can be used for the .eps file, so don't delete them   
+      //g_list_foreach(filelist, (GFunc)rm_temp_files, FALSE);
       g_list_free (filelist);
     }
+  g_free(output);
 }
 
 /**
@@ -732,11 +742,11 @@ export_png (gchar * filename, GChildWatchFunc finish, DenemoGUI * gui)
  * calls exportmudela and then  
  * runs lilypond to a create a filename.pdf
  *
- *	@param filename filename to save score to
- *  @param gui pointer to the DenemoGUI structure
+ *  @param filename filename to save score to
+ *  @param gui pointer to the DenemoProject structure
  */
 void
-export_pdf (gchar * filename, DenemoGUI * gui)
+export_pdf (gchar * filename, DenemoProject * gui)
 {
   gchar *basename;
   gchar *lilyfile;
@@ -778,17 +788,17 @@ export_pdf (gchar * filename, DenemoGUI * gui)
 
 /* callback to print current part (staff) of score */
 void
-printpart_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+printpart_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
 #ifndef USE_EVINCE  
   g_debug("This feature requires denemo to be built with evince");
 #else
   present_print_view_window();
-  DenemoGUI *gui = Denemo.gui;
-  if (gui->si->markstaffnum)
+  DenemoProject *gui = Denemo.project;
+  if (gui->movement->markstaffnum)
     if (confirm (_("A range of music is selected"), _("Print whole file?")))
       {
-        gui->si->markstaffnum = 0;
+        gui->movement->markstaffnum = 0;
       }
   if ((gui->movements && g_list_length (gui->movements) > 1) && (confirm (_("This piece has several movements"), _("Print this part from all of them?"))))
     create_pdf (TRUE, TRUE);
@@ -799,12 +809,12 @@ printpart_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
 }
 
 void
-printselection_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+printselection_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
 #ifndef USE_EVINCE  
   g_debug("This feature requires denemo to be built with evince");
 #else
-  if (Denemo.gui->si->markstaffnum) {
+  if (Denemo.project->movement->markstaffnum) {
     present_print_view_window();
     create_pdf (FALSE, FALSE);
     g_child_watch_add (get_print_status()->printpid, (GChildWatchFunc) printview_finished, (gpointer) (TRUE));
@@ -815,12 +825,12 @@ printselection_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer para
 }
 
 void
-printexcerptpreview_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+printexcerptpreview_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  if (!gui->si->markstaffnum)   //If no selection has been made 
+  DenemoProject *gui = Denemo.project;
+  if (!gui->movement->markstaffnum)   //If no selection has been made 
     printrangedialog (gui);     //Launch a dialog to get selection
-  if (gui->si->selection.firstmeasuremarked)
+  if (gui->movement->selection.firstmeasuremarked)
     {
       gui->lilycontrol.excerpt = TRUE;
       export_png ((gchar *) get_printfile_pathbasename (), (GChildWatchFunc) prepare_preview, gui);
@@ -830,7 +840,7 @@ printexcerptpreview_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer
 
 /* callback to print whole of score */
 void
-printall_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+printall_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
 #ifndef USE_EVINCE  
   g_debug("This feature requires denemo to be built with evince");
@@ -841,22 +851,20 @@ printall_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
 
 /* callback to print movement of score */
 void
-printmovement_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED gpointer param)
+printmovement_cb (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
 #ifndef USE_EVINCE  
   g_debug("This feature requires denemo to be built with evince");
 #else
-  changecount = -1;
   print_from_print_view (FALSE);
-  changecount = Denemo.gui->changecount;
 #endif
 }
 
 void
-show_print_view (GtkAction * action, G_GNUC_UNUSED gpointer param){
+show_print_view (GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param){
 #ifndef USE_EVINCE  
   g_debug("This feature requires denemo to be built with evince");
 #else
-  _show_print_view(action);
+  implement_show_print_view(action!=NULL);
 #endif
 }
