@@ -8,7 +8,7 @@
 #define SAME 1
 #define LESSER 0
 #define GPID_NONE (-1)
-#define INSTALLED_LILYPOND_VERSION "2.16"       /* FIXME set via gub */
+#define INSTALLED_LILYPOND_VERSION "2.18"       /* FIXME set via gub */
 #define MANUAL _("Manual Updates")
 #define CONTINUOUS _("Continuous")
 
@@ -86,6 +86,7 @@ typedef enum
   OBJ_NONE,
   Beam,
   Slur,
+  Tie,
   Articulation,
   BassFigure,
 } WwGrob;
@@ -115,27 +116,26 @@ typedef struct WysiwygInfo
 
 gint LilyPond_stderr;       //A file descriptor to pipe for LilyPond's stderr
 GError *lily_err;
-gint changecount;   //changecount when the printfile was last created FIXME multiple tabs are muddled
 GPid previewerpid;
 
 WysiwygInfo* get_wysiwyg_info();
 printstatus* get_print_status();
-void printall_cb (GtkAction * action, gpointer param);
-void printmovement_cb (GtkAction * action, gpointer param);
-void printpart_cb (GtkAction * action, gpointer param);
-void printselection_cb (GtkAction * action, gpointer param);
+void printall_cb (GtkAction * action, DenemoScriptParam * param);
+void printmovement_cb (GtkAction * action, DenemoScriptParam * param);
+void printpart_cb (GtkAction * action, DenemoScriptParam * param);
+void printselection_cb (GtkAction * action, DenemoScriptParam * param);
 
-void printexcerptpreview_cb (GtkAction * action, gpointer param);
+void printexcerptpreview_cb (GtkAction * action, DenemoScriptParam * param);
 gchar *get_lily_version_string (void);
-void export_pdf (gchar * filename, DenemoGUI * gui);
-void export_png (gchar * filename, GChildWatchFunc finish, DenemoGUI * gui);
+void export_pdf (gchar * filename, DenemoProject * gui);
+void export_png (gchar * filename, GChildWatchFunc finish, DenemoProject * gui);
 void printpng_finished (GPid pid, gint status, GList * filelist);
-gboolean create_thumbnail (gboolean async);
+gboolean create_thumbnail (gboolean async, gchar* thumbnail_path);
 gchar *large_thumbnail_name (gchar * filepath);
 gboolean stop_lilypond ();
 void process_lilypond_errors (gchar * filename);
 gchar *get_printfile_pathbasename (void);
 void create_pdf (gboolean part_only, gboolean all_movements);
-void show_print_view (GtkAction * action, gpointer param);
+void show_print_view (GtkAction * action, DenemoScriptParam * param);
 
 #endif /*PRINT_H */
