@@ -2,9 +2,9 @@
 #define __PRINT_VIEW_H__
 
 #include <denemo/denemo.h>
-
+#include "print.h"
 gboolean get_offset (gdouble * x, gdouble * y);
-gboolean get_positions (gdouble * neary, gdouble * fary, gboolean for_slur);
+gboolean get_positions (gdouble * neary, gdouble * fary, WwGrob grob);
 gboolean get_new_target (void);
 gboolean get_reference_point (void);
 gboolean get_control_point (gint which);
@@ -18,10 +18,10 @@ int check_lily_version (gchar * version);
 gboolean typeset_for_script (gchar * script);
 gboolean print_typeset_pdf (void);
 void typeset_current_layout (void);
-void _show_print_view (GtkAction * action);
+void implement_show_print_view (gboolean refresh_if_needed);
 void install_printpreview (GtkWidget * vbox);
 void refresh_print_view (gboolean interactive);
 void printview_finished (G_GNUC_UNUSED GPid pid, G_GNUC_UNUSED gint status, gboolean print);
 void print_from_print_view (gboolean all_movements);
 
-#endif
\ No newline at end of file
+#endif
