@@ -31,119 +31,122 @@
 
 
 /**
- * Create new DenemoScore with no staff
- * set it as gui->si but do not add it to the movements list.
+ * Create new DenemoMovement with no staff
+ * set it as gui->movement but do not add it to the movements list.
  */
 void
-point_to_empty_movement (DenemoGUI * gui)
+point_to_empty_movement (DenemoProject * gui)
 {
-  DenemoScore *newscore = (DenemoScore *) g_malloc0 (sizeof (DenemoScore));
+  DenemoMovement *newscore = (DenemoMovement *) g_malloc0 (sizeof (DenemoMovement));
   init_score (newscore, gui);
-  if (gui->si && gui->si->buttonbox)
-    gtk_widget_hide (gui->si->buttonbox);
+  if (!Denemo.non_interactive && gui->movement && gui->movement->buttonbox)
+    gtk_widget_hide (gui->movement->buttonbox);
   g_static_mutex_lock (&smfmutex);
-  gui->si = newscore;
+  gui->movement = newscore;
   g_static_mutex_unlock (&smfmutex);
-  gtk_widget_show (gui->si->buttonbox);
+  if(!Denemo.non_interactive)
+    gtk_widget_show (gui->movement->buttonbox);
+
 }
 
 /**
- * Create new DenemoScore with one empty staff
- * set it as gui->si but do not add it to the movements list.
+ * Create new DenemoMovement with one empty staff
+ * set it as gui->movement but do not add it to the movements list.
  */
 void
-point_to_new_movement (DenemoGUI * gui)
+point_to_new_movement (DenemoProject * gui)
 {
   point_to_empty_movement (gui);
   newstaff (gui, INITIAL, DENEMO_NONE);
-  gui->si->undo_guard = Denemo.prefs.disable_undo;
+  gui->movement->undo_guard = Denemo.prefs.disable_undo;
 }
 
 static void select_movement (gint movementnum) {
-	goto_movement_staff_obj (NULL, movementnum, 0, 0, 0);
-	set_movement_selector (Denemo.gui);
-	displayhelper (Denemo.gui);
-	write_status (Denemo.gui);	
+    goto_movement_staff_obj (NULL, movementnum, 0, 0, 0);
+    set_movement_selector (Denemo.project);
+    displayhelper (Denemo.project);
+    write_status (Denemo.project);  
 }
 
 #define NUM_MOVEMENTS_TO_SHOW (2*5)
-void set_movement_selector (DenemoGUI *gui)
+void set_movement_selector (DenemoProject *gui)
 {
   GtkWidget *button;
   GList *g;
   gint i;
   
   if(gui->movements_selector)
-	gtk_widget_destroy (gui->movements_selector);
+      gtk_widget_destroy (gui->movements_selector);
   gui->movements_selector = (GtkWidget*)gtk_hbox_new(FALSE,1);
   gtk_box_pack_start(GTK_BOX(gui->buttonbox), gui->movements_selector,  FALSE, TRUE, 0);
   gtk_widget_show (gui->movements_selector);
   gint num_movements = 1;
-  gint last = 1, first = 1;
+  gint last = 1;
+  gint first = 1;
   if(gui->movements) {
-	  gint current = g_list_index (gui->movements, gui->si) + 1;
-	  num_movements = g_list_length(gui->movements);
-	  first = current - NUM_MOVEMENTS_TO_SHOW/2;
-	  if(first<1) first = 1;
-	  last = first + NUM_MOVEMENTS_TO_SHOW -1;
-	  
-	  if(last>num_movements) 
-	  {
-		  last = num_movements;
-		  first = num_movements - NUM_MOVEMENTS_TO_SHOW;
-		  if(first<1) first = 1;
-		}
+      gint current = g_list_index (gui->movements, gui->movement) + 1;
+      num_movements = g_list_length(gui->movements);
+      first = current - NUM_MOVEMENTS_TO_SHOW/2;
+      if(first<1) first = 1;
+      last = first + NUM_MOVEMENTS_TO_SHOW -1;
+      
+      if(last>num_movements) 
+      {
+          last = num_movements;
+          first = num_movements - NUM_MOVEMENTS_TO_SHOW;
+          if(first<1) first = 1;
+        }
   }
   for (g=gui->movements, i=1;g;g=g->next, i++)
-	{
-		if(i<first)
-			continue;
-		if(i>last)
-			continue;
-		button = gtk_button_new_with_label("");
-		if (g->data == gui->si)
-		{
-			gchar *text = g_strdup_printf("<span foreground=\"blue\"><i><b>%d</b></i></span>", i);
-			GtkWidget *label_widget = gtk_bin_get_child(GTK_BIN(button));
-			gtk_label_set_use_markup (GTK_LABEL(label_widget), TRUE);
-			gtk_label_set_markup (GTK_LABEL (label_widget), text);
-			g_free(text);
-			text = g_strdup_printf(_("This is the current movement number %d\nClick on another button to change movements"), i);
-			gtk_widget_set_tooltip_text (button, text);
-			g_free(text);
-		} else 
-		{
-			gchar *more = "";
-			if((last<num_movements) && (i==last))
-				more = "+...";
-			gchar *text = g_strdup_printf("%d%s", i, more);
-			gtk_button_set_label (button, text);
-			g_free(text);
-			text = g_strdup_printf(_("Click to switch to movement number %d"), i);
-			gtk_widget_set_tooltip_text (button, text);
-			g_free(text);
-		}
-		
-		
-		gtk_widget_set_can_focus (button, FALSE);
-		gtk_widget_show(button);
-		g_signal_connect_swapped (G_OBJECT(button), "clicked", G_CALLBACK (select_movement), (gpointer) i);
-		gtk_box_pack_start (GTK_BOX(gui->movements_selector), button,  FALSE, TRUE, 0);
-	}
-	if(i==2) 
-		gtk_widget_hide (gui->movements_selector);
+    {
+        if(i<first)
+            continue;
+        if(i>last)
+            continue;
+        button = gtk_button_new_with_label("");
+        if (g->data == gui->movement)
+        {
+            gchar *text = g_strdup_printf("<span foreground=\"blue\"><i><b>%d</b></i></span>", i);
+            GtkWidget *label_widget = gtk_bin_get_child(GTK_BIN(button));
+            gtk_label_set_use_markup (GTK_LABEL(label_widget), TRUE);
+            gtk_label_set_markup (GTK_LABEL (label_widget), text);
+            g_free(text);
+            text = g_strdup_printf(_("This is the current movement number %d\nClick on another button to change movements"), i);
+            gtk_widget_set_tooltip_text (button, text);
+            g_free(text);
+        } else 
+        {
+            gchar *more = "";
+            if((last<num_movements) && (i==last))
+                more = "+...";
+            gchar *text = g_strdup_printf("%d%s", i, more);
+            gtk_button_set_label (button, text);
+            g_free(text);
+            text = g_strdup_printf(_("Click to switch to movement number %d"), i);
+            gtk_widget_set_tooltip_text (button, text);
+            g_free(text);
+        }
+        
+        
+        gtk_widget_set_can_focus (button, FALSE);
+        gtk_widget_show(button);
+        g_signal_connect_swapped (G_OBJECT(button), "clicked", G_CALLBACK (select_movement), (gpointer) i);
+        gtk_box_pack_start (GTK_BOX(gui->movements_selector), button,  FALSE, TRUE, 0);
+    }
+    if(i==2) 
+        gtk_widget_hide (gui->movements_selector);
 }
 static void
 new_movement (GtkAction * action, DenemoScriptParam * param, gboolean before)
 {
-  DenemoGUI *gui = Denemo.gui;
-  gint pos = g_list_index (gui->movements, gui->si);
+  DenemoProject *gui = Denemo.project;
+  gint pos = g_list_index (gui->movements, gui->movement);
   append_new_movement (action, param);
-  DenemoScore *newsi = g_list_last (gui->movements)->data;
+  DenemoMovement *newsi = g_list_last (gui->movements)->data;
   gui->movements = g_list_delete_link (gui->movements, g_list_last (gui->movements));
   gui->movements = g_list_insert (gui->movements, newsi, before ? pos : pos + 1);
   newsi->currentmovementnum = 1 + g_list_index (gui->movements, newsi);
-  setcurrentprimarystaff (gui->si);
+  setcurrentprimarystaff (gui->movement);
   gui->movements_selector = NULL;
   set_movement_selector (gui);
   
@@ -155,13 +158,13 @@ new_movement (GtkAction * action, DenemoScriptParam * param, gboolean before)
 static void
 append_movement (GtkAction * action, gpointer param, gboolean populate)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoScore *source_movement = gui->si;
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *source_movement = gui->movement;
   GList *g;
   (void) signal_structural_change (gui);
 
-  if (gui->si->lyricsbox)
-    gtk_widget_hide (gui->si->lyricsbox);
+  if (gui->movement->lyricsbox)
+    gtk_widget_hide (gui->movement->lyricsbox);
   point_to_empty_movement (gui);
   for (g = source_movement->thescore; g; g = g->next)
     {
@@ -169,19 +172,19 @@ append_movement (GtkAction * action, gpointer param, gboolean populate)
       newstaff (gui, LAST, DENEMO_NONE);
       if (!populate)
         break;
-      GList *dest = g_list_last (gui->si->thescore);
+      GList *dest = g_list_last (gui->movement->thescore);
       DenemoStaff *dest_staff = dest->data;
       copy_staff (source_staff, dest_staff);
     }
-  gui->movements = g_list_append (gui->movements, gui->si);
-  gui->si->currentmovementnum = 1 + g_list_index (gui->movements, gui->si);
+  gui->movements = g_list_append (gui->movements, gui->movement);
+  gui->movement->currentmovementnum = 1 + g_list_index (gui->movements, gui->movement);
   set_movement_selector (gui);
-  gui->si->undo_guard = Denemo.prefs.disable_undo;
+  gui->movement->undo_guard = Denemo.prefs.disable_undo;
   call_out_to_guile ("(d-DirectivePut-header-postfix \"SuppressTitleRepeats\" \"title = ##f\ninstrument = ##f\n\")");
   set_width_to_work_with (gui);
   //FIXME duplicate code
-  set_rightmeasurenum (gui->si);
-  find_leftmost_allcontexts (gui->si);
+  set_rightmeasurenum (gui->movement);
+  find_leftmost_allcontexts (gui->movement);
   set_bottom_staff (gui);
   update_hscrollbar (gui);
   update_vscrollbar (gui);
@@ -194,7 +197,7 @@ append_movement (GtkAction * action, gpointer param, gboolean populate)
 
 //copies staff structure to new movement
 void
-append_new_movement (GtkAction * action, gpointer param)
+append_new_movement (GtkAction * action, DenemoScriptParam * param)
 {
   append_movement (action, param, TRUE);
 }
@@ -229,25 +232,25 @@ terminate_playback (void)
   g_thread_yield ();            //FIXME find a better way of ensuring playing is finished - in principle the user could start playing again
   if (is_playing ())
     terminate_playback ();
-  //g_print("Terminated %d\n", is_playing());
+  //g_debug("Terminated %d\n", is_playing());
 }
 
 void
-reset_movement_numbers (DenemoGUI * gui)
+reset_movement_numbers (DenemoProject * gui)
 {
   GList *g;
   gint i;
   for (i = 1, g = gui->movements; g; g = g->next, i++)
     {
-      DenemoScore *si = g->data;
+      DenemoMovement *si = g->data;
       si->currentmovementnum = i;
     }
 }
 
 void
-delete_movement (GtkAction * action, gpointer param)
+delete_movement (GtkAction * action, DenemoScriptParam* param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   terminate_playback ();
   (void) signal_structural_change (gui);
   GString *primary = g_string_new (""), *secondary = g_string_new ("");
@@ -265,17 +268,17 @@ delete_movement (GtkAction * action, gpointer param)
     }
   else
     {                           // more than one movement
-      gint num = g_list_index (gui->movements, gui->si);
+      gint num = g_list_index (gui->movements, gui->movement);
       g_string_printf (primary, _("This is movement #%d"), num + 1);
       g_string_assign (secondary, _("Delete entire movement?"));
       if (confirm (primary->str, secondary->str))
         {
           free_score (gui);
-          DenemoScore *si = gui->si;
+          DenemoMovement *si = gui->movement;
           GList *g = g_list_find (gui->movements, si)->next;
           if (g == NULL)
             g = g_list_find (gui->movements, si)->prev;
-          gui->si = g->data;
+          gui->movement = g->data;
           gui->movements = g_list_remove (gui->movements, (gpointer) si);
         }
     }
@@ -293,12 +296,12 @@ delete_movement (GtkAction * action, gpointer param)
 possible_gui is really a flag interactive or not
 */
 gboolean
-goto_movement_staff_obj (DenemoGUI * possible_gui, gint movementnum, gint staffnum, gint measurenum, gint objnum)
+goto_movement_staff_obj (DenemoProject * possible_gui, gint movementnum, gint staffnum, gint measurenum, gint objnum)
 {
-  DenemoGUI *gui;
+  DenemoProject *gui;
   terminate_playback ();
   if (possible_gui == NULL)
-    gui = Denemo.gui;
+    gui = Denemo.project;
   else
     gui = possible_gui;
   if (movementnum > 0)
@@ -310,9 +313,9 @@ goto_movement_staff_obj (DenemoGUI * possible_gui, gint movementnum, gint staffn
             warningdialog (_("No such movement"));
           return FALSE;
         }
-      gtk_widget_hide (gui->si->buttonbox);
-      gui->si = this->data;
-      gtk_widget_show (gui->si->buttonbox);
+      gtk_widget_hide (gui->movement->buttonbox);
+      gui->movement = this->data;
+      gtk_widget_show (gui->movement->buttonbox);
     }
 
 
@@ -329,21 +332,21 @@ goto_movement_staff_obj (DenemoGUI * possible_gui, gint movementnum, gint staffn
       return FALSE;
     }
   //cursor_x is zero and we are on the first, if any, object
-  if (gui->si->currentobject == NULL && objnum)
+  if (gui->movement->currentobject == NULL && objnum)
     return FALSE;               //asking for an object in an empty measure
 
-  while (--objnum > 0 && gui->si->currentobject && gui->si->currentobject->next)
+  while (--objnum > 0 && gui->movement->currentobject && gui->movement->currentobject->next)
     {
-      gui->si->currentobject = gui->si->currentobject->next;
-      gui->si->cursor_x++;
+      gui->movement->currentobject = gui->movement->currentobject->next;
+      gui->movement->cursor_x++;
     }
-  // g_print("objnum %d\n",objnum);
+  //g_debug("objnum %d\n",objnum);
   if (objnum > 0)
     {
-      gui->si->cursor_x++;      // objnum;
-      if (!gui->si->currentobject)
+      gui->movement->cursor_x++;      // objnum;
+      if (!gui->movement->currentobject)
         return FALSE;
-      gui->si->cursor_appending = TRUE;
+      gui->movement->cursor_appending = TRUE;
     }
   set_movement_selector (gui);
   write_status (gui);
@@ -368,8 +371,8 @@ PopPosition (GtkAction * action, DenemoScriptParam * param)
   param->status = goto_movement_staff_obj (NULL, pos->movement, pos->staff, pos->measure, pos->object);
   if (param->status)
     {
-      Denemo.gui->si->cursor_appending = pos->appending;
-      Denemo.gui->si->cursoroffend = pos->offend;
+      Denemo.project->movement->cursor_appending = pos->appending;
+      Denemo.project->movement->cursoroffend = pos->offend;
     }
   g_free (pos);
 }
@@ -393,8 +396,8 @@ PopPushPosition (GtkAction * action, DenemoScriptParam * param)
       param->status = goto_movement_staff_obj (NULL, pos->movement, pos->staff, pos->measure, pos->object);
       if (param->status)
         {
-          Denemo.gui->si->cursor_appending = pos->appending;
-          Denemo.gui->si->cursoroffend = pos->offend;
+          Denemo.project->movement->cursor_appending = pos->appending;
+          Denemo.project->movement->cursoroffend = pos->offend;
         }
     }
   else
@@ -405,15 +408,15 @@ PopPushPosition (GtkAction * action, DenemoScriptParam * param)
 /**
  * Move to the next movement
  * @param action - Gtk Action event
- * @param gui - pointer to the DenemoGUI structure
+ * @param gui - pointer to the DenemoProject structure
  * @return none
 */
 void
 next_movement (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   terminate_playback ();
-  GList *this = g_list_find (gui->movements, gui->si);
+  GList *this = g_list_find (gui->movements, gui->movement);
   this = this->next;
   if (param)
     param->status = TRUE;
@@ -425,19 +428,20 @@ next_movement (GtkAction * action, DenemoScriptParam * param)
         warningmessage (_("This is the last movement"));
       return;
     }
-  gtk_widget_hide (gui->si->buttonbox);
-  if (gui->si->lyricsbox)
-    gtk_widget_hide (gui->si->lyricsbox);
-  gui->si = this->data;
-  if (gui->si->lyricsbox && Denemo.prefs.lyrics_pane)
-    gtk_widget_show (gui->si->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
-  gtk_widget_show (gui->si->buttonbox);
-  set_master_tempo (gui->si, 1.0);
+  if(Denemo.non_interactive) return;
+  gtk_widget_hide (gui->movement->buttonbox);
+  if (gui->movement->lyricsbox)
+    gtk_widget_hide (gui->movement->lyricsbox);
+  gui->movement = this->data;
+  if (gui->movement->lyricsbox && Denemo.prefs.lyrics_pane)
+    gtk_widget_show (gui->movement->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
+  gtk_widget_show (gui->movement->buttonbox);
+  set_master_tempo (gui->movement, 1.0);
   set_movement_selector (gui);
   //!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
-  set_rightmeasurenum (gui->si);
-  find_leftmost_allcontexts (gui->si);
+  set_rightmeasurenum (gui->movement);
+  find_leftmost_allcontexts (gui->movement);
   set_bottom_staff (gui);
 
   update_hscrollbar (gui);
@@ -454,15 +458,15 @@ next_movement (GtkAction * action, DenemoScriptParam * param)
 /**
  * Move to the previous movement
  * @param action - Gtk Action event
- * @param gui - pointer to the DenemoGUI structure
+ * @param gui - pointer to the DenemoProject structure
  * @return none
 */
 void
 prev_movement (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   terminate_playback ();
-  GList *this = g_list_find (gui->movements, gui->si);
+  GList *this = g_list_find (gui->movements, gui->movement);
   this = this->prev;
   if (param)
     param->status = TRUE;
@@ -474,18 +478,19 @@ prev_movement (GtkAction * action, DenemoScriptParam * param)
         warningmessage (_("This is the first movement"));
       return;
     }
-  gtk_widget_hide (gui->si->buttonbox);
-  if (gui->si->lyricsbox)
-    gtk_widget_hide (gui->si->lyricsbox);
-  gui->si = this->data;
-  if (gui->si->lyricsbox)
-    gtk_widget_show (gui->si->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
-  gtk_widget_show (gui->si->buttonbox);
-  set_master_tempo (gui->si, 1.0);
+  if(Denemo.non_interactive) return;
+  gtk_widget_hide (gui->movement->buttonbox);
+  if (gui->movement->lyricsbox)
+    gtk_widget_hide (gui->movement->lyricsbox);
+  gui->movement = this->data;
+  if (gui->movement->lyricsbox)
+    gtk_widget_show (gui->movement->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
+  gtk_widget_show (gui->movement->buttonbox);
+  set_master_tempo (gui->movement, 1.0);
    set_movement_selector (gui);
   //!!!!!!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
-  set_rightmeasurenum (gui->si);
+  set_rightmeasurenum (gui->movement);
   set_bottom_staff (gui);
 
   update_hscrollbar (gui);
@@ -507,7 +512,7 @@ prev_movement (GtkAction * action, DenemoScriptParam * param)
  * @param si pointer to the scoreinfo structure to initialise
  */
 void
-init_score (DenemoScore * si, DenemoGUI * gui)
+init_score (DenemoMovement * si, DenemoProject * gui)
 {
   gchar *dir = (gchar *) get_user_data_dir (TRUE);
 
@@ -544,14 +549,14 @@ init_score (DenemoScore * si, DenemoGUI * gui)
   si->stafftoplay = 0;
   si->start_time = 0;
   si->end_time = -1.0;          //ie unset
-  if (Denemo.gui->si)
+  if (Denemo.project->movement)
     set_master_volume (si, 1.0);
   else
     si->master_volume = 1.0;
 
 
   si->tempo_change_time = 0.0;
-  if (Denemo.gui->si)
+  if (Denemo.project->movement)
     set_master_tempo (si, 1.0);
   else
     si->master_tempo = 1.0;
@@ -578,19 +583,21 @@ init_score (DenemoScore * si, DenemoGUI * gui)
   si->redodata = g_queue_new ();
   si->undo_guard = 1;           //do not collect undo information until file is loaded
 
-  si->buttonbox = gtk_hbox_new (FALSE, 1);
-  set_movement_selector (gui);
-  gtk_widget_set_tooltip_text (si->buttonbox, _("A button bar that can be populated by Movement titles and other user generated buttons.\nGenerally by clicking the button you can edit the title or value or execute the action of the button"));
-  gtk_box_pack_end (GTK_BOX (gui->buttonboxes), si->buttonbox, FALSE, TRUE, 0);
-  gtk_widget_show (si->buttonbox);
-  gtk_widget_set_can_focus (si->buttonbox, FALSE);
-  //GTK_WIDGET_UNSET_FLAGS(si->buttonbox, GTK_CAN_FOCUS);
+  if(!Denemo.non_interactive){
+    si->buttonbox = gtk_hbox_new (FALSE, 1);
+    set_movement_selector (gui);
+    gtk_widget_set_tooltip_text (si->buttonbox, _("A button bar that can be populated by Movement titles and other user generated buttons.\nGenerally by clicking the button you can edit the title or value or execute the action of the button"));
+    gtk_box_pack_end (GTK_BOX (gui->buttonboxes), si->buttonbox, FALSE, TRUE, 0);
+    gtk_widget_show (si->buttonbox);
+    gtk_widget_set_can_focus (si->buttonbox, FALSE);
+    //GTK_WIDGET_UNSET_FLAGS(si->buttonbox, GTK_CAN_FOCUS);
+  }
 }
 
 static gboolean
-delete_all_staffs (DenemoGUI * gui)
+delete_all_staffs (DenemoProject * gui)
 {
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = gui->movement;
   gint i;
   for (i = g_list_length (si->thescore); i > 0; i--)
     {
@@ -617,44 +624,44 @@ extract_verses (GList * verses)
 }
 
 /**
- * FIXME there is a muddle here between DenemoScore and DenemoGUI
+ * FIXME there is a muddle here between DenemoMovement and DenemoProject
  * frees the data in the passed scoreinfo stucture 
  *
  * @param si pointer to the scoreinfo structure to free
  */
 void
-free_score (DenemoGUI * gui)
+free_score (DenemoProject * gui)
 {
   delete_all_staffs (gui);
-  delete_directives (&gui->si->layout.directives);
-  delete_directives (&gui->si->header.directives);
-  free_midi_data (gui->si);
-  if (gui->si->buttonbox)
+  delete_directives (&gui->movement->layout.directives);
+  delete_directives (&gui->movement->header.directives);
+  free_midi_data (gui->movement);
+  if (gui->movement->buttonbox)
     {
-      gtk_widget_destroy (gui->si->buttonbox);
-      gui->si->buttonbox = NULL;
+      gtk_widget_destroy (gui->movement->buttonbox);
+      gui->movement->buttonbox = NULL;
     }
-  if (gui->si->lyricsbox)
+  if (gui->movement->lyricsbox)
     {
-      gtk_widget_destroy (gui->si->lyricsbox);
-      gui->si->lyricsbox = NULL;
+      gtk_widget_destroy (gui->movement->lyricsbox);
+      gui->movement->lyricsbox = NULL;
     }
   reset_lyrics (NULL, 0);
-  g_queue_free (gui->si->undodata);
-  g_queue_free (gui->si->redodata);
+  g_queue_free (gui->movement->undodata);
+  g_queue_free (gui->movement->redodata);
 }
 
-DenemoScore *
-clone_movement (DenemoScore * si)
+DenemoMovement *
+clone_movement (DenemoMovement * si)
 {
-  DenemoScore *newscore = (DenemoScore *) g_malloc0 (sizeof (DenemoScore));
-  memcpy (newscore, si, sizeof (DenemoScore));
+  DenemoMovement *newscore = (DenemoMovement *) g_malloc0 (sizeof (DenemoMovement));
+  memcpy (newscore, si, sizeof (DenemoMovement));
 
   GList *g;
   newscore->measurewidths = NULL;
   if (newscore->sources)
     {
-      g_warning ("Undo will lose source screenshots\n");
+      g_warning ("Undo will lose source screenshots");
       newscore->sources = NULL;
     }
   for (g = si->measurewidths; g; g = g->next)
@@ -787,20 +794,20 @@ clone_movement (DenemoScore * si)
 
 /**
  * Recalculates the stored information about a movement
- * either gui->si or if that does exist yet, gui->movements->data, the first movement.(FIXME)
+ * either gui->movement or if that does exist yet, gui->movements->data, the first movement.(FIXME)
  *
  * @param gui pointer to the gui structure
  */
 void
-updatescoreinfo (DenemoGUI * gui)
+updatescoreinfo (DenemoProject * gui)
 {
   staffnode *curstaff;
-  DenemoScore *si;
+  DenemoMovement *si;
   GList *g = gui->movements;
   if (g)
     si = g->data;
   else
-    si = gui->si;
+    si = gui->movement;
   do
     {
       for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
@@ -830,7 +837,7 @@ updatescoreinfo (DenemoGUI * gui)
  * This is the action for the d-New command
  */
 void
-deletescore (GtkWidget * widget, DenemoGUI * gui)
+deletescore (GtkWidget * widget, DenemoProject * gui)
 {
   free_movements (gui);
   score_status (gui, FALSE);
@@ -848,10 +855,10 @@ deletescore (GtkWidget * widget, DenemoGUI * gui)
     }
 
   point_to_new_movement (gui);
-  gui->movements = g_list_append (gui->movements, gui->si);
+  gui->movements = g_list_append (gui->movements, gui->movement);
   reset_movement_numbers (gui);
   set_width_to_work_with (gui);
-  set_rightmeasurenum (gui->si);
+  set_rightmeasurenum (gui->movement);
   update_hscrollbar (gui);
   update_vscrollbar (gui);
   gtk_widget_queue_draw (Denemo.scorearea);
