@@ -52,7 +52,7 @@ cell_edited (GtkCellRendererText * cellrenderertext, gchar * path_string, gchar
 }
 */
 static gboolean
-abandon_editprops_custom_scoreblock (DenemoGUI * gui)
+abandon_editprops_custom_scoreblock (DenemoProject * gui)
 {
   if (gui->custom_scoreblocks)
     return confirm (_("Custom LilyPond Score Block"), _("You will need to edit the LilyPond text to copy these edits from the standard scoreblock.\nIt might be easier to edit your custom scoreblock directly. Abandon?"));
@@ -64,7 +64,7 @@ abandon_editprops_custom_scoreblock (DenemoGUI * gui)
  *
  */
 static void
-setpaperconfig (papersetupcb * cbdata, DenemoGUI * gui)
+setpaperconfig (papersetupcb * cbdata, DenemoProject * gui)
 {
 #if GTK_MAJOR_VERSION==3
   g_string_assign (gui->lilycontrol.papersize, (gchar *) gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (cbdata->papersize)));
@@ -84,7 +84,7 @@ setpaperconfig (papersetupcb * cbdata, DenemoGUI * gui)
   else
     gui->lilycontrol.orientation = FALSE;
 
-  //g_print(" %s %s %d %d \n", gui->lilycontrol.papersize->str, gui->lilycontrol.lilyversion->str, gui->lilycontrol.fontsize, gui->lilycontrol.orientation);
+  //g_debug(" %s %s %d %d \n", gui->lilycontrol.papersize->str, gui->lilycontrol.lilyversion->str, gui->lilycontrol.fontsize, gui->lilycontrol.orientation);
   score_status (gui, TRUE);
 }
 
@@ -95,7 +95,7 @@ setpaperconfig (papersetupcb * cbdata, DenemoGUI * gui)
 void
 score_properties_dialog (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
 
   GET_1PARAM (action, param, fontsize);
   if (query)
@@ -103,7 +103,7 @@ score_properties_dialog (GtkAction * action, DenemoScriptParam * param)
       if (*query)
         if (!strcmp ("fontsize", query))
           {
-            g_string_assign (param->string, Denemo.gui->lilycontrol.staffsize->str);
+            g_string_assign (param->string, Denemo.project->lilycontrol.staffsize->str);
             param->status = TRUE;
           }
       return;
@@ -111,7 +111,7 @@ score_properties_dialog (GtkAction * action, DenemoScriptParam * param)
 
   if (fontsize)
     {
-      g_string_assign (Denemo.gui->lilycontrol.staffsize, fontsize);
+      g_string_assign (Denemo.project->lilycontrol.staffsize, fontsize);
       param->status = TRUE;
       return;
     }
@@ -124,7 +124,7 @@ score_properties_dialog (GtkAction * action, DenemoScriptParam * param)
   GtkWidget *measure_width;
   GtkWidget *staff_spacing;
   gint i;
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = gui->movement;
   g_assert (si != NULL);
 
   dialog = gtk_dialog_new_with_buttons (_("Score properties"), GTK_WINDOW (Denemo.window), (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
@@ -282,7 +282,7 @@ score_properties_dialog (GtkAction * action, DenemoScriptParam * param)
 /***************** movement properties *********************/
 struct callbackdata
 {
-  DenemoGUI *gui;
+  DenemoProject *gui;
 
   GtkWidget *title;
   GtkWidget *subtitle;
@@ -306,7 +306,7 @@ struct callbackdata
 };
 
 /**
- * Creates a dialog for setting properties of current movement gui->si
+ * Creates a dialog for setting properties of current movement gui->movement
  *
  */
 void
