@@ -36,8 +36,8 @@
  * the buffer on each staff.  
  */
 
-static void undo (DenemoGUI * gui);
-static void redo (DenemoGUI * gui);
+static void undo (DenemoProject * gui);
+static void redo (DenemoProject * gui);
 static GList *copybuffer = NULL;        // this is a list one for each staff of lists of objects
 
 static gint staffsinbuffer = 0;
@@ -119,7 +119,7 @@ pop_off_clipboard (void)
  * 
  */
 void
-setcurrentobject (DenemoScore * si, gint cursorpos)
+setcurrentobject (DenemoMovement * si, gint cursorpos)
 {
 
   g_debug ("Set Current Object Cursor pos %d\n", cursorpos);
@@ -176,6 +176,8 @@ insert_clipboard (GList * clipboard)
       call_out_to_guile ("(d-Paste)");
       copybuffer = NULL;
       pop_clipboard ();
+      displayhelper (Denemo.project);
+      score_status(Denemo.project, TRUE);
     }
 }
 
@@ -187,7 +189,7 @@ insert_clipboard (GList * clipboard)
  *  @return none
  */
 void
-saveselection (DenemoScore * si)
+saveselection (DenemoMovement * si)
 {
   if (si->markstaffnum == 0)    /* Indicator that there's no selection.  */
     return;
@@ -217,7 +219,7 @@ saveselection (DenemoScore * si)
  *   @param si pointer to the score information structure
  */
 void
-copytobuffer (DenemoScore * si)
+copytobuffer (DenemoMovement * si)
 {
   staffnode *curstaff;
   measurenode *curmeasure;
@@ -286,7 +288,7 @@ copytobuffer (DenemoScore * si)
  *  @param si pointer to score information structure
  */
 static void
-cuttobuffer (DenemoScore * si, gboolean copyfirst)
+cuttobuffer (DenemoMovement * si, gboolean copyfirst)
 {
   staffnode *curstaff;
   measurenode *curmeasure;
@@ -434,10 +436,10 @@ cuttobuffer (DenemoScore * si, gboolean copyfirst)
   find_leftmost_allcontexts (si);
 
 
-  isoffleftside (Denemo.gui);
-  isoffrightside (Denemo.gui);
+  isoffleftside (Denemo.project);
+  isoffrightside (Denemo.project);
 
-  score_status (Denemo.gui, TRUE);
+  score_status (Denemo.project, TRUE);
 
 }
 
@@ -473,7 +475,7 @@ get_clip_objs (gint m)
 void
 insert_object (DenemoObject * clonedobj)
 {
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   staffnode *curstaff = si->currentstaff;
   clonedobj->starttick = (si->currentobject ? ((DenemoObject *) si->currentobject->data)->starttickofnextnote : 0);
   /* update undo information */
@@ -485,7 +487,7 @@ insert_object (DenemoObject * clonedobj)
       //do position after inserting, so we can go back to it to delete
     }
 
-  Denemo.gui->si->currentmeasure->data = g_list_insert ((objnode *) si->currentmeasure->data, clonedobj, si->cursor_x);
+  Denemo.project->movement->currentmeasure->data = g_list_insert ((objnode *) si->currentmeasure->data, clonedobj, si->cursor_x);
 
 
   if (!si->undo_guard)
@@ -521,7 +523,7 @@ insert_object (DenemoObject * clonedobj)
 gboolean
 insert_clip_obj (gint m, gint n)
 {
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   if (copybuffer == NULL)
     return FALSE;
   GList *stafflist = g_list_nth (copybuffer, m);
@@ -535,8 +537,8 @@ insert_clip_obj (gint m, gint n)
   clonedobj = dnm_clone_object (curobj);
   insert_object (clonedobj);
 #if 0
-  octave_up_key (Denemo.gui);   //FIXME up and down to fix clef change bug !!!!!!!!
-  octave_down_key (Denemo.gui); //FIXME up and down to fix clef change bug !!!!!!!!
+  octave_up_key (Denemo.project);   //FIXME up and down to fix clef change bug !!!!!!!!
+  octave_down_key (Denemo.project); //FIXME up and down to fix clef change bug !!!!!!!!
 #endif
   //reset_cursor_stats (si);
   fixnoteheights ((DenemoStaff *) si->currentstaff->data);
@@ -551,23 +553,23 @@ insert_clip_obj (gint m, gint n)
 DenemoObject *
 get_mark_object (void)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoScore *si = gui->si;
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
   if (!si->markstaffnum)
     return NULL;
   staffnode *curstaff = g_list_nth (si->thescore, si->selection.firststaffmarked - 1);
   DenemoStaff *firststaff = (DenemoStaff *) curstaff->data;
   measurenode *firstmeasure = g_list_nth (firststaff->measures, si->selection.firstmeasuremarked - 1);
   objnode *firstobj = g_list_nth (firstmeasure->data, si->selection.firstobjmarked);
-  //g_print("First %d\n",  si->selection.firstobjmarked);
+  //g_debug("First %d\n",  si->selection.firstobjmarked);
   return firstobj ? ((DenemoObject *) firstobj->data) : NULL;
 }
 
 DenemoObject *
 get_point_object (void)
 {
-  DenemoGUI *gui = Denemo.gui;
-  DenemoScore *si = gui->si;
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
   if (!si->markstaffnum)
     return NULL;
   staffnode *curstaff = g_list_nth (si->thescore, si->selection.laststaffmarked - 1);
@@ -583,7 +585,7 @@ get_point_object (void)
  * mark
  *
  * Inputs 
- * @param si pointer to the DenemoScore structure
+ * @param si pointer to the DenemoMovement structure
  * @param mark_staff  
  * @param mark_measure -
  * @param mark_object -
@@ -593,7 +595,7 @@ get_point_object (void)
  * @param type -
  */
 static void
-mark_boundaries_helper (DenemoScore * si, gint mark_staff, gint mark_measure, gint mark_object, gint point_staff, gint point_measure, gint point_object, enum drag_selection_type type)
+mark_boundaries_helper (DenemoMovement * si, gint mark_staff, gint mark_measure, gint mark_object, gint point_staff, gint point_measure, gint point_object, enum drag_selection_type type)
 {
   if (mark_staff)
     {
@@ -650,58 +652,61 @@ mark_boundaries_helper (DenemoScore * si, gint mark_staff, gint mark_measure, gi
  *  setmark
  *  Sets the current mark for the start of the buffer
  *
- *  @param gui pointer to the DenemoGUI structure
  */
 void
-set_mark (DenemoGUI * gui)
+set_mark (GtkAction* action, DenemoScriptParam * param)
 {
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   si->markstaffnum = si->currentstaffnum;
   si->markmeasurenum = si->currentmeasurenum;
   si->markcursor_x = si->cursor_x;
   calcmarkboundaries (si);
+  if(!Denemo.non_interactive)
+    gtk_widget_queue_draw(Denemo.scorearea);
 }
 
 /**
  *  set_point
  *  Sets the current cursor position as the end of the selection
  *
- *  @param gui pointer to the DenemoGUI structure
  */
 void
-set_point (DenemoGUI * gui)
+set_point (GtkAction* action, DenemoScriptParam * param)
 {
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   if (si->markstaffnum)
     {
       mark_boundaries_helper (si, si->markstaffnum, si->markmeasurenum, si->markcursor_x, si->currentstaffnum, si->currentmeasurenum, si->cursor_x, NORMAL_SELECT);
 
     }
+  if(!Denemo.non_interactive)
+    gtk_widget_queue_draw(Denemo.scorearea);
 }
 
 gboolean
 mark_status (void)
 {
-  return Denemo.gui->si->markstaffnum != 0;
+  return Denemo.project->movement->markstaffnum != 0;
 }
 
 /**
  * unset_mark
  * Remove the current mark
  *
- * @param gui pointer to the DenemoGUI structure
  */
 void
-unset_mark (DenemoGUI * gui)
+unset_mark (GtkAction* action, DenemoScriptParam * param)
 {
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   si->markstaffnum = 0;
   calcmarkboundaries (si);
+  if(!Denemo.non_interactive)
+    gtk_widget_queue_draw(Denemo.scorearea);
 }
 
 
 gboolean
-in_selection (DenemoScore * si)
+in_selection (DenemoMovement * si)
 {
   if (si->markstaffnum)
     {
@@ -749,7 +754,7 @@ static gint firstmeasure;
 static gint lastmeasure;
 
 void
-save_selection (DenemoScore * si)
+save_selection (DenemoMovement * si)
 {
   firststaff = si->selection.firststaffmarked;
   laststaff = si->selection.laststaffmarked;
@@ -760,7 +765,7 @@ save_selection (DenemoScore * si)
 }
 
 void
-restore_selection (DenemoScore * si)
+restore_selection (DenemoMovement * si)
 {
   si->selection.firststaffmarked = firststaff;
   si->selection.laststaffmarked = laststaff;
@@ -783,7 +788,7 @@ goto_mark (GtkAction * action, DenemoScriptParam * param)
 {
   DenemoScriptParam local_param;
   local_param.status = TRUE;
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   if (!action)
     ((DenemoScriptParam *) param)->status = si->markstaffnum;
   else
@@ -791,13 +796,13 @@ goto_mark (GtkAction * action, DenemoScriptParam * param)
   if (si->markstaffnum)
     {
       save_selection (si);
-      set_currentmeasurenum (Denemo.gui, si->markmeasurenum);
-      set_currentstaffnum (Denemo.gui, si->markstaffnum);
+      set_currentmeasurenum (Denemo.project, si->markmeasurenum);
+      set_currentstaffnum (Denemo.project, si->markstaffnum);
       while (si->cursor_x < si->markcursor_x && param->status)
-        cursorright (param);
+        cursorright (NULL, param);
       restore_selection (si);
       if (!action)
-        displayhelper (Denemo.gui);
+        displayhelper (Denemo.project);
     }
 }
 
@@ -810,20 +815,20 @@ goto_mark (GtkAction * action, DenemoScriptParam * param)
 void
 goto_selection_start (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   if (!action)
     ((DenemoScriptParam *) param)->status = si->markstaffnum;
   if (si->markstaffnum)
     {
       gint first = si->selection.firstobjmarked;
       save_selection (si);
-      set_currentmeasurenum (Denemo.gui, si->selection.firstmeasuremarked);
-      set_currentstaffnum (Denemo.gui, si->selection.firststaffmarked);
+      set_currentmeasurenum (Denemo.project, si->selection.firstmeasuremarked);
+      set_currentstaffnum (Denemo.project, si->selection.firststaffmarked);
       while (si->cursor_x < first)
-        cursorright (param);
+        cursorright (NULL, NULL);
       restore_selection (si);
       if (!action)
-        displayhelper (Denemo.gui);
+        displayhelper (Denemo.project);
     }
 }
 
@@ -845,9 +850,9 @@ pop_position (void)
 }
 
 void
-get_position (DenemoScore * si, DenemoPosition * pos)
+get_position (DenemoMovement * si, DenemoPosition * pos)
 {
-  pos->movement = g_list_index (Denemo.gui->movements, si) + 1;
+  pos->movement = g_list_index (Denemo.project->movements, si) + 1;
   pos->staff = si->currentstaffnum;
   pos->measure = si->currentmeasurenum;
   pos->object = si->currentobject ? si->cursor_x + 1 : 0;
@@ -858,14 +863,14 @@ get_position (DenemoScore * si, DenemoPosition * pos)
 void
 push_position (void)
 {
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   DenemoPosition *pos = (DenemoPosition *) g_malloc (sizeof (DenemoPosition));
   get_position (si, pos);
   if (pos->movement)
     positions = g_slist_prepend (positions, pos);
   else
     g_free (pos);
-  //g_print("%d %d %d %d \n", pos->movement, pos->staff, pos->measure, pos->object);
+  //g_debug("%d %d %d %d \n", pos->movement, pos->staff, pos->measure, pos->object);
 }
 
 static void
@@ -881,13 +886,13 @@ push_given_position (DenemoPosition * pos)
  *  Wrapper function for the copy command
  *  
  * @param action pointer to the GTKAction event
- * @param gui pointer to the DenemoGUI structure
+ * @param gui pointer to the DenemoProject structure
  */
 void
 copywrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  copytobuffer (gui->si);
+  DenemoProject *gui = Denemo.project;
+  copytobuffer (gui->movement);
 }
 
 /**
@@ -895,13 +900,13 @@ copywrapper (GtkAction * action, DenemoScriptParam * param)
  * Wrapper function for the cut command
  *
  * @param action pointer to the GTKAction event
- * @param gui pointer to the DenemoGUI structure 
+ * @param gui pointer to the DenemoProject structure 
  */
 void
 cutwrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  cuttobuffer (gui->si, TRUE);
+  DenemoProject *gui = Denemo.project;
+  cuttobuffer (gui->movement, TRUE);
   //check that measurewidths is long enough after cutting empty measures
   displayhelper (gui);
 }
@@ -909,8 +914,8 @@ cutwrapper (GtkAction * action, DenemoScriptParam * param)
 void
 delete_selection (void)
 {
-  DenemoGUI *gui = Denemo.gui;
-  cuttobuffer (gui->si, FALSE);
+  DenemoProject *gui = Denemo.project;
+  cuttobuffer (gui->movement, FALSE);
   displayhelper (gui);
 }
 
@@ -918,18 +923,18 @@ delete_selection (void)
  * pastewrapper
  * Wrapper function for the paste command
  *
- * @param gui pointer to the DenemoGUI structure
+ * @param gui pointer to the DenemoProject structure
  * @param action pointer to the GtkAction event
  */
 void
 pastewrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  stage_undo (Denemo.gui->si, ACTION_STAGE_END);        //undo is a queue (ie stack) so we push the end first
+  stage_undo (Denemo.project->movement, ACTION_STAGE_END);        //undo is a queue (ie stack) so we push the end first
   call_out_to_guile ("(DenemoPaste)");
   //FIXME if not success a ACTION_SCRIPT_ERROR will have been put in the undo queue...
-  stage_undo (Denemo.gui->si, ACTION_STAGE_START);
+  stage_undo (Denemo.project->movement, ACTION_STAGE_START);
 
-  score_status (Denemo.gui, TRUE);
+  score_status (Denemo.project, TRUE);
 }
 
 
@@ -938,13 +943,13 @@ pastewrapper (GtkAction * action, DenemoScriptParam * param)
  * Wrapper function for the Save selection command
  *
  * @param action pointer to the GtkAction event 
- * @param gui pointer to the DenemoGUI structure
+ * @param gui pointer to the DenemoProject structure
  */
 void
 saveselwrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  saveselection (gui->si);
+  DenemoProject *gui = Denemo.project;
+  saveselection (gui->movement);
 }
 
 
@@ -957,15 +962,15 @@ saveselwrapper (GtkAction * action, DenemoScriptParam * param)
  * scoreinfo - score information
  */
 void
-calcmarkboundaries (DenemoScore * si)
+calcmarkboundaries (DenemoMovement * si)
 {
   mark_boundaries_helper (si, si->markstaffnum, si->markmeasurenum, si->markcursor_x, si->currentstaffnum, si->currentmeasurenum, si->cursor_x, NORMAL_SELECT);
 }
 
 void
-swap_point_and_mark (GtkAction * action, gpointer param)
+swap_point_and_mark (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoScore *si = Denemo.gui->si;
+  DenemoMovement *si = Denemo.project->movement;
   gint temp = si->currentstaffnum;
   si->currentstaffnum = si->markstaffnum;
   si->markstaffnum = temp;
@@ -979,7 +984,7 @@ swap_point_and_mark (GtkAction * action, gpointer param)
   si->markcursor_x = temp;
   setcurrentobject (si, si->cursor_x);
   calcmarkboundaries (si);
-  displayhelper (Denemo.gui);
+  displayhelper (Denemo.project);
 }
 
 /**
@@ -992,9 +997,9 @@ swap_point_and_mark (GtkAction * action, gpointer param)
  * widget - unused
  */
 void
-undowrapper (GtkAction * action, gpointer param)
+undowrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   undo (gui);
   displayhelper (gui);
 }
@@ -1009,9 +1014,9 @@ undowrapper (GtkAction * action, gpointer param)
  * widget - unused
  */
 void
-redowrapper (GtkAction * action, gpointer param)
+redowrapper (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   redo (gui);
   displayhelper (gui);
 }
@@ -1019,7 +1024,7 @@ redowrapper (GtkAction * action, gpointer param)
 /* store the passed object as ACTION_CHANGE undo information */
 /* potentially we could optimize the storage of undo information by telescoping changes to the same object when the undo is staged, it would mean keeping a global note of whether the undo is currently staged. We would peek at the head of the queue and if it was an ACTION_CHANGE at the same position we could free the stored object and replace it with the clone created here */
 void
-store_for_undo_change (DenemoScore * si, DenemoObject * curobj)
+store_for_undo_change (DenemoMovement * si, DenemoObject * curobj)
 {
   if (!si->undo_guard)
     {
@@ -1032,7 +1037,7 @@ store_for_undo_change (DenemoScore * si, DenemoObject * curobj)
 }
 
 void
-store_for_undo_measure_insert (DenemoScore * si, gint staffnum, gint measurenum)
+store_for_undo_measure_insert (DenemoMovement * si, gint staffnum, gint measurenum)
 {
   if (!si->undo_guard)
     {
@@ -1047,7 +1052,7 @@ store_for_undo_measure_insert (DenemoScore * si, gint staffnum, gint measurenum)
 static void
 free_chunk (DenemoUndoData * chunk)
 {
-  g_print ("free %d\n", chunk->action);
+  g_debug ("free %d\n", chunk->action);
   switch (chunk->action)
     {
     case ACTION_STAGE_START:
@@ -1082,7 +1087,7 @@ static DenemoUndoData ActionStageEnd = { ACTION_STAGE_END };
 static DenemoUndoData ActionScriptError = { ACTION_SCRIPT_ERROR };
 
 void
-stage_undo (DenemoScore * si, action_type type)
+stage_undo (DenemoMovement * si, action_type type)
 {
   switch (type)
     {
@@ -1095,7 +1100,7 @@ stage_undo (DenemoScore * si, action_type type)
           {
             chunk = g_queue_pop_head (si->undodata);
             // free_chunk(chunk); not needed, is static anyway
-            // g_print("Script did not need undoing");
+            //g_debug("Script did not need undoing");
           }
         else
           update_undo_info (si, &ActionStageStart);
@@ -1108,14 +1113,14 @@ stage_undo (DenemoScore * si, action_type type)
       update_undo_info (si, &ActionScriptError);
       break;
     default:
-      g_warning ("Unknown undo action %d will not be stored\n", type);
+      g_warning ("Unknown undo action %d will not be stored", type);
     }
 }
 
 //return a string describing the top of the undo stack, or one below if stage start.
 // caller must g_free
 gchar *
-get_last_change (DenemoScore * si)
+get_last_change (DenemoMovement * si)
 {
   DenemoUndoData *last = g_queue_peek_head (si->undodata);
   gint n = 0;
@@ -1157,16 +1162,16 @@ get_last_change (DenemoScore * si)
 gboolean
 take_snapshot (void)
 {
-  if (!Denemo.gui->si->undo_guard)
+  if (!Denemo.project->movement->undo_guard)
     {
       DenemoUndoData *chunk;
       chunk = (DenemoUndoData *) g_malloc (sizeof (DenemoUndoData));
-      chunk->object = (DenemoObject *) clone_movement (Denemo.gui->si);
+      chunk->object = (DenemoObject *) clone_movement (Denemo.project->movement);
       //fix up somethings...
-      get_position (Denemo.gui->si, &chunk->position);
+      get_position (Denemo.project->movement, &chunk->position);
       chunk->position.appending = 0;
       chunk->action = ACTION_SNAPSHOT;
-      update_undo_info (Denemo.gui->si, chunk);
+      update_undo_info (Denemo.project->movement, chunk);
 
       return TRUE;
     }
@@ -1185,47 +1190,47 @@ print_queue (gchar * msg, GQueue * q)
       switch (chunk->action)
         {
         case ACTION_STAGE_START:
-          g_print ("[");
+          g_debug ("[");
           break;
         case ACTION_STAGE_END:
-          g_print ("]\n");
+          g_debug ("]\n");
           break;
         case ACTION_SNAPSHOT:
-          g_print ("Snapshot; ");
+          g_debug ("Snapshot; ");
           break;
         case ACTION_INSERT:
-          g_print ("Ins; ");
+          g_debug ("Ins; ");
           break;
         case ACTION_DELETE:
-          g_print ("Del %s; ", DenemoObjTypeNames[((DenemoObject *) chunk->object)->type]);
+          g_debug ("Del %s; ", DenemoObjTypeNames[((DenemoObject *) chunk->object)->type]);
           break;
         case ACTION_CHANGE:
-          g_print ("Chn %s; ", DenemoObjTypeNames[((DenemoObject *) chunk->object)->type]);
+          g_debug ("Chn %s; ", DenemoObjTypeNames[((DenemoObject *) chunk->object)->type]);
           break;
         case ACTION_MEASURE_CREATE:
-          g_print ("Create; ");
+          g_debug ("Create; ");
           break;
         case ACTION_MEASURE_REMOVE:
-          g_print ("Remove; ");
+          g_debug ("Remove; ");
           break;
         case ACTION_NOOP:
-          g_print ("No-op; ");
+          g_debug ("No-op; ");
           break;
         default:
-          g_print ("Unknown action %d\n", chunk->action);
+          g_debug ("Unknown action %d\n", chunk->action);
 
         }
     }
-  g_print ("\nEnd queue\n");
+  g_debug ("End queue");
 }
 
 
 static gboolean
-position_for_chunk (DenemoGUI * gui, DenemoUndoData * chunk)
+position_for_chunk (DenemoProject * gui, DenemoUndoData * chunk)
 {
   DenemoScriptParam param;
   param.status = TRUE;
-  //g_print("undo guard before %d level is %d\n undo action is %d\n",  gui->si->undo_guard, gui->undo_level, chunk->action);
+  //g_debug("undo guard before %d level is %d\n undo action is %d\n",  gui->movement->undo_guard, gui->undo_level, chunk->action);
 
   switch (chunk->action)
     {
@@ -1253,7 +1258,7 @@ position_for_chunk (DenemoGUI * gui, DenemoUndoData * chunk)
 //Takes the action needed for one chunk of undo/redo data
 
 static void
-action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
+action_chunk (DenemoProject * gui, DenemoUndoData ** pchunk)
 {
   DenemoUndoData *chunk = *pchunk;
   switch (chunk->action)
@@ -1261,14 +1266,14 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
     case ACTION_MEASURE_CREATE:
       {
         //delete the empty measure in the chunk->position.staff at measure number chunk->position->object
-        dnm_deletemeasure (gui->si);
+        dnm_deletemeasure (gui->movement);
         chunk->action = ACTION_MEASURE_REMOVE;
         if (chunk->position.measure > 1)
           chunk->position.measure--;
         else
           chunk->action = ACTION_NOOP;
 
-        if (!gui->si->currentmeasure)
+        if (!gui->movement->currentmeasure)
           {
             g_warning ("position after undo insert Bug in selectops.c");
             position_for_chunk (gui, chunk);
@@ -1280,10 +1285,10 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
     case ACTION_MEASURE_REMOVE:
       {
         //create empty measure in the chunk->position.staff at measure number chunk->position->object
-        insertmeasureafter (gui);
+        insertmeasureafter (NULL, NULL);
         chunk->action = ACTION_MEASURE_CREATE;
         chunk->position.measure++;
-        if (!gui->si->currentmeasure)
+        if (!gui->movement->currentmeasure)
           {
             g_warning ("position after undo insert Bug in selectops.c");
             position_for_chunk (gui, chunk);    //????
@@ -1311,8 +1316,8 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
 
     case ACTION_INSERT:
       {
-        chunk->object = dnm_clone_object (gui->si->currentobject->data);
-        dnm_deleteobject (gui->si);
+        chunk->object = dnm_clone_object (gui->movement->currentobject->data);
+        dnm_deleteobject (gui->movement);
         chunk->action = ACTION_DELETE;
       }
       break;
@@ -1325,27 +1330,27 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
       break;
     case ACTION_CHANGE:
       {
-        //FIXME guard against a corrupt undo queue here by checking  if(gui->si->currentobject) {
-        DenemoObject *temp = gui->si->currentobject->data;
-        gui->si->currentobject->data = chunk->object;
+        //FIXME guard against a corrupt undo queue here by checking  if(gui->movement->currentobject) {
+        DenemoObject *temp = gui->movement->currentobject->data;
+        gui->movement->currentobject->data = chunk->object;
         chunk->object = temp;
       }
       break;
     case ACTION_SNAPSHOT:
       {
 
-        DenemoScore *si = (DenemoScore *) chunk->object;
-        gint initial_guard = gui->si->undo_guard;
-        gint initial_changecount = gui->si->changecount;
-        gboolean initial_redo_invalid = gui->si->redo_invalid;
-        gpointer initial_smf = gui->si->smf;
-        // replace gui->si in gui->movements with si
-        GList *find = g_list_find (gui->movements, gui->si);
+        DenemoMovement *si = (DenemoMovement *) chunk->object;
+        gint initial_guard = gui->movement->undo_guard;
+        gint initial_changecount = gui->movement->changecount;
+        gboolean initial_redo_invalid = gui->movement->redo_invalid;
+        gpointer initial_smf = gui->movement->smf;
+        // replace gui->movement in gui->movements with si
+        GList *find = g_list_find (gui->movements, gui->movement);
         if (find)
           {
             find->data = si;
             GList *g, *gorig, *curstaff;
-            for (curstaff = gui->si->thescore; curstaff; curstaff = curstaff->next)
+            for (curstaff = gui->movement->thescore; curstaff; curstaff = curstaff->next)
               {
                 DenemoStaff *thestaff = curstaff->data;
                 gorig = g = thestaff->verses;
@@ -1390,7 +1395,7 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
 
             {
               GList *direc;
-              for (direc = gui->si->movementcontrol.directives; direc; direc = direc->next)
+              for (direc = gui->movement->movementcontrol.directives; direc; direc = direc->next)
                 {
                   DenemoDirective *directive = direc->data;
                   gtk_widget_destroy (directive->widget);
@@ -1400,7 +1405,7 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
             }
             {
               GList *direc;
-              for (direc = gui->si->header.directives; direc; direc = direc->next)
+              for (direc = gui->movement->header.directives; direc; direc = direc->next)
                 {
                   DenemoDirective *directive = direc->data;
                   gtk_widget_destroy (directive->widget);
@@ -1409,7 +1414,7 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
             }
             {
               GList *direc;
-              for (direc = gui->si->layout.directives; direc; direc = direc->next)
+              for (direc = gui->movement->layout.directives; direc; direc = direc->next)
                 {
                   DenemoDirective *directive = direc->data;
                   gtk_widget_destroy (directive->widget);
@@ -1418,9 +1423,9 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
             }
 
             g_list_free (gorig);
-            chunk->object = (DenemoObject *) gui->si;
+            chunk->object = (DenemoObject *) gui->movement;
             //FIXME fix up other values in stored object si?????? voice/staff directive widgets
-            gui->si = si;
+            gui->movement = si;
             for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
               {
                 DenemoStaff *thestaff = curstaff->data;
@@ -1462,7 +1467,7 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
 
             {
               GList *direc;
-              for (direc = gui->si->movementcontrol.directives; direc; direc = direc->next)
+              for (direc = gui->movement->movementcontrol.directives; direc; direc = direc->next)
                 {
                   DenemoDirective *directive = direc->data;
                   directive->widget = NULL;
@@ -1471,7 +1476,7 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
             }
             {
               GList *direc;
-              for (direc = gui->si->header.directives; direc; direc = direc->next)
+              for (direc = gui->movement->header.directives; direc; direc = direc->next)
                 {
                   DenemoDirective *directive = direc->data;
                   directive->widget = NULL;
@@ -1480,25 +1485,25 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
             }
             {
               GList *direc;
-              for (direc = gui->si->layout.directives; direc; direc = direc->next)
+              for (direc = gui->movement->layout.directives; direc; direc = direc->next)
                 {
                   DenemoDirective *directive = direc->data;
                   directive->widget = NULL;
                   widget_for_layout_directive (directive);
                 }
             }
-            gui->si->smf = initial_smf;
-            gui->si->smfsync = -1;      //force recalculation of midi
-            gui->si->redo_invalid = initial_redo_invalid;
-            gui->si->undo_guard = initial_guard;        //we keep all the guards we had on entry which will be removed when
-            gui->si->changecount = initial_changecount;
+            gui->movement->smf = initial_smf;
+            gui->movement->smfsync = -1;      //force recalculation of midi
+            gui->movement->redo_invalid = initial_redo_invalid;
+            gui->movement->undo_guard = initial_guard;        //we keep all the guards we had on entry which will be removed when
+            gui->movement->changecount = initial_changecount;
             position_for_chunk (gui, chunk);    //FIXME check return val
-            if (!gui->si->currentmeasure)
+            if (!gui->movement->currentmeasure)
               {
                 g_warning ("positioning after snapshot Bug in selectops.c");
                 movetoend (NULL, NULL);
               }
-            gui->si->currentstaffnum = 1 + g_list_position (gui->si->thescore, gui->si->currentstaff);
+            gui->movement->currentstaffnum = 1 + g_list_position (gui->movement->thescore, gui->movement->currentstaff);
           }
         else
           {
@@ -1520,17 +1525,17 @@ action_chunk (DenemoGUI * gui, DenemoUndoData ** pchunk)
 static void
 position_warning (DenemoUndoData * chunk)
 {
-  g_warning ("Could not find position for undotype %d  movement %d staff %d measure %d object %d appending %d offend %d\n", chunk->action, chunk->position.movement, chunk->position.staff, chunk->position.measure, chunk->position.object, chunk->position.appending, chunk->position.offend);
-  print_queue ("The undo queue was:", Denemo.gui->si->undodata);
-  print_queue ("The redo queue was:", Denemo.gui->si->redodata);
+  g_warning ("Could not find position for undotype %d  movement %d staff %d measure %d object %d appending %d offend %d", chunk->action, chunk->position.movement, chunk->position.staff, chunk->position.measure, chunk->position.object, chunk->position.appending, chunk->position.offend);
+  print_queue ("The undo queue was:", Denemo.project->movement->undodata);
+  print_queue ("The redo queue was:", Denemo.project->movement->redodata);
 }
 
 static void
-warn_no_more_undo (DenemoGUI * gui)
+warn_no_more_undo (DenemoProject * gui)
 {
-  g_warning ("No more undo information at level %d guard %d ... resetting", gui->undo_level, gui->si->undo_guard);
+  g_warning ("No more undo information at level %d guard %d ... resetting", gui->undo_level, gui->movement->undo_guard);
   gui->undo_level = 0;
-  gui->si->undo_guard = Denemo.prefs.disable_undo;
+  gui->movement->undo_guard = Denemo.prefs.disable_undo;
 }
 
 
@@ -1539,10 +1544,10 @@ static void
 free_queue (GQueue * queue)
 {
   DenemoUndoData *chunk;
-  //g_print("before redo queue %p is %d empty\n", queue, g_queue_is_empty(queue));
+  //g_debug("before redo queue %p is %d empty\n", queue, g_queue_is_empty(queue));
   while ((chunk = (DenemoUndoData *) g_queue_pop_head (queue)))
     free_chunk (chunk);
-  //g_print("after redo queue %p is %d empty\n", queue, g_queue_is_empty(queue));
+  //g_debug("after redo queue %p is %d empty\n", queue, g_queue_is_empty(queue));
 }
 
 /**
@@ -1553,14 +1558,14 @@ free_queue (GQueue * queue)
  * PARAM gui  the score (why??? this is per movement undo FIXME)
  */
 static void
-undo (DenemoGUI * gui)
+undo (DenemoProject * gui)
 {
 
-  DenemoUndoData *chunk = (DenemoUndoData *) g_queue_pop_head (gui->si->undodata);
+  DenemoUndoData *chunk = (DenemoUndoData *) g_queue_pop_head (gui->movement->undodata);
   if (chunk)
     {
-      gui->si->undo_guard++;
-      //g_print("undo %d\n", chunk->action);
+      gui->movement->undo_guard++;
+      //g_debug("undo %d\n", chunk->action);
       if (position_for_chunk (gui, chunk))
         {
           action_chunk (gui, &chunk);
@@ -1568,24 +1573,24 @@ undo (DenemoGUI * gui)
       else
         {
           position_warning (chunk);
-          free_queue (gui->si->redodata);
-          free_queue (gui->si->undodata);
+          free_queue (gui->movement->redodata);
+          free_queue (gui->movement->undodata);
           warn_no_more_undo (gui);      //returns guard to user preference and sets level 0
           return;
         }
-      //g_print("actioned undo now pushing %d\n", chunk->action);
-      update_redo_info (gui->si, chunk);
-      gui->si->undo_guard--;
-      //g_print("***undo guard after undo %d\n",  gui->si->undo_guard);
+      //g_debug("actioned undo now pushing %d\n", chunk->action);
+      update_redo_info (gui->movement, chunk);
+      gui->movement->undo_guard--;
+      //g_debug("***undo guard after undo %d\n",  gui->movement->undo_guard);
       if (gui->undo_level > 0)
         undo (gui);
       score_status (gui, TRUE);
-      if (gui->si->currentmeasurenum > g_list_length (gui->si->measurewidths))
+      if (gui->movement->currentmeasurenum > g_list_length (gui->movement->measurewidths))
         {
-          g_warning ("Undo failed to set current measurenum %d out of %d\n", gui->si->currentmeasurenum, g_list_length (gui->si->measurewidths));
-          gui->si->currentmeasurenum = g_list_length (gui->si->measurewidths);
+          g_warning ("Undo failed to set current measurenum %d out of %d", gui->movement->currentmeasurenum, g_list_length (gui->movement->measurewidths));
+          gui->movement->currentmeasurenum = g_list_length (gui->movement->measurewidths);
         }
-      //print_queue("Undo, queue: ", gui->si->undodata);
+      //print_queue("Undo, queue: ", gui->movement->undodata);
     }
   else
     warn_no_more_undo (gui);
@@ -1602,13 +1607,13 @@ undo (DenemoGUI * gui)
  * scoreinfo - score data
  */
 void
-redo (DenemoGUI * gui)
+redo (DenemoProject * gui)
 {
-  DenemoUndoData *chunk = (DenemoUndoData *) g_queue_pop_head (gui->si->redodata);
+  DenemoUndoData *chunk = (DenemoUndoData *) g_queue_pop_head (gui->movement->redodata);
   if (chunk)
     {
-      //g_print("Before %s and %d\n", gui->si->currentobject?"Obj":"noObj", gui->si->cursor_x);
-      gui->si->undo_guard++;
+      //g_debug("Before %s and %d\n", gui->movement->currentobject?"Obj":"noObj", gui->movement->cursor_x);
+      gui->movement->undo_guard++;
       if (position_for_chunk (gui, chunk))
         {
           action_chunk (gui, &chunk);
@@ -1618,9 +1623,9 @@ redo (DenemoGUI * gui)
           position_warning (chunk);
 
         }
-      update_undo_info (gui->si, chunk);
-      gui->si->undo_guard--;
-      //g_print("After %s and %d\n", gui->si->currentobject?"Obj":"noObj!!", gui->si->cursor_x);
+      update_undo_info (gui->movement, chunk);
+      gui->movement->undo_guard--;
+      //g_debug("After %s and %d\n", gui->movement->currentobject?"Obj":"noObj!!", gui->movement->cursor_x);
       if (gui->undo_level > 0)
         redo (gui);
       score_status (gui, TRUE);
@@ -1640,16 +1645,16 @@ redo (DenemoGUI * gui)
  *
  */
 void
-update_undo_info (DenemoScore * si, DenemoUndoData * undo)
+update_undo_info (DenemoMovement * si, DenemoUndoData * undo)
 {
 
 
-  //g_print ("Adding: Action %d at pos %d appending %d\n",  undo->action, undo->position.object, undo->position.appending); 
+  //g_debug ("Adding: Action %d at pos %d appending %d\n",  undo->action, undo->position.object, undo->position.appending); 
 
   //  if (g_queue_get_length (si->undodata) == MAX_UNDOS)
   //    {
   //      tmp = g_queue_pop_tail (si->undodata);//FIXME freeing undo info, especially the object
-  //      g_warning("Lost undo of %p %p\n", tmp, tmp->object);
+  //      g_warning("Lost undo of %p %p", tmp, tmp->object);
   //   }
 
   g_queue_push_head (si->undodata, undo);
@@ -1663,12 +1668,12 @@ update_undo_info (DenemoScore * si, DenemoUndoData * undo)
  *  
  *  Updates the redo list with last undo operation.
  *  Is passed score structure and redo_data structure
- *  @param si pointer to the DenemoScore structure
+ *  @param si pointer to the DenemoMovement structure
  *  @param redo redo data structure to prepend to the queue
 g */
 
 void
-update_redo_info (DenemoScore * si, DenemoUndoData * redo)
+update_redo_info (DenemoMovement * si, DenemoUndoData * redo)
 {
   //print_queue("Update redo ******************\nUndo queue:\n", si->undodata);
   //print_queue("Update redo ******************\nredo queue:\n", si->redodata);
@@ -1678,7 +1683,7 @@ update_redo_info (DenemoScore * si, DenemoUndoData * redo)
     {
       free_queue (si->redodata);
       si->redo_invalid = FALSE;
-      //g_print("queue = %p\n", si->redodata);
+      //g_debug("queue = %p\n", si->redodata);
     }
   g_queue_push_head (si->redodata, redo);
 }
