@@ -60,7 +60,7 @@ overdraw (cairo_t * cr, EvView * view)
   gint x, y, page;
   gdouble scale;
   get_window_position (view, &x, &y, &page, &scale);
-  // cairo_scale( cr, Denemo.gui->si->preview_zoom, Denemo.gui->si->preview_zoom );
+  // cairo_scale( cr, Denemo.project->movement->preview_zoom, Denemo.project->movement->preview_zoom );
   cairo_translate (cr, -x, -y);
   if (Mark.width)
     {
@@ -103,7 +103,7 @@ static gint
 button_press (EvView * view, GdkEventButton * event)
 {
   if (event->button == 1)
-    g_print ("Use right button to create link\n");
+    g_warning ("Use right button to create link");
   else
     {
       gint x, y, page;
@@ -114,7 +114,9 @@ button_press (EvView * view, GdkEventButton * event)
       gchar *filename = g_object_get_data (G_OBJECT (view), "filename");
       x += event->x;
       y += event->y;
-      gchar *text = g_strdup_printf ("(InsertLink \"%s:%d:%d:%d\")", filename, (gint) (x / scale), (gint) (y / scale), page);
+      gchar *escaped = g_strescape(filename, "");
+      gchar *text = g_strdup_printf ("(InsertLink \"%s:%d:%d:%d\")", escaped, (gint) (x / scale), (gint) (y / scale), page);
+      g_free(escaped);
       Mark.x = (x - MARKER / 2) / scale;
       Mark.y = (y - MARKER / 2) / scale;
       Mark.width = Mark.height = MARKER;
@@ -144,19 +146,28 @@ static gboolean
 position_source_window (EvView * view)
 {
   GtkWidget *top_vbox = gtk_widget_get_toplevel (GTK_WIDGET (view));
-  if (Denemo.gui->source_scale)
+  if (Denemo.project->source_scale)
     {
-      //gtk_widget_set_size_request(GTK_WIDGET(top_vbox), Denemo.gui->source_width, Denemo.gui->source_height);
+      //gtk_widget_set_size_request(GTK_WIDGET(top_vbox), Denemo.project->source_width, Denemo.project->source_height);
       //EvDocumentModel *model = (EvDocumentModel*)g_object_get_data(G_OBJECT(view), "model");
-      //ev_document_model_set_scale(model, Denemo.gui->source_scale/1000.0);
-      gtk_window_move (GTK_WINDOW (top_vbox), Denemo.gui->source_x, Denemo.gui->source_y);
+      //ev_document_model_set_scale(model, Denemo.project->source_scale/1000.0);
+      gtk_window_move (GTK_WINDOW (top_vbox), Denemo.project->source_x, Denemo.project->source_y);
     }
   else
     gtk_window_present (GTK_WINDOW (top_vbox));
   return FALSE;
 }
 
-
+static gchar *locate_file (gchar *filename) {
+    if(!g_file_test(filename, G_FILE_TEST_EXISTS)) {    
+     gchar *basename = g_path_get_basename(filename);
+     gchar *pathdir = g_path_get_dirname (Denemo.project->filename->str);
+     filename = g_build_filename (pathdir, basename, NULL);
+     g_free(basename);
+     g_free(pathdir);
+    }
+    return filename;
+}
 static EvView *
 get_view (gchar * filename)
 {
@@ -164,6 +175,7 @@ get_view (gchar * filename)
   GError *err = NULL;
   EvView *view = NULL;
   GList *g;
+  filename = locate_file (filename);
   for (g = theviews; g; g = g->next)
     if (!strcmp (((fileview *) g->data)->filename, filename))
       return (((fileview *) g->data)->view);
@@ -171,8 +183,10 @@ get_view (gchar * filename)
   gchar *uri = g_file_get_uri (file);
   g_object_unref (file);
   EvDocument *doc = ev_document_factory_get_document (uri, &err);
-  if (err)
-    return NULL;
+  if (err) {
+      g_critical("Error creating view from URI <%s> : message was %s", uri, err->message);
+      return NULL;
+    }
   OldMark.width = Mark.width = 0;
   view = (EvView *) ev_view_new ();
   EvDocumentModel *model = ev_document_model_new_with_document (doc);
@@ -180,10 +194,12 @@ get_view (gchar * filename)
 
   ev_view_set_model (view, model);
   GtkWidget *top_vbox = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    gtk_widget_set_tooltip_text (top_vbox, _("To place a link at the Denemo cursor position to a place in this document\nright-click on the place in this document.\nLater you will be able to re-open the document at this place by right clicking on the link in the Denemo display."));
+
   gtk_window_set_title (GTK_WINDOW (top_vbox), g_strdup_printf ("Denemo - Source File: %s", filename));
 
 #if 0
-  if (Denemo.gui->source_scale)
+  if (Denemo.project->source_scale)
     {
       ! ! ! !nooooo, get_window_position is getting the vadj, hadj settings, ie where it is scrolled to we need to get the position of the root window top vbox on the desk top, and its width and height, possibly the scale will follow ... ! ! ! ! ! ! ! !this is the gtk window widget not the gdk window ! gtk_window_move (GtkWindow * window, gint x, gint y);
       gtk_window_get_position (GtkWindow * window, gint * root_x, gint * root_y);
@@ -194,10 +210,10 @@ get_view (gchar * filename)
 #else
 
   g_idle_add ((GSourceFunc) position_source_window, view);
-//gtk_window_move (GTK_WINDOW(top_vbox), Denemo.gui->source_x, Denemo.gui->source_y);
+//gtk_window_move (GTK_WINDOW(top_vbox), Denemo.project->source_x, Denemo.project->source_y);
 //gtk_widget_set_size_request(GTK_WIDGET(top_vbox), 600, 750);
-  if (Denemo.gui->source_scale)
-    gtk_window_set_default_size (GTK_WINDOW (top_vbox), Denemo.gui->source_width, Denemo.gui->source_height);
+  if (Denemo.project->source_scale)
+    gtk_window_set_default_size (GTK_WINDOW (top_vbox), Denemo.project->source_width, Denemo.project->source_height);
   else
     gtk_window_set_default_size (GTK_WINDOW (top_vbox), 600, 750);
 #endif
