@@ -37,96 +37,99 @@ static gboolean playing = FALSE;
 
 
 
-//Creates a list of times which the aubio onset detector thinks are note onset times for the audio Denemo->si->audio
+//Creates a list of times which the aubio onset detector thinks are note onset times for the audio Denemo->si->recording
 //Result is placed in Denemo->si->note_onsets
-void generate_note_onsets(void)
+void
+generate_note_onsets (void)
 {
-  DenemoAudio *audio = Denemo.gui->si->audio;
+  DenemoRecording *audio = Denemo.project->movement->recording;
   gint channels = audio->channels;
-  
- aubio_onsetdetection_type type_onset = aubio_onset_kl;
- aubio_onsetdetection_type type_onset2 = aubio_onset_complex;
- smpl_t threshold = 0.3;
- smpl_t silence = -90.;
- uint_t buffer_size = 1024;
- uint_t overlap_size = 512;       
 
- uint_t samplerate = 44100;
+  aubio_onsetdetection_type type_onset = aubio_onset_kl;
+  aubio_onsetdetection_type type_onset2 = aubio_onset_complex;
+  smpl_t threshold = 0.3;
+  smpl_t silence = -90.;
+  uint_t buffer_size = 1024;
+  uint_t overlap_size = 512;
+
+  uint_t samplerate = 44100;
+
+  aubio_pvoc_t *pv;
+  fvec_t *ibuf;
+  fvec_t *obuf;
+  cvec_t *fftgrain;
+
+  aubio_onsetdetection_t *o;
+  aubio_onsetdetection_t *o2;
+  fvec_t *onset;
+  fvec_t *onset2;
+  int isonset = 0;
+  aubio_pickpeak_t *parms;
+
 
- aubio_pvoc_t *pv;
- fvec_t *ibuf;
- fvec_t *obuf;
- cvec_t *fftgrain;
 
- aubio_onsetdetection_t *o;
- aubio_onsetdetection_t *o2;
- fvec_t *onset;
- fvec_t *onset2;
- int isonset = 0;
- aubio_pickpeak_t *parms;
-  
-  
-  
   unsigned int pos = 0;         /*frames%dspblocksize */
   unsigned int i;               /*channels */
   unsigned int j;               /*frames */
 
   busy_cursor (Denemo.notebook);
   gtk_window_set_modal (progressbar (_("Analysing Audio"), NULL), TRUE);
-   
+
   ibuf = new_fvec (overlap_size, channels);
   obuf = new_fvec (overlap_size, channels);
   fftgrain = new_cvec (buffer_size, channels);
- 
-   /* phase vocoder */
+
+  /* phase vocoder */
   pv = new_aubio_pvoc (buffer_size, overlap_size, channels);
   /* onsets */
   parms = new_aubio_peakpicker (threshold);
   o = new_aubio_onsetdetection (type_onset, buffer_size, channels);
-  
+
   // if (usedoubled)
-   // {
-      o2 = new_aubio_onsetdetection (type_onset2, buffer_size, channels);
-      onset2 = new_fvec (1, channels);
-   // }
-    
+  // {
+  o2 = new_aubio_onsetdetection (type_onset2, buffer_size, channels);
+  onset2 = new_fvec (1, channels);
+  // }
+
   onset = new_fvec (1, channels);
   rewind_audio ();
-  if(audio->onsets)
-	{
-		g_list_free(audio->onsets);
-		audio->onsets = NULL;
-	}
+  if (audio->notes)
+    {
+      g_list_free_full (audio->notes, g_free);
+      audio->notes = NULL;
+    }
   for (j = 0; j < (unsigned) audio->nframes; j++)
-    {	
-         sf_read_float (audio->sndfile, ibuf->data[0]+pos, 2); //g_print("\t%f", ibuf->data[0][pos]);
-		if (pos == overlap_size - 1)
-			{
-			/* block loop */
-			gtk_main_iteration_do (FALSE);
-			aubio_pvoc_do (pv, ibuf, fftgrain);
-						while (gtk_events_pending ())
-  gtk_main_iteration ();
+    {
+      sf_read_float (audio->sndfile, ibuf->data[0] + pos, 2);   //g_debug("\t%f", ibuf->data[0][pos]);
+      if (pos == overlap_size - 1)
+        {
+          /* block loop */
+          gtk_main_iteration_do (FALSE);
+          aubio_pvoc_do (pv, ibuf, fftgrain);
+          while (gtk_events_pending ())
+            gtk_main_iteration ();
 
-			aubio_onsetdetection (o, fftgrain, onset);
-						while (gtk_events_pending ())
-  gtk_main_iteration ();
+          aubio_onsetdetection (o, fftgrain, onset);
+          while (gtk_events_pending ())
+            gtk_main_iteration ();
 
-			     // if (usedoubled) {
-        aubio_onsetdetection(o2,fftgrain, onset2);
-        			while (gtk_events_pending ())
-  gtk_main_iteration ();
+          // if (usedoubled) {
+          aubio_onsetdetection (o2, fftgrain, onset2);
+          while (gtk_events_pending ())
+            gtk_main_iteration ();
 
-        onset->data[0][0] *= onset2->data[0][0];
-     // }
-			isonset = aubio_peakpick_pimrt (onset, parms);
-			if(isonset)
-				audio->onsets = g_list_append(audio->onsets, GINT_TO_POINTER(j) /* /audio->samplerate for seconds */);
-          
-			pos = -1;                 /* so it will be zero next j loop */
-			}                           /* end of if pos==overlap_size-1 */
-  pos++;
-	}
+          onset->data[0][0] *= onset2->data[0][0];
+          // }
+          isonset = aubio_peakpick_pimrt (onset, parms);
+          if (isonset) {
+			  DenemoRecordedNote *note = g_malloc0(sizeof(DenemoRecordedNote));
+			  note->timing = j;/* /audio->samplerate for seconds */ 
+            audio->notes = g_list_append (audio->notes, note);
+		}
+          pos = -1;             /* so it will be zero next j loop */
+        }                       /* end of if pos==overlap_size-1 */
+      pos++;
+    }
 
 #ifndef G_OS_WIN32
   del_aubio_onsetdetection (o2);
@@ -140,7 +143,7 @@ void generate_note_onsets(void)
   del_cvec (fftgrain);
   del_fvec (onset);
 #else
-  g_print("\n\n\n!!!!!!!!!skipping memory free for windows to avoid crash\n\n\n");
+  g_debug ("\n\n\n!!!!!!!!!skipping memory free for windows to avoid crash\n\n\n");
 #endif
   aubio_cleanup ();
 
@@ -154,15 +157,17 @@ void generate_note_onsets(void)
 
 
 
-  progressbar_stop();
-  normal_cursor(Denemo.notebook);  
-
+  progressbar_stop ();
+  normal_cursor (Denemo.notebook);
+/*
 #ifdef DEBUG
-GList *g;
-for(g=audio->onsets;g;g=g->next) {
-	g_print("Note at %f seconds\n", ((gint)g->data)/(double)audio->samplerate);
-}
+  GList *g;
+  for (g = audio->onsets; g; g = g->next)
+    {
+      g_debug ("Note at %f seconds\n", ((gint) g->data) / (double) audio->samplerate);
+    }
 #endif
+*/
 }
 
 gboolean
@@ -179,12 +184,12 @@ get_audio_sample (float *sample)
     }
   else
     {
-      if (Denemo.gui->si && Denemo.gui->si->audio && Denemo.gui->si->audio->sndfile)
+      if (Denemo.project->movement && Denemo.project->movement->recording && Denemo.project->movement->recording->sndfile)
         {
-          ret = (2 == sf_read_float (Denemo.gui->si->audio->sndfile, sample, 2));
+          ret = (2 == sf_read_float (Denemo.project->movement->recording->sndfile, sample, 2));
           if (ret)
-            *sample *= Denemo.gui->si->audio->volume;
-          *(sample + 1) *= Denemo.gui->si->audio->volume;
+            *sample *= Denemo.project->movement->recording->volume;
+          *(sample + 1) *= Denemo.project->movement->recording->volume;
         }
     }
   return ret;
@@ -194,66 +199,52 @@ gboolean
 open_source_audio (gchar * filename)
 {
   SF_INFO sfinfo;
-  DenemoAudio *temp;
+  DenemoRecording *temp;
   sfinfo.format = 0;
 
-  
-  //FIXME a better name for the mutex which originally was just for midi data, but will work for audio data too.
-  if (Denemo.gui->si->audio && Denemo.gui->si->audio->sndfile)
-    {
-      temp = Denemo.gui->si->audio;
-      g_static_mutex_lock (&smfmutex);
-      Denemo.gui->si->audio = NULL;
-      g_static_mutex_unlock (&smfmutex);
-      sf_close (temp->sndfile);
-      g_free (temp->filename);
-      g_free (temp);
-
-    }
+  delete_recording();
+ 
   if (filename)
     {
       gpointer sndfile = sf_open (filename, SFM_READ, &sfinfo);
       if (sndfile)
         {
-          temp = (DenemoAudio *) g_malloc (sizeof (DenemoAudio));
+          temp = (DenemoRecording *) g_malloc (sizeof (DenemoRecording));
+          temp->type = DENEMO_RECORDING_AUDIO;
           temp->sndfile = sndfile;
           temp->filename = g_strdup (filename);
           temp->samplerate = sfinfo.samplerate;
           temp->channels = sfinfo.channels;
           temp->nframes = (int) sf_seek (temp->sndfile, -1, SEEK_END);
-          g_print ("sndfile: %s sample rate is %d channels %d containing %d \n", 
-                   sf_strerror (temp->sndfile), 
-                   sfinfo.samplerate, 
-                   sfinfo.channels, 
-                   temp->nframes);
-          
-          
+          g_info ("sndfile: %s sample rate is %d channels %d containing %d \n", sf_strerror (temp->sndfile), sfinfo.samplerate, sfinfo.channels, temp->nframes);
+
+
           temp->volume = 1.0;
           g_static_mutex_lock (&smfmutex);
-          Denemo.gui->si->audio = temp;
+          Denemo.project->movement->recording = temp;
           g_static_mutex_unlock (&smfmutex);
           update_leadin_widget (-1.0);
-          if(sfinfo.channels != 2)
-			warningdialog(_("Audio is not stereo - expect bad things!"));
-          if(sfinfo.samplerate != 44100)
-			warningdialog(_("Audio does not have 44100 sample rate: this could be bad"));
-			//FIXME here generate a click track if the score is empty
-		  if (Denemo.gui->si->smfsync != Denemo.gui->si->changecount)
-			{
-				exportmidi (NULL, Denemo.gui->si, 0, 0);//generate a timebase
-			}
-		  generate_note_onsets();
-		  gtk_widget_queue_draw (Denemo.scorearea);
+          if (sfinfo.channels != 2)
+            warningdialog (_("Audio is not stereo - expect bad things!"));
+          if (sfinfo.samplerate != 44100)
+            warningdialog (_("Audio does not have 44100 sample rate: this could be bad"));
+          //FIXME here generate a click track if the score is empty
+          if (Denemo.project->movement->smfsync != Denemo.project->movement->changecount)
+            {
+              exportmidi (NULL, Denemo.project->movement, 0, 0);  //generate a timebase
+            }
+          generate_note_onsets ();
+          gtk_widget_queue_draw (Denemo.scorearea);
         }
     }
-  Denemo.gui->si->audio ? gtk_widget_show (Denemo.audio_vol_control) : gtk_widget_hide (Denemo.audio_vol_control);
-  return (Denemo.gui->si->audio != NULL);
+  Denemo.project->movement->recording ? gtk_widget_show (Denemo.audio_vol_control) : gtk_widget_hide (Denemo.audio_vol_control);
+  return (Denemo.project->movement->recording != NULL);
 }
 
 gboolean
 close_source_audio (void)
 {
-  gboolean ret = (Denemo.gui->si->audio != NULL);
+  gboolean ret = (Denemo.project->movement->recording != NULL);
   (void) open_source_audio (NULL);
   return ret;
 }
@@ -261,23 +252,28 @@ close_source_audio (void)
 void
 rewind_audio (void)
 {
-  if (Denemo.gui->si->audio)
+  if (Denemo.project->movement->recording && (Denemo.project->movement->recording->type==DENEMO_RECORDING_AUDIO))
     {
-      if (Denemo.gui->si->audio->sndfile == NULL)
+      if (Denemo.project->movement->recording->sndfile == NULL)
         {
-          gint leadin = Denemo.gui->si->audio->leadin;  /* not part of the audio file itself */
-          open_source_audio (Denemo.gui->si->audio->filename);
-          if (Denemo.gui->si->audio->samplerate)
+          gint leadin = Denemo.project->movement->recording->leadin;  /* not part of the audio file itself */
+          open_source_audio (Denemo.project->movement->recording->filename);
+          if (Denemo.project->movement->recording==NULL)
+          {
+			g_warning("Unable to open audio file");
+			return;  			  
+		  }
+          if (Denemo.project->movement->recording->samplerate)
             {
-              Denemo.gui->si->audio->leadin = leadin;
-              update_leadin_widget (((double) leadin) / Denemo.gui->si->audio->samplerate);
+              Denemo.project->movement->recording->leadin = leadin;
+              update_leadin_widget (((double) leadin) / Denemo.project->movement->recording->samplerate);
             }
         }
       gdouble start = get_start_time ();
       if (start < 0.0)
         start = 0.0;
-      gint startframe = start * Denemo.gui->si->audio->samplerate;
-      startframe += Denemo.gui->si->audio->leadin;
+      gint startframe = start * Denemo.project->movement->recording->samplerate;
+      startframe += Denemo.project->movement->recording->leadin;
       if (startframe < 0)
         {
           leadin = -startframe;
@@ -285,7 +281,7 @@ rewind_audio (void)
         }
       else
         leadin = 0;
-      sf_seek (Denemo.gui->si->audio->sndfile, startframe, SEEK_SET);
+      sf_seek (Denemo.project->movement->recording->sndfile, startframe, SEEK_SET);
     }
   else
     gtk_widget_hide (Denemo.audio_vol_control);
@@ -294,15 +290,18 @@ rewind_audio (void)
 gboolean
 set_lead_in (gdouble secs)
 {
-  if (Denemo.gui->si->audio)
+  if (Denemo.project->movement->recording)
     {
-      if (Denemo.gui->si->audio->sndfile == NULL)
-        open_source_audio (Denemo.gui->si->audio->filename);
-      if (Denemo.gui->si->audio->sndfile)
+      if ((Denemo.project->movement->recording->type==DENEMO_RECORDING_AUDIO) && Denemo.project->movement->recording->sndfile == NULL)
         {
-          Denemo.gui->si->audio->leadin = secs * Denemo.gui->si->audio->samplerate;
-          return TRUE;
-        }
+			open_source_audio (Denemo.project->movement->recording->filename);
+			if (Denemo.project->movement->recording==NULL) {
+				g_warning("Unable to open source audio");
+				return FALSE;
+			}
+		}
+      Denemo.project->movement->recording->leadin = secs * Denemo.project->movement->recording->samplerate;
+      return TRUE;   
     }
   return FALSE;
 }
@@ -389,7 +388,7 @@ gboolean
 open_source_audio_file (void)
 {
   gboolean ret = FALSE;
-  GtkWidget *dialog = gtk_file_chooser_dialog_new ("Open Audio Source File",
+  GtkWidget *dialog = gtk_file_chooser_dialog_new (_("Open Audio Source File"),
                                                    NULL,
                                                    GTK_FILE_CHOOSER_ACTION_OPEN,
                                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -401,16 +400,16 @@ open_source_audio_file (void)
       filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
       gtk_widget_destroy (dialog);
 
-      
+
 
       ret = open_source_audio (filename);
       g_free (filename);
-      
-      if(!ret)
-		warningdialog(_("Could not load the audio file. Note only stereo with sample rate 44100 are supported at present. Use Audacity or similar to convert."));
-    } else
-	gtk_widget_destroy (dialog);
-	      
-	return ret;
-}
 
+      if (!ret)
+        warningdialog (_("Could not load the audio file. Note only stereo with sample rate 44100 are supported at present. Use Audacity or similar to convert."));
+    }
+  else
+    gtk_widget_destroy (dialog);
+
+  return ret;
+}
