@@ -88,7 +88,7 @@ firstobjnodeinstaff (staffnode * thestaff)
  * @return none
  */
 void
-setcurrentprimarystaff (DenemoScore * si)
+setcurrentprimarystaff (DenemoMovement * si)
 {
   for (si->currentprimarystaff = si->currentstaff; !((DenemoStaff *) si->currentprimarystaff->data)->voicecontrol & DENEMO_PRIMARY; si->currentprimarystaff = si->currentprimarystaff->prev)
     ;
@@ -189,7 +189,7 @@ copy_staff (DenemoStaff * src, DenemoStaff * dest)
  * @return none
  */
 static void
-insert_staff (DenemoScore * si, DenemoStaff * thestaffstruct, enum newstaffcallbackaction action, gint addat)
+insert_staff (DenemoMovement * si, DenemoStaff * thestaffstruct, enum newstaffcallbackaction action, gint addat)
 {
   si->thescore = g_list_insert (si->thescore, thestaffstruct, addat - 1);
   if (action != BEFORE)
@@ -213,19 +213,17 @@ insert_staff (DenemoScore * si, DenemoStaff * thestaffstruct, enum newstaffcallb
  * @return none
  */
 void
-newstaff (DenemoGUI * gui, enum newstaffcallbackaction action, DenemoContext context)
+newstaff (DenemoProject * gui, enum newstaffcallbackaction action, DenemoContext context)
 {
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = gui->movement;
   g_assert (si != NULL);
   take_snapshot ();
   DenemoStaff *thestaffstruct = (DenemoStaff *) g_malloc (sizeof (DenemoStaff));
 
-
-
-
-  thestaffstruct->staffmenu = (GtkMenu *) gtk_menu_new ();
-  thestaffstruct->voicemenu = (GtkMenu *) gtk_menu_new ();
-
+  if(!Denemo.non_interactive){
+    thestaffstruct->staffmenu = (GtkMenu *) gtk_menu_new ();
+    thestaffstruct->voicemenu = (GtkMenu *) gtk_menu_new ();
+  }
 
   measurenode *themeasures = NULL;      /* Initial set of measures in staff */
   gint numstaffs = g_list_length (si->thescore);
@@ -234,7 +232,7 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action, DenemoContext con
     g_free (thestaffstruct);
     return;          /* no code for this yet - just edit textually */
   }
-  g_debug ("newstaff: Num staffs %d\n", numstaffs);
+  g_debug ("newstaff: Num staffs %d", numstaffs);
   if (numstaffs == 0)
     {
       action = INITIAL;
@@ -249,7 +247,7 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action, DenemoContext con
       thestaffstruct->no_of_lines = 5;
       thestaffstruct->transposition = 0;
 
-      thestaffstruct->space_above = 0;
+      thestaffstruct->space_above = 20;
       thestaffstruct->space_below = 0;
       thestaffstruct->nummeasures = 1;
       thestaffstruct->midi_channel = 0;
@@ -390,30 +388,31 @@ newstaff (DenemoGUI * gui, enum newstaffcallbackaction action, DenemoContext con
       insert_staff (si, thestaffstruct, action, addat);
       si->leftmeasurenum = 1;
     }
-
+  if ( addat==1)
+       thestaffstruct->space_above = 20;
   //si->haschanged = TRUE;
 }
 
 
 gboolean
-signal_structural_change (DenemoGUI * gui)
+signal_structural_change (DenemoProject * gui)
 {
   gui->layout_sync = gui->changecount;
   return TRUE;
 }
 
 /**
- * Remove the gui->si->currentstaff from the piece gui and reset si->currentstaff
+ * Remove the gui->movement->currentstaff from the piece gui and reset si->currentstaff
  * if only one staff, inserts a new empty one
  * if interactive checks for custom_scoreblock
  * if a staff is deleted, updates the changecount
- * @param gui the DenemoGUI structure
+ * @param gui the DenemoProject structure
  * @return nothing
  */
 void
-deletestaff (DenemoGUI * gui, gboolean interactive)
+deletestaff (DenemoProject * gui, gboolean interactive)
 {
-  DenemoScore *si = gui->si;
+  DenemoMovement *si = gui->movement;
   DenemoStaff *curstaffstruct = si->currentstaff->data;
   gboolean has_next = (si->currentstaff->next != NULL);
   (void) signal_structural_change (gui);
@@ -433,9 +432,10 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
   free_directives (curstaffstruct->timesig.directives);
   free_directives (curstaffstruct->keysig.directives);
 
-  gtk_widget_destroy ((GtkWidget *) (curstaffstruct->staffmenu));
-  gtk_widget_destroy ((GtkWidget *) (curstaffstruct->voicemenu));
-
+  if(!Denemo.non_interactive){
+    gtk_widget_destroy ((GtkWidget *) (curstaffstruct->staffmenu));
+    gtk_widget_destroy ((GtkWidget *) (curstaffstruct->voicemenu));
+  }
 
   g_list_foreach (curstaffstruct->measures, freeobjlist, NULL);
   g_list_free (curstaffstruct->measures);
@@ -475,13 +475,16 @@ deletestaff (DenemoGUI * gui, gboolean interactive)
   setcurrents (si);
   if (si->markstaffnum)
     calcmarkboundaries (si);
-  if (gui->si->currentstaffnum < gui->si->top_staff)
-    gui->si->top_staff = gui->si->currentstaffnum;
+  if (gui->movement->currentstaffnum < gui->movement->top_staff)
+    gui->movement->top_staff = gui->movement->currentstaffnum;
   show_lyrics ();
-  update_vscrollbar (gui);
 
-  displayhelper (gui);
-  score_status (gui, TRUE);
+  if(!Denemo.non_interactive){
+    update_vscrollbar (gui);
+    displayhelper (gui);
+    score_status (gui, TRUE);
+  }
+  
   if (give_info)
     infodialog (_("The staff deleted had a start/end context; if you still have the staff with the matching end/start context\n then you should remove it (or its context) now.\nSee Staff->properties->context\nYou will not be able to print with miss-matched contexts."));
   return;
@@ -574,40 +577,40 @@ fixnoteheights (DenemoStaff * thestaff)
 /**
  * Callback function to insert a staff in the initial position
  * @param action a Gtk Action
- * @param gui the DenemoGUI structure
+ * @param gui the DenemoProject structure
  * @return none
  */
 void
-newstaffinitial (GtkAction * action, gpointer param)
+newstaffinitial (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  while (gui->si->currentstaff && gui->si->currentstaff->prev)
-    movetostaffup (param);
+  DenemoProject *gui = Denemo.project;
+  while (gui->movement->currentstaff && gui->movement->currentstaff->prev)
+    movetostaffup (NULL, NULL);
   newstaffbefore (action, NULL);
 }
 
 /**
  Callback function to insert a staff before the current staff
  * @param action a Gtk Action
- * @param gui the DenemoGUI structure
+ * @param gui the DenemoProject structure
  * @return none
  */
 void
-newstaffbefore (GtkAction * action, gpointer param)
+newstaffbefore (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   (void) signal_structural_change (gui);
 
   movetostart (NULL, NULL);
   newstaff (gui, BEFORE, DENEMO_NONE);
-  if (gui->si->currentstaffnum >= gui->si->top_staff)
-    gui->si->top_staff++;
-  gui->si->currentstaffnum++;
-  gui->si->bottom_staff++;
+  if (gui->movement->currentstaffnum >= gui->movement->top_staff)
+    gui->movement->top_staff++;
+  gui->movement->currentstaffnum++;
+  gui->movement->bottom_staff++;
   set_bottom_staff (gui);
   move_viewport_down (gui);
 
-  movetostaffup (param);
+  movetostaffup (NULL, NULL);
   displayhelper (gui);
 
 }
@@ -615,53 +618,53 @@ newstaffbefore (GtkAction * action, gpointer param)
 /**
  * Callback function to insert a staff after the current staff
  * @param action a Gtk Action
- * @param gui the DenemoGUI structure
+ * @param gui the DenemoProject structure
  * @return none
  */
 void
-dnm_newstaffafter (GtkAction * action, gpointer param)
+dnm_newstaffafter (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (!signal_structural_change (gui))
     return;
   movetostart (NULL, NULL);
   newstaff (gui, AFTER, DENEMO_NONE);
   set_bottom_staff (gui);
   update_vscrollbar (gui);
-  movetostaffdown (param);
+  movetostaffdown (NULL, NULL);
   displayhelper (gui);
 }
 
 /**
  * Callback function to insert a staff at the bottom of the score
  * @param action a Gtk Action
- * @param gui the DenemoGUI structure
+ * @param gui the DenemoProject structure
  * @return none
  */
 void
-newstafflast (GtkAction * action, gpointer param)
+newstafflast (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
-  while (gui->si->currentstaff && gui->si->currentstaff->next)
-    movetostaffdown (param);
+  DenemoProject *gui = Denemo.project;
+  while (gui->movement->currentstaff && gui->movement->currentstaff->next)
+    movetostaffdown (NULL, NULL);
   dnm_newstaffafter (action, param);
 }
 
 /**
  * Callback function to add a new voice to the current staff
  * @param action a Gtk Action
- * @param gui the DenemoGUI structure
+ * @param gui the DenemoProject structure
  * @return none
  */
 void
-dnm_newstaffvoice (GtkAction * action, gpointer param)
+dnm_newstaffvoice (GtkAction * action, DenemoScriptParam * param)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   newstaff (gui, NEWVOICE, DENEMO_NONE);
   set_bottom_staff (gui);
   update_vscrollbar (gui);
-  setcurrents (gui->si);
-  if (gui->si->markstaffnum)
-    calcmarkboundaries (gui->si);
+  setcurrents (gui->movement);
+  if (gui->movement->markstaffnum)
+    calcmarkboundaries (gui->movement);
   displayhelper (gui);
 }
