@@ -44,9 +44,9 @@ executeScript (void)
 {
   gchar *text = getSchemeText ();
   g_debug ("Calling script %s\n", text);
-  stage_undo (Denemo.gui->si, ACTION_STAGE_END);        //undo is a queue so this is the end :)
+  stage_undo (Denemo.project->movement, ACTION_STAGE_END);        //undo is a queue so this is the end :)
   (void) call_out_to_guile (text);
-  stage_undo (Denemo.gui->si, ACTION_STAGE_START);
+  stage_undo (Denemo.project->movement, ACTION_STAGE_START);
   g_free (text);
 }
 
@@ -59,7 +59,7 @@ executeCLI (GtkWidget * button, GtkEntry * entry)
   if (entry)
     {
       display = g_strdup_printf ("%s%s%s", "(format #t \"~%=> ~A~%\"", gtk_entry_get_text (entry), ")\n");
-      //g_print("displaying %s\n", display);
+      //g_debug("displaying %s\n", display);
       (void) call_out_to_guile (display);
       g_free (display);
     }
@@ -71,6 +71,8 @@ executeCLI (GtkWidget * button, GtkEntry * entry)
 
 
 /* Return number of characters in Scheme script */
+//TODO: Avoid to use gtk widgets for this since it can be used in non 
+//interactive mode.
 gint
 getNumCharsSchemeText (void)
 {
@@ -281,11 +283,13 @@ create_editor_window (void)
   //GtkWidget *w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   GtkWidget *menu, *menuBar, *fileMenu, *item;
   gchar **filename = g_malloc0 (sizeof (gchar *));
+  GtkSourceLanguage* language = NULL;
 
 
   buffer = gtk_source_buffer_new (NULL);
   gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (buffer), TRUE);
-  gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (buffer), gtk_source_language_manager_get_language (LanguageManager, "scheme"));
+  language = gtk_source_language_manager_get_language (LanguageManager, "scheme");
+  gtk_source_buffer_set_language (GTK_SOURCE_BUFFER (buffer), language);
   gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (buffer), TRUE);
 
   TextView = GTK_WIDGET (gtk_source_view_new_with_buffer (GTK_SOURCE_BUFFER (buffer)));
@@ -365,10 +369,12 @@ create_editor_window (void)
   gtk_widget_show (menuBar);
   gtk_menu_shell_append (GTK_MENU_SHELL (menuBar), fileMenu);
 
-
+  GtkWidget *inner_hbox = gtk_hbox_new (FALSE, 1);
+  gtk_box_pack_start (GTK_BOX (main_vbox), inner_hbox, FALSE, FALSE, 0);
   GtkWidget *wid = gtk_check_button_new ();
   gtk_activatable_set_related_action (GTK_ACTIVATABLE (wid), gtk_ui_manager_get_action (Denemo.ui_manager, "/MainMenu/ModeMenu/RecordScript"));
-  gtk_box_pack_start (GTK_BOX (main_vbox), wid, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (inner_hbox), wid, FALSE, FALSE, 0);
+  
   GtkWidget *sw = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
