@@ -118,9 +118,9 @@ make_temp_dir (void)
 
   gint fail = g_mkdir_with_parents (ret, 0700);
   if (fail)
-    g_print ("Could not create temp dir %s\n", ret);
+    g_warning ("Could not create temp dir %s", ret);
   else
-    g_print ("Created temp dir %s\n", ret);
+    g_info ("Created temp dir %s\n", ret);
 #else
   ret = g_strdup ("/tmp/DenemoXXXXXX");
   mkdtemp ((char *) ret);
@@ -137,9 +137,9 @@ run_file_association (gchar * filename)
     {
       value = CoInitializeExCalled = TRUE;
       CoInitializeEx (NULL, COINIT_APARTMENTTHREADED | COINIT_DISABLE_OLE1DDE);
-      g_print ("coinit returned %d\n", value);
+      g_debug ("coinit returned %d\n", value);
     }
-  g_print ("Running ShellExecute %s \n", filename);
+  g_info ("Running ShellExecute %s \n", filename);
   return ShellExecute (NULL, NULL, filename, NULL, NULL, 0) > 32 /* value above 32 indicating success */ ;
 #else
   g_warning ("No file assoc code - set pref in externals tab of prefs dialog");
@@ -166,7 +166,7 @@ void
 warningmessage (gchar * msg)
 {
   gdk_beep ();
-  g_message ("%s", msg);
+  g_warning ("%s", msg);
 }
 
 /**
@@ -177,12 +177,17 @@ warningmessage (gchar * msg)
 void
 warningdialog (gchar * msg)
 {
-  GtkWidget *dialog;
-  dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, "%s", msg);
-  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
-  gtk_dialog_run (GTK_DIALOG (dialog));
-  gtk_window_set_keep_above (GTK_WINDOW (dialog), TRUE);
-  gtk_widget_destroy (dialog);
+  if(Denemo.non_interactive)
+    g_warning("%s", msg);
+
+  else{
+    GtkWidget *dialog;
+    dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, "%s", msg);
+    gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_window_set_keep_above (GTK_WINDOW (dialog), TRUE);
+    gtk_widget_destroy (dialog);
+  }
 }
 
 /**
@@ -194,6 +199,11 @@ warningdialog (gchar * msg)
 GtkWidget *
 infodialog (gchar * msg)
 {
+  if(Denemo.non_interactive){
+    g_info("%s", msg);
+    return NULL;
+  }
+
   GtkWidget *dialog;
   dialog = gtk_message_dialog_new (GTK_WINDOW (Denemo.window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, "%s", msg);
 #ifdef G_OS_WIN32
@@ -426,7 +436,7 @@ draw_for_directives (cairo_t * cr, GList * directives, gint x, gint y, gboolean
           gheight = directive->graphic->height;
 
           maxwidth = MAX (gwidth, maxwidth);
-          //g_print("drawing a graphic at %d %d\n", xx+directive->gx+count-gwidth/2,  y+height+directive->gy-gheight/2);
+          //g_debug("drawing a graphic at %d %d\n", xx+directive->gx+count-gwidth/2,  y+height+directive->gy-gheight/2);
           drawbitmapinverse_cr (cr, directive->graphic, x + directive->gx + count - gwidth / 2, y + directive->gy - gheight / 2, FALSE);
 
         }
@@ -976,7 +986,7 @@ printmeasures (staffnode * thestaff)
 }
 
 G_GNUC_UNUSED void
-printscoreinfo (DenemoScore * si)
+printscoreinfo (DenemoMovement * si)
 {
   if (si->thescore == NULL)
     {
@@ -1013,14 +1023,14 @@ static gchar *DENEMO_datadir = NULL;
 const gchar *
 get_system_data_dir ()
 {
-  //DENEMO_datadir?g_print("datadir is %s at %p", DENEMO_datadir, DENEMO_datadir):g_print("datadir not yet set");
+  //DENEMO_datadir?g_debug("datadir is %s at %p", DENEMO_datadir, DENEMO_datadir):g_debug("datadir not yet set");
   if (DENEMO_datadir == NULL)
     {
 #ifdef G_OS_WIN32
       gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
       DENEMO_datadir = g_build_filename (rootdir, "share", "denemo", NULL);
-      g_print ("rootdir=%s\n", rootdir);
-      g_print ("datadir=%s\n", DENEMO_datadir);
+      g_message ("rootdir=%s", rootdir);
+      g_message ("datadir=%s", DENEMO_datadir);
       g_free (rootdir);
 #else /* not G_OS_WIN32 */
 
@@ -1032,11 +1042,11 @@ get_system_data_dir ()
         _NSGetExecutablePath (path, &size);
         gchar *bindir = (gchar *) g_malloc (size);
         if (_NSGetExecutablePath (bindir, &size) == 0)
-          g_print ("using bin path %s\n", bindir);
+          g_message ("Using bin path %s", bindir);
         else
-          g_critical ("Cannot get bin dir\n");
+          g_critical ("Cannot get bin dir");
         DENEMO_datadir = g_build_filename (g_path_get_dirname (bindir), "..", "share", "denemo", NULL);
-        g_print ("OSX set data dir to %s\n", DENEMO_datadir);
+        g_message ("OSX set data dir to %s", DENEMO_datadir);
       }
 #else
 #ifndef ENABLE_BINRELOC
@@ -1067,10 +1077,10 @@ get_prefix_dir (void)
     if (_NSGetExecutablePath (bindir, &size) == 0)
       {
         prefix = g_build_filename (bindir, "..", "..", NULL);
-        g_print ("OSX set data prefix to %s\n", prefix);
+        g_message ("OSX set data prefix to %s", prefix);
       }
     else
-      g_critical ("Cannot get bin dir\n");
+      g_critical ("Cannot get bin dir");
   }
 #else
 
@@ -1094,8 +1104,8 @@ get_system_bin_dir (void)
 #ifdef G_OS_WIN32
       gchar *rootdir = g_win32_get_package_installation_directory (NULL, NULL);
       DENEMO_bindir = g_build_filename (rootdir, "bin", NULL);
-      g_print ("rootdir=%s\n", rootdir);
-      g_print ("bindir=%s\n", DENEMO_bindir);
+      g_message ("rootdir=%s", rootdir);
+      g_message ("bindir=%s", DENEMO_bindir);
       g_free (rootdir);
 #else /* not G_OS_WIN32 */
 
@@ -1109,12 +1119,12 @@ get_system_bin_dir (void)
         if (_NSGetExecutablePath (bin, &size) == 0)
           {
             DENEMO_bindir = g_build_filename (bin, "..", NULL);
-            g_print ("using bin path %s\n", DENEMO_bindir);
+            g_message ("Using bin path %s", DENEMO_bindir);
           }
         else
-          g_critical ("Cannot get bin dir\n");
+          g_critical ("Cannot get bin dir");
 
-        g_print ("OSX set bin dir to %s\n", DENEMO_bindir);
+        g_message ("OSX set bin dir to %s", DENEMO_bindir);
       }
 #else
 
@@ -1150,11 +1160,11 @@ get_system_conf_dir ()
         _NSGetExecutablePath (path, &size);
         gchar *bindir = (gchar *) g_malloc (size);
         if (_NSGetExecutablePath (bindir, &size) == 0)
-          g_print ("using bin path %s\n", bindir);
+          g_debug ("using bin path %s\n", bindir);
         else
           g_critical ("Cannot get bin dir\n");
         confdir = g_build_filename (g_path_get_dirname (bindir), "..", "etc", "denemo", NULL);
-        g_print ("OSX set conf dir to %s\n", confdir);
+        g_debug ("OSX set conf dir to %s\n", confdir);
       }
 #else
 
@@ -1190,11 +1200,11 @@ get_system_locale_dir ()
         _NSGetExecutablePath (path, &size);
         gchar *bindir = (gchar *) g_malloc (size);
         if (_NSGetExecutablePath (bindir, &size) == 0)
-          g_print ("using bin path %s\n", bindir);
+          g_message ("Using bin path %s", bindir);
         else
-          g_critical ("Cannot get bin dir\n");
+          g_critical ("Cannot get bin dir");
         localedir = g_build_filename (g_path_get_dirname (bindir), "..", "share", "locale", NULL);
-        g_print ("OSX set locale dir to %s\n", localedir);
+        g_message ("OSX set locale dir to %s", localedir);
       }
 #else
 #ifndef ENABLE_BINRELOC
@@ -1243,27 +1253,6 @@ kill_process (GPid pid)
 }
 
 
-
-#define NOTE0 "\xF0\x9D\x85\x9D"
-#define NOTE1 "\xF0\x9D\x85\x9E"
-#define NOTE2 "\xF0\x9D\x85\x9F"
-#define NOTE3 "\xF0\x9D\x85\xA0"
-#define NOTE4 "\xF0\x9D\x85\xA1"
-#define NOTE5 "\xF0\x9D\x85\xA2"
-#define NOTE6 "\xF0\x9D\x85\xA3"
-#define NOTE7 "\xF0\x9D\x85\xA4"
-#define NOTE8 "\xF0\x9D\x85\xA5"
-
-#define REST0 "\xF0\x9D\x84\xBB"
-#define REST1 "\xF0\x9D\x84\xBC"
-#define REST2 "\xF0\x9D\x84\xBD"
-#define REST3 "\xF0\x9D\x84\xBE"
-#define REST4 "\xF0\x9D\x84\xBF"
-#define REST5 "\xF0\x9D\x85\x80"
-#define REST6 "\xF0\x9D\x85\x81"
-#define REST7 "\xF0\x9D\x85\x82"
-#define REST8 "\xF0\x9D\x85\x83"
-
 void
 init_denemo_notenames (void)
 {
@@ -1421,7 +1410,7 @@ music_font (gchar * str)
 }
 
 void
-set_title_bar (DenemoGUI * gui)
+set_title_bar (DenemoProject * gui)
 {
   gchar *title;
   if (gui->tabname && gui->tabname->len)
@@ -1431,7 +1420,7 @@ set_title_bar (DenemoGUI * gui)
   title = g_strdup_printf ("%s%c", title, gui->notsaved ? '*' : ' ');
   gtk_window_set_title (GTK_WINDOW (Denemo.window), title);
   gchar *base = g_path_get_basename (title);
-  gint index = g_list_index (Denemo.guis, gui);
+  gint index = g_list_index (Denemo.projects, gui);
   GtkWidget *page = gtk_notebook_get_nth_page (GTK_NOTEBOOK (Denemo.notebook), index);
   gtk_notebook_set_tab_label_text (GTK_NOTEBOOK (Denemo.notebook), page, base);
 
@@ -1464,28 +1453,31 @@ enshift_string (gint enshift)
 
 /* set the status of the current musical score - its change count and
    title bar and status bars.
-   DenemoGUI *gui the musical score.
+   DenemoProject *gui the musical score.
    gboolean change TRUE = a change has just been made
                    FALSE = the score is to be assumed saved
 */
 void
-score_status (DenemoGUI * gui, gboolean change)
+score_status (DenemoProject * gui, gboolean change)
 {
   if (change)
     {
       gboolean just_changed = !gui->notsaved;
       gui->notsaved = TRUE;
       gui->changecount++;
-      gui->si->changecount++;
+      gui->movement->changecount++;
       if (just_changed)
-        set_title_bar (gui);
+        if(!Denemo.non_interactive)
+          set_title_bar (gui);
     }
   else
     {
       gui->notsaved = FALSE;
-      set_title_bar (gui);
+      if(!Denemo.non_interactive)
+        set_title_bar (gui);
     }
-  write_status (gui);
+  if(!Denemo.non_interactive)
+    write_status (gui);
 }
 
 /**
@@ -1503,7 +1495,7 @@ findnote (DenemoObject * curObj, gint cursory)
       for (; notes; notes = notes->next)
         {
           curnote = (note *) notes->data;
-          //g_print("comparing %d and %d\n", cursory, curnote->y);
+          //g_debug("comparing %d and %d\n", cursory, curnote->y);
           if (cursory <= curnote->mid_c_offset)
             break;
         }
@@ -1550,7 +1542,7 @@ append_directives_information (GString * selection, GList * directives)
 void
 display_current_object (void)
 {
-  DenemoGUI *gui = Denemo.gui;
+  DenemoProject *gui = Denemo.project;
   if (ObjectInfo == NULL)
     {
       ObjectInfo = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -1566,15 +1558,15 @@ display_current_object (void)
   GtkWidget *vbox = gtk_vbox_new (FALSE, 8);
   gtk_container_add (GTK_CONTAINER (ObjectInfo), vbox);
 
-  if (gui->si->currentobject == NULL)
+  if (gui->movement->currentobject == NULL)
     {
       GtkWidget *label = gtk_label_new ("The cursor is in an empty measure.\n" "As a special case this will be typeset as a non-printing whole measure rest.\n" "Note that if you put anything at all in this measure\n" "you must insert a real whole measure rest if that is what you want.");
       gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
     }
   else
     {
-      DenemoObject *curObj = gui->si->currentobject->data;
-      GString *selection = g_string_new (gui->si->cursor_appending ? _("The cursor is in the appending position after ") : _("The cursor is on "));
+      DenemoObject *curObj = gui->movement->currentobject->data;
+      GString *selection = g_string_new (gui->movement->cursor_appending ? _("The cursor is in the appending position after ") : _("The cursor is on "));
       GString *warning = g_string_new ("");
       switch (curObj->type)
         {
@@ -1607,8 +1599,8 @@ display_current_object (void)
 
 
 
-                note *thenote = findnote (curObj, gui->si->cursor_y);
-                if (thenote && gui->si->cursor_y==thenote->mid_c_offset)
+                note *thenote = findnote (curObj, gui->movement->cursor_y);
+                if (thenote && gui->movement->cursor_y==thenote->mid_c_offset)
                   {
   
 										g_string_append_printf (selection, _("Within the chord the cursor is on the note %s \n"),
@@ -1645,6 +1637,8 @@ display_current_object (void)
               append_directives_information (selection, thechord->directives);
 						}
           g_string_append_printf (selection, _("This starts %d/384 quarter notes into the measure and lasts %d/384 quarter notes.\n"), curObj->starttick, curObj->durinticks);
+			if(curObj->lilypond)
+				          g_string_append_printf (selection, _("The LilyPond syntax generated is: %s\n"), curObj->lilypond);
 
           }
           break;
@@ -1691,7 +1685,7 @@ display_current_object (void)
 								selection = g_string_append (selection, _("Attached to the Time Signature Change:"));
 								append_directives_information (selection, thetime->directives);
 							}           
-            if (gui->si->currentobject->prev)
+            if (gui->movement->currentobject->prev)
               g_string_append_printf (warning, _("A Time Signature Change should be the first object in a measure\n" "unless you are trying to do something unusual"));
           }
           break;
@@ -1741,7 +1735,7 @@ display_current_object (void)
 							directive->prefix?directive->prefix->str:"",
 							directive->postfix?directive->postfix->str:"");
 						
-           if (gui->si->currentobject->next == NULL && (gui->si->currentmeasure->next == NULL))
+           if (gui->movement->currentobject->next == NULL && (gui->movement->currentmeasure->next == NULL))
               g_string_assign (warning, _("This Directive is at the end of the music" "\nYou may need a closing double bar line - see Directives → barlines"));
           }
           break;
@@ -1776,18 +1770,18 @@ display_current_object (void)
 ********************/
 
 void
-write_status (DenemoGUI * gui)
+write_status (DenemoProject * gui)
 {
   gint minutes = 0;
   gdouble seconds = 0.0;
   gdouble early = 0.0, late = 0.0;
   gchar *selection;
-  if (gui->si == NULL)
+  if (gui->movement == NULL)
     return;
-  if (gui->si->currentobject && gui->si->currentobject->data)
+  if (gui->movement->currentobject && gui->movement->currentobject->data)
     {
-      DenemoObject *curObj = gui->si->currentobject->data;
-      if ((gui->si->smfsync == gui->si->changecount))
+      DenemoObject *curObj = gui->movement->currentobject->data;
+      if ((gui->movement->smfsync == gui->movement->changecount))
         {
           if (curObj->midi_events)
             {
@@ -1864,7 +1858,7 @@ write_status (DenemoGUI * gui)
     selection = g_strdup_printf (_("Cursor not on any object"));
 
   GString *status = g_string_new (_("Movement"));
-  gint index = g_list_index (gui->movements, gui->si);
+  gint index = g_list_index (gui->movements, gui->movement);
   const gchar *dur ="";
   switch (get_prevailing_duration())
   {
@@ -1889,14 +1883,14 @@ write_status (DenemoGUI * gui)
 	 
 	  
   }
-  g_string_printf (status, "%s%s %d: %s: ", enshift_string (gui->si->pending_enshift), dur, index + 1, selection);
+  g_string_printf (status, "%s%s %d: %s: ", enshift_string (gui->movement->pending_enshift), dur, index + 1, selection);
   
 
   
-  if (gui->si->smf && (gui->si->smfsync == gui->si->changecount) && Denemo.prefs.playback_controls)
+  if (gui->movement->smf && (gui->movement->smfsync == gui->movement->changecount) && Denemo.prefs.playback_controls)
     g_string_append_printf (status, _("%d min %.2f sec %.2f %.2f"), minutes, seconds, early, late);
   else
-    g_string_append_printf (status, _(" Staff %d Measure %d Position %d %s"), gui->si->currentstaffnum, gui->si->currentmeasurenum, gui->si->cursor_x + 1, gui->si->cursor_appending ? _("Appending") : _("Not Appending") /*not understood this one... , gui->si->cursoroffend?"Off End":"Not Off End" */ );
+    g_string_append_printf (status, _(" Staff %d Measure %d Position %d %s"), gui->movement->currentstaffnum, gui->movement->currentmeasurenum, gui->movement->cursor_x + 1, gui->movement->cursor_appending ? _("Appending") : _("Not Appending") /*not understood this one... , gui->movement->cursoroffend?"Off End":"Not Off End" */ );
 
   if (Denemo.prefs.midi_in_controls)
     {
@@ -1908,8 +1902,8 @@ write_status (DenemoGUI * gui)
     }
 
   g_free (selection);
-  gtk_statusbar_pop (GTK_STATUSBAR (Denemo.statusbar), Denemo.status_context_id);
-  gtk_statusbar_push (GTK_STATUSBAR (Denemo.statusbar), Denemo.status_context_id, status->str);
+  
+  gtk_label_set_text (GTK_LABEL (Denemo.statuslabel), status->str);
   g_string_free (status, TRUE);
   drop_object_info ();
 }
@@ -1959,14 +1953,14 @@ nullify_gstring (GString ** s)
  */
 
 gchar *
-string_dialog_entry (DenemoGUI * gui, gchar * title, gchar * instruction, gchar * initial_value)
+string_dialog_entry (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value)
 {
   return string_dialog_entry_with_widget (gui, title, instruction, initial_value, NULL);
 }
 
 /* as string_dialog_entry() but with extra widget */
 gchar *
-string_dialog_entry_with_widget_opt (DenemoGUI * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal)
+string_dialog_entry_with_widget_opt (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal)
 {
 
   GtkWidget *dialog;
@@ -2030,14 +2024,14 @@ string_dialog_entry_with_widget_opt (DenemoGUI * gui, gchar * wlabel, gchar * di
 }
 
 gchar *
-string_dialog_entry_with_widget (DenemoGUI * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget)
+string_dialog_entry_with_widget (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget)
 {
   return string_dialog_entry_with_widget_opt (gui, wlabel, direction, PreValue, widget, TRUE);
 }
 
 /* as string_dialog_entry_with_widget() but gives a text editor instead of a single line editor */
 gchar *
-string_dialog_editor_with_widget_opt (DenemoGUI * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal)
+string_dialog_editor_with_widget_opt (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal)
 {
   GtkWidget *dialog;
   GtkWidget *textview;
@@ -2108,7 +2102,7 @@ string_dialog_editor_with_widget_opt (DenemoGUI * gui, gchar * wlabel, gchar * d
 }
 
 gchar *
-string_dialog_editor_with_widget (DenemoGUI * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget)
+string_dialog_editor_with_widget (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget)
 {
   return string_dialog_editor_with_widget_opt (gui, wlabel, direction, PreValue, widget, TRUE);
 }
@@ -2357,7 +2351,7 @@ KeyStrokeShow (gchar * str, gint command_idx, DenemoShortcutType type)
               gtk_window_set_title (GTK_WINDOW (KeyStrokes), _("Key Press"));
               gtk_label_set_text (GTK_LABEL (KeyStrokeHelp), "");
               text = g_strdup_printf (_("Key Press <span font_desc=\"24\" foreground=\"blue\">%s</span>" " Is not a shortcut.\n%s"), str,
-              (Denemo.gui->view != DENEMO_MENU_VIEW)?
+              (Denemo.project->view != DENEMO_MENU_VIEW)?
               _("(The menus are now restored in case you are lost.)"):"");
               break;
             case TwoKey:
@@ -2423,27 +2417,57 @@ initialize_keystroke_help (void)
  * Returns: The dir path if found, NULL either
  **/
 gchar*
-find_dir_for_file(gchar* filename, gchar* dirs[])
+find_dir_for_file(gchar* filename, GList* dirs)
 {
   gchar *dir = NULL;
   gchar *path = NULL;
-  gint i;
+  GList* curdir = NULL;
 
-  for(i = 0; dirs[i]; i++)
+  for(curdir = dirs ; curdir ; curdir = g_list_next(curdir))
   {
-	  //g_print("Searching %s\n", dirs[i]);
     if(!dir)
     {
-      path = g_build_filename (dirs[i], filename, NULL);
+      path = g_build_filename (curdir->data, filename, NULL);
       if(g_file_test (path, G_FILE_TEST_EXISTS))
-        {
-		 dir = g_strdup(dirs[i]);
-			//g_print("Found file %s\n", path);
-		} else
-			//g_print("No file %s\n", path);
-      g_free(path);
+	      dir = g_strdup(curdir->data);
+      else
+        g_free(path);
     }
-    g_free(dirs[i]);
+    g_free(curdir->data);
+  }
+  return dir;
+}
+
+/**
+ * find_dir_for_files:
+ * @files: The files to search
+ * @dirs: A dir paths list, where to search.
+ *
+ * Finds the first dir in the list that contains 'filename', and free the array.
+ *
+ * Returns: The dir path if found, NULL either
+ **/
+gchar*
+find_dir_for_files(GList* files, GList* dirs)
+{
+  gchar *dir = NULL;
+  gchar *path = NULL;
+  GList* curdir = NULL;
+  GList* curfile = NULL;
+
+  for(curdir = dirs; curdir; curdir = g_list_next(curdir))
+  {
+    for(curfile = files; curfile; curfile = g_list_next(curfile))
+    {
+      if(!dir)
+      {
+        path = g_build_filename (curdir->data, curfile->data, NULL);
+        if(g_file_test (path, G_FILE_TEST_EXISTS))
+          dir = g_strdup(curdir->data);
+        g_free(path);
+      }
+    }
+    g_free(curdir->data);
   }
   return dir;
 }
@@ -2451,14 +2475,14 @@ find_dir_for_file(gchar* filename, gchar* dirs[])
 /**
  * find_path_for_file:
  * @filename: The file to search
- * @dirs: A dir paths array, ending by NULL, where to search.
+ * @dirs: A dir paths list, where to search.
  *
  * Finds the first dir in the list that contains 'filename', and free the array.
  *
  * Returns: The file path if found, NULL either
  **/
 gchar*
-find_path_for_file(gchar* filename, gchar* dirs[])
+find_path_for_file(gchar* filename, GList* dirs)
 {
   gchar* dir = find_dir_for_file (filename, dirs);
   if(dir){
@@ -2520,7 +2544,6 @@ get_executable_dir ()
     GetModuleFileNameW(NULL, path, MAX_PATH);
 
 #elif defined _MACH_O_
-    char path[1024];
     guint size = sizeof (path);
     _NSGetExecutablePath (path, &size);
 
@@ -2532,6 +2555,7 @@ get_executable_dir ()
   }
   return dir;
 }
+
 /**
  * find:
  * @dir: The denemo directory where to search
@@ -2546,13 +2570,11 @@ get_executable_dir ()
 gchar*
 find_denemo_file (DenemoDirectory dir, gchar* filename)
 {
-  //g_print("find_denemo_file called with %d and %s\n", dir, filename);
-  gchar* dirs[] = {
-    g_build_filename(get_executable_dir (TRUE), "..", get_local_dir (dir), NULL),
-    g_build_filename(get_user_data_dir (TRUE), get_local_dir (dir), NULL),
-    g_strdup(get_system_dir(dir)),
-    NULL
-  };
+  //g_debug("find_denemo_file called with %d and %s\n", dir, filename);
+  GList* dirs = NULL;
+  dirs = g_list_append(dirs, g_build_filename(get_executable_dir (TRUE), "..", get_local_dir (dir), NULL));
+  dirs = g_list_append(dirs, g_build_filename(get_user_data_dir (TRUE), get_local_dir (dir), NULL));
+  dirs = g_list_append(dirs, g_strdup(get_system_dir(dir)));
  
   return find_path_for_file (filename, dirs);
 }
