@@ -35,6 +35,12 @@
 #define FONT "Sans 9"
 #define TIMESIGFONT "Sans 24"
 
+#ifdef G_HAVE_ISO_VARARGS
+#define g_info(...) g_log(G_LOG_DOMAIN, G_LOG_LEVEL_INFO, __VA_ARGS__);
+#elif defined(G_HAVE_GNUC_VARARGS)
+#define g_info(format) g_log(G_LOG_DOMAIN, G_LOG_LEVEL_INFO, format);
+#endif
+
 const gchar *get_user_data_dir (gboolean create);
 
 const gchar *locateprintdir (void);
@@ -108,7 +114,7 @@ GtkWindow *progressbar (gchar * msg, gpointer callback);
 void progressbar_stop (void);
 void busy_cursor (GtkWidget *area);
 void normal_cursor (GtkWidget *area);
-void headerfields (GtkWidget * dialog, GtkListStore * list_store, GtkTreeIter * iter, DenemoScore * si, gboolean isdialog);
+void headerfields (GtkWidget * dialog, GtkListStore * list_store, GtkTreeIter * iter, DenemoMovement * si, gboolean isdialog);
 /* default isdialog shall be TRUE */
 
 
@@ -126,18 +132,18 @@ void kill_process (GPid pid);
 
 gchar *music_font (gchar * str);
 
-void set_title_bar (DenemoGUI * gui);
-void score_status (DenemoGUI * gui, gboolean change);
-void write_status (DenemoGUI * gui);
+void set_title_bar (DenemoProject * gui);
+void score_status (DenemoProject * gui, gboolean change);
+void write_status (DenemoProject * gui);
 gboolean confirm (gchar * primary, gchar * secondary);
 void nullify_gstring (GString ** s);
 
-gchar *string_dialog_entry (DenemoGUI * gui, gchar * title, gchar * instruction, gchar * initial_value);
+gchar *string_dialog_entry (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value);
 
-gchar *string_dialog_entry_with_widget (DenemoGUI * gui, gchar * title, gchar * instruction, gchar * initial_value, GtkWidget * extra_widget);
-gchar *string_dialog_editor_with_widget (DenemoGUI * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget);
-gchar *string_dialog_entry_with_widget_opt (DenemoGUI * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal);
-gchar *string_dialog_editor_with_widget_opt (DenemoGUI * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal);
+gchar *string_dialog_entry_with_widget (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value, GtkWidget * extra_widget);
+gchar *string_dialog_editor_with_widget (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget);
+gchar *string_dialog_entry_with_widget_opt (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal);
+gchar *string_dialog_editor_with_widget_opt (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal);
 void note2lilynotename (struct note *noteobject, GString * ret);
 void note2lilyaccidental (struct note *noteobject, GString * ret);
 void note2lilyoctave (struct note *noteobject, GString * ret);
@@ -292,7 +298,9 @@ findnote (DenemoObject * curObj, gint cursory);
 
 void write_input_status();
 enum clefs cleftypefromname (gchar * str);
-gchar* find_dir_for_file(gchar* filename, gchar* dirs[]);
-gchar* find_path_for_file(gchar* filename, gchar* dirs[]);
+gchar* find_dir_for_file(gchar* filename, GList* dirs);
+gchar* find_dir_for_files(GList* files, GList* dirs);
+gchar* find_path_for_file(gchar* filename, GList* dirs);
 gchar* find_denemo_file (DenemoDirectory dir, gchar* filename);
+
 #endif /* UTILS_H */
